"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTransaction = getTransaction;
var _server = require("@kbn/observability-plugin/server");
var _utils = require("@kbn/apm-data-access-plugin/server/utils");
var _maybe = require("../../../../common/utils/maybe");
var _apm = require("../../../../common/es_fields/apm");
var _as_mutable_array = require("../../../../common/utils/as_mutable_array");
var _document_type = require("../../../../common/document_type");
var _rollup = require("../../../../common/rollup");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

async function getTransaction({
  transactionId,
  traceId,
  apmEventClient,
  start,
  end
}) {
  const requiredFields = (0, _as_mutable_array.asMutableArray)([_apm.TRACE_ID, _apm.AGENT_NAME, _apm.PROCESSOR_EVENT, _apm.AT_TIMESTAMP, _apm.TIMESTAMP_US, _apm.SERVICE_NAME, _apm.TRANSACTION_ID, _apm.TRANSACTION_DURATION, _apm.TRANSACTION_NAME, _apm.TRANSACTION_SAMPLED, _apm.TRANSACTION_TYPE]);
  const optionalFields = (0, _as_mutable_array.asMutableArray)([_apm.PROCESSOR_NAME, _apm.SERVICE_LANGUAGE_NAME]);
  const resp = await apmEventClient.search('get_transaction', {
    apm: {
      sources: [{
        documentType: _document_type.ApmDocumentType.TransactionEvent,
        rollupInterval: _rollup.RollupInterval.None
      }]
    },
    body: {
      track_total_hits: false,
      size: 1,
      terminate_after: 1,
      query: {
        bool: {
          filter: (0, _as_mutable_array.asMutableArray)([{
            term: {
              [_apm.TRANSACTION_ID]: transactionId
            }
          }, ...(0, _server.termQuery)(_apm.TRACE_ID, traceId), ...(0, _server.rangeQuery)(start, end)])
        }
      },
      fields: [...requiredFields, ...optionalFields],
      _source: [_apm.SPAN_LINKS, _apm.TRANSACTION_AGENT_MARKS]
    }
  });
  const hit = (0, _maybe.maybe)(resp.hits.hits[0]);
  if (!hit) {
    return undefined;
  }
  const event = (0, _utils.unflattenKnownApmEventFields)(hit.fields, requiredFields);
  const source = 'span' in hit._source && 'transaction' in hit._source ? hit._source : undefined;
  return {
    ...event,
    transaction: {
      ...event.transaction,
      marks: source === null || source === void 0 ? void 0 : source.transaction.marks
    },
    processor: {
      name: 'transaction',
      event: 'transaction'
    },
    span: source === null || source === void 0 ? void 0 : source.span
  };
}