"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.normalizeError = void 0;
var _bfetchError = require("@kbn/bfetch-error");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const normalizeError = err => {
  if (!err) {
    return {
      message: 'Unknown error.'
    };
  }
  if (err instanceof _bfetchError.BfetchRequestError) {
    // ignoring so we can return the error as is
    // @ts-expect-error
    return err;
  }
  if (err instanceof Error) {
    return {
      message: err.message
    };
  }
  if (typeof err === 'object') {
    return {
      ...err,
      message: err.message || 'Unknown error.'
    };
  }
  return {
    message: String(err)
  };
};
exports.normalizeError = normalizeError;