"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAutoplayHelper = void 0;
var _react = require("react");
var _workpad_routing_context = require("../workpad_routing_context");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const useAutoplayHelper = () => {
  const {
    nextPage,
    isFullscreen,
    autoplayInterval,
    isAutoplayPaused
  } = (0, _react.useContext)(_workpad_routing_context.WorkpadRoutingContext);
  const timer = (0, _react.useRef)(undefined);
  (0, _react.useEffect)(() => {
    if (timer.current || !isFullscreen || isAutoplayPaused) {
      clearTimeout(timer.current);
    }
    if (isFullscreen && !isAutoplayPaused && autoplayInterval > 0) {
      timer.current = window.setTimeout(() => {
        nextPage();
      }, autoplayInterval);
    }
    return () => clearTimeout(timer.current);
  }, [isFullscreen, nextPage, autoplayInterval, isAutoplayPaused]);
};
exports.useAutoplayHelper = useAutoplayHelper;