"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUnsplittableKey = void 0;
exports.replaceEnvVarRefs = replaceEnvVarRefs;
exports.splitKey = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const splitKey = rawKey => {
  if (rawKey.startsWith('[') && rawKey.endsWith(']')) {
    return [rawKey.substring(1, rawKey.length - 1)];
  }
  return rawKey.split('.');
};
exports.splitKey = splitKey;
const getUnsplittableKey = rawKey => {
  if (rawKey.startsWith('[') && rawKey.endsWith(']')) {
    return rawKey.substring(1, rawKey.length - 1);
  }
  return undefined;
};
exports.getUnsplittableKey = getUnsplittableKey;
function replaceEnvVarRefs(val, env = process.env) {
  return val.replace(/\$\{(\w+)(:(\w+))?\}/g, (match, ...groups) => {
    const envVarName = groups[0];
    const defaultValue = groups[2];
    const envVarValue = env[envVarName];
    if (envVarValue !== undefined) {
      return envVarValue;
    }
    if (defaultValue !== undefined) {
      return defaultValue;
    }
    throw new Error(`Unknown environment variable referenced in config : ${envVarName}`);
  });
}