"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ControlGroupEditor = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _editor_constants = require("../../controls/data_controls/editor_constants");
var _control_group_strings = require("../control_group_strings");
var _control_setting_tooltip_label = require("./control_setting_tooltip_label");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const ControlGroupEditor = ({
  onCancel,
  onSave,
  onDeleteAll,
  stateManager,
  api
}) => {
  const [children, selectedLabelPosition, selectedChainingSystem, selectedAutoApplySelections, selectedIgnoreParentSettings] = (0, _presentationPublishing.useBatchedPublishingSubjects)(api.children$, stateManager.labelPosition, stateManager.chainingSystem, stateManager.autoApplySelections, stateManager.ignoreParentSettings);
  const controlCount = (0, _react.useMemo)(() => Object.keys(children).length, [children]);
  const updateIgnoreSetting = (0, _react.useCallback)(newSettings => {
    stateManager.ignoreParentSettings.next({
      ...(selectedIgnoreParentSettings !== null && selectedIgnoreParentSettings !== void 0 ? selectedIgnoreParentSettings : {}),
      ...newSettings
    });
  }, [stateManager.ignoreParentSettings, selectedIgnoreParentSettings]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutHeader, {
    hasBorder: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("h2", null, _control_group_strings.ControlGroupStrings.management.getFlyoutTitle()))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutBody, {
    "data-test-subj": "control-group-settings-flyout"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiForm, {
    component: "form",
    fullWidth: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _control_group_strings.ControlGroupStrings.management.labelPosition.getLabelPositionTitle()
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonGroup, {
    buttonSize: "compressed",
    options: _editor_constants.CONTROL_LAYOUT_OPTIONS,
    "data-test-subj": "control-group-layout-options",
    idSelected: selectedLabelPosition,
    legend: _control_group_strings.ControlGroupStrings.management.labelPosition.getLabelPositionLegend(),
    onChange: newPosition => {
      stateManager.labelPosition.next(newPosition);
    }
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _control_group_strings.ControlGroupStrings.management.filteringSettings.getFilteringSettingsTitle()
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    compressed: true,
    "data-test-subj": "control-group-filter-sync",
    label: _control_group_strings.ControlGroupStrings.management.filteringSettings.getUseGlobalFiltersTitle(),
    onChange: e => updateIgnoreSetting({
      ignoreFilters: !e.target.checked,
      ignoreQuery: !e.target.checked
    }),
    checked: !Boolean(selectedIgnoreParentSettings === null || selectedIgnoreParentSettings === void 0 ? void 0 : selectedIgnoreParentSettings.ignoreFilters) || !Boolean(selectedIgnoreParentSettings === null || selectedIgnoreParentSettings === void 0 ? void 0 : selectedIgnoreParentSettings.ignoreQuery)
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    compressed: true,
    "data-test-subj": "control-group-query-sync-time-range",
    label: _control_group_strings.ControlGroupStrings.management.filteringSettings.getUseGlobalTimeRangeTitle(),
    onChange: e => updateIgnoreSetting({
      ignoreTimerange: !e.target.checked
    }),
    checked: !Boolean(selectedIgnoreParentSettings === null || selectedIgnoreParentSettings === void 0 ? void 0 : selectedIgnoreParentSettings.ignoreTimerange)
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _control_group_strings.ControlGroupStrings.management.selectionSettings.getSelectionSettingsTitle()
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    compressed: true,
    "data-test-subj": "control-group-validate-selections",
    label: /*#__PURE__*/_react.default.createElement(_control_setting_tooltip_label.ControlSettingTooltipLabel, {
      label: _control_group_strings.ControlGroupStrings.management.selectionSettings.validateSelections.getValidateSelectionsTitle(),
      tooltip: _control_group_strings.ControlGroupStrings.management.selectionSettings.validateSelections.getValidateSelectionsTooltip()
    }),
    checked: !Boolean(selectedIgnoreParentSettings === null || selectedIgnoreParentSettings === void 0 ? void 0 : selectedIgnoreParentSettings.ignoreValidations),
    onChange: e => updateIgnoreSetting({
      ignoreValidations: !e.target.checked
    })
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    compressed: true,
    "data-test-subj": "control-group-chaining",
    label: /*#__PURE__*/_react.default.createElement(_control_setting_tooltip_label.ControlSettingTooltipLabel, {
      label: _control_group_strings.ControlGroupStrings.management.selectionSettings.controlChaining.getHierarchyTitle(),
      tooltip: _control_group_strings.ControlGroupStrings.management.selectionSettings.controlChaining.getHierarchyTooltip()
    }),
    checked: selectedChainingSystem === 'HIERARCHICAL',
    onChange: e => stateManager.chainingSystem.next(e.target.checked ? 'HIERARCHICAL' : 'NONE')
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    compressed: true,
    "data-test-subj": "control-group-auto-apply-selections",
    label: /*#__PURE__*/_react.default.createElement(_control_setting_tooltip_label.ControlSettingTooltipLabel, {
      label: _control_group_strings.ControlGroupStrings.management.selectionSettings.showApplySelections.getShowApplySelectionsTitle(),
      tooltip: _control_group_strings.ControlGroupStrings.management.selectionSettings.showApplySelections.getShowApplySelectionsTooltip()
    }),
    checked: selectedAutoApplySelections,
    onChange: e => stateManager.autoApplySelections.next(e.target.checked)
  }))), controlCount > 0 && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, {
    margin: "m"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, null, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    onClick: onDeleteAll,
    "data-test-subj": "delete-all-controls-button",
    "aria-label": 'delete-all',
    iconType: "trash",
    color: "danger",
    flush: "left",
    size: "s"
  }, _control_group_strings.ControlGroupStrings.management.getDeleteAllButtonTitle()))))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutFooter, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    responsive: false,
    justifyContent: "spaceBetween"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    "aria-label": `cancel-editing-group`,
    flush: "left",
    onClick: () => {
      onCancel();
    }
  }, _control_group_strings.ControlGroupStrings.getCancelTitle())), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    "aria-label": `save-group`,
    fill: true,
    color: "primary",
    "data-test-subj": "control-group-editor-save",
    onClick: () => {
      onSave();
    }
  }, _control_group_strings.ControlGroupStrings.getSaveChangesTitle())))));
};
exports.ControlGroupEditor = ControlGroupEditor;