"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRangesliderControlFactory = void 0;
var _react = _interopRequireWildcard(require("react"));
var _rxjs = require("rxjs");
var _eui = require("@elastic/eui");
var _esQuery = require("@kbn/es-query");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _is_compressed = require("../../../control_group/utils/is_compressed");
var _common = require("../../../../common");
var _initialize_data_control = require("../initialize_data_control");
var _range_slider_control = require("./components/range_slider_control");
var _has_no_results = require("./has_no_results");
var _min_max = require("./min_max");
var _range_control_selections = require("./range_control_selections");
var _range_slider_strings = require("./range_slider_strings");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const getRangesliderControlFactory = () => {
  return {
    type: _common.RANGE_SLIDER_CONTROL,
    getIconType: () => 'controlsHorizontal',
    getDisplayName: _range_slider_strings.RangeSliderStrings.control.getDisplayName,
    isFieldCompatible: field => {
      return field.aggregatable && field.type === 'number';
    },
    CustomOptionsComponent: ({
      initialState,
      updateState,
      setControlEditorValid
    }) => {
      var _initialState$step;
      const [step, setStep] = (0, _react.useState)((_initialState$step = initialState.step) !== null && _initialState$step !== void 0 ? _initialState$step : 1);
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
        fullWidth: true,
        label: _range_slider_strings.RangeSliderStrings.editor.getStepTitle()
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldNumber, {
        compressed: true,
        value: step,
        onChange: event => {
          const newStep = event.target.valueAsNumber;
          setStep(newStep);
          updateState({
            step: newStep
          });
          setControlEditorValid(newStep > 0);
        },
        min: 0,
        isInvalid: step === undefined || step <= 0,
        "data-test-subj": "rangeSliderControl__stepAdditionalSetting"
      })));
    },
    buildControl: async (initialState, buildApi, uuid, controlGroupApi) => {
      var _initialState$step2;
      const controlFetch$ = controlGroupApi.controlFetch$(uuid);
      const loadingMinMax$ = new _rxjs.BehaviorSubject(false);
      const loadingHasNoResults$ = new _rxjs.BehaviorSubject(false);
      const dataLoading$ = new _rxjs.BehaviorSubject(undefined);
      const step$ = new _rxjs.BehaviorSubject((_initialState$step2 = initialState.step) !== null && _initialState$step2 !== void 0 ? _initialState$step2 : 1);
      const dataControl = (0, _initialize_data_control.initializeDataControl)(uuid, _common.RANGE_SLIDER_CONTROL, 'rangeSliderDataView', initialState, {
        step: step$
      }, controlGroupApi);
      const selections = (0, _range_control_selections.initializeRangeControlSelections)(initialState, dataControl.setters.onSelectionChange);
      const api = buildApi({
        ...dataControl.api,
        dataLoading: dataLoading$,
        getTypeDisplayName: _range_slider_strings.RangeSliderStrings.control.getDisplayName,
        serializeState: () => {
          const {
            rawState: dataControlState,
            references
          } = dataControl.serialize();
          return {
            rawState: {
              ...dataControlState,
              step: step$.getValue(),
              value: selections.value$.getValue()
            },
            references // does not have any references other than those provided by the data control serializer
          };
        },
        clearSelections: () => {
          selections.setValue(undefined);
        }
      }, {
        ...dataControl.comparators,
        ...selections.comparators,
        step: [step$, nextStep => step$.next(nextStep), (a, b) => (a !== null && a !== void 0 ? a : 1) === (b !== null && b !== void 0 ? b : 1)]
      });
      const dataLoadingSubscription = (0, _rxjs.combineLatest)([loadingMinMax$, loadingHasNoResults$, dataControl.api.dataLoading]).pipe((0, _rxjs.debounceTime)(100), (0, _rxjs.map)(values => values.some(value => value))).subscribe(isLoading => {
        dataLoading$.next(isLoading);
      });

      // Clear state when the field changes
      const fieldChangedSubscription = (0, _rxjs.combineLatest)([dataControl.stateManager.fieldName, dataControl.stateManager.dataViewId]).pipe((0, _rxjs.skip)(1)).subscribe(() => {
        step$.next(1);
        selections.setValue(undefined);
      });
      const max$ = new _rxjs.BehaviorSubject(undefined);
      const min$ = new _rxjs.BehaviorSubject(undefined);
      const minMaxSubscription = (0, _min_max.minMax$)({
        controlFetch$,
        dataViews$: dataControl.api.dataViews,
        fieldName$: dataControl.stateManager.fieldName,
        setIsLoading: isLoading => {
          // clear previous loading error on next loading start
          if (isLoading && dataControl.api.blockingError.value) {
            dataControl.api.setBlockingError(undefined);
          }
          loadingMinMax$.next(isLoading);
        },
        controlGroupApi
      }).subscribe(({
        error,
        min,
        max
      }) => {
        if (error) {
          dataControl.api.setBlockingError(error);
        }
        max$.next(max !== undefined ? Math.ceil(max) : undefined);
        min$.next(min !== undefined ? Math.floor(min) : undefined);
      });
      const outputFilterSubscription = (0, _rxjs.combineLatest)([dataControl.api.dataViews, dataControl.stateManager.fieldName, selections.value$]).pipe((0, _rxjs.debounceTime)(0)).subscribe(([dataViews, fieldName, value]) => {
        var _value$, _value$2;
        const dataView = dataViews === null || dataViews === void 0 ? void 0 : dataViews[0];
        const dataViewField = dataView && fieldName ? dataView.getFieldByName(fieldName) : undefined;
        const gte = parseFloat((_value$ = value === null || value === void 0 ? void 0 : value[0]) !== null && _value$ !== void 0 ? _value$ : '');
        const lte = parseFloat((_value$2 = value === null || value === void 0 ? void 0 : value[1]) !== null && _value$2 !== void 0 ? _value$2 : '');
        let rangeFilter;
        if (value && dataView && dataViewField && !isNaN(gte) && !isNaN(lte)) {
          const params = {
            gte,
            lte
          };
          rangeFilter = (0, _esQuery.buildRangeFilter)(dataViewField, params, dataView);
          rangeFilter.meta.key = fieldName;
          rangeFilter.meta.type = 'range';
          rangeFilter.meta.params = params;
        }
        dataControl.setters.setOutputFilter(rangeFilter);
      });
      const selectionHasNoResults$ = new _rxjs.BehaviorSubject(false);
      const hasNotResultsSubscription = (0, _has_no_results.hasNoResults$)({
        controlFetch$,
        dataViews$: dataControl.api.dataViews,
        rangeFilters$: dataControl.api.filters$,
        ignoreParentSettings$: controlGroupApi.ignoreParentSettings$,
        setIsLoading: isLoading => {
          loadingHasNoResults$.next(isLoading);
        }
      }).subscribe(hasNoResults => {
        selectionHasNoResults$.next(hasNoResults);
      });
      if (selections.hasInitialSelections) {
        await dataControl.api.untilFiltersReady();
      }
      return {
        api,
        Component: ({
          className: controlPanelClassName
        }) => {
          const [dataLoading, fieldFormatter, max, min, selectionHasNotResults, step, value] = (0, _presentationPublishing.useBatchedPublishingSubjects)(dataLoading$, dataControl.api.fieldFormatter, max$, min$, selectionHasNoResults$, step$, selections.value$);
          (0, _react.useEffect)(() => {
            return () => {
              dataLoadingSubscription.unsubscribe();
              fieldChangedSubscription.unsubscribe();
              hasNotResultsSubscription.unsubscribe();
              minMaxSubscription.unsubscribe();
              outputFilterSubscription.unsubscribe();
            };
          }, []);
          return /*#__PURE__*/_react.default.createElement(_range_slider_control.RangeSliderControl, {
            controlPanelClassName: controlPanelClassName,
            fieldFormatter: fieldFormatter,
            isInvalid: selectionHasNotResults,
            isLoading: typeof dataLoading === 'boolean' ? dataLoading : false,
            max: max,
            min: min,
            onChange: selections.setValue,
            step: step !== null && step !== void 0 ? step : 1,
            value: value,
            uuid: uuid,
            compressed: (0, _is_compressed.isCompressed)(api)
          });
        }
      };
    }
  };
};
exports.getRangesliderControlFactory = getRangesliderControlFactory;