"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.passThroughValidation = exports.CoreVersionedRoute = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _configSchema = require("@kbn/config-schema");
var _coreHttpCommon = require("@kbn/core-http-common");
var _validate = require("./validate");
var _route_version_utils = require("./route_version_utils");
var _util = require("../util");
var _security_route_config_validator = require("../security_route_config_validator");
var _handler_resolvers = require("./handler_resolvers");
var _util2 = require("./util");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

// This validation is a pass-through so that we can apply our version-specific validation later
const passThroughValidation = exports.passThroughValidation = {
  body: _configSchema.schema.nullable(_configSchema.schema.any()),
  params: _configSchema.schema.nullable(_configSchema.schema.any()),
  query: _configSchema.schema.nullable(_configSchema.schema.any())
};
function extractValidationSchemaFromHandler(handler) {
  if (handler.options.validate === false) return undefined;
  if (typeof handler.options.validate === 'function') return handler.options.validate();
  return handler.options.validate;
}
class CoreVersionedRoute {
  static from({
    router,
    method,
    path,
    options
  }) {
    return new CoreVersionedRoute(router, method, path, options);
  }
  constructor(router, method, path, internalOptions) {
    (0, _defineProperty2.default)(this, "handlers", new Map());
    (0, _defineProperty2.default)(this, "options", void 0);
    (0, _defineProperty2.default)(this, "useDefaultStrategyForPath", void 0);
    (0, _defineProperty2.default)(this, "isPublic", void 0);
    (0, _defineProperty2.default)(this, "isDev", void 0);
    (0, _defineProperty2.default)(this, "enableQueryVersion", void 0);
    (0, _defineProperty2.default)(this, "defaultSecurityConfig", void 0);
    (0, _defineProperty2.default)(this, "defaultHandlerResolutionStrategy", void 0);
    (0, _defineProperty2.default)(this, "requestHandler", async (ctx, originalReq, res) => {
      var _handler$options$opti, _validation$response, _validation$response$;
      if (this.handlers.size <= 0) {
        return res.custom({
          statusCode: 500,
          body: `No handlers registered for [${this.method}] [${this.path}].`
        });
      }
      const req = originalReq;
      const version = this.getVersion(req);
      req.apiVersion = version;
      if (!version) {
        return res.badRequest({
          body: `Please specify a version via ${_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER} header. Available versions: ${this.versionsToString()}`
        });
      }
      if ((0, _route_version_utils.hasQueryVersion)(req)) {
        if (this.enableQueryVersion) {
          // This endpoint has opted-in to query versioning, so we remove the query parameter as it is reserved
          (0, _route_version_utils.removeQueryVersion)(req);
        } else return res.badRequest({
          body: `Use of query parameter "${_coreHttpCommon.ELASTIC_HTTP_VERSION_QUERY_PARAM}" is not allowed. Please specify the API version using the "${_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER}" header.`
        });
      }
      const invalidVersionMessage = (0, _route_version_utils.isValidRouteVersion)(this.isPublic, version);
      if (invalidVersionMessage) {
        return res.badRequest({
          body: invalidVersionMessage
        });
      }
      const handler = this.handlers.get(version);
      if (!handler) {
        return res.badRequest({
          body: `No version "${version}" available for [${this.method}] [${this.path}]. Available versions are: ${this.versionsToString()}`
        });
      }
      const validation = extractValidationSchemaFromHandler(handler);
      const postValidateMetadata = {
        deprecated: (_handler$options$opti = handler.options.options) === null || _handler$options$opti === void 0 ? void 0 : _handler$options$opti.deprecated,
        isInternalApiRequest: req.isInternalApiRequest,
        isPublicAccess: this.isPublic
      };
      if (validation !== null && validation !== void 0 && validation.request && Boolean(validation.request.body || validation.request.params || validation.request.query)) {
        try {
          const {
            body,
            params,
            query
          } = (0, _validate.validate)(req, validation.request);
          req.body = body;
          req.params = params;
          req.query = query;
        } catch (e) {
          // Emit onPostValidation even if validation fails.

          this.router.emitPostValidate(req, postValidateMetadata);
          return res.badRequest({
            body: e.message,
            headers: (0, _util.getVersionHeader)(version)
          });
        }
      } else {
        // Preserve behavior of not passing through unvalidated data
        req.body = {};
        req.params = {};
        req.query = {};
      }
      this.router.emitPostValidate(req, postValidateMetadata);
      const response = await handler.fn(ctx, req, res);
      if (this.isDev && validation !== null && validation !== void 0 && (_validation$response = validation.response) !== null && _validation$response !== void 0 && (_validation$response$ = _validation$response[response.status]) !== null && _validation$response$ !== void 0 && _validation$response$.body) {
        const {
          [response.status]: responseValidation,
          unsafe
        } = validation.response;
        try {
          (0, _validate.validate)({
            body: response.payload
          }, {
            body: (0, _util2.unwrapVersionedResponseBodyValidation)(responseValidation.body),
            unsafe: {
              body: unsafe === null || unsafe === void 0 ? void 0 : unsafe.body
            }
          });
        } catch (e) {
          return res.custom({
            statusCode: 500,
            body: `Failed output validation: ${e.message}`
          });
        }
      }
      return (0, _util.injectVersionHeader)(version, response);
    });
    (0, _defineProperty2.default)(this, "getSecurity", req => {
      var _this$handlers$get$op, _this$handlers$get;
      const version = this.getVersion(req);
      return (_this$handlers$get$op = (_this$handlers$get = this.handlers.get(version)) === null || _this$handlers$get === void 0 ? void 0 : _this$handlers$get.options.security) !== null && _this$handlers$get$op !== void 0 ? _this$handlers$get$op : this.defaultSecurityConfig;
    });
    this.router = router;
    this.method = method;
    this.path = path;
    const {
      isDev,
      useVersionResolutionStrategyForInternalPaths,
      defaultHandlerResolutionStrategy,
      ...options
    } = internalOptions;
    this.isPublic = options.access === 'public';
    this.isDev = isDev;
    this.defaultHandlerResolutionStrategy = defaultHandlerResolutionStrategy;
    this.useDefaultStrategyForPath = this.isPublic || useVersionResolutionStrategyForInternalPaths.has(path);
    this.enableQueryVersion = options.enableQueryVersion === true;
    this.defaultSecurityConfig = (0, _security_route_config_validator.validRouteSecurity)(options.security, options.options);
    this.options = options;
    this.router[this.method]({
      path: this.path,
      validate: passThroughValidation,
      // @ts-expect-error upgrade typescript v5.1.6
      options: this.getRouteConfigOptions(),
      security: this.getSecurity
    }, this.requestHandler, {
      isVersioned: true,
      events: false
    });
  }
  getRouteConfigOptions() {
    return {
      access: this.options.access,
      ...this.options.options
    };
  }

  /** This method assumes that one or more versions handlers are registered  */
  getDefaultVersion() {
    return _handler_resolvers.resolvers[this.defaultHandlerResolutionStrategy]([...this.handlers.keys()], this.options.access);
  }
  versionsToString() {
    return this.handlers.size ? '[' + [...this.handlers.keys()].join(', ') + ']' : '<none>';
  }
  getVersion(req) {
    let version;
    const maybeVersion = (0, _route_version_utils.readVersion)(req, this.enableQueryVersion);
    if (!maybeVersion) {
      if (this.useDefaultStrategyForPath) {
        version = this.getDefaultVersion();
      } else if (!this.isDev && !this.isPublic) {
        // When in production, we default internal routes to v1 to allow
        // gracefully onboarding of un-versioned to versioned routes
        version = '1';
      }
    } else {
      version = maybeVersion;
    }
    return version;
  }
  validateVersion(version) {
    // We do an additional check here while we only have a single allowed public version
    // for all public Kibana HTTP APIs
    if (this.isDev && this.isPublic) {
      const message = (0, _route_version_utils.isAllowedPublicVersion)(version);
      if (message) {
        throw new Error(message);
      }
    }
    const message = (0, _route_version_utils.isValidRouteVersion)(this.isPublic, version);
    if (message) {
      throw new Error(message);
    }
    if (this.handlers.has(version)) {
      throw new Error(`Version "${version}" handler has already been registered for the route [${this.method.toLowerCase()}] [${this.path}]"`);
    }
  }
  addVersion(options, handler) {
    this.validateVersion(options.version);
    options = (0, _util2.prepareVersionedRouteValidation)(options);
    this.handlers.set(options.version, {
      fn: handler,
      options
    });
    return this;
  }
  getHandlers() {
    return [...this.handlers.values()];
  }
}
exports.CoreVersionedRoute = CoreVersionedRoute;