"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractReferences = extractReferences;
exports.injectReferences = injectReferences;
var _dashboard_panel_converters = require("../../lib/dashboard_panel_converters");
var _dashboard_container_references = require("../../dashboard_container/persistable_state/dashboard_container_references");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

function parseDashboardAttributesWithType({
  panels
}) {
  return {
    type: 'dashboard',
    panels: (0, _dashboard_panel_converters.convertPanelsArrayToPanelMap)(panels)
  };
}
function injectReferences({
  attributes,
  references = []
}, deps) {
  const parsedAttributes = parseDashboardAttributesWithType(attributes);

  // inject references back into panels via the Embeddable persistable state service.
  const inject = (0, _dashboard_container_references.createInject)(deps.embeddablePersistableStateService);
  const injectedState = inject(parsedAttributes, references);
  const injectedPanels = (0, _dashboard_panel_converters.convertPanelMapToPanelsArray)(injectedState.panels);
  const newAttributes = {
    ...attributes,
    panels: injectedPanels
  };
  return newAttributes;
}
function extractReferences({
  attributes,
  references = []
}, deps) {
  const parsedAttributes = parseDashboardAttributesWithType(attributes);
  const panels = parsedAttributes.panels;
  const panelMissingType = Object.values(panels).find(panel => panel.type === undefined);
  if (panelMissingType) {
    throw new Error(`"type" attribute is missing from panel "${panelMissingType.explicitInput.id}"`);
  }
  const extract = (0, _dashboard_container_references.createExtract)(deps.embeddablePersistableStateService);
  const {
    references: extractedReferences,
    state: extractedState
  } = extract(parsedAttributes);
  const extractedPanels = (0, _dashboard_panel_converters.convertPanelMapToPanelsArray)(extractedState.panels);
  const newAttributes = {
    ...attributes,
    panels: extractedPanels
  };
  return {
    references: [...references, ...extractedReferences],
    attributes: newAttributes
  };
}