"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.boundsDescendingRaw = void 0;
exports.calcAutoIntervalLessThan = calcAutoIntervalLessThan;
exports.calcAutoIntervalNear = calcAutoIntervalNear;
var _moment = _interopRequireDefault(require("moment"));
var _i18n_messages = require("./i18n_messages");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const boundsDescendingRaw = exports.boundsDescendingRaw = [{
  bound: Infinity,
  interval: _moment.default.duration(1, 'year'),
  boundLabel: (0, _i18n_messages.infinityLabel)(),
  intervalLabel: (0, _i18n_messages.yearLabel)()
}, {
  bound: _moment.default.duration(1, 'year'),
  interval: _moment.default.duration(1, 'month'),
  boundLabel: (0, _i18n_messages.yearLabel)(),
  intervalLabel: (0, _i18n_messages.monthLabel)()
}, {
  bound: _moment.default.duration(3, 'week'),
  interval: _moment.default.duration(1, 'week'),
  boundLabel: (0, _i18n_messages.dayLabel)(21),
  intervalLabel: (0, _i18n_messages.dayLabel)(7)
}, {
  bound: _moment.default.duration(1, 'week'),
  interval: _moment.default.duration(1, 'd'),
  boundLabel: (0, _i18n_messages.dayLabel)(7),
  intervalLabel: (0, _i18n_messages.dayLabel)(1)
}, {
  bound: _moment.default.duration(24, 'hour'),
  interval: _moment.default.duration(12, 'hour'),
  boundLabel: (0, _i18n_messages.dayLabel)(1),
  intervalLabel: (0, _i18n_messages.hourLabel)(12)
}, {
  bound: _moment.default.duration(6, 'hour'),
  interval: _moment.default.duration(3, 'hour'),
  boundLabel: (0, _i18n_messages.hourLabel)(6),
  intervalLabel: (0, _i18n_messages.hourLabel)(3)
}, {
  bound: _moment.default.duration(2, 'hour'),
  interval: _moment.default.duration(1, 'hour'),
  boundLabel: (0, _i18n_messages.hourLabel)(2),
  intervalLabel: (0, _i18n_messages.hourLabel)(1)
}, {
  bound: _moment.default.duration(45, 'minute'),
  interval: _moment.default.duration(30, 'minute'),
  boundLabel: (0, _i18n_messages.minuteLabel)(45),
  intervalLabel: (0, _i18n_messages.minuteLabel)(30)
}, {
  bound: _moment.default.duration(20, 'minute'),
  interval: _moment.default.duration(10, 'minute'),
  boundLabel: (0, _i18n_messages.minuteLabel)(20),
  intervalLabel: (0, _i18n_messages.minuteLabel)(10)
}, {
  bound: _moment.default.duration(9, 'minute'),
  interval: _moment.default.duration(5, 'minute'),
  boundLabel: (0, _i18n_messages.minuteLabel)(9),
  intervalLabel: (0, _i18n_messages.minuteLabel)(5)
}, {
  bound: _moment.default.duration(3, 'minute'),
  interval: _moment.default.duration(1, 'minute'),
  boundLabel: (0, _i18n_messages.minuteLabel)(3),
  intervalLabel: (0, _i18n_messages.minuteLabel)(1)
}, {
  bound: _moment.default.duration(45, 'second'),
  interval: _moment.default.duration(30, 'second'),
  boundLabel: (0, _i18n_messages.secondLabel)(45),
  intervalLabel: (0, _i18n_messages.secondLabel)(30)
}, {
  bound: _moment.default.duration(15, 'second'),
  interval: _moment.default.duration(10, 'second'),
  boundLabel: (0, _i18n_messages.secondLabel)(15),
  intervalLabel: (0, _i18n_messages.secondLabel)(10)
}, {
  bound: _moment.default.duration(7.5, 'second'),
  interval: _moment.default.duration(5, 'second'),
  boundLabel: (0, _i18n_messages.secondLabel)(7.5),
  intervalLabel: (0, _i18n_messages.secondLabel)(5)
}, {
  bound: _moment.default.duration(5, 'second'),
  interval: _moment.default.duration(1, 'second'),
  boundLabel: (0, _i18n_messages.secondLabel)(5),
  intervalLabel: (0, _i18n_messages.secondLabel)(1)
}, {
  bound: _moment.default.duration(500, 'ms'),
  interval: _moment.default.duration(100, 'ms'),
  boundLabel: (0, _i18n_messages.millisecondLabel)(500),
  intervalLabel: (0, _i18n_messages.millisecondLabel)(100)
}];
const boundsDescending = boundsDescendingRaw.map(({
  bound,
  interval
}) => ({
  bound: Number(bound),
  interval: Number(interval)
}));
function getPerBucketMs(count, duration) {
  const ms = duration / count;
  return isFinite(ms) ? ms : NaN;
}
function normalizeMinimumInterval(targetMs) {
  const value = isNaN(targetMs) ? 0 : Math.max(Math.floor(targetMs), 1);
  return _moment.default.duration(value);
}

/**
 * Using some simple rules we pick a "pretty" interval that will
 * produce around the number of buckets desired given a time range.
 *
 * @param targetBucketCount desired number of buckets
 * @param duration time range the agg covers
 */
function calcAutoIntervalNear(targetBucketCount, duration) {
  const targetPerBucketMs = getPerBucketMs(targetBucketCount, duration);

  // Find the first bound which is smaller than our target.
  const lowerBoundIndex = boundsDescending.findIndex(({
    bound
  }) => {
    const boundMs = Number(bound);
    return boundMs <= targetPerBucketMs;
  });

  // The bound immediately preceeding that lower bound contains the
  // interval most closely matching our target.
  if (lowerBoundIndex !== -1) {
    const nearestInterval = boundsDescending[lowerBoundIndex - 1].interval;
    return _moment.default.duration(nearestInterval);
  }

  // If the target is smaller than any of our bounds, then we'll use it for the interval as-is.
  return normalizeMinimumInterval(targetPerBucketMs);
}

/**
 * Pick a "pretty" interval that produces no more than the maxBucketCount
 * for the given time range.
 *
 * @param maxBucketCount maximum number of buckets to create
 * @param duration amount of time covered by the agg
 */
function calcAutoIntervalLessThan(maxBucketCount, duration) {
  const maxPerBucketMs = getPerBucketMs(maxBucketCount, duration);
  for (const {
    interval
  } of boundsDescending) {
    // Find the highest interval which meets our per bucket limitation.
    if (interval <= maxPerBucketMs) {
      return _moment.default.duration(interval);
    }
  }

  // If the max is smaller than any of our intervals, then we'll use it for the interval as-is.
  return normalizeMinimumInterval(maxPerBucketMs);
}