"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.HasData = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _coreHttpBrowser = require("@kbn/core-http-browser");
var _lodash = require("lodash");
var _i18n = require("@kbn/i18n");
var _common = require("../../common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

class HasData {
  constructor() {
    (0, _defineProperty2.default)(this, "removeAliases", source => !source.item.indices);
    (0, _defineProperty2.default)(this, "isUserDataSource", source => {
      // filter out indices that start with `.`
      if (source.name.startsWith('.')) return false;

      // filter out sources from DEFAULT_ASSETS_TO_IGNORE
      if (_common.DEFAULT_ASSETS_TO_IGNORE.DATA_STREAMS_TO_IGNORE.includes(source.name)) return false; // filter out data streams that we know are created automatically during on-boarding

      return true;
    });
    // ES Data
    (0, _defineProperty2.default)(this, "isResponseError", e => (0, _coreHttpBrowser.isHttpFetchError)(e) && (0, _lodash.isObject)(e.body) && 'message' in e.body && 'statusCode' in e.body);
    (0, _defineProperty2.default)(this, "responseToItemArray", response => {
      const {
        indices = [],
        aliases = []
      } = response;
      const source = [];
      [...indices, ...aliases, ...(response.data_streams || [])].forEach(item => {
        source.push({
          name: item.name,
          item
        });
      });
      return source;
    });
    (0, _defineProperty2.default)(this, "getIndicesViaSearch", async ({
      http,
      pattern,
      showAllIndices
    }) => http.post(`/internal/search/ese`, {
      version: '1',
      body: JSON.stringify({
        params: {
          ignore_unavailable: true,
          expand_wildcards: showAllIndices ? 'all' : 'open',
          index: pattern,
          body: {
            size: 0,
            // no hits
            aggs: {
              indices: {
                terms: {
                  field: '_index',
                  size: 200
                }
              }
            }
          }
        }
      })
    }).then(resp => {
      return !!(resp && resp.total >= 0);
    }).catch(e => {
      // eslint-disable-next-line no-console
      console.warn(`getIndicesViaSearch failed with error, assuming there is data`, e);
      return true;
    }));
    (0, _defineProperty2.default)(this, "getIndices", async ({
      http,
      pattern,
      showAllIndices
    }) => http.get(`/internal/index-pattern-management/resolve_index/${pattern}`, {
      query: showAllIndices ? {
        expand_wildcards: 'all'
      } : undefined
    }).then(response => {
      if (!response) {
        return [];
      } else {
        return this.responseToItemArray(response);
      }
    }));
    (0, _defineProperty2.default)(this, "checkLocalESData", http => this.getIndices({
      http,
      pattern: '*',
      showAllIndices: false
    }).then(dataSources => {
      return dataSources.some(this.isUserDataSource);
    }).catch(() => this.getIndicesViaSearch({
      http,
      pattern: '*',
      showAllIndices: false
    })));
    (0, _defineProperty2.default)(this, "checkRemoteESData", http => this.getIndices({
      http,
      pattern: '*:*',
      showAllIndices: false
    }).then(dataSources => {
      return !!dataSources.filter(this.removeAliases).length;
    }).catch(() => this.getIndicesViaSearch({
      http,
      pattern: '*:*',
      showAllIndices: false
    })));
    // Data Views
    (0, _defineProperty2.default)(this, "getHasDataViews", async ({
      http
    }) => http.get(`/internal/data_views/has_data_views`, {
      version: '1'
    }));
    (0, _defineProperty2.default)(this, "hasDataViews", http => {
      return this.getHasDataViews({
        http
      }).then(response => {
        const {
          hasDataView
        } = response;
        return hasDataView;
      }).catch(e => {
        // eslint-disable-next-line no-console
        console.warn(`hasDataViews failed with error, assuming there are data views`, e);
        return true;
      });
    });
    (0, _defineProperty2.default)(this, "hasUserDataViews", http => {
      return this.getHasDataViews({
        http
      }).then(response => {
        const {
          hasUserDataView
        } = response;
        return hasUserDataView;
      }).catch(e => {
        // eslint-disable-next-line no-console
        console.warn(`hasUserDataViews failed with error, assuming there are user-created data views`, e);
        return true;
      });
    });
  }
  start(core, callResolveCluster) {
    const {
      http
    } = core;
    const hasESDataViaResolveIndex = async () => {
      // fallback to previous implementation
      const hasLocalESData = await this.checkLocalESData(http);
      if (!hasLocalESData) {
        const hasRemoteESData = await this.checkRemoteESData(http);
        return hasRemoteESData;
      }
      return hasLocalESData;
    };
    const hasESDataViaResolveCluster = async onRemoteDataTimeout => {
      try {
        const {
          hasEsData
        } = await http.get('/internal/data_views/has_es_data', {
          version: '1'
        });
        return hasEsData;
      } catch (e) {
        var _e$body, _e$body2, _e$body2$attributes;
        if (this.isResponseError(e) && ((_e$body = e.body) === null || _e$body === void 0 ? void 0 : _e$body.statusCode) === 504 && ((_e$body2 = e.body) === null || _e$body2 === void 0 ? void 0 : (_e$body2$attributes = _e$body2.attributes) === null || _e$body2$attributes === void 0 ? void 0 : _e$body2$attributes.failureReason) === _common.HasEsDataFailureReason.remoteDataTimeout) {
          onRemoteDataTimeout(e.body);

          // In the case of a remote cluster timeout,
          // we can't be sure if there is data or not,
          // so just assume there is
          return true;
        }

        // fallback to previous implementation
        return hasESDataViaResolveIndex();
      }
    };
    const showRemoteDataTimeoutToast = () => core.notifications.toasts.addDanger({
      title: _i18n.i18n.translate('dataViews.hasData.remoteDataTimeoutTitle', {
        defaultMessage: 'Remote cluster timeout'
      }),
      text: _i18n.i18n.translate('dataViews.hasData.remoteDataTimeoutText', {
        defaultMessage: 'Checking for data on remote clusters timed out. One or more remote clusters may be unavailable.'
      })
    });
    return {
      /**
       * Check to see if ES data exists
       */
      hasESData: async ({
        onRemoteDataTimeout = showRemoteDataTimeoutToast
      } = {}) => {
        if (callResolveCluster) {
          return hasESDataViaResolveCluster(onRemoteDataTimeout);
        }
        return hasESDataViaResolveIndex();
      },
      /**
       * Check to see if a data view exists
       */
      hasDataView: async () => {
        const dataViewsCheck = await this.hasDataViews(http);
        return dataViewsCheck;
      },
      /**
       * Check to see if user created data views exist
       */
      hasUserDataView: async () => {
        const userDataViewsCheck = await this.hasUserDataViews(http);
        return userDataViewsCheck;
      }
    };
  }
}
exports.HasData = HasData;