"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateDatasets = generateDatasets;
var _constants = require("../../common/constants");
var _utils = require("../../common/utils");
var _data_stream_stat = require("../../common/data_streams_stats/data_stream_stat");
var _flatten_stats = require("./flatten_stats");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function generateDatasets(dataStreamStats = [], degradedDocStats = [], integrations, totalDocsStats) {
  const {
    datasetIntegrationMap,
    integrationsMap
  } = integrations.reduce((acc, integration) => {
    return {
      datasetIntegrationMap: {
        ...acc.datasetIntegrationMap,
        ...Object.keys(integration.datasets).reduce((datasetsAcc, dataset) => Object.assign(datasetsAcc, {
          [dataset]: {
            integration,
            title: integration.datasets[dataset]
          }
        }), {})
      },
      integrationsMap: {
        ...acc.integrationsMap,
        [integration.name]: integration
      }
    };
  }, {
    datasetIntegrationMap: {},
    integrationsMap: {}
  });
  const totalDocs = (0, _flatten_stats.flattenStats)(totalDocsStats);
  const totalDocsMap = Object.fromEntries(totalDocs.map(({
    dataset,
    count
  }) => [dataset, count]));
  const degradedMap = degradedDocStats.reduce((degradedMapAcc, {
    dataset,
    count
  }) => Object.assign(degradedMapAcc, {
    [dataset]: {
      count,
      percentage: _data_stream_stat.DataStreamStat.calculatePercentage({
        totalDocs: totalDocsMap[dataset],
        count
      })
    }
  }), {});
  if (!dataStreamStats.length) {
    // We want to pick up all datasets even when they don't have degraded docs
    const dataStreams = [...new Set([...Object.keys(totalDocsMap), ...Object.keys(degradedMap)])];
    return dataStreams.map(dataset => {
      var _totalDocsMap$dataset;
      return _data_stream_stat.DataStreamStat.fromDegradedDocStat({
        degradedDocStat: {
          dataset,
          ...(degradedMap[dataset] || _constants.DEFAULT_DEGRADED_DOCS)
        },
        datasetIntegrationMap,
        totalDocs: (_totalDocsMap$dataset = totalDocsMap[dataset]) !== null && _totalDocsMap$dataset !== void 0 ? _totalDocsMap$dataset : 0
      });
    });
  }
  return dataStreamStats === null || dataStreamStats === void 0 ? void 0 : dataStreamStats.map(dataStream => {
    var _datasetIntegrationMa, _datasetIntegrationMa2, _datasetIntegrationMa3, _dataStream$integrati, _totalDocsMap$dataset2;
    const dataset = _data_stream_stat.DataStreamStat.create(dataStream);
    return {
      ...dataset,
      title: ((_datasetIntegrationMa = datasetIntegrationMap[dataset.name]) === null || _datasetIntegrationMa === void 0 ? void 0 : _datasetIntegrationMa.title) || dataset.title,
      integration: (_datasetIntegrationMa2 = (_datasetIntegrationMa3 = datasetIntegrationMap[dataset.name]) === null || _datasetIntegrationMa3 === void 0 ? void 0 : _datasetIntegrationMa3.integration) !== null && _datasetIntegrationMa2 !== void 0 ? _datasetIntegrationMa2 : integrationsMap[(_dataStream$integrati = dataStream.integration) !== null && _dataStream$integrati !== void 0 ? _dataStream$integrati : ''],
      degradedDocs: degradedMap[dataset.rawName] || dataset.degradedDocs,
      docsInTimeRange: (_totalDocsMap$dataset2 = totalDocsMap[dataset.rawName]) !== null && _totalDocsMap$dataset2 !== void 0 ? _totalDocsMap$dataset2 : 0,
      quality: (0, _utils.mapPercentageToQuality)((degradedMap[dataset.rawName] || dataset.degradedDocs).percentage)
    };
  });
}