"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAggregatedDatasetPaginatedResults = getAggregatedDatasetPaginatedResults;
var _server = require("@kbn/observability-plugin/server");
var _utils = require("../../utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SIZE_LIMIT = 10000;
async function getAggregatedDatasetPaginatedResults(options) {
  var _response$aggregation, _response$aggregation2, _response$aggregation3, _response$aggregation4;
  const {
    esClient,
    index,
    query,
    start,
    end,
    after,
    prevResults = []
  } = options;
  const datasetQualityESClient = (0, _utils.createDatasetQualityESClient)(esClient);
  const aggs = afterKey => ({
    datasets: {
      composite: {
        ...(afterKey ? {
          after: afterKey
        } : {}),
        size: SIZE_LIMIT,
        sources: [{
          type: {
            terms: {
              field: 'data_stream.type'
            }
          }
        }, {
          dataset: {
            terms: {
              field: 'data_stream.dataset'
            }
          }
        }, {
          namespace: {
            terms: {
              field: 'data_stream.namespace'
            }
          }
        }]
      }
    }
  });
  const bool = {
    ...query,
    filter: [...(query !== null && query !== void 0 && query.filter ? Array.isArray(query.filter) ? query.filter : [query.filter] : []), ...[...(0, _server.rangeQuery)(start, end)]]
  };
  const response = await datasetQualityESClient.search({
    index,
    size: 0,
    query: {
      bool
    },
    aggs: aggs(after)
  });
  const currResults = (_response$aggregation = (_response$aggregation2 = response.aggregations) === null || _response$aggregation2 === void 0 ? void 0 : _response$aggregation2.datasets.buckets.map(bucket => ({
    dataset: `${bucket.key.type}-${bucket.key.dataset}-${bucket.key.namespace}`,
    count: bucket.doc_count
  }))) !== null && _response$aggregation !== void 0 ? _response$aggregation : [];
  const results = [...prevResults, ...currResults];
  if ((_response$aggregation3 = response.aggregations) !== null && _response$aggregation3 !== void 0 && _response$aggregation3.datasets.after_key && ((_response$aggregation4 = response.aggregations) === null || _response$aggregation4 === void 0 ? void 0 : _response$aggregation4.datasets.buckets.length) === SIZE_LIMIT) {
    var _response$aggregation5;
    return getAggregatedDatasetPaginatedResults({
      esClient,
      index,
      start,
      end,
      after: ((_response$aggregation5 = response.aggregations) === null || _response$aggregation5 === void 0 ? void 0 : _response$aggregation5.datasets.after_key) || after,
      prevResults: results
    });
  }
  return results;
}