"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DiscoverTopNav = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireWildcard(require("react"));
var _public = require("@kbn/data-views-plugin/public");
var _esqlUtils = require("@kbn/esql-utils");
var _discoverUtils = require("@kbn/discover-utils");
var _discover_state_provider = require("../../state_management/discover_state_provider");
var _constants = require("../../../../../common/constants");
var _discover_internal_state_container = require("../../state_management/discover_internal_state_container");
var _use_discover_services = require("../../../../hooks/use_discover_services");
var _on_save_search = require("./on_save_search");
var _customizations = require("../../../../customizations");
var _discover_app_state_container = require("../../state_management/discover_app_state_container");
var _use_discover_topnav = require("./use_discover_topnav");
var _use_is_esql_mode = require("../../hooks/use_is_esql_mode");
var _esql_dataview_transition = require("./esql_dataview_transition");
require("./top_nav.scss");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const DiscoverTopNav = ({
  savedQuery,
  stateContainer,
  esqlModeErrors,
  esqlModeWarning,
  onFieldEdited,
  isLoading,
  onCancelClick
}) => {
  const services = (0, _use_discover_services.useDiscoverServices)();
  const {
    dataViewEditor,
    navigation,
    dataViewFieldEditor,
    data,
    uiSettings,
    setHeaderActionMenu
  } = services;
  const query = (0, _discover_app_state_container.useAppStateSelector)(state => state.query);
  const adHocDataViews = (0, _discover_internal_state_container.useInternalStateSelector)(state => state.adHocDataViews);
  const dataView = (0, _discover_internal_state_container.useInternalStateSelector)(state => state.dataView);
  const savedDataViews = (0, _discover_internal_state_container.useInternalStateSelector)(state => state.savedDataViews);
  const isESQLToDataViewTransitionModalVisible = (0, _discover_internal_state_container.useInternalStateSelector)(state => state.isESQLToDataViewTransitionModalVisible);
  const savedSearch = (0, _discover_state_provider.useSavedSearchInitial)();
  const isEsqlMode = (0, _use_is_esql_mode.useIsEsqlMode)();
  const showDatePicker = (0, _react.useMemo)(() => {
    // always show the timepicker for ES|QL mode
    return isEsqlMode || !isEsqlMode && dataView.isTimeBased() && dataView.type !== _public.DataViewType.ROLLUP;
  }, [dataView, isEsqlMode]);
  const closeFieldEditor = (0, _react.useRef)();
  const closeDataViewEditor = (0, _react.useRef)();
  (0, _react.useEffect)(() => {
    return () => {
      // Make sure to close the editors when unmounting
      if (closeFieldEditor.current) {
        closeFieldEditor.current();
      }
      if (closeDataViewEditor.current) {
        closeDataViewEditor.current();
      }
    };
  }, []);
  const canEditDataView = Boolean(dataViewEditor === null || dataViewEditor === void 0 ? void 0 : dataViewEditor.userPermissions.editDataView()) || !dataView.isPersisted();
  const editField = (0, _react.useMemo)(() => canEditDataView ? async fieldName => {
    if (dataView !== null && dataView !== void 0 && dataView.id) {
      const dataViewInstance = await data.dataViews.get(dataView.id);
      closeFieldEditor.current = await dataViewFieldEditor.openEditor({
        ctx: {
          dataView: dataViewInstance
        },
        fieldName,
        onSave: async () => {
          await onFieldEdited();
        }
      });
    }
  } : undefined, [canEditDataView, dataView === null || dataView === void 0 ? void 0 : dataView.id, data.dataViews, dataViewFieldEditor, onFieldEdited]);
  const addField = (0, _react.useMemo)(() => canEditDataView && editField ? () => editField() : undefined, [editField, canEditDataView]);
  const createNewDataView = (0, _react.useCallback)(() => {
    closeDataViewEditor.current = dataViewEditor.openEditor({
      onSave: stateContainer.actions.onDataViewCreated,
      allowAdHocDataView: true
    });
  }, [dataViewEditor, stateContainer]);
  const updateSavedQueryId = newSavedQueryId => {
    const {
      appState
    } = stateContainer;
    if (newSavedQueryId) {
      appState.update({
        savedQuery: newSavedQueryId
      });
    } else {
      // remove savedQueryId from state
      const newState = {
        ...appState.getState()
      };
      delete newState.savedQuery;
      appState.set(newState);
    }
  };
  const onESQLToDataViewTransitionModalClose = (0, _react.useCallback)((shouldDismissModal, needsSave) => {
    if (shouldDismissModal) {
      services.storage.set(_constants.ESQL_TRANSITION_MODAL_KEY, true);
    }
    stateContainer.internalState.transitions.setIsESQLToDataViewTransitionModalVisible(false);
    // the user dismissed the modal, we don't need to save the search or switch to the data view mode
    if (needsSave == null) {
      return;
    }
    if (needsSave) {
      (0, _on_save_search.onSaveSearch)({
        savedSearch: stateContainer.savedSearchState.getState(),
        services,
        state: stateContainer,
        onClose: () => stateContainer.internalState.transitions.setIsESQLToDataViewTransitionModalVisible(false),
        onSaveCb: () => {
          var _dataView$id;
          stateContainer.actions.transitionFromESQLToDataView((_dataView$id = dataView.id) !== null && _dataView$id !== void 0 ? _dataView$id : '');
        }
      });
    } else {
      var _dataView$id2;
      stateContainer.actions.transitionFromESQLToDataView((_dataView$id2 = dataView.id) !== null && _dataView$id2 !== void 0 ? _dataView$id2 : '');
    }
  }, [dataView.id, services, stateContainer]);
  const {
    topNavBadges,
    topNavMenu
  } = (0, _use_discover_topnav.useDiscoverTopNav)({
    stateContainer
  });
  const topNavProps = (0, _react.useMemo)(() => {
    if (stateContainer.customizationContext.inlineTopNav.enabled) {
      return undefined;
    }
    return {
      badges: topNavBadges,
      config: topNavMenu,
      setMenuMountPoint: setHeaderActionMenu,
      className: 'dscTopNav' // FIXME: Delete the scss file and pass `gutterSize="xxs"` instead (after next Eui release)
    };
  }, [setHeaderActionMenu, stateContainer.customizationContext.inlineTopNav.enabled, topNavBadges, topNavMenu]);
  const dataViewPickerProps = (0, _react.useMemo)(() => {
    const isESQLModeEnabled = uiSettings.get(_esqlUtils.ENABLE_ESQL);
    const supportedTextBasedLanguages = isESQLModeEnabled ? [_esqlUtils.TextBasedLanguages.ESQL] : [];
    return {
      trigger: {
        label: (dataView === null || dataView === void 0 ? void 0 : dataView.getName()) || '',
        'data-test-subj': 'discover-dataView-switch-link',
        title: (dataView === null || dataView === void 0 ? void 0 : dataView.getIndexPattern()) || ''
      },
      currentDataViewId: dataView === null || dataView === void 0 ? void 0 : dataView.id,
      onAddField: addField,
      onDataViewCreated: createNewDataView,
      onCreateDefaultAdHocDataView: stateContainer.actions.createAndAppendAdHocDataView,
      onChangeDataView: stateContainer.actions.onChangeDataView,
      textBasedLanguages: supportedTextBasedLanguages,
      adHocDataViews,
      savedDataViews,
      onEditDataView: stateContainer.actions.onDataViewEdited
    };
  }, [adHocDataViews, addField, createNewDataView, dataView, savedDataViews, stateContainer, uiSettings]);
  const onESQLDocsFlyoutVisibilityChanged = (0, _react.useCallback)(isOpen => {
    if (isOpen) {
      (0, _discoverUtils.dismissAllFlyoutsExceptFor)(_discoverUtils.DiscoverFlyouts.esqlDocs);
    }
  }, []);
  const searchBarCustomization = (0, _customizations.useDiscoverCustomization)('search_bar');
  const SearchBar = (0, _react.useMemo)(() => {
    var _searchBarCustomizati;
    return (_searchBarCustomizati = searchBarCustomization === null || searchBarCustomization === void 0 ? void 0 : searchBarCustomization.CustomSearchBar) !== null && _searchBarCustomizati !== void 0 ? _searchBarCustomizati : navigation.ui.AggregateQueryTopNavMenu;
  }, [searchBarCustomization === null || searchBarCustomization === void 0 ? void 0 : searchBarCustomization.CustomSearchBar, navigation.ui.AggregateQueryTopNavMenu]);
  const shouldHideDefaultDataviewPicker = !!(searchBarCustomization !== null && searchBarCustomization !== void 0 && searchBarCustomization.CustomDataViewPicker) || !!(searchBarCustomization !== null && searchBarCustomization !== void 0 && searchBarCustomization.hideDataViewPicker);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(SearchBar, (0, _extends2.default)({}, topNavProps, {
    appName: "discover",
    indexPatterns: [dataView],
    onQuerySubmit: stateContainer.actions.onUpdateQuery,
    onCancel: onCancelClick,
    isLoading: isLoading,
    onSavedQueryIdChange: updateSavedQueryId,
    query: query,
    savedQueryId: savedQuery,
    screenTitle: savedSearch.title,
    showDatePicker: showDatePicker,
    saveQueryMenuVisibility: services.capabilities.discover.saveQuery ? 'allowed_by_app_privilege' : 'globally_managed',
    showSearchBar: true,
    useDefaultBehaviors: true,
    dataViewPickerOverride: searchBarCustomization !== null && searchBarCustomization !== void 0 && searchBarCustomization.CustomDataViewPicker ? /*#__PURE__*/_react.default.createElement(searchBarCustomization.CustomDataViewPicker, null) : undefined,
    dataViewPickerComponentProps: shouldHideDefaultDataviewPicker ? undefined : dataViewPickerProps,
    displayStyle: "detached",
    textBasedLanguageModeErrors: esqlModeErrors ? [esqlModeErrors] : undefined,
    textBasedLanguageModeWarning: esqlModeWarning,
    prependFilterBar: searchBarCustomization !== null && searchBarCustomization !== void 0 && searchBarCustomization.PrependFilterBar ? /*#__PURE__*/_react.default.createElement(searchBarCustomization.PrependFilterBar, null) : undefined,
    onESQLDocsFlyoutVisibilityChanged: onESQLDocsFlyoutVisibilityChanged
  })), isESQLToDataViewTransitionModalVisible && /*#__PURE__*/_react.default.createElement(_esql_dataview_transition.ESQLToDataViewTransitionModal, {
    onClose: onESQLToDataViewTransitionModalClose
  }));
};
exports.DiscoverTopNav = DiscoverTopNav;