"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseConnectorFilter = exports.SelectConnector = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactRouterDom = require("react-router-dom");
var _react2 = require("@emotion/react");
var _kea = require("kea");
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _constants = require("../../../../../../common/constants");
var _connector_logo_network_drive_version = _interopRequireDefault(require("../../../../../assets/images/connector_logo_network_drive_version.svg"));
var _kibana = require("../../../../shared/kibana");
var _licensing = require("../../../../shared/licensing");
var _query_params = require("../../../../shared/query_params");
var _routes = require("../../../routes");
var _layout = require("../../layout");
var _connectors = require("../connectors");
var _connector_checkable = require("./connector_checkable");
var _connector_description_badge_popout = require("./connector_description_badge_popout");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const parseConnectorFilter = filter => {
  const temp = Array.isArray(filter) ? filter[0] : filter !== null && filter !== void 0 ? filter : null;
  if (!temp) return null;
  if (temp === _constants.CONNECTOR_CLIENTS_TYPE) {
    return _constants.CONNECTOR_CLIENTS_TYPE;
  }
  if (temp === _constants.CONNECTOR_NATIVE_TYPE) {
    return _constants.CONNECTOR_NATIVE_TYPE;
  }
  return null;
};
exports.parseConnectorFilter = parseConnectorFilter;
const SelectConnector = () => {
  const {
    search
  } = (0, _reactRouterDom.useLocation)();
  const {
    connectorTypes,
    isCloud
  } = (0, _kea.useValues)(_kibana.KibanaLogic);
  const {
    hasPlatinumLicense
  } = (0, _kea.useValues)(_licensing.LicensingLogic);
  const hasNativeAccess = isCloud;
  const {
    filter
  } = (0, _query_params.parseQueryParams)(search);
  const [selectedConnectorFilter, setSelectedConnectorFilter] = (0, _react.useState)(parseConnectorFilter(filter));
  const useNativeFilter = selectedConnectorFilter === _constants.CONNECTOR_NATIVE_TYPE;
  const useClientsFilter = selectedConnectorFilter === _constants.CONNECTOR_CLIENTS_TYPE;
  const [showTechPreview, setShowTechPreview] = (0, _react.useState)(true);
  const [showBeta, setShowBeta] = (0, _react.useState)(true);
  const [searchTerm, setSearchTerm] = (0, _react.useState)('');
  const filteredConnectors = (0, _react.useMemo)(() => {
    const nativeConnectors = hasNativeAccess ? connectorTypes.filter(connector => connector.isNative).sort((a, b) => a.name.localeCompare(b.name)) : [];
    const nonNativeConnectors = hasNativeAccess ? connectorTypes.filter(connector => !connector.isNative).sort((a, b) => a.name.localeCompare(b.name)) : connectorTypes.sort((a, b) => a.name.localeCompare(b.name));
    const connectors = !hasNativeAccess || useClientsFilter ? connectorTypes.sort((a, b) => a.name.localeCompare(b.name)) : [...nativeConnectors, ...nonNativeConnectors];
    return connectors.filter(connector => showBeta ? true : !connector.isBeta).filter(connector => showTechPreview ? true : !connector.isTechPreview).filter(connector => useNativeFilter ? connector.isNative : true).filter(connector => searchTerm ? connector.name.toLowerCase().includes(searchTerm.toLowerCase()) : true);
  }, [hasNativeAccess, useClientsFilter, showBeta, showTechPreview, useNativeFilter, searchTerm]);
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  return /*#__PURE__*/_react.default.createElement(_layout.EnterpriseSearchContentPageTemplate, {
    pageChrome: [..._connectors.connectorsBreadcrumbs, _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.breadcrumb', {
      defaultMessage: 'Select connector'
    })],
    pageViewTelemetry: "select_connector",
    isLoading: false,
    pageHeader: {
      description: _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.description', {
        defaultMessage: "Select which third-party data source you'd like to sync to Elastic. All data sources are supported by self-managed connectors. Check the availability for Elastic managed connectors by using the filters."
      }),
      pageTitle: _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.title', {
        defaultMessage: 'Select a connector'
      })
    }
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false,
    css: (0, _react2.css)`
            max-width: calc(${euiTheme.size.xxl} * 5);
          `
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "none"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFacetGroup, null, hasNativeAccess && /*#__PURE__*/_react.default.createElement(_eui.EuiFacetButton, {
    quantity: connectorTypes.length,
    isSelected: !useNativeFilter && !useClientsFilter,
    onClick: () => setSelectedConnectorFilter(null)
  }, _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.allConnectorsLabel', {
    defaultMessage: 'All connectors'
  })), hasNativeAccess && /*#__PURE__*/_react.default.createElement(_eui.EuiFacetButton, {
    key: "native",
    quantity: connectorTypes.filter(connector => connector.isNative).length,
    isSelected: useNativeFilter,
    onClick: () => setSelectedConnectorFilter(!useNativeFilter ? _constants.CONNECTOR_NATIVE_TYPE : null)
  }, _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.nativeLabel', {
    defaultMessage: 'Elastic managed'
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFacetButton, {
    quantity: connectorTypes.length,
    isSelected: !hasNativeAccess && !useNativeFilter || useClientsFilter,
    onClick: () => setSelectedConnectorFilter(!useClientsFilter ? _constants.CONNECTOR_CLIENTS_TYPE : null)
  }, _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.connectorClients', {
    defaultMessage: 'Self-managed'
  })), !hasNativeAccess && /*#__PURE__*/_react.default.createElement(_eui.EuiFacetButton, {
    key: "native",
    quantity: connectorTypes.filter(connector => connector.isNative).length,
    isSelected: useNativeFilter,
    onClick: () => setSelectedConnectorFilter(!useNativeFilter ? _constants.CONNECTOR_NATIVE_TYPE : null)
  }, _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.nativeLabel', {
    defaultMessage: 'Elastic managed'
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, {
    margin: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    paddingSize: "s",
    hasShadow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    checked: showBeta,
    label: _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.showBetaLabel', {
      defaultMessage: 'Display Beta connectors'
    }),
    onChange: e => setShowBeta(e.target.checked)
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    checked: showTechPreview,
    label: _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.showTechPreviewLabel', {
      defaultMessage: 'Display Tech Preview connectors'
    }),
    onChange: e => setShowTechPreview(e.target.checked)
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, {
    margin: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    paddingSize: "s",
    hasShadow: false,
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xs",
    alignItems: "center",
    responsive: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: "logoCloud"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("h4", null, _i18n.i18n.translate('xpack.enterpriseSearch.selectConnector.nativeConnectorsTitleLabel', {
    defaultMessage: 'Elastic managed connectors'
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_connector_description_badge_popout.ConnectorDescriptionBadge, {
    isNative: true
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "xs",
    grow: false
  }, /*#__PURE__*/_react.default.createElement("p", null, _i18n.i18n.translate('xpack.enterpriseSearch.selectConnector.p.areAvailableDirectlyWithinLabel', {
    defaultMessage: 'Available directly within Elastic Cloud deployments. No additional infrastructure is required. You can also convert Elastic managed connectors to self-managed connectors.'
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    paddingSize: "s",
    hasShadow: false,
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xs",
    alignItems: "center",
    responsive: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: _connector_logo_network_drive_version.default
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("h4", null, _i18n.i18n.translate('xpack.enterpriseSearch.selectConnector.h4.connectorClientsLabel', {
    defaultMessage: 'Self-managed connectors'
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_connector_description_badge_popout.ConnectorDescriptionBadge, {
    isNative: false
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "xs",
    grow: false
  }, /*#__PURE__*/_react.default.createElement("p", null, _i18n.i18n.translate('xpack.enterpriseSearch.selectConnector.p.deployConnectorsOnYourLabel', {
    defaultMessage: 'Deploy connectors on your own infrastructure. You can also customize existing self-managed connectors, or build your own using our connector framework.'
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldSearch, {
    "data-test-subj": "entSearchContent-connectors-selectConnector-searchInput",
    "data-telemetry-id": "entSearchContent-connectors-selectConnector-searchInput",
    "aria-label": _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.search.ariaLabel', {
      defaultMessage: 'Search through connectors'
    }),
    isClearable: true,
    onChange: event => setSearchTerm(event.target.value),
    placeholder: _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.searchPlaceholder', {
      defaultMessage: 'Search'
    }),
    value: searchTerm,
    fullWidth: true
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGrid, {
    columns: 3
  }, filteredConnectors.map(connector => {
    var _ref, _ref2;
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      key: connector.name,
      grow: true
    }, /*#__PURE__*/_react.default.createElement(_connector_checkable.ConnectorCheckable, {
      showNativePopover: (_ref = !hasNativeAccess && useNativeFilter) !== null && _ref !== void 0 ? _ref : false,
      showLicensePopover: connector.platinumOnly && !hasPlatinumLicense && !isCloud,
      isDisabled: (_ref2 = !hasNativeAccess && useNativeFilter) !== null && _ref2 !== void 0 ? _ref2 : false,
      iconType: connector.iconPath,
      isBeta: connector.isBeta,
      isTechPreview: Boolean(connector.isTechPreview),
      showNativeBadge: hasNativeAccess && connector.isNative && !useClientsFilter || !hasNativeAccess && useNativeFilter,
      name: connector.name,
      serviceType: connector.serviceType,
      onConnectorSelect: isNative => {
        const queryParam = new URLSearchParams();
        queryParam.append('service_type', connector.serviceType);
        if (isNative !== undefined) {
          queryParam.append('connector_type', isNative && !useClientsFilter ? _constants.CONNECTOR_NATIVE_TYPE : _constants.CONNECTOR_CLIENTS_TYPE);
        }
        _kibana.KibanaLogic.values.navigateToUrl(`${_routes.NEW_CONNECTOR_PATH}?${queryParam.toString()}`);
      },
      documentationUrl: connector.docsUrl
    }));
  })), !hasNativeAccess && useNativeFilter && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    size: "m",
    title: _i18n.i18n.translate('xpack.enterpriseSearch.content.indices.selectConnector.cloudCallout.title', {
      defaultMessage: 'Elastic Cloud'
    }),
    iconType: "iInCircle"
  }, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.enterpriseSearch.content.indices.selectConnector.cloudCallout.description",
    defaultMessage: "Elastic managed connectors are hosted on Elastic Cloud. Get started with a free 14-day trial."
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    "data-test-subj": "entSearchContent-connectors-selectConnector-cloudCallout-trialButton",
    "data-telemetry-id": "entSearchContent-connectors-selectConnector-cloudCallout-trialButton",
    color: "primary",
    fill: true,
    href: "https://www.elastic.co/cloud/cloud-trial-overview",
    iconType: "popout",
    iconSide: "right",
    target: "_blank"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.enterpriseSearch.content.indices.selectConnector.cloudCallout.trialLink",
    defaultMessage: "Elastic Cloud Trial"
  })))))));
};
exports.SelectConnector = SelectConnector;