"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConfigureOauth = void 0;
var _react = _interopRequireWildcard(require("react"));
var _kea = require("kea");
var _eui = require("@elastic/eui");
var _loading = require("../../../../../shared/loading");
var _add_source_logic = require("./add_source_logic");
var _constants = require("./constants");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ConfigureOauth = ({
  name,
  onFormCreated,
  header
}) => {
  const [formLoading, setFormLoading] = (0, _react.useState)(false);
  const {
    getPreContentSourceConfigData,
    setSelectedGithubOrganizations,
    createContentSource
  } = (0, _kea.useActions)(_add_source_logic.AddSourceLogic);
  const {
    githubOrganizations,
    selectedGithubOrganizationsMap,
    sectionLoading
  } = (0, _kea.useValues)(_add_source_logic.AddSourceLogic);
  const checkboxOptions = githubOrganizations.map(item => ({
    id: item,
    label: item
  }));
  (0, _react.useEffect)(() => {
    getPreContentSourceConfigData();
  }, []);
  const handleChange = option => setSelectedGithubOrganizations(option);
  const formSubmitSuccess = () => onFormCreated(name);
  const handleFormSubmitError = () => setFormLoading(false);
  const handleFormSubmit = e => {
    setFormLoading(true);
    e.preventDefault();
    createContentSource(formSubmitSuccess, handleFormSubmitError);
  };
  const configfieldsForm = /*#__PURE__*/_react.default.createElement("form", {
    onSubmit: handleFormSubmit
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "row",
    alignItems: "flexStart",
    justifyContent: "spaceBetween",
    gutterSize: "xl",
    responsive: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 1,
    className: "adding-a-source__connect-an-instance"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _constants.CONFIG_OAUTH_LABEL
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiCheckboxGroup, {
    options: checkboxOptions,
    idToSelectedMap: selectedGithubOrganizationsMap,
    onChange: handleChange
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xl"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, null, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    isLoading: formLoading,
    color: "primary",
    fill: true,
    type: "submit"
  }, _constants.CONFIG_OAUTH_BUTTON)))));
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, header, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), sectionLoading ? /*#__PURE__*/_react.default.createElement(_loading.Loading, null) : configfieldsForm);
};
exports.ConfigureOauth = ConfigureOauth;