"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.builtInKubernetesClusterEcsEntityDefinition = void 0;
var _entitiesSchema = require("@kbn/entities-schema");
var _constants = require("../../constants");
var _ecs_index_patterns = require("../common/ecs_index_patterns");
var _global_metadata = require("../common/global_metadata");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const builtInKubernetesClusterEcsEntityDefinition = exports.builtInKubernetesClusterEcsEntityDefinition = _entitiesSchema.entityDefinitionSchema.parse({
  id: `${_constants.BUILT_IN_ID_PREFIX}kubernetes_cluster_ecs`,
  filter: 'orchestrator.cluster.name: *',
  managed: true,
  version: '0.1.0',
  name: 'Kubernetes Clusters from ECS data',
  description: 'This definition extracts Kubernetes cluster entities from the Kubernetes integration data streams',
  type: 'k8s.cluster.ecs',
  indexPatterns: _ecs_index_patterns.commonEcsIndexPatterns,
  identityFields: ['orchestrator.cluster.name'],
  displayNameTemplate: '{{orchestrator.cluster.name}}',
  latest: {
    timestampField: '@timestamp',
    lookbackPeriod: '10m',
    settings: {
      frequency: '5m'
    }
  },
  metadata: [..._global_metadata.globalMetadata, {
    source: 'orchestrator.namespace',
    destination: 'orchestrator.namespace',
    aggregation: {
      type: 'terms',
      limit: 10
    }
  }, {
    source: 'orchestrator.cluster_ip',
    destination: 'orchestrator.cluster_id',
    aggregation: {
      type: 'top_value',
      sort: {
        '@timestamp': 'desc'
      }
    }
  }]
});