"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.builtInKubernetesStatefulSetEcsEntityDefinition = void 0;
var _entitiesSchema = require("@kbn/entities-schema");
var _constants = require("../../constants");
var _ecs_metadata = require("../common/ecs_metadata");
var _ecs_index_patterns = require("../common/ecs_index_patterns");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const builtInKubernetesStatefulSetEcsEntityDefinition = exports.builtInKubernetesStatefulSetEcsEntityDefinition = _entitiesSchema.entityDefinitionSchema.parse({
  id: `${_constants.BUILT_IN_ID_PREFIX}kubernetes_stateful_set_ecs`,
  filter: 'kubernetes.statefulset.name : *',
  managed: true,
  version: '0.1.0',
  name: 'Kubernetes StatefulSet from ECS data',
  description: 'This definition extracts Kubernetes stateful set entities from the Kubernetes integration data streams',
  type: 'k8s.statefulset.ecs',
  indexPatterns: _ecs_index_patterns.commonEcsIndexPatterns,
  identityFields: ['kubernetes.statefulset.name'],
  displayNameTemplate: '{{kubernetes.statefulset.name}}',
  latest: {
    timestampField: '@timestamp',
    lookbackPeriod: '10m',
    settings: {
      frequency: '5m'
    }
  },
  metadata: _ecs_metadata.commonEcsMetadata
});