"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.builtInKubernetesPodSemConvEntityDefinition = void 0;
var _entitiesSchema = require("@kbn/entities-schema");
var _constants = require("../../constants");
var _otel_metadata = require("../common/otel_metadata");
var _otel_index_patterns = require("../common/otel_index_patterns");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const builtInKubernetesPodSemConvEntityDefinition = exports.builtInKubernetesPodSemConvEntityDefinition = _entitiesSchema.entityDefinitionSchema.parse({
  id: `${_constants.BUILT_IN_ID_PREFIX}kubernetes_pod_semconv`,
  filter: 'k8s.pod.uid : *',
  managed: true,
  version: '0.1.0',
  name: 'Kubernetes Pod from SemConv data',
  description: 'This definition extracts Kubernetes pod entities using data collected with OpenTelemetry',
  type: 'k8s.pod.otel',
  indexPatterns: _otel_index_patterns.commonOtelIndexPatterns,
  identityFields: ['k8s.pod.uid'],
  displayNameTemplate: '{{k8s.pod.name}}',
  latest: {
    timestampField: '@timestamp',
    lookbackPeriod: '10m',
    settings: {
      frequency: '5m'
    }
  },
  metadata: [..._otel_metadata.commonOtelMetadata, {
    source: 'k8s.pod.name',
    destination: 'k8s.pod.name',
    aggregation: {
      type: 'top_value',
      sort: {
        '@timestamp': 'desc'
      }
    }
  }]
});