"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isSupportedDataType = exports.isReturnType = exports.isParameterType = exports.isFieldType = exports.fieldTypes = exports.dataTypes = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

/**
 * All supported field types in ES|QL. This is all the types
 * that can come back in the table from a query.
 */
const fieldTypes = exports.fieldTypes = ['boolean', 'date', 'double', 'ip', 'keyword', 'integer', 'long', 'text', 'unsigned_long', 'version', 'cartesian_point', 'cartesian_shape', 'geo_point', 'geo_shape', 'counter_integer', 'counter_long', 'counter_double', 'unsupported', 'date_nanos'];
const isFieldType = type => fieldTypes.includes(type);

/**
 * This is the list of all data types that are supported in ES|QL.
 *
 * Not all of these can be used as field types. Some can only be literals,
 * others may be the value of a field, but cannot be used in the index mapping.
 *
 * This is a partial list. The full list is here and we may need to expand this type as
 * the capabilities of the client-side engines grow.
 * https://github.com/elastic/elasticsearch/blob/main/x-pack/plugin/esql-core/src/main/java/org/elasticsearch/xpack/esql/core/type/DataType.java
 */
exports.isFieldType = isFieldType;
const dataTypes = exports.dataTypes = [...fieldTypes, 'null', 'time_literal',
// @TODO consider merging time_literal with time_duration
'time_duration', 'date_period'];
const isSupportedDataType = type => dataTypes.includes(type);

/**
 * This is a set of array types. These aren't official ES|QL types, but they are
 * currently used in the function definitions in a couple of specific scenarios.
 *
 * The fate of these is uncertain. They may be removed in the future.
 */
exports.isSupportedDataType = isSupportedDataType;
const arrayTypes = ['double[]', 'unsigned_long[]', 'long[]', 'integer[]', 'counter_integer[]', 'counter_long[]', 'counter_double[]', 'keyword[]', 'text[]', 'boolean[]', 'any[]', 'date[]', 'date_period[]'];

/**
 * This is the type of a parameter in a function definition.
 */

const isParameterType = str => typeof str !== undefined && str !== 'unsupported' && [...dataTypes, ...arrayTypes, 'any'].includes(str);

/**
 * This is the return type of a function definition.
 *
 * TODO: remove `any`
 */
exports.isParameterType = isParameterType;
const isReturnType = str => str !== 'unsupported' && (dataTypes.includes(str) || str === 'unknown' || str === 'any');
exports.isReturnType = isReturnType;