"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SpaceSelector = void 0;
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _react = _interopRequireWildcard(require("react"));
var _hooks = require("../../../../../../hooks");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SpaceSelector = ({
  setInvalidSpaceError,
  value,
  onChange,
  isDisabled
}) => {
  const res = (0, _hooks.useAgentPoliciesSpaces)();
  const [error, setError] = _react.default.useState();
  const renderOption = _react.default.useCallback((option, searchValue, contentClassName) => /*#__PURE__*/_react.default.createElement(_eui.EuiHealth, {
    color: option.color
  }, /*#__PURE__*/_react.default.createElement("span", {
    className: contentClassName
  }, option.label)), []);
  const options = (0, _react.useMemo)(() => {
    var _res$data$items$map, _res$data;
    return (_res$data$items$map = (_res$data = res.data) === null || _res$data === void 0 ? void 0 : _res$data.items.map(item => ({
      label: item.name,
      key: item.id,
      ...item
    }))) !== null && _res$data$items$map !== void 0 ? _res$data$items$map : [];
  }, [res.data]);
  const selectedOptions = (0, _react.useMemo)(() => {
    if (res.isInitialLoading) {
      return [];
    }
    return value.map(v => {
      const existingOption = options.find(opt => opt.key === v);
      return existingOption ? existingOption : {
        label: v,
        key: v
      };
    });
  }, [options, value, res.isInitialLoading]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    fullWidth: true,
    key: "space",
    error: error,
    isDisabled: isDisabled,
    isInvalid: Boolean(error)
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiComboBox, {
    "data-test-subj": 'spaceSelectorComboBox',
    "aria-label": _i18n.i18n.translate('xpack.fleet.agentPolicies.spaceSelectorLabel', {
      defaultMessage: 'Spaces'
    }),
    fullWidth: true,
    options: options,
    renderOption: renderOption,
    selectedOptions: selectedOptions,
    isDisabled: res.isInitialLoading || isDisabled,
    isClearable: false,
    onSearchChange: (searchValue, hasMatchingOptions) => {
      const newError = searchValue.length === 0 || hasMatchingOptions ? undefined : _i18n.i18n.translate('xpack.fleet.agentPolicies.spaceSelectorInvalid', {
        defaultMessage: '{space} is not a valid space.',
        values: {
          space: searchValue
        }
      });
      setError(newError);
      if (setInvalidSpaceError) {
        setInvalidSpaceError(!!newError);
      }
    },
    onChange: newOptions => {
      onChange(newOptions.map(({
        key
      }) => key));
    }
  }));
};
exports.SpaceSelector = SpaceSelector;