"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createOutputApi = createOutputApi;
var _inferenceCommon = require("@kbn/inference-common");
var _rxjs = require("rxjs");
var _ensure_multi_turn = require("../utils/ensure_multi_turn");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function createOutputApi(chatCompleteApi) {
  return ({
    id,
    connectorId,
    input,
    schema,
    system,
    previousMessages,
    functionCalling,
    stream
  }) => {
    const response = chatCompleteApi({
      connectorId,
      stream,
      functionCalling,
      system,
      messages: (0, _ensure_multi_turn.ensureMultiTurn)([...(previousMessages || []), {
        role: _inferenceCommon.MessageRole.User,
        content: input
      }]),
      ...(schema ? {
        tools: {
          structuredOutput: {
            description: `Use the following schema to respond to the user's request in structured data, so it can be parsed and handled.`,
            schema
          }
        },
        toolChoice: {
          function: 'structuredOutput'
        }
      } : {})
    });
    if ((0, _rxjs.isObservable)(response)) {
      return response.pipe((0, _inferenceCommon.withoutTokenCountEvents)(), (0, _rxjs.map)(event => {
        if (event.type === _inferenceCommon.ChatCompletionEventType.ChatCompletionChunk) {
          return {
            type: _inferenceCommon.OutputEventType.OutputUpdate,
            id,
            content: event.content
          };
        }
        return {
          id,
          output: event.toolCalls.length && 'arguments' in event.toolCalls[0].function ? event.toolCalls[0].function.arguments : undefined,
          content: event.content,
          type: _inferenceCommon.OutputEventType.OutputComplete
        };
      }));
    } else {
      return response.then(chatResponse => {
        return {
          id,
          content: chatResponse.content,
          output: chatResponse.toolCalls.length && 'arguments' in chatResponse.toolCalls[0].function ? chatResponse.toolCalls[0].function.arguments : undefined
        };
      });
    }
  };
}