"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Overview = void 0;
var _react = _interopRequireDefault(require("react"));
var _eui = require("@elastic/eui");
var _react2 = require("@emotion/react");
var _useLocalStorage = _interopRequireDefault(require("react-use/lib/useLocalStorage"));
var _metadata_summary_list = require("./metadata_summary/metadata_summary_list");
var _alerts = require("./alerts/alerts");
var _kpi_grid = require("./kpis/kpi_grid");
var _use_asset_details_render_props = require("../../hooks/use_asset_details_render_props");
var _use_metadata_state = require("../../hooks/use_metadata_state");
var _use_data_views = require("../../hooks/use_data_views");
var _use_date_picker = require("../../hooks/use_date_picker");
var _metadata_error_callout = require("../../components/metadata_error_callout");
var _cpu_profiling_prompt = require("./kpis/cpu_profiling_prompt");
var _services = require("./services");
var _metrics = require("./metrics/metrics");
var _add_metrics_callout = require("../../add_metrics_callout");
var _use_entity_summary = require("../../hooks/use_entity_summary");
var _get_data_stream_types = require("../../utils/get_data_stream_types");
var _constants = require("../../constants");
var _use_integration_check = require("../../hooks/use_integration_check");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const Overview = () => {
  const {
    dateRange
  } = (0, _use_date_picker.useDatePickerContext)();
  const {
    asset,
    renderMode
  } = (0, _use_asset_details_render_props.useAssetDetailsRenderPropsContext)();
  const {
    metadata,
    loading: metadataLoading,
    error: fetchMetadataError
  } = (0, _use_metadata_state.useMetadataStateContext)();
  const {
    metrics
  } = (0, _use_data_views.useDataViewsContext)();
  const isFullPageView = renderMode.mode === 'page';
  const {
    dataStreams,
    status: dataStreamsStatus
  } = (0, _use_entity_summary.useEntitySummary)({
    entityType: asset.type,
    entityId: asset.id
  });
  const addMetricsCalloutId = asset.type === 'host' ? 'hostOverview' : 'containerOverview';
  const [dismissedAddMetricsCallout, setDismissedAddMetricsCallout] = (0, _useLocalStorage.default)(`infra.dismissedAddMetricsCallout.${addMetricsCalloutId}`, false);
  const isDockerContainer = (0, _use_integration_check.useIntegrationCheck)({
    dependsOn: _constants.INTEGRATIONS.docker
  });
  const isKubernetesContainer = (0, _use_integration_check.useIntegrationCheck)({
    dependsOn: _constants.INTEGRATIONS.kubernetesContainer
  });
  const metadataSummarySection = isFullPageView ? /*#__PURE__*/_react.default.createElement(_metadata_summary_list.MetadataSummaryList, {
    metadata: metadata,
    loading: metadataLoading,
    assetType: asset.type
  }) : /*#__PURE__*/_react.default.createElement(_metadata_summary_list.MetadataSummaryListCompact, {
    metadata: metadata,
    loading: metadataLoading,
    assetType: asset.type
  });
  const shouldShowCallout = () => {
    if (dataStreamsStatus !== 'success' || renderMode.mode !== 'page' || dismissedAddMetricsCallout) {
      return false;
    }
    const {
      type
    } = asset;
    const baseCondition = !(0, _get_data_stream_types.isMetricsSignal)(dataStreams);
    const isRelevantContainer = type === 'container' && (isDockerContainer || isKubernetesContainer);
    return baseCondition && (type === 'host' || isRelevantContainer);
  };
  const showAddMetricsCallout = shouldShowCallout();
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "m"
  }, showAddMetricsCallout ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_add_metrics_callout.AddMetricsCallout, {
    id: addMetricsCalloutId,
    onDismiss: () => {
      setDismissedAddMetricsCallout(true);
    }
  })) : /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_kpi_grid.KPIGrid, {
    assetId: asset.id,
    assetType: asset.type,
    dateRange: dateRange,
    dataView: metrics.dataView
  }), asset.type === 'host' ? /*#__PURE__*/_react.default.createElement(_cpu_profiling_prompt.CpuProfilingPrompt, null) : null), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, fetchMetadataError && !metadataLoading ? /*#__PURE__*/_react.default.createElement(_metadata_error_callout.MetadataErrorCallout, null) : metadataSummarySection, /*#__PURE__*/_react.default.createElement(SectionSeparator, null)), asset.type === 'host' || asset.type === 'container' ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_alerts.AlertsSummaryContent, {
    assetId: asset.id,
    assetType: asset.type,
    dateRange: dateRange
  }), /*#__PURE__*/_react.default.createElement(SectionSeparator, null)) : null, asset.type === 'host' ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_services.ServicesContent, {
    hostName: asset.id,
    dateRange: dateRange
  }), /*#__PURE__*/_react.default.createElement(SectionSeparator, null)) : null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_metrics.MetricsContent, {
    assetId: asset.id,
    assetType: asset.type,
    dateRange: dateRange,
    dataView: metrics.dataView
  })));
};
exports.Overview = Overview;
const SectionSeparator = () => /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, {
  margin: "m",
  css: (0, _react2.css)`
      margin-bottom: 0;
    `
});