"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LogsPageContent = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _react = _interopRequireWildcard(require("react"));
var _sharedUxRouter = require("@kbn/shared-ux-router");
var _public = require("@kbn/kibana-react-plugin/public");
var _public2 = require("@kbn/observability-shared-plugin/public");
var _deeplinksObservability = require("@kbn/deeplinks-observability");
var _sharedUxUtility = require("@kbn/shared-ux-utility");
var _xstateUtils = require("@kbn/xstate-utils");
var _managementSettingsIds = require("@kbn/management-settings-ids");
var _log_threshold = require("../../alerting/log_threshold");
var _help_center_content = require("../../components/help_center_content");
var _use_readonly_badge = require("../../hooks/use_readonly_badge");
var _header_action_menu_provider = require("../../containers/header_action_menu_provider");
var _redirect_with_query_params = require("../../utils/redirect_with_query_params");
var _ = require("../404");
var _routes = require("./routes");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const StreamPage = (0, _sharedUxUtility.dynamic)(() => Promise.resolve().then(() => _interopRequireWildcard(require('./stream'))).then(mod => ({
  default: mod.StreamPage
})));
const LogEntryCategoriesPage = (0, _sharedUxUtility.dynamic)(() => Promise.resolve().then(() => _interopRequireWildcard(require('./log_entry_categories'))).then(mod => ({
  default: mod.LogEntryCategoriesPage
})));
const LogEntryRatePage = (0, _sharedUxUtility.dynamic)(() => Promise.resolve().then(() => _interopRequireWildcard(require('./log_entry_rate'))).then(mod => ({
  default: mod.LogEntryRatePage
})));
const LogsSettingsPage = (0, _sharedUxUtility.dynamic)(() => Promise.resolve().then(() => _interopRequireWildcard(require('./settings'))).then(mod => ({
  default: mod.LogsSettingsPage
})));
const StateMachinePlayground = (0, _sharedUxUtility.dynamic)(() => Promise.resolve().then(() => _interopRequireWildcard(require('../../observability_logs/xstate_helpers'))).then(mod => ({
  default: mod.StateMachinePlayground
})));
const LogsPageContent = () => {
  var _uiCapabilities$logs, _routes$stream$path, _routes$stream;
  const {
    application,
    share
  } = (0, _public.useKibana)().services;
  const isLogsStreamEnabled = (0, _public.useUiSetting)(_managementSettingsIds.OBSERVABILITY_ENABLE_LOGS_STREAM, false);
  const uiCapabilities = application === null || application === void 0 ? void 0 : application.capabilities;
  const onboardingLocator = share === null || share === void 0 ? void 0 : share.url.locators.get(_deeplinksObservability.OBSERVABILITY_ONBOARDING_LOCATOR);
  const {
    setHeaderActionMenu,
    theme$
  } = (0, _react.useContext)(_header_action_menu_provider.HeaderActionMenuContext);
  const enableDeveloperRoutes = (0, _xstateUtils.isDevMode)();
  (0, _use_readonly_badge.useReadOnlyBadge)(!(uiCapabilities !== null && uiCapabilities !== void 0 && (_uiCapabilities$logs = uiCapabilities.logs) !== null && _uiCapabilities$logs !== void 0 && _uiCapabilities$logs.save));
  const routes = (0, _routes.getLogsAppRoutes)({
    isLogsStreamEnabled
  });
  const settingsLinkProps = (0, _public2.useLinkProps)({
    app: 'logs',
    pathname: 'settings'
  });
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_help_center_content.HelpCenterContent, {
    feedbackLink: feedbackLinkUrl,
    appName: pageTitle
  }), setHeaderActionMenu && theme$ && /*#__PURE__*/_react.default.createElement(_public2.HeaderMenuPortal, {
    setHeaderActionMenu: setHeaderActionMenu,
    theme$: theme$
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    responsive: false,
    gutterSize: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiHeaderLinks, {
    gutterSize: "xs"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiHeaderLink, (0, _extends2.default)({
    color: 'text'
  }, settingsLinkProps), settingsTabTitle), /*#__PURE__*/_react.default.createElement(_log_threshold.LazyAlertDropdownWrapper, null), /*#__PURE__*/_react.default.createElement(_eui.EuiHeaderLink, {
    href: onboardingLocator === null || onboardingLocator === void 0 ? void 0 : onboardingLocator.useUrl({
      category: 'logs'
    }),
    color: "primary",
    iconType: "indexOpen"
  }, ADD_DATA_LABEL))))), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Routes, null, routes.stream ? /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    path: routes.stream.path,
    component: StreamPage
  }) : /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    path: "/stream",
    exact: true,
    render: () => {
      var _share$url$locators$g;
      (_share$url$locators$g = share.url.locators.get(_deeplinksObservability.ALL_DATASETS_LOCATOR_ID)) === null || _share$url$locators$g === void 0 ? void 0 : _share$url$locators$g.navigate({});
      return null;
    }
  }), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    path: routes.logsAnomalies.path,
    component: LogEntryRatePage
  }), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    path: routes.logsCategories.path,
    component: LogEntryCategoriesPage
  }), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    path: routes.settings.path,
    component: LogsSettingsPage
  }), enableDeveloperRoutes && /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    path: '/state-machine-playground',
    component: StateMachinePlayground
  }), /*#__PURE__*/_react.default.createElement(_redirect_with_query_params.RedirectWithQueryParams, {
    from: '/analysis',
    to: routes.logsAnomalies.path,
    exact: true
  }), /*#__PURE__*/_react.default.createElement(_redirect_with_query_params.RedirectWithQueryParams, {
    from: '/log-rate',
    to: routes.logsAnomalies.path,
    exact: true
  }), /*#__PURE__*/_react.default.createElement(_redirect_with_query_params.RedirectWithQueryParams, {
    from: '/',
    to: (_routes$stream$path = (_routes$stream = routes.stream) === null || _routes$stream === void 0 ? void 0 : _routes$stream.path) !== null && _routes$stream$path !== void 0 ? _routes$stream$path : routes.logsAnomalies.path,
    exact: true
  }), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
    render: () => /*#__PURE__*/_react.default.createElement(_.NotFoundPage, {
      title: pageTitle
    })
  })));
};
exports.LogsPageContent = LogsPageContent;
const pageTitle = _i18n.i18n.translate('xpack.infra.header.logsTitle', {
  defaultMessage: 'Logs'
});
const settingsTabTitle = _i18n.i18n.translate('xpack.infra.logs.index.settingsTabTitle', {
  defaultMessage: 'Settings'
});
const feedbackLinkUrl = 'https://discuss.elastic.co/c/logs';
const ADD_DATA_LABEL = _i18n.i18n.translate('xpack.infra.logsHeaderAddDataButtonLabel', {
  defaultMessage: 'Add data'
});