"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerRelatedRoutes = registerRelatedRoutes;
var _server = require("@kbn/data-plugin/server");
var _apm = require("@kbn/langchain/server/tracers/apm");
var _langsmith = require("@kbn/langchain/server/tracers/langsmith");
var _common = require("../../common");
var _constants = require("../constants");
var _related = require("../graphs/related");
var _llm = require("../util/llm");
var _route_validation = require("../util/route_validation");
var _with_availability = require("./with_availability");
var _errors = require("../lib/errors");
var _routes_util = require("./routes_util");
var _constants2 = require("../../common/constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function registerRelatedRoutes(router) {
  router.versioned.post({
    path: _common.RELATED_GRAPH_PATH,
    access: 'internal',
    options: {
      timeout: {
        idleSocket: _constants.ROUTE_HANDLER_TIMEOUT
      }
    }
  }).addVersion({
    version: '1',
    security: {
      authz: {
        enabled: false,
        reason: 'This route is opted out from authorization because the privileges are not defined yet.'
      }
    },
    validate: {
      request: {
        body: (0, _route_validation.buildRouteValidationWithZod)(_common.RelatedRequestBody)
      }
    }
  }, (0, _with_availability.withAvailability)(async (context, req, res) => {
    const {
      packageName,
      dataStreamName,
      rawSamples,
      samplesFormat,
      currentPipeline,
      langSmithOptions
    } = req.body;
    const services = await context.resolve(['core']);
    const {
      client
    } = services.core.elasticsearch;
    const {
      getStartServices,
      logger
    } = await context.integrationAssistant;
    const [, {
      actions: actionsPlugin
    }] = await getStartServices();
    try {
      var _connector$config, _langSmithOptions$pro;
      const actionsClient = await actionsPlugin.getActionsClientWithRequest(req);
      const connector = await actionsClient.get({
        id: req.body.connectorId
      });
      const abortSignal = (0, _server.getRequestAbortedSignal)(req.events.aborted$);
      const actionTypeId = connector.actionTypeId;
      const llmType = (0, _llm.getLLMType)(actionTypeId);
      const llmClass = (0, _llm.getLLMClass)(llmType);
      const model = new llmClass({
        actionsClient,
        connectorId: connector.id,
        logger,
        llmType,
        model: (_connector$config = connector.config) === null || _connector$config === void 0 ? void 0 : _connector$config.defaultModel,
        temperature: 0.05,
        maxTokens: 4096,
        signal: abortSignal,
        streaming: false
      });
      const parameters = {
        packageName,
        dataStreamName,
        rawSamples,
        currentPipeline,
        samplesFormat
      };
      const options = {
        callbacks: [new _apm.APMTracer({
          projectName: (_langSmithOptions$pro = langSmithOptions === null || langSmithOptions === void 0 ? void 0 : langSmithOptions.projectName) !== null && _langSmithOptions$pro !== void 0 ? _langSmithOptions$pro : 'default'
        }, logger), ...(0, _langsmith.getLangSmithTracer)({
          ...langSmithOptions,
          logger
        })]
      };
      const graph = await (0, _related.getRelatedGraph)({
        client,
        model
      });
      const results = await graph.withConfig({
        runName: 'Related'
      }).invoke(parameters, options);
      return res.ok({
        body: _common.RelatedResponse.parse(results)
      });
    } catch (err) {
      try {
        (0, _routes_util.handleCustomErrors)(err, _constants2.GenerationErrorCode.RECURSION_LIMIT);
      } catch (e) {
        if ((0, _errors.isErrorThatHandlesItsOwnResponse)(e)) {
          return e.sendResponse(res);
        }
      }
      return res.badRequest({
        body: err
      });
    }
  }));
}