"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GroupSelector = GroupSelector;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _use_inventory_params = require("../../hooks/use_inventory_params");
var _use_inventory_router = require("../../hooks/use_inventory_router");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const GROUP_LABELS = {
  unified: _i18n.i18n.translate('xpack.inventory.groupedInventoryPage.noneLabel', {
    defaultMessage: 'None'
  }),
  grouped: _i18n.i18n.translate('xpack.inventory.groupedInventoryPage.typeLabel', {
    defaultMessage: 'Type'
  })
};
function GroupSelector() {
  var _query$view;
  const {
    query
  } = (0, _use_inventory_params.useInventoryParams)('/');
  const inventoryRoute = (0, _use_inventory_router.useInventoryRouter)();
  const [isPopoverOpen, setIsPopoverOpen] = (0, _react.useState)(false);
  const groupBy = (_query$view = query.view) !== null && _query$view !== void 0 ? _query$view : 'grouped';
  const onGroupChange = selected => {
    const {
      pagination: _,
      ...rest
    } = query;
    inventoryRoute.push('/', {
      path: {},
      query: {
        ...rest,
        view: groupBy === selected ? 'unified' : selected
      }
    });
  };
  const isGroupSelected = groupKey => {
    return groupBy === groupKey;
  };
  const panels = [{
    id: 'firstPanel',
    title: _i18n.i18n.translate('xpack.inventory.groupedInventoryPage.groupSelectorLabel', {
      defaultMessage: 'Select grouping'
    }),
    items: [{
      'data-test-subj': 'panelUnified',
      name: GROUP_LABELS.unified,
      icon: isGroupSelected('unified') ? 'check' : 'empty',
      onClick: () => onGroupChange('unified')
    }, {
      'data-test-subj': 'panelType',
      name: GROUP_LABELS.grouped,
      icon: isGroupSelected('grouped') ? 'check' : 'empty',
      onClick: () => onGroupChange('grouped')
    }]
  }];
  const onButtonClick = (0, _react.useCallback)(() => setIsPopoverOpen(currentVal => !currentVal), []);
  const closePopover = (0, _react.useCallback)(() => setIsPopoverOpen(false), []);
  const button = /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    "data-test-subj": "groupSelectorDropdown",
    iconSide: "right",
    iconSize: "s",
    iconType: "arrowDown",
    onClick: onButtonClick,
    title: GROUP_LABELS[groupBy],
    size: "s"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.inventory.groupedInventoryPage.groupedByLabel",
    defaultMessage: `Group entities by: {grouping}`,
    values: {
      grouping: GROUP_LABELS[groupBy]
    }
  }));
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPopover, {
    "data-test-subj": "inventoryGroupsPopover",
    button: button,
    closePopover: closePopover,
    isOpen: isPopoverOpen,
    panelPaddingSize: "none"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenu, {
    "data-test-subj": "entitiesGroupByContextMenu",
    initialPanelId: "firstPanel",
    panels: panels
  }));
}