"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GroupedInventory = GroupedInventory;
var _eui = require("@elastic/eui");
var _common = require("@kbn/observability-shared-plugin/common");
var _react = _interopRequireDefault(require("react"));
var _useEffectOnce = _interopRequireDefault(require("react-use/lib/useEffectOnce"));
var _flatten_object = require("@kbn/observability-utils-common/object/flatten_object");
var _use_inventory_abortable_async = require("../../hooks/use_inventory_abortable_async");
var _use_kibana = require("../../hooks/use_kibana");
var _use_unified_search_context = require("../../hooks/use_unified_search_context");
var _inventory_group_accordion = require("./inventory_group_accordion");
var _inventory_summary = require("./inventory_summary");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function GroupedInventory() {
  const {
    services: {
      inventoryAPIClient
    }
  } = (0, _use_kibana.useKibana)();
  const {
    refreshSubject$,
    isControlPanelsInitiated,
    stringifiedEsQuery
  } = (0, _use_unified_search_context.useUnifiedSearchContext)();
  const {
    value = {
      groupBy: _common.ENTITY_TYPE,
      groups: [],
      entitiesCount: 0
    },
    refresh,
    loading
  } = (0, _use_inventory_abortable_async.useInventoryAbortableAsync)(({
    signal
  }) => {
    if (isControlPanelsInitiated) {
      return inventoryAPIClient.fetch('GET /internal/inventory/entities/group_by/{field}', {
        params: {
          path: {
            field: _common.ENTITY_TYPE
          },
          query: {
            esQuery: stringifiedEsQuery
          }
        },
        signal
      });
    }
  }, [inventoryAPIClient, stringifiedEsQuery, isControlPanelsInitiated]);
  (0, _useEffectOnce.default)(() => {
    const refreshSubscription = refreshSubject$.subscribe(refresh);
    return () => refreshSubscription.unsubscribe();
  });
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_inventory_summary.InventorySummary, {
    totalEntities: value.entitiesCount,
    totalGroups: value.groups.length
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), value.groups.map(group => {
    const groupValue = (0, _flatten_object.flattenObject)(group)[value.groupBy];
    return /*#__PURE__*/_react.default.createElement(_inventory_group_accordion.InventoryGroupAccordion, {
      key: `${value.groupBy}-${groupValue}`,
      groupBy: value.groupBy,
      groupValue: groupValue,
      groupCount: group.count,
      isLoading: loading
    });
  }));
}