"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ControlGroups = ControlGroups;
var _public = require("@kbn/controls-plugin/public");
var _common = require("@kbn/observability-shared-plugin/common");
var _public2 = require("@kbn/observability-shared-plugin/public");
var _react = _interopRequireWildcard(require("react"));
var _rxjs = require("rxjs");
var _use_unified_search_context = require("../../hooks/use_unified_search_context");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const controlPanelDefinitions = {
  [_common.ENTITY_TYPE]: {
    order: 0,
    type: 'optionsListControl',
    fieldName: _common.ENTITY_TYPE,
    width: 'small',
    grow: false,
    title: 'Type'
  }
};
function ControlGroups() {
  const {
    isControlPanelsInitiated,
    setIsControlPanelsInitiated,
    dataView,
    searchState,
    onPanelFiltersChange
  } = (0, _use_unified_search_context.useUnifiedSearchContext)();
  const [controlPanels, setControlPanels] = (0, _public2.useControlPanels)(controlPanelDefinitions, dataView);
  const subscriptions = (0, _react.useRef)(new _rxjs.Subscription());
  const getInitialInput = (0, _react.useCallback)(() => async () => {
    const initialInput = {
      chainingSystem: 'HIERARCHICAL',
      labelPosition: 'oneLine',
      initialChildControlState: controlPanels
    };
    return {
      initialState: initialInput
    };
  }, [controlPanels]);
  const loadCompleteHandler = (0, _react.useCallback)(controlGroup => {
    if (!controlGroup) return;
    subscriptions.current.add(controlGroup.filters$.pipe((0, _rxjs.skip)(1)).subscribe((newFilters = []) => {
      onPanelFiltersChange(newFilters);
    }));
    subscriptions.current.add(controlGroup.getInput$().subscribe(({
      initialChildControlState
    }) => {
      if (!isControlPanelsInitiated) {
        setIsControlPanelsInitiated(true);
      }
      setControlPanels(initialChildControlState);
    }));
  }, [isControlPanelsInitiated, onPanelFiltersChange, setControlPanels, setIsControlPanelsInitiated]);
  (0, _react.useEffect)(() => {
    const currentSubscriptions = subscriptions.current;
    return () => {
      currentSubscriptions.unsubscribe();
    };
  }, []);
  if (!dataView) {
    return null;
  }
  return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_public.ControlGroupRenderer, {
    getCreationOptions: getInitialInput(),
    onApiAvailable: loadCompleteHandler,
    query: searchState.query,
    compressed: false,
    filters: searchState.filters
  }));
}