"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SearchBar = SearchBar;
var _i18n = require("@kbn/i18n");
var _fastDeepEqual = _interopRequireDefault(require("fast-deep-equal"));
var _react = _interopRequireWildcard(require("react"));
var _use_kibana = require("../../hooks/use_kibana");
var _use_unified_search_context = require("../../hooks/use_unified_search_context");
var _get_kql_field_names_with_fallback = require("../../utils/get_kql_field_names_with_fallback");
var _control_groups = require("./control_groups");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function SearchBar() {
  const {
    refreshSubject$,
    dataView,
    searchState,
    onQueryChange
  } = (0, _use_unified_search_context.useUnifiedSearchContext)();
  const {
    services: {
      unifiedSearch,
      telemetry,
      data: {
        query: {
          queryString: queryStringService
        }
      }
    }
  } = (0, _use_kibana.useKibana)();
  const {
    SearchBar: UnifiedSearchBar
  } = unifiedSearch.ui;
  const syncSearchBarWithUrl = (0, _react.useCallback)(() => {
    const query = searchState.query;
    if (query && !(0, _fastDeepEqual.default)(queryStringService.getQuery(), query)) {
      queryStringService.setQuery(query);
    }
    if (!query) {
      queryStringService.clearQuery();
    }
  }, [searchState.query, queryStringService]);
  (0, _react.useEffect)(() => {
    syncSearchBarWithUrl();
  }, [syncSearchBarWithUrl]);
  const registerSearchSubmittedEvent = (0, _react.useCallback)(({
    searchQuery,
    searchIsUpdate
  }) => {
    telemetry.reportEntityInventorySearchQuerySubmitted({
      kuery_fields: (0, _get_kql_field_names_with_fallback.getKqlFieldsWithFallback)(searchQuery === null || searchQuery === void 0 ? void 0 : searchQuery.query),
      action: searchIsUpdate ? 'submit' : 'refresh'
    });
  }, [telemetry]);
  const handleQuerySubmit = (0, _react.useCallback)(({
    query = {
      language: 'kuery',
      query: ''
    }
  }, isUpdate) => {
    if (isUpdate) {
      onQueryChange(query);
    } else {
      refreshSubject$.next();
    }
    registerSearchSubmittedEvent({
      searchQuery: query,
      searchIsUpdate: isUpdate
    });
  }, [registerSearchSubmittedEvent, onQueryChange, refreshSubject$]);
  return /*#__PURE__*/_react.default.createElement(UnifiedSearchBar, {
    appName: "Inventory",
    displayStyle: "inPage",
    indexPatterns: dataView ? [dataView] : undefined,
    renderQueryInputAppend: () => /*#__PURE__*/_react.default.createElement(_control_groups.ControlGroups, null),
    onQuerySubmit: handleQuerySubmit,
    placeholder: _i18n.i18n.translate('xpack.inventory.searchBar.placeholder', {
      defaultMessage: 'Search for your entities by name or its metadata (e.g. entity.type : service)'
    }),
    showDatePicker: false,
    showFilterBar: true,
    showQueryInput: true,
    showQueryMenu: true
  });
}