"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UnifiedInventory = UnifiedInventory;
var _ioTsUtils = require("@kbn/io-ts-utils");
var _react = _interopRequireDefault(require("react"));
var _useEffectOnce = _interopRequireDefault(require("react-use/lib/useEffectOnce"));
var _entities = require("../../../common/entities");
var _use_inventory_abortable_async = require("../../hooks/use_inventory_abortable_async");
var _use_inventory_params = require("../../hooks/use_inventory_params");
var _use_inventory_router = require("../../hooks/use_inventory_router");
var _use_kibana = require("../../hooks/use_kibana");
var _use_unified_search_context = require("../../hooks/use_unified_search_context");
var _entities_grid = require("../entities_grid");
var _inventory_summary = require("../grouped_inventory/inventory_summary");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const paginationDecoder = (0, _ioTsUtils.decodeOrThrow)(_entities.entityPaginationRt);
function UnifiedInventory() {
  var _pagination$unified, _pagination;
  const {
    services: {
      inventoryAPIClient
    }
  } = (0, _use_kibana.useKibana)();
  const {
    refreshSubject$,
    isControlPanelsInitiated,
    stringifiedEsQuery
  } = (0, _use_unified_search_context.useUnifiedSearchContext)();
  const {
    query
  } = (0, _use_inventory_params.useInventoryParams)('/');
  const {
    sortDirection,
    sortField,
    pagination: paginationQuery
  } = query;
  let pagination = {};
  const inventoryRoute = (0, _use_inventory_router.useInventoryRouter)();
  try {
    pagination = paginationDecoder(paginationQuery);
  } catch (error) {
    inventoryRoute.push('/', {
      path: {},
      query: {
        ...query,
        pagination: undefined
      }
    });
    window.location.reload();
  }
  const pageIndex = (_pagination$unified = (_pagination = pagination) === null || _pagination === void 0 ? void 0 : _pagination.unified) !== null && _pagination$unified !== void 0 ? _pagination$unified : 0;
  const {
    value = {
      entities: []
    },
    loading,
    refresh
  } = (0, _use_inventory_abortable_async.useInventoryAbortableAsync)(({
    signal
  }) => {
    if (isControlPanelsInitiated) {
      return inventoryAPIClient.fetch('GET /internal/inventory/entities', {
        params: {
          query: {
            sortDirection,
            sortField,
            esQuery: stringifiedEsQuery
          }
        },
        signal
      });
    }
  }, [inventoryAPIClient, sortDirection, sortField, isControlPanelsInitiated, stringifiedEsQuery]);
  (0, _useEffectOnce.default)(() => {
    const refreshSubscription = refreshSubject$.subscribe(refresh);
    return () => refreshSubscription.unsubscribe();
  });
  function handlePageChange(nextPage) {
    inventoryRoute.push('/', {
      path: {},
      query: {
        ...query,
        pagination: _entities.entityPaginationRt.encode({
          ...pagination,
          unified: nextPage
        })
      }
    });
  }
  function handleSortChange(sorting) {
    inventoryRoute.push('/', {
      path: {},
      query: {
        ...query,
        sortField: sorting.id,
        sortDirection: sorting.direction
      }
    });
  }
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_inventory_summary.InventorySummary, null), /*#__PURE__*/_react.default.createElement(_entities_grid.EntitiesGrid, {
    entities: value.entities,
    loading: loading,
    sortDirection: sortDirection,
    sortField: sortField,
    onChangePage: handlePageChange,
    onChangeSort: handleSortChange,
    pageIndex: pageIndex
  }));
}