"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDetailViewRedirect = void 0;
var _common = require("@kbn/observability-shared-plugin/common");
var _react = require("react");
var _deeplinksAnalytics = require("@kbn/deeplinks-analytics");
var _lodash = require("lodash");
var _entity_type_guards = require("../../common/utils/entity_type_guards");
var _use_kibana = require("./use_kibana");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const KUBERNETES_DASHBOARDS_IDS = {
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.CLUSTER.ecs]: 'kubernetes-f4dc26db-1b53-4ea2-a78b-1bfab8ea267c',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.CLUSTER.semconv]: 'kubernetes_otel-cluster-overview',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.CRONJOB.ecs]: 'kubernetes-0a672d50-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.DAEMONSET.ecs]: 'kubernetes-85879010-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.DEPLOYMENT.ecs]: 'kubernetes-5be46210-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.JOB.ecs]: 'kubernetes-9bf990a0-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.NODE.ecs]: 'kubernetes-b945b7b0-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.POD.ecs]: 'kubernetes-3d4d9290-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.SERVICE.ecs]: 'kubernetes-ff1b3850-bcb1-11ec-b64f-7dd6e8e82013',
  [_common.BUILT_IN_ENTITY_TYPES.KUBERNETES.STATEFULSET.ecs]: 'kubernetes-21694370-bcb2-11ec-b64f-7dd6e8e82013'
};
const useDetailViewRedirect = () => {
  const {
    services: {
      share,
      entityManager
    }
  } = (0, _use_kibana.useKibana)();
  const locators = share.url.locators;
  const assetDetailsLocator = locators.get(_common.ASSET_DETAILS_LOCATOR_ID);
  const dashboardLocator = locators.get(_deeplinksAnalytics.DASHBOARD_APP_LOCATOR);
  const serviceOverviewLocator = locators.get(_common.SERVICE_OVERVIEW_LOCATOR_ID);
  const getDetailViewRedirectUrl = (0, _react.useCallback)(entity => {
    const identityFieldsValue = entityManager.entityClient.getIdentityFieldsValue({
      entity: {
        identity_fields: entity.entityIdentityFields
      },
      ...entity
    });
    const identityFields = (0, _lodash.castArray)(entity.entityIdentityFields);
    if ((0, _entity_type_guards.isBuiltinEntityOfType)('host', entity) || (0, _entity_type_guards.isBuiltinEntityOfType)('container', entity)) {
      return assetDetailsLocator === null || assetDetailsLocator === void 0 ? void 0 : assetDetailsLocator.getRedirectUrl({
        assetId: identityFieldsValue[identityFields[0]],
        assetType: entity.entityType
      });
    }
    if ((0, _entity_type_guards.isBuiltinEntityOfType)('service', entity)) {
      var _entity$service, _entity$service2;
      return serviceOverviewLocator === null || serviceOverviewLocator === void 0 ? void 0 : serviceOverviewLocator.getRedirectUrl({
        serviceName: identityFieldsValue[identityFields[0]],
        environment: (_entity$service = entity.service) !== null && _entity$service !== void 0 && _entity$service.environment ? (0, _lodash.castArray)((_entity$service2 = entity.service) === null || _entity$service2 === void 0 ? void 0 : _entity$service2.environment)[0] : undefined
      });
    }
    return undefined;
  }, [assetDetailsLocator, entityManager.entityClient, serviceOverviewLocator]);
  const getDashboardRedirectUrl = (0, _react.useCallback)(entity => {
    const type = entity.entityType;
    const dashboardId = KUBERNETES_DASHBOARDS_IDS[type];
    return dashboardId ? dashboardLocator === null || dashboardLocator === void 0 ? void 0 : dashboardLocator.getRedirectUrl({
      dashboardId,
      query: {
        language: 'kuery',
        query: entityManager.entityClient.asKqlFilter({
          entity: {
            identity_fields: entity.entityIdentityFields
          },
          ...entity
        })
      }
    }) : undefined;
  }, [dashboardLocator, entityManager.entityClient]);
  const getEntityRedirectUrl = (0, _react.useCallback)(entity => {
    var _getDetailViewRedirec;
    return (_getDetailViewRedirec = getDetailViewRedirectUrl(entity)) !== null && _getDetailViewRedirec !== void 0 ? _getDetailViewRedirec : getDashboardRedirectUrl(entity);
  }, [getDashboardRedirectUrl, getDetailViewRedirectUrl]);
  return {
    getEntityRedirectUrl
  };
};
exports.useDetailViewRedirect = useDetailViewRedirect;