"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDiscoverRedirect = void 0;
var _react = require("react");
var _use_kibana = require("./use_kibana");
var _use_fetch_entity_definition = require("./use_fetch_entity_definition");
var _use_adhoc_data_view = require("./use_adhoc_data_view");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const useDiscoverRedirect = entity => {
  var _application$capabili2;
  const {
    services: {
      share,
      application,
      entityManager
    }
  } = (0, _use_kibana.useKibana)();
  const {
    entityDefinitions,
    isEntityDefinitionLoading
  } = (0, _use_fetch_entity_definition.useFetchEntityDefinition)(entity.entityDefinitionId);
  const title = (0, _react.useMemo)(() => {
    var _entityDefinitions$, _entityDefinitions$$i;
    return !isEntityDefinitionLoading && entityDefinitions && (entityDefinitions === null || entityDefinitions === void 0 ? void 0 : entityDefinitions.length) > 0 ? (_entityDefinitions$ = entityDefinitions[0]) === null || _entityDefinitions$ === void 0 ? void 0 : (_entityDefinitions$$i = _entityDefinitions$.indexPatterns) === null || _entityDefinitions$$i === void 0 ? void 0 : _entityDefinitions$$i.join(',') : '';
  }, [entityDefinitions, isEntityDefinitionLoading]);
  const {
    dataView
  } = (0, _use_adhoc_data_view.useAdHocDataView)(title);
  const discoverLocator = share.url.locators.get('DISCOVER_APP_LOCATOR');
  const getDiscoverEntitiesRedirectUrl = (0, _react.useCallback)(() => {
    var _application$capabili, _dataView$id;
    const entityKqlFilter = entity ? entityManager.entityClient.asKqlFilter({
      entity: {
        identity_fields: entity.entityIdentityFields
      },
      ...entity
    }) : '';
    return (_application$capabili = application.capabilities.discover) !== null && _application$capabili !== void 0 && _application$capabili.show ? discoverLocator === null || discoverLocator === void 0 ? void 0 : discoverLocator.getRedirectUrl({
      indexPatternId: (_dataView$id = dataView === null || dataView === void 0 ? void 0 : dataView.id) !== null && _dataView$id !== void 0 ? _dataView$id : '',
      query: {
        query: entityKqlFilter,
        language: 'kuery'
      }
    }) : undefined;
  }, [(_application$capabili2 = application.capabilities.discover) === null || _application$capabili2 === void 0 ? void 0 : _application$capabili2.show, dataView === null || dataView === void 0 ? void 0 : dataView.id, discoverLocator, entity, entityManager.entityClient]);
  return {
    getDiscoverEntitiesRedirectUrl,
    isEntityDefinitionLoading
  };
};
exports.useDiscoverRedirect = useDiscoverRedirect;