"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUnifiedSearchContext = exports.UnifiedSearchProvider = void 0;
var _esQuery = require("@kbn/es-query");
var _constate = _interopRequireDefault(require("constate"));
var _react = require("react");
var _rxjs = require("rxjs");
var _public = require("@kbn/data-plugin/public");
var _useEffectOnce = _interopRequireDefault(require("react-use/lib/useEffectOnce"));
var _fastDeepEqual = _interopRequireDefault(require("fast-deep-equal"));
var _i18n = require("@kbn/i18n");
var _public2 = require("@kbn/observability-shared-plugin/public");
var _entities = require("../../common/entities");
var _use_adhoc_data_view = require("./use_adhoc_data_view");
var _use_unified_search_url = require("./use_unified_search_url");
var _use_kibana = require("./use_kibana");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useUnifiedSearch() {
  const [isControlPanelsInitiated, setIsControlPanelsInitiated] = (0, _react.useState)(false);
  const {
    dataView
  } = (0, _use_adhoc_data_view.useAdHocDataView)(_entities.ENTITIES_LATEST_ALIAS);
  const [refreshSubject$] = (0, _react.useState)(new _rxjs.Subject());
  const {
    searchState,
    setSearchState
  } = (0, _use_unified_search_url.useUnifiedSearchUrl)();
  const kibanaQuerySettings = (0, _public2.useKibanaQuerySettings)();
  const {
    services: {
      data: {
        query: {
          filterManager: filterManagerService,
          queryString: queryStringService
        }
      },
      notifications
    }
  } = (0, _use_kibana.useKibana)();
  (0, _useEffectOnce.default)(() => {
    if (!(0, _fastDeepEqual.default)(filterManagerService.getFilters(), searchState.filters)) {
      filterManagerService.setFilters(searchState.filters.map(item => ({
        ...item,
        meta: {
          ...item.meta,
          index: dataView === null || dataView === void 0 ? void 0 : dataView.id
        }
      })));
    }
    if (!(0, _fastDeepEqual.default)(queryStringService.getQuery(), searchState.query)) {
      queryStringService.setQuery(searchState.query);
    }
  });
  (0, _react.useEffect)(() => {
    const subscription = new _rxjs.Subscription();
    subscription.add(filterManagerService.getUpdates$().pipe((0, _rxjs.map)(() => filterManagerService.getFilters()), (0, _rxjs.tap)(filters => setSearchState({
      type: 'SET_FILTERS',
      filters
    }))).subscribe());
    subscription.add(queryStringService.getUpdates$().pipe((0, _rxjs.map)(() => queryStringService.getQuery()), (0, _rxjs.tap)(query => setSearchState({
      type: 'SET_QUERY',
      query
    }))).subscribe());
    return () => {
      subscription.unsubscribe();
    };
  }, [filterManagerService, queryStringService, setSearchState]);
  const validateQuery = (0, _react.useCallback)(query => {
    (0, _esQuery.fromKueryExpression)(query.query, kibanaQuerySettings);
  }, [kibanaQuerySettings]);
  const onQueryChange = (0, _react.useCallback)(query => {
    try {
      validateQuery(query);
      setSearchState({
        type: 'SET_QUERY',
        query
      });
    } catch (e) {
      const err = e;
      notifications.toasts.addDanger({
        title: _i18n.i18n.translate('xpack.inventory.unifiedSearchContext.queryError', {
          defaultMessage: 'Error while updating the new query'
        }),
        text: err.message
      });
    }
  }, [validateQuery, setSearchState, notifications.toasts]);
  const onPanelFiltersChange = (0, _react.useCallback)(panelFilters => {
    setSearchState({
      type: 'SET_PANEL_FILTERS',
      panelFilters
    });
  }, [setSearchState]);
  const onFiltersChange = (0, _react.useCallback)(filters => {
    setSearchState({
      type: 'SET_FILTERS',
      filters
    });
  }, [setSearchState]);
  const addFilter = (0, _react.useCallback)(({
    fieldName,
    operation,
    value
  }) => {
    if (dataView) {
      const newFilters = (0, _public.generateFilters)(filterManagerService, fieldName, value, operation, dataView);
      setSearchState({
        type: 'SET_FILTERS',
        filters: [...newFilters, ...searchState.filters]
      });
    }
  }, [dataView, filterManagerService, searchState.filters, setSearchState]);
  const stringifiedEsQuery = (0, _react.useMemo)(() => {
    if (dataView) {
      return JSON.stringify((0, _esQuery.buildEsQuery)(dataView, searchState.query, [...searchState.panelFilters, ...searchState.filters]));
    }
  }, [dataView, searchState.panelFilters, searchState.filters, searchState.query]);
  return {
    isControlPanelsInitiated,
    setIsControlPanelsInitiated,
    dataView,
    refreshSubject$,
    searchState,
    addFilter,
    stringifiedEsQuery,
    onQueryChange,
    onPanelFiltersChange,
    onFiltersChange
  };
}
const UnifiedSearch = (0, _constate.default)(useUnifiedSearch);
const [UnifiedSearchProvider, useUnifiedSearchContext] = UnifiedSearch;
exports.useUnifiedSearchContext = useUnifiedSearchContext;
exports.UnifiedSearchProvider = UnifiedSearchProvider;