"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUnifiedSearchUrl = useUnifiedSearchUrl;
var _esQuery = require("@kbn/es-query");
var _public = require("@kbn/observability-shared-plugin/public");
var _securitysolutionIoTsTypes = require("@kbn/securitysolution-io-ts-types");
var _Either = require("fp-ts/lib/Either");
var _function = require("fp-ts/lib/function");
var _pipeable = require("fp-ts/lib/pipeable");
var t = _interopRequireWildcard(require("io-ts"));
var _react = require("react");
var _fastDeepEqual = _interopRequireDefault(require("fast-deep-equal"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const FilterRT = t.intersection([t.type({
  meta: t.partial({
    alias: t.union([t.null, t.string]),
    disabled: t.boolean,
    negate: t.boolean,
    controlledBy: t.string,
    group: t.string,
    index: t.string,
    isMultiIndex: t.boolean,
    type: t.string,
    key: t.string,
    params: t.any,
    value: t.any
  })
}), t.partial({
  query: t.record(t.string, t.any),
  $state: t.type({
    store: (0, _securitysolutionIoTsTypes.enumeration)('FilterStateStore', _esQuery.FilterStateStore)
  })
})]);
const FiltersRT = t.array(FilterRT);
const QueryStateRT = t.type({
  language: t.string,
  query: t.union([t.string, t.record(t.string, t.any)])
});
const SearchStateRT = t.type({
  panelFilters: FiltersRT,
  filters: FiltersRT,
  query: QueryStateRT
});
const encodeUrlState = SearchStateRT.encode;
const decodeUrlState = value => {
  return (0, _pipeable.pipe)(SearchStateRT.decode(value), (0, _Either.fold)((0, _function.constant)(undefined), _function.identity));
};
const INITIAL_VALUE = {
  query: {
    language: 'kuery',
    query: ''
  },
  panelFilters: [],
  filters: []
};
const reducer = (state, action) => {
  switch (action.type) {
    case 'SET_FILTERS':
      return {
        ...state,
        filters: action.filters
      };
    case 'SET_QUERY':
      return {
        ...state,
        query: action.query
      };
    case 'SET_PANEL_FILTERS':
      return {
        ...state,
        panelFilters: action.panelFilters
      };
    default:
      return state;
  }
};
function useUnifiedSearchUrl() {
  const [urlState, setUrlState] = (0, _public.useUrlState)({
    defaultState: INITIAL_VALUE,
    decodeUrlState,
    encodeUrlState,
    urlStateKey: '_a',
    writeDefaultState: true
  });
  const [searchState, setSearchState] = (0, _react.useReducer)(reducer, urlState);
  if (!(0, _fastDeepEqual.default)(searchState, urlState)) {
    setUrlState(searchState);
  }
  return {
    searchState,
    setSearchState
  };
}