"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLatestEntities = getLatestEntities;
var _common = require("@kbn/observability-shared-plugin/common");
var _entities = require("../../../common/entities");
var _query_helper = require("./query_helper");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SORT_FIELDS_TO_ES_FIELDS = {
  entityLastSeenTimestamp: _common.ENTITY_LAST_SEEN,
  entityDisplayName: _common.ENTITY_DISPLAY_NAME,
  entityType: _common.ENTITY_TYPE
};
async function getLatestEntities({
  inventoryEsClient,
  sortDirection,
  sortField,
  esQuery,
  entityTypes
}) {
  var _SORT_FIELDS_TO_ES_FI;
  // alertsCount doesn't exist in entities index. Ignore it and sort by entity.lastSeenTimestamp by default.
  const entitiesSortField = (_SORT_FIELDS_TO_ES_FI = SORT_FIELDS_TO_ES_FIELDS[sortField]) !== null && _SORT_FIELDS_TO_ES_FI !== void 0 ? _SORT_FIELDS_TO_ES_FI : _common.ENTITY_LAST_SEEN;
  const from = `FROM ${_entities.ENTITIES_LATEST_ALIAS}`;
  const where = [(0, _query_helper.getBuiltinEntityDefinitionIdESQLWhereClause)()];
  const params = [];
  if (entityTypes) {
    where.push(`WHERE ${_common.ENTITY_TYPE} IN (${entityTypes.map(() => '?').join()})`);
    params.push(...entityTypes);
  }
  const sort = `SORT ${entitiesSortField} ${sortDirection}`;
  const limit = `LIMIT ${_entities.MAX_NUMBER_OF_ENTITIES}`;
  const query = [from, ...where, sort, limit].join(' | ');
  const latestEntitiesEsqlResponse = await inventoryEsClient.esql('get_latest_entities', {
    query,
    filter: esQuery,
    params
  });
  return latestEntitiesEsqlResponse.map(lastestEntity => {
    const {
      entity,
      ...metadata
    } = lastestEntity;
    return {
      entityId: entity.id,
      entityType: entity.type,
      entityDefinitionId: entity.definition_id,
      entityDisplayName: entity.display_name,
      entityIdentityFields: entity.identity_fields,
      entityLastSeenTimestamp: entity.last_seen_timestamp,
      entityDefinitionVersion: entity.definition_version,
      entitySchemaVersion: entity.schema_version,
      ...metadata
    };
  });
}