"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUpdateInvestigationNote = useUpdateInvestigationNote;
var _reactQuery = require("@tanstack/react-query");
var _i18n = require("@kbn/i18n");
var _use_kibana = require("./use_kibana");
var _query_key_factory = require("./query_key_factory");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useUpdateInvestigationNote() {
  const queryClient = (0, _reactQuery.useQueryClient)();
  const {
    core: {
      http,
      notifications: {
        toasts
      }
    }
  } = (0, _use_kibana.useKibana)();
  return (0, _reactQuery.useMutation)(['updateInvestigationNote'], ({
    investigationId,
    noteId,
    note
  }) => {
    const body = JSON.stringify(note);
    return http.put(`/api/observability/investigations/${investigationId}/notes/${noteId}`, {
      body,
      version: '2023-10-31'
    });
  }, {
    onSuccess: (response, {
      investigationId
    }) => {
      toasts.addSuccess(_i18n.i18n.translate('xpack.investigateApp.useUpdateInvestigationNote.successMessage', {
        defaultMessage: 'Note updated'
      }));
      queryClient.invalidateQueries({
        queryKey: _query_key_factory.investigationKeys.detailNotes(investigationId)
      });
    },
    onError: (error, {}, context) => {
      var _error$body$message, _error$body;
      toasts.addError(new Error((_error$body$message = (_error$body = error.body) === null || _error$body === void 0 ? void 0 : _error$body.message) !== null && _error$body$message !== void 0 ? _error$body$message : _i18n.i18n.translate('xpack.investigateApp.useUpdateInvestigationNote.errorMessage', {
        defaultMessage: 'an error occurred'
      })), {
        title: _i18n.i18n.translate('xpack.investigateApp.useUpdateInvestigationNote.errorTitle', {
          defaultMessage: 'Error'
        })
      });
    }
  });
}