"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VectorIcon = VectorIcon;
var _react = _interopRequireDefault(require("react"));
var _circle_icon = require("./circle_icon");
var _line_icon = require("./line_icon");
var _polygon_icon = require("./polygon_icon");
var _symbol_icon = require("./symbol_icon");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function VectorIcon({
  borderStyle = {},
  fillColor,
  isPointsOnly,
  isLinesOnly,
  strokeColor,
  symbolId,
  svg
}) {
  if (isLinesOnly) {
    const style = {
      stroke: strokeColor,
      strokeWidth: '4px',
      ...borderStyle
    };
    return /*#__PURE__*/_react.default.createElement(_line_icon.LineIcon, {
      style: style
    });
  }
  const style = {
    stroke: strokeColor,
    strokeWidth: '1px',
    fill: fillColor,
    ...borderStyle
  };
  if (!isPointsOnly) {
    return /*#__PURE__*/_react.default.createElement(_polygon_icon.PolygonIcon, {
      style: style
    });
  }
  if (!symbolId) {
    return /*#__PURE__*/_react.default.createElement(_circle_icon.CircleIcon, {
      style: style
    });
  }
  if (svg) {
    return /*#__PURE__*/_react.default.createElement(_symbol_icon.SymbolIcon, {
      key: `${symbolId}${fillColor}${strokeColor}`,
      symbolId: symbolId,
      fill: fillColor,
      stroke: strokeColor,
      style: borderStyle,
      svg: svg
    });
  }
  return null;
}