"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDefaultModelsListState = exports.ModelsList = void 0;
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _mlDatePicker = require("@kbn/ml-date-picker");
var _mlIsPopulatedObject = require("@kbn/ml-is-populated-object");
var _mlLocalStorage = require("@kbn/ml-local-storage");
var _mlTrainedModelsUtils = require("@kbn/ml-trained-models-utils");
var _mlUrlState = require("@kbn/ml-url-state");
var _sharedUxUtility = require("@kbn/shared-ux-utility");
var _lodash = require("lodash");
var _react = _interopRequireWildcard(require("react"));
var _useMountedState = _interopRequireDefault(require("react-use/lib/useMountedState"));
var _locator = require("../../../common/constants/locator");
var _storage = require("../../../common/types/storage");
var _trained_models = require("../../../common/types/trained_models");
var _ml_inference = require("../components/ml_inference");
var _saved_objects_warning = require("../components/saved_objects_warning");
var _stats_bar = require("../components/stats_bar");
var _technical_preview_badge = require("../components/technical_preview_badge");
var _kibana = require("../contexts/kibana");
var _ml = require("../contexts/ml");
var _use_table_settings = require("../data_frame_analytics/pages/analytics_management/components/analytics_list/use_table_settings");
var _use_refresh = require("../routing/use_refresh");
var _trained_models2 = require("../services/ml_api_service/trained_models");
var _toast_notification_service = require("../services/toast_notification_service");
var _config_mapping = require("./config_mapping");
var _delete_models_modal = require("./delete_models_modal");
var _get_model_state = require("./get_model_state");
var _model_actions = require("./model_actions");
var _test_dfa_models_flyout = require("./test_dfa_models_flyout");
var _test_models = require("./test_models");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const ExpandedRow = (0, _sharedUxUtility.dynamic)(async () => ({
  default: (await Promise.resolve().then(() => _interopRequireWildcard(require('./expanded_row')))).ExpandedRow
}));
const AddModelFlyout = (0, _sharedUxUtility.dynamic)(async () => ({
  default: (await Promise.resolve().then(() => _interopRequireWildcard(require('./add_model_flyout')))).AddModelFlyout
}));
const modelIdColumnName = _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.modelIdHeader', {
  defaultMessage: 'ID'
});
const getDefaultModelsListState = () => ({
  pageIndex: 0,
  pageSize: 10,
  sortField: modelIdColumnName,
  sortDirection: 'asc',
  showAll: false
});
exports.getDefaultModelsListState = getDefaultModelsListState;
const DOWNLOAD_POLL_INTERVAL = 3000;
const ModelsList = ({
  pageState: pageStateExternal,
  updatePageState: updatePageStateExternal
}) => {
  var _pageState$queryText;
  const isMounted = (0, _useMountedState.default)();
  const {
    services: {
      application: {
        capabilities
      },
      docLinks
    }
  } = (0, _kibana.useMlKibana)();
  const nlpElserDocUrl = docLinks.links.ml.nlpElser;
  const {
    isNLPEnabled
  } = (0, _ml.useEnabledFeatures)();
  const [isElserCalloutDismissed, setIsElserCalloutDismissed] = (0, _mlLocalStorage.useStorage)(_storage.ML_ELSER_CALLOUT_DISMISSED, false);
  (0, _mlDatePicker.useTimefilter)({
    timeRangeSelector: false,
    autoRefreshSelector: true
  });

  // allow for an internally controlled page state which stores the state in the URL
  // or an external page state, which is passed in as a prop.
  // external page state is used on the management page.
  const [pageStateInternal, updatePageStateInternal] = (0, _mlUrlState.usePageUrlState)(_locator.ML_PAGES.TRAINED_MODELS_MANAGE, getDefaultModelsListState());
  const [pageState, updatePageState] = pageStateExternal && updatePageStateExternal ? [pageStateExternal, updatePageStateExternal] : [pageStateInternal, updatePageStateInternal];
  const refresh = (0, _use_refresh.useRefresh)();
  const searchQueryText = (_pageState$queryText = pageState.queryText) !== null && _pageState$queryText !== void 0 ? _pageState$queryText : '';
  const canDeleteTrainedModels = capabilities.ml.canDeleteTrainedModels;
  const trainedModelsApiService = (0, _trained_models2.useTrainedModelsApiService)();
  const {
    displayErrorToast
  } = (0, _toast_notification_service.useToastNotificationService)();
  const [isInitialized, setIsInitialized] = (0, _react.useState)(false);
  const [isLoading, setIsLoading] = (0, _react.useState)(false);
  const [items, setItems] = (0, _react.useState)([]);
  const [selectedModels, setSelectedModels] = (0, _react.useState)([]);
  const [modelsToDelete, setModelsToDelete] = (0, _react.useState)([]);
  const [modelToDeploy, setModelToDeploy] = (0, _react.useState)();
  const [itemIdToExpandedRowMap, setItemIdToExpandedRowMap] = (0, _react.useState)({});
  const [modelToTest, setModelToTest] = (0, _react.useState)(null);
  const [dfaModelToTest, setDfaModelToTest] = (0, _react.useState)(null);
  const [isAddModelFlyoutVisible, setIsAddModelFlyoutVisible] = (0, _react.useState)(false);

  // List of downloaded/existing models
  const existingModels = (0, _react.useMemo)(() => {
    return items.filter(i => !(0, _trained_models.isModelDownloadItem)(i));
  }, [items]);

  /**
   * Fetches trained models.
   */
  const fetchModelsData = (0, _react.useCallback)(async () => {
    setIsLoading(true);
    try {
      const resultItems = await trainedModelsApiService.getTrainedModelsList();
      setItems(prevItems => {
        // Need to merge existing items with new items
        // to preserve state and download status
        return resultItems.map(item => {
          const prevItem = prevItems.find(i => i.model_id === item.model_id);
          return {
            ...item,
            ...((0, _trained_models.isBaseNLPModelItem)(prevItem) && (prevItem === null || prevItem === void 0 ? void 0 : prevItem.state) === _mlTrainedModelsUtils.MODEL_STATE.DOWNLOADING ? {
              state: prevItem.state,
              downloadState: prevItem.downloadState
            } : {})
          };
        });
      });
      setItemIdToExpandedRowMap(prev => {
        // Refresh expanded rows
        return Object.fromEntries(Object.keys(prev).map(modelId => {
          const item = resultItems.find(i => i.model_id === modelId);
          return item ? [modelId, /*#__PURE__*/_react.default.createElement(ExpandedRow, {
            item: item
          })] : [];
        }));
      });
    } catch (error) {
      displayErrorToast(error, _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.fetchFailedErrorMessage', {
        defaultMessage: 'Error loading trained models'
      }));
    }
    setIsInitialized(true);
    setIsLoading(false);
    await fetchDownloadStatus();

    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [itemIdToExpandedRowMap, isNLPEnabled]);
  (0, _react.useEffect)(function updateOnTimerRefresh() {
    if (!refresh) return;
    fetchModelsData();
  },
  // eslint-disable-next-line react-hooks/exhaustive-deps
  [refresh]);
  const modelsStats = (0, _react.useMemo)(() => {
    return {
      total: {
        show: true,
        value: existingModels.length,
        label: _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.totalAmountLabel', {
          defaultMessage: 'Total trained models'
        })
      }
    };
  }, [existingModels]);
  const downLoadStatusFetchInProgress = (0, _react.useRef)(false);
  const abortedDownload = (0, _react.useRef)(new Set());

  /**
   * Updates model list with download status
   */
  const fetchDownloadStatus = (0, _react.useCallback)(
  /**
   * @param downloadInProgress Set of model ids that reports download in progress
   */
  async (downloadInProgress = new Set()) => {
    // Allows only single fetch to be in progress
    if (downLoadStatusFetchInProgress.current && downloadInProgress.size === 0) return;
    try {
      downLoadStatusFetchInProgress.current = true;
      const downloadStatus = await trainedModelsApiService.getModelsDownloadStatus();
      if (isMounted()) {
        setItems(prevItems => {
          return prevItems.map(item => {
            if (!(0, _trained_models.isBaseNLPModelItem)(item)) {
              return item;
            }
            const newItem = (0, _lodash.cloneDeep)(item);
            if (downloadStatus[item.model_id]) {
              newItem.state = _mlTrainedModelsUtils.MODEL_STATE.DOWNLOADING;
              newItem.downloadState = downloadStatus[item.model_id];
            } else {
              /* Unfortunately, model download status does not report 100% download state, only from 1 to 99. Hence, there might be 3 cases
               * 1. Model is not downloaded at all
               * 2. Model download was in progress and finished
               * 3. Model download was in progress and aborted
               */
              delete newItem.downloadState;
              if (abortedDownload.current.has(item.model_id)) {
                // Change downloading state to not downloaded
                newItem.state = _mlTrainedModelsUtils.MODEL_STATE.NOT_DOWNLOADED;
                abortedDownload.current.delete(item.model_id);
              } else if (downloadInProgress.has(item.model_id) || !newItem.state) {
                // Change downloading state to downloaded
                newItem.state = _mlTrainedModelsUtils.MODEL_STATE.DOWNLOADED;
              }
              downloadInProgress.delete(item.model_id);
            }
            return newItem;
          });
        });
      }
      Object.keys(downloadStatus).forEach(modelId => {
        if (downloadStatus[modelId]) {
          downloadInProgress.add(modelId);
        }
      });
      if ((0, _lodash.isEmpty)(downloadStatus)) {
        downLoadStatusFetchInProgress.current = false;
        return;
      }
      await new Promise(resolve => setTimeout(resolve, DOWNLOAD_POLL_INTERVAL));
      await fetchDownloadStatus(downloadInProgress);
    } catch (e) {
      downLoadStatusFetchInProgress.current = false;
    }
  }, [trainedModelsApiService, isMounted]);

  /**
   * Unique inference types from models
   */
  const inferenceTypesOptions = (0, _react.useMemo)(() => {
    const result = existingModels.reduce((acc, item) => {
      const type = item.inference_config && Object.keys(item.inference_config)[0];
      if (type) {
        acc.add(type);
      }
      if (item.model_type) {
        acc.add(item.model_type);
      }
      return acc;
    }, new Set());
    return [...result].sort((a, b) => a.localeCompare(b)).map(v => ({
      value: v,
      name: v
    }));
  }, [existingModels]);
  const modelAndDeploymentIds = (0, _react.useMemo)(() => {
    const nlpModels = existingModels.filter(_trained_models.isNLPModelItem);
    return [...new Set([...nlpModels.flatMap(v => v.deployment_ids), ...nlpModels.map(i => i.model_id)])];
  }, [existingModels]);
  const onModelDownloadRequest = (0, _react.useCallback)(async modelId => {
    try {
      setIsLoading(true);
      await trainedModelsApiService.installElasticTrainedModelConfig(modelId);
      // Need to fetch model state updates
      await fetchModelsData();
    } catch (e) {
      displayErrorToast(e, _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.downloadFailed', {
        defaultMessage: 'Failed to download "{modelId}"',
        values: {
          modelId
        }
      }));
      setIsLoading(true);
    }
  }, [displayErrorToast, fetchModelsData, trainedModelsApiService]);

  /**
   * Table actions
   */
  const actions = (0, _model_actions.useModelActions)({
    isLoading,
    fetchModels: fetchModelsData,
    onTestAction: setModelToTest,
    onDfaTestAction: setDfaModelToTest,
    onModelsDeleteRequest: setModelsToDelete,
    onModelDeployRequest: setModelToDeploy,
    onLoading: setIsLoading,
    modelAndDeploymentIds,
    onModelDownloadRequest
  });
  const toggleDetails = async item => {
    const itemIdToExpandedRowMapValues = {
      ...itemIdToExpandedRowMap
    };
    if (itemIdToExpandedRowMapValues[item.model_id]) {
      delete itemIdToExpandedRowMapValues[item.model_id];
    } else {
      itemIdToExpandedRowMapValues[item.model_id] = /*#__PURE__*/_react.default.createElement(ExpandedRow, {
        item: item
      });
    }
    setItemIdToExpandedRowMap(itemIdToExpandedRowMapValues);
  };
  const columns = [{
    isExpander: true,
    align: 'center',
    render: item => {
      if ((0, _trained_models.isModelDownloadItem)(item) || !item.stats) {
        return null;
      }
      return /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
        onClick: toggleDetails.bind(null, item),
        "aria-label": itemIdToExpandedRowMap[item.model_id] ? _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.collapseRow', {
          defaultMessage: 'Collapse'
        }) : _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.expandRow', {
          defaultMessage: 'Expand'
        }),
        iconType: itemIdToExpandedRowMap[item.model_id] ? 'arrowDown' : 'arrowRight'
      });
    },
    'data-test-subj': 'mlModelsTableRowDetailsToggle'
  }, {
    name: modelIdColumnName,
    sortable: ({
      model_id: modelId
    }) => modelId,
    truncateText: false,
    textOnly: false,
    'data-test-subj': 'mlModelsTableColumnId',
    render: item => {
      const {
        description,
        model_id: modelId,
        type
      } = item;
      const isTechPreview = (description === null || description === void 0 ? void 0 : description.includes('(Tech Preview)')) || (0, _trained_models.isNLPModelItem)(item) && item.techPreview;
      let descriptionText = description === null || description === void 0 ? void 0 : description.replace('(Tech Preview)', '');
      let tooltipContent = null;
      if ((0, _trained_models.isBaseNLPModelItem)(item)) {
        const {
          disclaimer,
          recommended,
          supported
        } = item;
        if (disclaimer) {
          descriptionText += '. ' + disclaimer;
        }
        tooltipContent = supported === false ? /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "xpack.ml.trainedModels.modelsList.notSupportedDownloadContent",
          defaultMessage: "Model version is not supported by your cluster's hardware configuration"
        }) : recommended === false ? /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "xpack.ml.trainedModels.modelsList.notRecommendedDownloadContent",
          defaultMessage: "Model version is not optimized for your cluster's hardware configuration"
        }) : null;
      }
      return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        gutterSize: 'xs',
        direction: 'column'
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        gutterSize: 's',
        alignItems: 'center',
        wrap: true
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        grow: false
      }, /*#__PURE__*/_react.default.createElement("strong", {
        "data-test-subj": "mlModelsTableColumnIdValueId"
      }, modelId)), isTechPreview ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        grow: false
      }, /*#__PURE__*/_react.default.createElement(_technical_preview_badge.TechnicalPreviewBadge, {
        compressed: true
      })) : null), descriptionText ? /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        color: 'subdued',
        size: 'xs',
        "data-test-subj": "mlModelsTableColumnIdValueDescription"
      }, descriptionText, tooltipContent ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, "\xA0", /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
        content: tooltipContent
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
        type: 'warning',
        color: "warning"
      }))) : null) : null, Array.isArray(type) && type.length > 0 ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        gutterSize: 'xs',
        direction: 'row'
      }, type.map(t => /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        key: t,
        grow: false
      }, /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_eui.EuiBadge, {
        color: "hollow",
        "data-test-subj": "mlModelType"
      }, t))))) : null);
    }
  }, {
    name: _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.stateHeader', {
      defaultMessage: 'State'
    }),
    truncateText: false,
    width: '150px',
    render: item => {
      var _downloadState$downlo, _downloadState$total_, _config$component;
      if (!(0, _trained_models.isBaseNLPModelItem)(item)) return null;
      const {
        state,
        downloadState
      } = item;
      const config = (0, _get_model_state.getModelStateColor)(state);
      if (!config) return null;
      const isProgressbarVisible = state === _mlTrainedModelsUtils.MODEL_STATE.DOWNLOADING && downloadState;
      const label = /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        size: "xs",
        color: config.color
      }, config.name);
      return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        direction: 'column',
        gutterSize: 'none',
        css: {
          width: '100%'
        }
      }, isProgressbarVisible ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiProgress, {
        label: config.name,
        valueText: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, downloadState ? (downloadState.downloaded_parts / (downloadState.total_parts || -1) * 100).toFixed(0) + '%' : '100%'),
        value: (_downloadState$downlo = downloadState === null || downloadState === void 0 ? void 0 : downloadState.downloaded_parts) !== null && _downloadState$downlo !== void 0 ? _downloadState$downlo : 1,
        max: (_downloadState$total_ = downloadState === null || downloadState === void 0 ? void 0 : downloadState.total_parts) !== null && _downloadState$total_ !== void 0 ? _downloadState$total_ : 1,
        size: "xs",
        color: config.color
      })) : /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        grow: false
      }, /*#__PURE__*/_react.default.createElement("span", null, (_config$component = config.component) !== null && _config$component !== void 0 ? _config$component : label)));
    },
    'data-test-subj': 'mlModelsTableColumnDeploymentState'
  }, {
    name: _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.actionsHeader', {
      defaultMessage: 'Actions'
    }),
    width: '200px',
    actions,
    'data-test-subj': 'mlModelsTableColumnActions'
  }];
  const filters = inferenceTypesOptions && inferenceTypesOptions.length > 0 ? [{
    type: 'field_value_selection',
    field: 'type',
    name: _i18n.i18n.translate('xpack.ml.dataframe.analyticsList.typeFilter', {
      defaultMessage: 'Type'
    }),
    multiSelect: 'or',
    options: inferenceTypesOptions
  }] : [];
  const toolsLeft = /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "spaceBetween",
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("h5", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.ml.trainedModels.modelsList.selectedModelsMessage",
    defaultMessage: "{modelsCount, plural, one{# model} other {# models}} selected",
    values: {
      modelsCount: selectedModels.length
    }
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    color: "danger",
    onClick: setModelsToDelete.bind(null, selectedModels),
    "data-test-subj": "mlTrainedModelsDeleteSelectedModelsButton"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.ml.trainedModels.modelsList.deleteModelsButtonLabel",
    defaultMessage: "Delete"
  })))));
  const isSelectionAllowed = canDeleteTrainedModels;
  const selection = isSelectionAllowed ? {
    selectableMessage: (selectable, item) => {
      if (selectable) {
        return _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.selectableMessage', {
          defaultMessage: 'Select a model'
        });
      }
      // TODO support multiple model downloads with selection
      if (!(0, _trained_models.isModelDownloadItem)(item) && (0, _mlIsPopulatedObject.isPopulatedObject)(item.pipelines)) {
        return _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.disableSelectableMessage', {
          defaultMessage: 'Model has associated pipelines'
        });
      }
      if ((0, _trained_models.isBuiltInModel)(item)) {
        return _i18n.i18n.translate('xpack.ml.trainedModels.modelsList.builtInModelMessage', {
          defaultMessage: 'Built-in model'
        });
      }
      return '';
    },
    selectable: item => !(0, _trained_models.isModelDownloadItem)(item) && !(0, _mlIsPopulatedObject.isPopulatedObject)(item.pipelines) && !(0, _trained_models.isBuiltInModel)(item),
    onSelectionChange: selectedItems => {
      setSelectedModels(selectedItems);
    }
  } : undefined;
  const {
    onTableChange,
    pagination,
    sorting
  } = (0, _use_table_settings.useTableSettings)(items.length, pageState, updatePageState, true);
  const search = {
    query: searchQueryText,
    onChange: searchChange => {
      if (searchChange.error !== null) {
        return false;
      }
      updatePageState({
        queryText: searchChange.queryText,
        pageIndex: 0
      });
      return true;
    },
    box: {
      incremental: true
    },
    ...(inferenceTypesOptions && inferenceTypesOptions.length > 0 ? {
      filters
    } : {}),
    ...(selectedModels.length > 0 ? {
      toolsLeft
    } : {})
  };
  const isElserCalloutVisible = !isElserCalloutDismissed && items.findIndex(i => i.model_id === _mlTrainedModelsUtils.ELSER_ID_V1) >= 0;
  const tableItems = (0, _react.useMemo)(() => {
    if (pageState.showAll) {
      return items;
    } else {
      // by default show only deployed models or recommended for download
      return items.filter(item => !(0, _trained_models.isModelDownloadItem)(item) || item.recommended);
    }
  }, [items, pageState.showAll]);
  if (!isInitialized) return null;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_saved_objects_warning.SavedObjectsWarning, {
    onCloseFlyout: fetchModelsData,
    forceRefresh: isLoading
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "spaceBetween"
  }, modelsStats ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_stats_bar.StatsBar, {
    stats: modelsStats,
    dataTestSub: 'mlInferenceModelsStatsBar'
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    label: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.ml.trainedModels.modelsList.showAllLabel",
      defaultMessage: "Show all"
    }),
    checked: !!pageState.showAll,
    onChange: e => updatePageState({
      showAll: e.target.checked
    }),
    "data-test-subj": "mlModelsShowAllSwitch"
  })))) : null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    fill: true,
    iconType: 'plusInCircle',
    color: 'primary',
    onClick: setIsAddModelFlyoutVisible.bind(null, true),
    "data-test-subj": "mlModelsAddTrainedModelButton"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.ml.trainedModels.modelsList.addModelButtonLabel",
    defaultMessage: "Add trained model"
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement("div", {
    "data-test-subj": "mlModelsTableContainer"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiInMemoryTable, {
    tableLayout: 'auto',
    responsiveBreakpoint: 'xl',
    allowNeutralSort: false,
    columns: columns,
    itemIdToExpandedRowMap: itemIdToExpandedRowMap,
    items: tableItems,
    itemId: _config_mapping.ModelsTableToConfigMapping.id,
    loading: isLoading,
    search: search,
    selection: selection,
    rowProps: item => ({
      'data-test-subj': `mlModelsTableRow row-${item.model_id}`
    }),
    pagination: pagination,
    onTableChange: onTableChange,
    sorting: sorting,
    "data-test-subj": isLoading ? 'mlModelsTable loading' : 'mlModelsTable loaded',
    childrenBetween: isElserCalloutVisible ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      size: "s",
      title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.ml.trainedModels.modelsList.newElserModelTitle",
        defaultMessage: "New ELSER model now available"
      }),
      onDismiss: setIsElserCalloutDismissed.bind(null, true)
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.ml.trainedModels.modelsList.newElserModelDescription",
      defaultMessage: "A new version of ELSER that shows faster performance and improved relevance is now available. {docLink} for information on how to start using it.",
      values: {
        docLink: /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
          href: nlpElserDocUrl,
          external: true,
          target: '_blank'
        }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "xpack.ml.trainedModels.modelsList.startDeployment.viewElserDocLink",
          defaultMessage: "View documentation"
        }))
      }
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    })) : null
  })), modelsToDelete.length > 0 && /*#__PURE__*/_react.default.createElement(_delete_models_modal.DeleteModelsModal, {
    onClose: refreshList => {
      modelsToDelete.forEach(model => {
        if ((0, _trained_models.isBaseNLPModelItem)(model) && model.state === _mlTrainedModelsUtils.MODEL_STATE.DOWNLOADING) {
          abortedDownload.current.add(model.model_id);
        }
      });
      setItemIdToExpandedRowMap(prev => {
        const newMap = {
          ...prev
        };
        modelsToDelete.forEach(model => {
          delete newMap[model.model_id];
        });
        return newMap;
      });
      setModelsToDelete([]);
      if (refreshList) {
        fetchModelsData();
      }
    },
    models: modelsToDelete
  }), modelToTest === null ? null : /*#__PURE__*/_react.default.createElement(_test_models.TestModelAndPipelineCreationFlyout, {
    model: modelToTest,
    onClose: refreshList => {
      setModelToTest(null);
      if (refreshList) {
        fetchModelsData();
      }
    }
  }), dfaModelToTest === null ? null : /*#__PURE__*/_react.default.createElement(_test_dfa_models_flyout.TestDfaModelsFlyout, {
    model: dfaModelToTest,
    onClose: setDfaModelToTest.bind(null, null)
  }), modelToDeploy !== undefined ? /*#__PURE__*/_react.default.createElement(_ml_inference.AddInferencePipelineFlyout, {
    onClose: setModelToDeploy.bind(null, undefined),
    model: modelToDeploy
  }) : null, isAddModelFlyoutVisible ? /*#__PURE__*/_react.default.createElement(AddModelFlyout, {
    modelDownloads: items.filter(_trained_models.isModelDownloadItem),
    onClose: setIsAddModelFlyoutVisible.bind(null, false),
    onSubmit: modelId => {
      onModelDownloadRequest(modelId);
      setIsAddModelFlyoutVisible(false);
    }
  }) : null);
};
exports.ModelsList = ModelsList;