"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertMessagesForInference = convertMessagesForInference;
var _common = require("@kbn/observability-ai-assistant-plugin/common");
var _inferenceCommon = require("@kbn/inference-common");
var _common2 = require("@kbn/inference-plugin/common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function convertMessagesForInference(messages) {
  const inferenceMessages = [];
  messages.forEach(message => {
    if (message.message.role === _common.MessageRole.Assistant) {
      var _message$message$cont, _message$message$func;
      inferenceMessages.push({
        role: _inferenceCommon.MessageRole.Assistant,
        content: (_message$message$cont = message.message.content) !== null && _message$message$cont !== void 0 ? _message$message$cont : null,
        ...((_message$message$func = message.message.function_call) !== null && _message$message$func !== void 0 && _message$message$func.name ? {
          toolCalls: [{
            function: {
              name: message.message.function_call.name,
              arguments: JSON.parse(message.message.function_call.arguments || '{}')
            },
            toolCallId: (0, _common2.generateFakeToolCallId)()
          }]
        } : {})
      });
      return;
    }
    const isUserMessage = message.message.role === _common.MessageRole.User;
    const isUserMessageWithToolCall = isUserMessage && !!message.message.name;
    if (isUserMessageWithToolCall) {
      var _message$message$cont2;
      const toolCallRequest = inferenceMessages.findLast(msg => {
        var _msg$toolCalls, _msg$toolCalls$;
        return msg.role === _inferenceCommon.MessageRole.Assistant && ((_msg$toolCalls = msg.toolCalls) === null || _msg$toolCalls === void 0 ? void 0 : (_msg$toolCalls$ = _msg$toolCalls[0]) === null || _msg$toolCalls$ === void 0 ? void 0 : _msg$toolCalls$.function.name) === message.message.name;
      });
      if (!toolCallRequest) {
        throw new Error(`Could not find tool call request for ${message.message.name}`);
      }
      inferenceMessages.push({
        role: _inferenceCommon.MessageRole.Tool,
        response: JSON.parse((_message$message$cont2 = message.message.content) !== null && _message$message$cont2 !== void 0 ? _message$message$cont2 : '{}'),
        toolCallId: toolCallRequest.toolCalls[0].toolCallId
      });
      return;
    }
    if (isUserMessage) {
      var _message$message$cont3;
      inferenceMessages.push({
        role: _inferenceCommon.MessageRole.User,
        content: (_message$message$cont3 = message.message.content) !== null && _message$message$cont3 !== void 0 ? _message$message$cont3 : ''
      });
      return;
    }
    throw new Error(`Unsupported message type: ${message.message.role}`);
  });
  return inferenceMessages;
}