"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ProductDocEntry = ProductDocEntry;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _use_kibana = require("../../../hooks/use_kibana");
var _use_get_product_doc_status = require("../../../hooks/use_get_product_doc_status");
var _use_install_product_doc = require("../../../hooks/use_install_product_doc");
var _use_uninstall_product_doc = require("../../../hooks/use_uninstall_product_doc");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function ProductDocEntry() {
  const {
    overlays
  } = (0, _use_kibana.useKibana)().services;
  const [isInstalled, setInstalled] = (0, _react.useState)(true);
  const [isInstalling, setInstalling] = (0, _react.useState)(false);
  const {
    mutateAsync: installProductDoc
  } = (0, _use_install_product_doc.useInstallProductDoc)();
  const {
    mutateAsync: uninstallProductDoc
  } = (0, _use_uninstall_product_doc.useUninstallProductDoc)();
  const {
    status,
    isLoading: isStatusLoading
  } = (0, _use_get_product_doc_status.useGetProductDocStatus)();
  (0, _react.useEffect)(() => {
    if (status) {
      setInstalled(status.overall === 'installed');
    }
  }, [status]);
  const onClickInstall = (0, _react.useCallback)(() => {
    setInstalling(true);
    installProductDoc().then(() => {
      setInstalling(false);
      setInstalled(true);
    }, () => {
      setInstalling(false);
      setInstalled(false);
    });
  }, [installProductDoc]);
  const onClickUninstall = (0, _react.useCallback)(() => {
    overlays.openConfirm(_i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.productDocUninstallConfirmText', {
      defaultMessage: `Are you sure you want to uninstall the Elastic documentation?`
    }), {
      title: _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.productDocUninstallConfirmTitle', {
        defaultMessage: `Uninstalling Elastic documentation`
      })
    }).then(confirmed => {
      if (confirmed) {
        uninstallProductDoc().then(() => {
          setInstalling(false);
          setInstalled(false);
        });
      }
    });
  }, [overlays, uninstallProductDoc]);
  const content = (0, _react.useMemo)(() => {
    if (isStatusLoading) {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null);
    }
    if (isInstalling) {
      return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        justifyContent: "flexStart",
        alignItems: "center"
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingSpinner, {
        size: "m"
      }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        size: "s"
      }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.observabilityAiAssistantManagement.settingsPage.installingText",
        defaultMessage: "Installing..."
      })));
    }
    if (isInstalled) {
      return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        justifyContent: "flexStart",
        alignItems: "center"
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        grow: false
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiHealth, {
        textSize: "s",
        color: "success"
      }, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.installProductDocInstalledLabel', {
        defaultMessage: 'Installed'
      }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        grow: false
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
        "data-test-subj": "settingsTabUninstallProductDocButton",
        onClick: onClickUninstall,
        color: "warning"
      }, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.uninstallProductDocButtonLabel', {
        defaultMessage: 'Uninstall'
      }))));
    }
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      justifyContent: "flexStart",
      alignItems: "center"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      "data-test-subj": "settingsTabInstallProductDocButton",
      onClick: onClickInstall
    }, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.installProductDocButtonLabel', {
      defaultMessage: 'Install'
    }))));
  }, [isInstalled, isInstalling, isStatusLoading, onClickInstall, onClickUninstall]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiDescribedFormGroup, {
    fullWidth: true,
    title: /*#__PURE__*/_react.default.createElement("h3", null, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.productDocLabel', {
      defaultMessage: 'Elastic documentation'
    })),
    description: /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement("em", null, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.techPreview', {
      defaultMessage: '[technical preview] '
    })), _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.settingsPage.productDocDescription', {
      defaultMessage: "Install Elastic documentation to improve the assistant's efficiency."
    }))
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    fullWidth: true
  }, content));
}