"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CodeBlock = CodeBlock;
exports.EsqlCodeBlock = EsqlCodeBlock;
var _eui = require("@elastic/eui");
var _css = require("@emotion/css");
var _i18n = require("@kbn/i18n");
var _react = _interopRequireDefault(require("react"));
var _types = require("../chat/types");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getCodeBlockClassName = theme => (0, _css.css)`
  background-color: ${theme.euiTheme.colors.lightestShade};
  .euiCodeBlock__pre {
    margin-bottom: 0;
    padding: ${theme.euiTheme.size.m};
    min-block-size: 48px;
  }
  .euiCodeBlock__controls {
    inset-block-start: ${theme.euiTheme.size.m};
    inset-inline-end: ${theme.euiTheme.size.m};
  }
`;
function CodeBlockWrapper({
  children
}) {
  const theme = (0, _eui.useEuiTheme)();
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasShadow: false,
    hasBorder: false,
    paddingSize: "s",
    className: getCodeBlockClassName(theme)
  }, children);
}
function CodeBlock({
  children
}) {
  return /*#__PURE__*/_react.default.createElement(CodeBlockWrapper, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "xs"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiCodeBlock, {
    isCopyable: true,
    fontSize: "m"
  }, children))));
}
function EsqlCodeBlock({
  value,
  actionsDisabled,
  onActionClick
}) {
  return /*#__PURE__*/_react.default.createElement(CodeBlockWrapper, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "xs"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiCodeBlock, {
    isCopyable: true,
    fontSize: "m"
  }, value)), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "row",
    gutterSize: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    "data-test-subj": "observabilityAiAssistantEsqlCodeBlockRunThisQueryButton",
    size: "xs",
    iconType: "play",
    onClick: () => onActionClick({
      type: _types.ChatActionClickType.executeEsqlQuery,
      query: value
    }),
    disabled: actionsDisabled
  }, _i18n.i18n.translate('xpack.observabilityAiAssistant.runThisQuery', {
    defaultMessage: 'Display results'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    "data-test-subj": "observabilityAiAssistantEsqlCodeBlockVisualizeThisQueryButton",
    size: "xs",
    iconType: "lensApp",
    onClick: () => onActionClick({
      type: _types.ChatActionClickType.visualizeEsqlQuery,
      query: value
    }),
    disabled: actionsDisabled
  }, _i18n.i18n.translate('xpack.observabilityAiAssistant.visualizeThisQuery', {
    defaultMessage: 'Visualize this query'
  })))))));
}