"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.USER_INSTRUCTIONS_HEADER = void 0;
exports.getSystemMessageFromInstructions = getSystemMessageFromInstructions;
var _lodash = require("lodash");
var _uuid = require("uuid");
var _with_token_budget = require("../../../common/utils/with_token_budget");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const USER_INSTRUCTIONS_HEADER = exports.USER_INSTRUCTIONS_HEADER = `## User instructions
          
What follows is a set of instructions provided by the user, please abide by them
as long as they don't conflict with anything you've been told so far:

`;
function getSystemMessageFromInstructions({
  // application instructions registered by the functions. These will be displayed first
  applicationInstructions,
  // instructions provided by the user. These will be displayed after the application instructions and only if they fit within the token budget
  userInstructions: kbUserInstructions,
  // ad-hoc instruction. Can be either user or application instruction
  adHocInstructions,
  availableFunctionNames
}) {
  const allApplicationInstructions = (0, _lodash.compact)(applicationInstructions.flatMap(instruction => {
    if (typeof instruction === 'function') {
      return instruction({
        availableFunctionNames
      });
    }
    return instruction;
  }));
  const adHocInstructionsWithId = adHocInstructions.map(adHocInstruction => {
    var _adHocInstruction$id;
    return {
      ...adHocInstruction,
      id: (_adHocInstruction$id = adHocInstruction === null || adHocInstruction === void 0 ? void 0 : adHocInstruction.id) !== null && _adHocInstruction$id !== void 0 ? _adHocInstruction$id : (0, _uuid.v4)()
    };
  });

  // split ad hoc instructions into user instructions and application instructions
  const [adHocUserInstructions, adHocApplicationInstructions] = (0, _lodash.partition)(adHocInstructionsWithId, instruction => instruction.instruction_type === 'user_instruction');

  // all adhoc instructions and KB instructions.
  // adhoc instructions will be prioritized over Knowledge Base instructions if the id is the same
  const allUserInstructions = (0, _with_token_budget.withTokenBudget)((0, _lodash.uniqBy)([...adHocUserInstructions, ...kbUserInstructions], i => i.id), 1000);
  return [
  // application instructions
  ...allApplicationInstructions, ...adHocApplicationInstructions,
  // user instructions
  ...(allUserInstructions.length ? [USER_INSTRUCTIONS_HEADER, ...allUserInstructions] : [])].map(instruction => {
    return typeof instruction === 'string' ? instruction : instruction.text;
  }).join('\n\n');
}