"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OnboardingLink = exports.ConnectedOnboardingLink = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _eui = require("@elastic/eui");
var _locators = require("@kbn/deeplinks-observability/locators");
var _routerUtils = require("@kbn/router-utils");
var _react = _interopRequireDefault(require("react"));
var _translations = require("../../common/translations");
var _use_kibana = require("../utils/use_kibana");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ConnectedOnboardingLink = exports.ConnectedOnboardingLink = /*#__PURE__*/_react.default.memo(() => {
  const {
    services: {
      share: {
        url
      }
    }
  } = (0, _use_kibana.useKibanaContextForPlugin)();
  return /*#__PURE__*/_react.default.createElement(OnboardingLink, {
    urlService: url
  });
});
const OnboardingLink = exports.OnboardingLink = /*#__PURE__*/_react.default.memo(({
  urlService
}) => {
  const locator = urlService.locators.get(_locators.OBSERVABILITY_ONBOARDING_LOCATOR);
  const onboardingUrl = locator === null || locator === void 0 ? void 0 : locator.useUrl({
    category: 'logs'
  });
  const navigateToOnboarding = () => locator === null || locator === void 0 ? void 0 : locator.navigate({
    category: 'logs'
  });
  const onboardingLinkProps = (0, _routerUtils.getRouterLinkProps)({
    href: onboardingUrl,
    onClick: navigateToOnboarding
  });
  return /*#__PURE__*/_react.default.createElement(_eui.EuiButton, (0, _extends2.default)({}, onboardingLinkProps, {
    fill: true,
    size: "s",
    iconType: "indexOpen",
    "data-test-subj": "logsExplorerOnboardingLink"
  }), _translations.onboardingLinkTitle);
});