"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OnboardingFlowForm = void 0;
var _i18n = require("@kbn/i18n");
var _react = _interopRequireWildcard(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _eui = require("@elastic/eui");
var _react2 = require("@emotion/react");
var _reactRouterDomV5Compat = require("react-router-dom-v5-compat");
var _public = require("@kbn/kibana-react-plugin/public");
var _packages_list = require("../packages_list");
var _use_custom_cards_for_category = require("./use_custom_cards_for_category");
var _use_virtual_search_results = require("./use_virtual_search_results");
var _logo_icon = require("../shared/logo_icon");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const OnboardingFlowForm = () => {
  var _searchParams$get;
  const options = [{
    id: 'host',
    label: _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.euiCheckableCard.hostLabel', {
      defaultMessage: 'Host'
    }),
    description: _i18n.i18n.translate('xpack.observability_onboarding.onboardingFlowForm.hostDescription', {
      defaultMessage: 'Monitor your host and the services running on it, set-up SLO, get alerted, remediate performance issues'
    }),
    logos: ['opentelemetry', 'apache', 'mysql']
  }, {
    id: 'kubernetes',
    label: _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.euiCheckableCard.kubernetesLabel', {
      defaultMessage: 'Kubernetes'
    }),
    description: _i18n.i18n.translate('xpack.observability_onboarding.onboardingFlowForm.kubernetesDescription', {
      defaultMessage: 'Observe your Kubernetes cluster, and your container workloads using logs, metrics, traces and profiling data'
    }),
    logos: ['kubernetes', 'opentelemetry']
  }, {
    id: 'application',
    label: _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.euiCheckableCard.applicationLabel', {
      defaultMessage: 'Application'
    }),
    description: _i18n.i18n.translate('xpack.observability_onboarding.onboardingFlowForm.applicationDescription', {
      defaultMessage: 'Monitor the frontend and backend application that you have developed, set-up synthetic monitors'
    }),
    logos: ['opentelemetry', 'java', 'ruby', 'dotnet']
  }, {
    id: 'cloud',
    label: _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.euiCheckableCard.cloudLabel', {
      defaultMessage: 'Cloud'
    }),
    description: _i18n.i18n.translate('xpack.observability_onboarding.onboardingFlowForm.cloudDescription', {
      defaultMessage: 'Ingest telemetry data from the Cloud for your applications and services'
    }),
    logos: ['azure', 'aws', 'gcp']
  }];
  const {
    services: {
      context: {
        isCloud
      }
    }
  } = (0, _public.useKibana)();
  const radioGroupId = (0, _eui.useGeneratedHtmlId)({
    prefix: 'onboardingCategory'
  });
  const categorySelectorTitleId = (0, _eui.useGeneratedHtmlId)();
  const packageListTitleId = (0, _eui.useGeneratedHtmlId)();
  const [searchParams, setSearchParams] = (0, _reactRouterDomV5Compat.useSearchParams)();
  const suggestedPackagesRef = (0, _react.useRef)(null);
  const searchResultsRef = (0, _react.useRef)(null);
  const [integrationSearch, setIntegrationSearch] = (0, _react.useState)((_searchParams$get = searchParams.get('search')) !== null && _searchParams$get !== void 0 ? _searchParams$get : '');
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  (0, _react.useEffect)(() => {
    var _searchParams$get2;
    const searchParam = (_searchParams$get2 = searchParams.get('search')) !== null && _searchParams$get2 !== void 0 ? _searchParams$get2 : '';
    if (integrationSearch === searchParam) return;
    const entries = Object.fromEntries(searchParams.entries());
    if (integrationSearch) {
      entries.search = integrationSearch;
    } else {
      delete entries.search;
    }
    setSearchParams(entries, {
      replace: true
    });
  }, [integrationSearch, searchParams, setSearchParams]);
  const createCollectionCardHandler = (0, _react.useCallback)(query => () => {
    setIntegrationSearch(query);
    if (searchResultsRef.current) {
      setTimeout(scrollIntoViewWithOffset, 40,
      // Adding slight delay to ensure DOM is updated before calculating scroll position
      searchResultsRef.current, parseInt(euiTheme.size.l, 10));
    }
  }, [] // eslint-disable-line react-hooks/exhaustive-deps
  );
  const customCards = (0, _use_custom_cards_for_category.useCustomCardsForCategory)(createCollectionCardHandler, searchParams.get('category'));
  const virtualSearchResults = (0, _use_virtual_search_results.useVirtualSearchResults)();
  /**
   * Cloud deployments have the new Firehose quick start
   * flow enabled, so the ond card 'epr:awsfirehose' should
   * not show up in the search results.
   */
  const searchExcludePackageIdList = isCloud ? ['epr:awsfirehose'] : [];
  let isSelectingCategoryWithKeyboard = false;
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasBorder: true,
    paddingSize: "xl"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s",
    id: categorySelectorTitleId
  }, /*#__PURE__*/_react.default.createElement("strong", null, _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.strong.startCollectingYourDataLabel', {
    defaultMessage: 'What do you want to monitor?'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGrid, {
    columns: 2,
    role: "group",
    "aria-labelledby": categorySelectorTitleId
  }, options.map(option => {
    var _option$logos;
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      key: option.id,
      "data-test-subj": `observabilityOnboardingUseCaseCard-${option.id}` // EuiCheckableCard does not forward `data-test-subj` prop so using parent element instead
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiCheckableCard, {
      id: `${radioGroupId}_${option.id}`,
      name: radioGroupId,
      label: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("strong", null, option.label)), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
        size: "s"
      }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        color: "subdued",
        size: "s",
        css: (0, _react2.css)`
                      flex-grow: 1; // Allow the description to grow to fill the space
                    `
      }, option.description), (option.logos || option.showIntegrationsBadge) && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
        size: "m"
      }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
        gutterSize: "m",
        responsive: false,
        css: (0, _react2.css)`
                          flex-grow: 0; // Prevent the logos from growing to align to the bottom
                        `,
        "aria-hidden": true // Hide from screen readers as the logos are mainly decorative
      }, (_option$logos = option.logos) === null || _option$logos === void 0 ? void 0 : _option$logos.map(logo => /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        key: logo,
        grow: false
      }, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
        logo: logo,
        size: "l"
      }))), option.showIntegrationsBadge && /*#__PURE__*/_react.default.createElement(_eui.EuiBadge, {
        color: "hollow"
      }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        defaultMessage: "+ Integrations",
        id: "xpack.observability_onboarding.experimentalOnboardingFlow.form.addIntegrations",
        description: "A badge indicating that the user can add additional observability integrations to their deployment via this option"
      }))))),
      checked: option.id === searchParams.get('category')
      /**
       * onKeyDown and onKeyUp handlers disable
       * scrolling to the category items when user
       * changes the selected category using keyboard,
       * which prevents our custom scroll behavior
       * from conflicting with browser's native one to
       * put keyboard-focused item into the view.
       */,
      onKeyDown: () => isSelectingCategoryWithKeyboard = true,
      onKeyUp: () => isSelectingCategoryWithKeyboard = false,
      onChange: () => {
        setIntegrationSearch('');
        setSearchParams({
          category: option.id
        }, {
          replace: true
        });
      },
      onClick: () => {
        if (!isSelectingCategoryWithKeyboard && suggestedPackagesRef.current) {
          setTimeout(scrollIntoViewWithOffset, 40,
          // Adding slight delay to ensure DOM is updated before calculating scroll position
          suggestedPackagesRef.current, parseInt(euiTheme.size.l, 10));
        }
      },
      css: (0, _react2.css)`
                flex-grow: 1;

                & > .euiPanel {
                  display: flex;

                  & > .euiCheckableCard__label {
                    display: flex;
                    flex-direction: column;
                  }
                }
              `
    }));
  })), /*#__PURE__*/_react.default.createElement("div", {
    hidden: !searchParams.get('category') || !customCards,
    role: "group",
    "aria-labelledby": packageListTitleId
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xxl"
  }), /*#__PURE__*/_react.default.createElement("div", {
    ref: suggestedPackagesRef
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s",
    id: packageListTitleId
  }, /*#__PURE__*/_react.default.createElement("strong", null, searchParams.get('category') === 'kubernetes' ? _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.kubernetesPackagesTitle', {
    defaultMessage: 'Monitor your Kubernetes cluster using:'
  }) : searchParams.get('category') === 'application' ? _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.applicationPackagesTitle', {
    defaultMessage: 'Monitor your Application using:'
  }) : searchParams.get('category') === 'cloud' ? _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.cloudPackagesTitle', {
    defaultMessage: 'Select your Cloud provider:'
  }) : _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.hostPackagesTitle', {
    defaultMessage: 'Monitor your Host using:'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_packages_list.OnboardingFlowPackageList, {
    customCards: customCards,
    flowSearch: integrationSearch,
    flowCategory: searchParams.get('category')
  }))), /*#__PURE__*/_react.default.createElement("div", {
    ref: searchResultsRef
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xxl"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s",
    color: "subdued"
  }, /*#__PURE__*/_react.default.createElement("strong", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.observability_onboarding.experimentalOnboardingFlow.form.searchPromptText",
    defaultMessage: "Search through other ways of ingesting data:"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_packages_list.OnboardingFlowPackageList, {
    showSearchBar: true,
    searchQuery: integrationSearch,
    flowSearch: integrationSearch,
    setSearchQuery: setIntegrationSearch,
    flowCategory: searchParams.get('category'),
    customCards: customCards === null || customCards === void 0 ? void 0 : customCards.filter(
    // Filter out collection cards and regular integrations that show up via search anyway
    card => card.type === 'virtual' && !card.isCollectionCard).concat(virtualSearchResults),
    excludePackageIdList: searchExcludePackageIdList,
    joinCardLists: true
  })));
};
exports.OnboardingFlowForm = OnboardingFlowForm;
function scrollIntoViewWithOffset(element, offset = 0) {
  // Fixed header in Kibana is different height between serverless and stateful so need to calculate dynamically.
  const fixedHeaders = document.querySelectorAll('#globalHeaderBars [data-fixed-header=true]');
  fixedHeaders.forEach(header => {
    offset += header.getBoundingClientRect().height;
  });
  window.scrollTo({
    behavior: 'smooth',
    top: element.getBoundingClientRect().top - document.body.getBoundingClientRect().top - offset
  });
}