"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCustomCardsForCategory = useCustomCardsForCategory;
var _i18n = require("@kbn/i18n");
var _react = _interopRequireDefault(require("react"));
var _eui = require("@elastic/eui");
var _public = require("@kbn/kibana-react-plugin/public");
var _reactRouterDom = require("react-router-dom");
var _reactRouterDomV5Compat = require("react-router-dom-v5-compat");
var _logo_icon = require("../shared/logo_icon");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useCustomCardsForCategory(createCollectionCardHandler, category) {
  var _http$staticAssets$ge, _http$staticAssets$ge2, _http$staticAssets$ge3, _getUrlForApp;
  const history = (0, _reactRouterDom.useHistory)();
  const location = (0, _reactRouterDomV5Compat.useLocation)();
  const {
    services: {
      application,
      http,
      context: {
        isServerless
      }
    }
  } = (0, _public.useKibana)();
  const getUrlForApp = application === null || application === void 0 ? void 0 : application.getUrlForApp;
  const {
    href: autoDetectUrl
  } = (0, _public.reactRouterNavigate)(history, `/auto-detect/${location.search}`);
  const {
    href: otelLogsUrl
  } = (0, _public.reactRouterNavigate)(history, `/otel-logs/${location.search}`);
  const {
    href: kubernetesUrl
  } = (0, _public.reactRouterNavigate)(history, `/kubernetes/${location.search}`);
  const {
    href: otelKubernetesUrl
  } = (0, _public.reactRouterNavigate)(history, `/otel-kubernetes/${location.search}`);
  const apmUrl = `${getUrlForApp === null || getUrlForApp === void 0 ? void 0 : getUrlForApp('apm')}/${isServerless ? 'onboarding' : 'tutorial'}`;
  const otelApmUrl = isServerless ? `${apmUrl}?agent=openTelemetry` : apmUrl;
  switch (category) {
    case 'host':
      return [{
        id: 'auto-detect-logs',
        name: 'auto-detect-logs-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.autoDetectTitle', {
          defaultMessage: 'Elastic Agent: Logs & Metrics'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.autoDetectDescription', {
          defaultMessage: 'Scan your host for log files, metrics, auto-install integrations'
        }),
        extraLabelsBadges: [/*#__PURE__*/_react.default.createElement(ExtraLabelBadgeWrapper, null, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
          logo: "apple",
          size: "m"
        })), /*#__PURE__*/_react.default.createElement(ExtraLabelBadgeWrapper, null, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
          logo: "linux",
          size: "m"
        }))],
        categories: ['observability'],
        icons: [{
          type: 'eui',
          src: 'agentApp'
        }],
        url: autoDetectUrl,
        version: '',
        integration: '',
        isQuickstart: true
      }, {
        id: 'otel-logs',
        name: 'custom-logs-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.logsOtelTitle', {
          defaultMessage: 'OpenTelemetry: Logs & Metrics'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.logsOtelDescription', {
          defaultMessage: 'Collect logs and host metrics with the Elastic Distro for OTel Collector'
        }),
        extraLabelsBadges: [/*#__PURE__*/_react.default.createElement(ExtraLabelBadgeWrapper, null, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
          logo: "apple",
          size: "m"
        })), /*#__PURE__*/_react.default.createElement(ExtraLabelBadgeWrapper, null, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
          logo: "linux",
          size: "m"
        }))],
        categories: ['observability'],
        icons: [{
          type: 'svg',
          src: (_http$staticAssets$ge = http === null || http === void 0 ? void 0 : http.staticAssets.getPluginAssetHref('opentelemetry.svg')) !== null && _http$staticAssets$ge !== void 0 ? _http$staticAssets$ge : ''
        }],
        url: otelLogsUrl,
        version: '',
        integration: '',
        isQuickstart: true,
        release: 'preview'
      }];
    case 'kubernetes':
      return [{
        id: 'kubernetes-quick-start',
        name: 'kubernetes-quick-start',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.kubernetesTitle', {
          defaultMessage: 'Elastic Agent: Logs & Metrics'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.kubernetesDescription', {
          defaultMessage: 'Collect logs and metrics from Kubernetes using Elastic Agent'
        }),
        extraLabelsBadges: [/*#__PURE__*/_react.default.createElement(ExtraLabelBadgeWrapper, null, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
          logo: "kubernetes",
          size: "m"
        }))],
        categories: ['observability'],
        icons: [{
          type: 'eui',
          src: 'agentApp'
        }],
        url: kubernetesUrl,
        version: '',
        integration: '',
        isQuickstart: true
      }, {
        id: 'otel-kubernetes',
        name: 'otel-kubernetes-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.kubernetesOtelTitle', {
          defaultMessage: 'OpenTelemetry: Full Observability'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.kubernetesOtelDescription', {
          defaultMessage: 'Collect logs, traces and metrics with the Elastic Distro for OTel Collector'
        }),
        extraLabelsBadges: [/*#__PURE__*/_react.default.createElement(ExtraLabelBadgeWrapper, null, /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
          logo: "kubernetes",
          size: "m"
        }))],
        categories: ['observability'],
        icons: [{
          type: 'svg',
          src: (_http$staticAssets$ge2 = http === null || http === void 0 ? void 0 : http.staticAssets.getPluginAssetHref('opentelemetry.svg')) !== null && _http$staticAssets$ge2 !== void 0 ? _http$staticAssets$ge2 : ''
        }],
        url: otelKubernetesUrl,
        version: '',
        integration: '',
        isQuickstart: true,
        release: 'preview'
      }];
    case 'application':
      return [{
        id: 'apm-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.apmTitle', {
          defaultMessage: 'Elastic APM'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.apmDescription', {
          defaultMessage: 'Collect distributed traces from your applications with Elastic APM'
        }),
        name: 'apm',
        categories: ['observability'],
        icons: [{
          type: 'eui',
          src: 'apmApp'
        }],
        url: apmUrl,
        version: '',
        integration: ''
      }, {
        id: 'otel-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.apmOtelTitle', {
          defaultMessage: 'OpenTelemetry'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.apmOtelDescription', {
          defaultMessage: 'Collect distributed traces with OpenTelemetry'
        }),
        name: 'otel',
        categories: ['observability'],
        icons: [{
          type: 'svg',
          src: (_http$staticAssets$ge3 = http === null || http === void 0 ? void 0 : http.staticAssets.getPluginAssetHref('opentelemetry.svg')) !== null && _http$staticAssets$ge3 !== void 0 ? _http$staticAssets$ge3 : ''
        }],
        url: otelApmUrl,
        version: '',
        integration: ''
      }, {
        id: 'synthetics-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.syntheticsTitle', {
          defaultMessage: 'Synthetic monitor'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.syntheticsDescription', {
          defaultMessage: 'Monitor endpoints, pages, and user journeys'
        }),
        name: 'synthetics',
        categories: ['observability'],
        icons: [{
          type: 'eui',
          src: 'logoUptime'
        }],
        url: (_getUrlForApp = getUrlForApp === null || getUrlForApp === void 0 ? void 0 : getUrlForApp('synthetics')) !== null && _getUrlForApp !== void 0 ? _getUrlForApp : '',
        version: '',
        integration: ''
      }];
    case 'cloud':
      return [{
        id: 'azure-logs-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.azureTitle', {
          defaultMessage: 'Azure'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.azureDescription', {
          defaultMessage: 'Collect logs from Microsoft Azure'
        }),
        name: 'azure',
        categories: ['observability'],
        icons: [],
        url: 'https://azure.com',
        version: '',
        integration: '',
        isCollectionCard: true,
        onCardClick: createCollectionCardHandler('azure')
      }, {
        id: 'aws-logs-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.awsTitle', {
          defaultMessage: 'AWS'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.awsDescription', {
          defaultMessage: 'Collect logs from Amazon Web Services (AWS)'
        }),
        name: 'aws',
        categories: ['observability'],
        icons: [],
        url: 'https://aws.com',
        version: '',
        integration: '',
        isCollectionCard: true,
        onCardClick: createCollectionCardHandler('aws')
      }, {
        id: 'gcp-logs-virtual',
        type: 'virtual',
        title: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.gcpTitle', {
          defaultMessage: 'Google Cloud Platform'
        }),
        description: _i18n.i18n.translate('xpack.observability_onboarding.useCustomCardsForCategory.gcpDescription', {
          defaultMessage: 'Collect logs from Google Cloud Platform'
        }),
        name: 'gcp',
        categories: ['observability'],
        icons: [],
        url: '',
        version: '',
        integration: '',
        isCollectionCard: true,
        onCardClick: createCollectionCardHandler('gcp')
      }];
    default:
      return undefined;
  }
}
function ExtraLabelBadgeWrapper({
  children
}) {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false,
    css: {
      alignSelf: 'center'
    }
  }, children);
}