"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useVirtualSearchResults = useVirtualSearchResults;
var _i18n = require("@kbn/i18n");
var _reactRouterDom = require("react-router-dom");
var _public = require("@kbn/kibana-react-plugin/public");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useVirtualSearchResults() {
  const {
    services: {
      application,
      context: {
        isCloud
      }
    }
  } = (0, _public.useKibana)();
  const history = (0, _reactRouterDom.useHistory)();
  const {
    href: customLogsUrl
  } = (0, _public.reactRouterNavigate)(history, `/customLogs/${location.search}`);
  const {
    href: firehoseUrl
  } = (0, _public.reactRouterNavigate)(history, `/firehose/${location.search}`);
  const getUrlForApp = application === null || application === void 0 ? void 0 : application.getUrlForApp;
  const firehoseQuickstartCard = {
    id: 'firehose-quick-start',
    name: 'firehose-quick-start',
    type: 'virtual',
    title: _i18n.i18n.translate('xpack.observability_onboarding.packageList.uploadFileTitle', {
      defaultMessage: 'AWS Firehose'
    }),
    release: 'preview',
    description: _i18n.i18n.translate('xpack.observability_onboarding.packageList.uploadFileDescription', {
      defaultMessage: 'Collect logs and metrics from Amazon Web Services (AWS).'
    }),
    categories: [],
    icons: [{
      type: 'svg',
      src: 'https://epr.elastic.co/package/awsfirehose/1.1.0/img/logo_firehose.svg'
    }],
    url: firehoseUrl,
    version: '',
    integration: '',
    isQuickstart: true
  };
  return [{
    id: 'upload-file-virtual',
    type: 'virtual',
    title: _i18n.i18n.translate('xpack.observability_onboarding.packageList.uploadFileTitle', {
      defaultMessage: 'Upload a file'
    }),
    description: _i18n.i18n.translate('xpack.observability_onboarding.packageList.uploadFileDescription', {
      defaultMessage: 'Upload data from a CSV, TSV, JSON or other log file to Elasticsearch for analysis.'
    }),
    name: 'upload-file',
    categories: [],
    icons: [{
      type: 'eui',
      src: 'addDataApp'
    }],
    url: `${getUrlForApp === null || getUrlForApp === void 0 ? void 0 : getUrlForApp('home')}#/tutorial_directory/fileDataViz`,
    version: '',
    integration: '',
    isCollectionCard: false
  }, {
    id: 'custom-logs',
    type: 'virtual',
    title: 'Stream log files',
    description: 'Stream any logs into Elastic in a simple way and explore their data',
    name: 'custom-logs-virtual',
    categories: ['observability'],
    icons: [{
      type: 'eui',
      src: 'filebeatApp'
    }],
    url: customLogsUrl,
    version: '',
    integration: ''
  },
  /**
   * The new Firehose card should only be visible on Cloud
   * as Firehose integration requires additional proxy,
   * which is not available for on-prem customers.
   */
  ...(isCloud ? [firehoseQuickstartCard] : [])];
}