"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AutoDetectPanel = void 0;
var _react = _interopRequireDefault(require("react"));
var _i18n = require("@kbn/i18n");
var _eui = require("@elastic/eui");
var _locators = require("@kbn/deeplinks-observability/locators");
var _public = require("@kbn/kibana-react-plugin/public");
var _deeplinksAnalytics = require("@kbn/deeplinks-analytics");
var _common = require("@kbn/observability-shared-plugin/common");
var _get_auto_detect_command = require("./get_auto_detect_command");
var _use_onboarding_flow = require("./use_onboarding_flow");
var _progress_indicator = require("../shared/progress_indicator");
var _accordion_with_icon = require("../shared/accordion_with_icon");
var _empty_prompt = require("../shared/empty_prompt");
var _copy_to_clipboard_button = require("../shared/copy_to_clipboard_button");
var _locator_button_empty = require("../shared/locator_button_empty");
var _get_started_panel = require("../shared/get_started_panel");
var _logo_icon = require("../../shared/logo_icon");
var _feedback_buttons = require("../shared/feedback_buttons");
var _use_auto_detect_telemetry = require("./use_auto_detect_telemetry");
var _supported_integrations_list = require("./supported_integrations_list");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const AutoDetectPanel = () => {
  const {
    status,
    data,
    error,
    refetch,
    installedIntegrations
  } = (0, _use_onboarding_flow.useOnboardingFlow)();
  const command = data ? (0, _get_auto_detect_command.getAutoDetectCommand)(data) : undefined;
  const accordionId = (0, _eui.useGeneratedHtmlId)({
    prefix: 'accordion'
  });
  const {
    services: {
      share
    }
  } = (0, _public.useKibana)();
  (0, _use_auto_detect_telemetry.useAutoDetectTelemetry)(status, installedIntegrations.map(({
    title,
    pkgName,
    pkgVersion,
    installSource
  }) => ({
    title,
    pkgName,
    pkgVersion,
    installSource
  })));
  if (error) {
    return /*#__PURE__*/_react.default.createElement(_empty_prompt.EmptyPrompt, {
      onboardingFlowType: "auto-detect",
      error: error,
      onRetryClick: refetch
    });
  }
  const registryIntegrations = installedIntegrations.filter(integration => integration.installSource === 'registry');
  const customIntegrations = installedIntegrations.filter(integration => integration.installSource === 'custom');
  const dashboardLocator = share.url.locators.get(_deeplinksAnalytics.DASHBOARD_APP_LOCATOR);
  const assetDetailsLocator = share.url.locators.get(_common.ASSET_DETAILS_LOCATOR_ID);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasBorder: true,
    paddingSize: "xl"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSteps, {
    steps: [{
      title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.runTheCommandOnLabel', {
        defaultMessage: 'Install standalone Elastic Agent on your host'
      }),
      status: status === 'notStarted' ? 'current' : 'complete',
      children: command ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("p", null, _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.p.wellScanYourHostLabel', {
        defaultMessage: "We'll scan your host for logs and metrics, including:"
      }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
        size: "s"
      }), /*#__PURE__*/_react.default.createElement(_supported_integrations_list.SupportedIntegrationsList, null), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_eui.EuiCodeBlock, {
        paddingSize: "m",
        language: "text"
      }, command), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_copy_to_clipboard_button.CopyToClipboardButton, {
        textToCopy: command,
        fill: status === 'notStarted'
      })) : /*#__PURE__*/_react.default.createElement(_eui.EuiSkeletonText, {
        lines: 6
      })
    }, {
      title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.visualizeYourDataLabel', {
        defaultMessage: 'Visualize your data'
      }),
      status: status === 'dataReceived' ? 'complete' : status === 'awaitingData' || status === 'inProgress' ? 'current' : 'incomplete',
      children: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, status === 'dataReceived' ? /*#__PURE__*/_react.default.createElement(_progress_indicator.ProgressIndicator, {
        iconType: "cheer",
        title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.yourDataIsReadyToExploreLabel', {
          defaultMessage: 'Your data is ready to explore!'
        }),
        isLoading: false,
        "data-test-subj": "observabilityOnboardingAutoDetectPanelDataReceivedProgressIndicator"
      }) : status === 'awaitingData' ? /*#__PURE__*/_react.default.createElement(_progress_indicator.ProgressIndicator, {
        title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.installingElasticAgentFlexItemLabel', {
          defaultMessage: 'Waiting for data to arrive...'
        }),
        "data-test-subj": "observabilityOnboardingAutoDetectPanelAwaitingDataProgressIndicator"
      }) : status === 'inProgress' ? /*#__PURE__*/_react.default.createElement(_progress_indicator.ProgressIndicator, {
        title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.lookingForLogFilesFlexItemLabel', {
          defaultMessage: 'Waiting for installation to complete...'
        }),
        "data-test-subj": "observabilityOnboardingAutoDetectPanelInProgressProgressIndicator"
      }) : null, (status === 'awaitingData' || status === 'dataReceived') && installedIntegrations.length > 0 ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), registryIntegrations.slice()
      /**
       * System integration should always be on top
       */.sort((a, b) => a.pkgName === 'system' ? -1 : 0).map(integration => {
        var _integration$metadata, _data$onboardingFlow;
        let actionLinks;
        switch (integration.pkgName) {
          case 'system':
            actionLinks = assetDetailsLocator !== undefined ? [{
              id: 'inventory-host-details',
              title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.systemOverviewTitle', {
                defaultMessage: 'Overview your system health within the Hosts Inventory'
              }),
              label: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.systemOverviewLabel', {
                defaultMessage: 'Explore metrics data'
              }),
              href: assetDetailsLocator.getRedirectUrl({
                assetType: 'host',
                assetId: (_integration$metadata = integration.metadata) === null || _integration$metadata === void 0 ? void 0 : _integration$metadata.hostname
              })
            }] : [];
            break;
          default:
            actionLinks = dashboardLocator !== undefined ? integration.kibanaAssets.filter(asset => asset.type === 'dashboard').map(asset => {
              const dashboard = _use_onboarding_flow.DASHBOARDS[asset.id];
              const href = dashboardLocator.getRedirectUrl({
                dashboardId: asset.id
              });
              return {
                id: asset.id,
                title: dashboard.type === 'metrics' ? _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.exploreMetricsDataTitle', {
                  defaultMessage: 'Overview your metrics data with this pre-made dashboard'
                }) : _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.exploreLogsDataTitle', {
                  defaultMessage: 'Overview your logs data with this pre-made dashboard'
                }),
                label: dashboard.type === 'metrics' ? _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.exploreMetricsDataLabel', {
                  defaultMessage: 'Explore metrics data'
                }) : _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.exploreLogsDataLabel', {
                  defaultMessage: 'Explore logs data'
                }),
                href
              };
            }) : [];
        }
        return /*#__PURE__*/_react.default.createElement(_accordion_with_icon.AccordionWithIcon, {
          key: integration.pkgName,
          id: `${accordionId}_${integration.pkgName}`,
          icon: (0, _logo_icon.isSupportedLogo)(integration.pkgName) ? /*#__PURE__*/_react.default.createElement(_logo_icon.LogoIcon, {
            size: "l",
            logo: integration.pkgName
          }) : /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
            type: "desktop",
            size: "l"
          }),
          title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.h3.getStartedWithNginxLabel', {
            defaultMessage: 'Get started with {title}',
            values: {
              title: integration.title
            }
          }),
          isDisabled: status !== 'dataReceived',
          initialIsOpen: true
        }, /*#__PURE__*/_react.default.createElement(_get_started_panel.GetStartedPanel, {
          onboardingFlowType: "auto-detect",
          dataset: integration.pkgName,
          onboardingId: data === null || data === void 0 ? void 0 : (_data$onboardingFlow = data.onboardingFlow) === null || _data$onboardingFlow === void 0 ? void 0 : _data$onboardingFlow.id,
          telemetryEventContext: {
            autoDetect: {
              installSource: integration.installSource,
              pkgVersion: integration.pkgVersion,
              title: integration.title
            }
          },
          integration: integration.pkgName,
          newTab: true,
          isLoading: status !== 'dataReceived',
          actionLinks: actionLinks
        }));
      }), customIntegrations.length > 0 && /*#__PURE__*/_react.default.createElement(_accordion_with_icon.AccordionWithIcon, {
        id: `${accordionId}_custom`,
        icon: /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
          type: "documents",
          size: "l"
        }),
        title: _i18n.i18n.translate('xpack.observability_onboarding.autoDetectPanel.h3.getStartedWithlogLabel', {
          defaultMessage: 'Get started with custom .log files'
        }),
        isDisabled: status !== 'dataReceived',
        initialIsOpen: true
      }, /*#__PURE__*/_react.default.createElement("ul", null, customIntegrations.map(integration => integration.dataStreams.map(datastream => /*#__PURE__*/_react.default.createElement("li", {
        key: `${integration.pkgName}/${datastream.dataset}`
      }, /*#__PURE__*/_react.default.createElement(_locator_button_empty.LocatorButtonEmpty, {
        locator: _locators.SINGLE_DATASET_LOCATOR_ID,
        params: {
          integration: integration.pkgName,
          dataset: datastream.dataset
        },
        target: "_blank",
        iconType: "document",
        isDisabled: status !== 'dataReceived',
        flush: "left",
        size: "s"
      }, integration.pkgName))))))) : null)
    }]
  }), /*#__PURE__*/_react.default.createElement(_feedback_buttons.FeedbackButtons, {
    flow: "auto-detect"
  }));
};
exports.AutoDetectPanel = AutoDetectPanel;