"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAutoDetectTelemetry = useAutoDetectTelemetry;
var _react = require("react");
var _public = require("@kbn/kibana-react-plugin/public");
var _telemetry_events = require("../../../../common/telemetry_events");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useAutoDetectTelemetry(status, integrations) {
  const [waitingMessageSent, setWaitingMessageSent] = (0, _react.useState)(false);
  const [dataShippedMessageSent, setDataShippedMessageSent] = (0, _react.useState)(false);
  const {
    services: {
      analytics
    }
  } = (0, _public.useKibana)();
  (0, _react.useEffect)(() => {
    if (status === 'awaitingData' && !waitingMessageSent) {
      analytics === null || analytics === void 0 ? void 0 : analytics.reportEvent(_telemetry_events.OBSERVABILITY_ONBOARDING_AUTODETECT_TELEMETRY_EVENT.eventType, {
        uses_legacy_onboarding_page: false,
        flow: 'auto_detect',
        step: 'awaiting_data',
        integrations
      });
      setWaitingMessageSent(true);
    }
    if (status === 'dataReceived' && !dataShippedMessageSent) {
      analytics === null || analytics === void 0 ? void 0 : analytics.reportEvent(_telemetry_events.OBSERVABILITY_ONBOARDING_AUTODETECT_TELEMETRY_EVENT.eventType, {
        uses_legacy_onboarding_page: false,
        flow: 'auto_detect',
        step: 'data_shipped',
        integrations
      });
      setDataShippedMessageSent(true);
    }
  }, [analytics, dataShippedMessageSent, integrations, status, waitingMessageSent]);
}