"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.KubernetesPanel = void 0;
var _react = _interopRequireDefault(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _use_fetcher = require("../../../hooks/use_fetcher");
var _empty_prompt = require("../shared/empty_prompt");
var _command_snippet = require("./command_snippet");
var _data_ingest_status = require("./data_ingest_status");
var _feedback_buttons = require("../shared/feedback_buttons");
var _use_kubernetes_flow = require("./use_kubernetes_flow");
var _use_window_blur_data_monitoring_trigger = require("../shared/use_window_blur_data_monitoring_trigger");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const KubernetesPanel = () => {
  const {
    data,
    status,
    error,
    refetch
  } = (0, _use_kubernetes_flow.useKubernetesFlow)();
  const isMonitoringStepActive = (0, _use_window_blur_data_monitoring_trigger.useWindowBlurDataMonitoringTrigger)({
    isActive: status === _use_fetcher.FETCH_STATUS.SUCCESS,
    onboardingFlowType: 'kubernetes',
    onboardingId: data === null || data === void 0 ? void 0 : data.onboardingId
  });
  if (error !== undefined) {
    return /*#__PURE__*/_react.default.createElement(_empty_prompt.EmptyPrompt, {
      onboardingFlowType: "kubernetes",
      error: error,
      onRetryClick: refetch
    });
  }
  const steps = [{
    title: _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.kubernetes.installStepTitle', {
      defaultMessage: 'Install standalone Elastic Agent on your Kubernetes cluster'
    }),
    children: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, status !== _use_fetcher.FETCH_STATUS.SUCCESS && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSkeletonText, {
      lines: 5
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_eui.EuiSkeletonRectangle, {
      width: "170px",
      height: "40px"
    })), status === _use_fetcher.FETCH_STATUS.SUCCESS && data !== undefined && /*#__PURE__*/_react.default.createElement(_command_snippet.CommandSnippet, {
      encodedApiKey: data.apiKeyEncoded,
      onboardingId: data.onboardingId,
      elasticsearchUrl: data.elasticsearchUrl,
      elasticAgentVersionInfo: data.elasticAgentVersionInfo,
      isCopyPrimaryAction: !isMonitoringStepActive
    }))
  }, {
    title: _i18n.i18n.translate('xpack.observability_onboarding.experimentalOnboardingFlow.kubernetes.monitorStepTitle', {
      defaultMessage: 'Monitor your Kubernetes cluster'
    }),
    status: isMonitoringStepActive ? 'current' : 'incomplete',
    children: isMonitoringStepActive && data && /*#__PURE__*/_react.default.createElement(_data_ingest_status.DataIngestStatus, {
      onboardingId: data.onboardingId
    })
  }];
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasBorder: true,
    paddingSize: "xl"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSteps, {
    steps: steps
  }), /*#__PURE__*/_react.default.createElement(_feedback_buttons.FeedbackButtons, {
    flow: "kubernetes"
  }));
};
exports.KubernetesPanel = KubernetesPanel;