"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPersistentControlsHook = void 0;
var _react = require("react");
var _alertsGrouping = require("@kbn/alerts-grouping");
var _use_alerts_data_view = require("@kbn/alerts-ui-shared/src/common/hooks/use_alerts_data_view");
var _use_get_group_selector = require("@kbn/grouping/src/hooks/use_get_group_selector");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getPersistentControlsHook = ({
  groupingId,
  featureIds,
  maxGroupingLevels = 3,
  services: {
    dataViews,
    http,
    notifications
  }
}) => () => {
  var _dataView$fields, _grouping$options$fil, _grouping$options;
  const {
    grouping,
    updateGrouping
  } = (0, _alertsGrouping.useAlertsGroupingState)(groupingId);
  const onGroupChange = (0, _react.useCallback)(selectedGroups => {
    var _grouping$activeGroup, _grouping$activeGroup2;
    updateGrouping({
      activeGroups: (_grouping$activeGroup = (_grouping$activeGroup2 = grouping.activeGroups) === null || _grouping$activeGroup2 === void 0 ? void 0 : _grouping$activeGroup2.filter(g => g !== 'none').concat(selectedGroups)) !== null && _grouping$activeGroup !== void 0 ? _grouping$activeGroup : []
    });
  }, [grouping, updateGrouping]);
  const {
    dataView
  } = (0, _use_alerts_data_view.useAlertsDataView)({
    featureIds,
    dataViewsService: dataViews,
    http,
    toasts: notifications.toasts
  });
  const groupSelector = (0, _use_get_group_selector.useGetGroupSelectorStateless)({
    groupingId,
    onGroupChange,
    fields: (_dataView$fields = dataView === null || dataView === void 0 ? void 0 : dataView.fields) !== null && _dataView$fields !== void 0 ? _dataView$fields : [],
    defaultGroupingOptions: (_grouping$options$fil = (_grouping$options = grouping.options) === null || _grouping$options === void 0 ? void 0 : _grouping$options.filter(option => !grouping.activeGroups.includes(option.key))) !== null && _grouping$options$fil !== void 0 ? _grouping$options$fil : [],
    maxGroupingLevels
  });
  return (0, _react.useMemo)(() => {
    return {
      right: groupSelector
    };
  }, [groupSelector]);
};
exports.getPersistentControlsHook = getPersistentControlsHook;