"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CreateAnnotation = CreateAnnotation;
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _eui = require("@elastic/eui");
var _reactHookForm = require("react-hook-form");
var _annotation_form = require("../annotation_form");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function CreateAnnotation({
  onSave,
  onCancel,
  isLoading,
  editAnnotation,
  createAnnotation,
  deleteAnnotation,
  updateAnnotation,
  isCreateAnnotationsOpen
}) {
  const {
    trigger,
    getValues
  } = (0, _reactHookForm.useFormContext)();
  const onSubmit = (0, _react.useCallback)(async () => {
    const isValid = await trigger();
    if (!isValid) return;
    const values = getValues();
    const timestamp = values['@timestamp'].toISOString();
    if (editAnnotation !== null && editAnnotation !== void 0 && editAnnotation.id) {
      var _values$event, _values$event$end;
      await updateAnnotation({
        annotation: {
          ...values,
          id: editAnnotation.id,
          '@timestamp': timestamp,
          event: {
            start: timestamp,
            end: (_values$event = values.event) === null || _values$event === void 0 ? void 0 : (_values$event$end = _values$event.end) === null || _values$event$end === void 0 ? void 0 : _values$event$end.toISOString()
          }
        }
      });
    } else {
      var _values$event2, _values$event2$end;
      await createAnnotation({
        annotation: {
          ...values,
          '@timestamp': timestamp,
          event: {
            start: timestamp,
            end: (_values$event2 = values.event) === null || _values$event2 === void 0 ? void 0 : (_values$event2$end = _values$event2.end) === null || _values$event2$end === void 0 ? void 0 : _values$event2$end.toISOString()
          }
        }
      });
    }
    onSave();
  }, [trigger, getValues, editAnnotation === null || editAnnotation === void 0 ? void 0 : editAnnotation.id, onSave, updateAnnotation, createAnnotation]);
  const onDelete = async () => {
    if (editAnnotation !== null && editAnnotation !== void 0 && editAnnotation.id) {
      await deleteAnnotation({
        annotations: [editAnnotation]
      });
      onSave();
    }
  };
  let flyout;
  if (isCreateAnnotationsOpen) {
    flyout = /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutResizable, {
      onClose: onCancel,
      type: "push",
      size: "s",
      maxWidth: 700
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutHeader, {
      hasBorder: true
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, null, /*#__PURE__*/_react.default.createElement("h2", null, editAnnotation ? _i18n.i18n.translate('xpack.observability.createAnnotation.editAnnotationModalHeaderTitleLabel', {
      defaultMessage: 'Update annotation'
    }) : _i18n.i18n.translate('xpack.observability.createAnnotation.addAnnotationModalHeaderTitleLabel', {
      defaultMessage: 'Create annotation'
    })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutBody, null, /*#__PURE__*/_react.default.createElement(_annotation_form.AnnotationForm, {
      editAnnotation: editAnnotation
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutFooter, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      justifyContent: "flexStart"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
      "data-test-subj": "observabilitySolutionCancelButton",
      onClick: onCancel,
      isLoading: isLoading
    }, _i18n.i18n.translate('xpack.observability.createAnnotation.closeButtonEmptyLabel', {
      defaultMessage: 'Close'
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null), (editAnnotation === null || editAnnotation === void 0 ? void 0 : editAnnotation.id) && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
      "data-test-subj": "annotationDeleteButton",
      type: "submit",
      onClick: () => onDelete(),
      isLoading: isLoading,
      color: "danger"
    }, _i18n.i18n.translate('xpack.observability.createAnnotation.deleteButtonLabel', {
      defaultMessage: 'Delete'
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      "data-test-subj": "annotationSaveButton",
      type: "submit",
      onClick: () => onSubmit(),
      isLoading: isLoading,
      fill: true
    }, editAnnotation !== null && editAnnotation !== void 0 && editAnnotation.id ? _i18n.i18n.translate('xpack.observability.createAnnotation.updateButtonLabel', {
      defaultMessage: 'Update'
    }) : _i18n.i18n.translate('xpack.observability.createAnnotation.saveButtonLabel', {
      defaultMessage: 'Save'
    }))))));
  }
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, flyout);
}

// eslint-disable-next-line import/no-default-export
var _default = exports.default = CreateAnnotation;