"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDeleteAnnotation = useDeleteAnnotation;
var _react = _interopRequireDefault(require("react"));
var _reactQuery = require("@tanstack/react-query");
var _reactKibanaMount = require("@kbn/react-kibana-mount");
var _i18nReact = require("@kbn/i18n-react");
var _i18n = require("@kbn/i18n");
var _sharedUxLinkRedirectApp = require("@kbn/shared-ux-link-redirect-app");
var _kibana_react = require("../../../utils/kibana_react");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useDeleteAnnotation() {
  const {
    i18n: i18nStart,
    theme,
    http,
    notifications: {
      toasts
    }
  } = (0, _kibana_react.useKibana)().services;
  const services = (0, _kibana_react.useKibana)().services;
  return (0, _reactQuery.useMutation)(['deleteAnnotation'], async ({
    annotations
  }) => {
    for (const annotation of annotations) {
      await http.delete(`/api/observability/annotation/${annotation.id}`);
    }
    return Promise.resolve();
  }, {
    onSuccess: (data, {
      annotations
    }) => {
      toasts.addSuccess({
        title: (0, _reactKibanaMount.toMountPoint)( /*#__PURE__*/_react.default.createElement(_sharedUxLinkRedirectApp.RedirectAppLinks, {
          coreStart: services,
          "data-test-subj": "observabilityMainContainer"
        }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "xpack.observability.annotation.delete.successNotification",
          defaultMessage: "Successfully deleted annotations {name}.",
          values: {
            name: annotations.map(annotation => annotation.message).join(', ')
          }
        })), {
          i18n: i18nStart,
          theme
        })
      });
    },
    onError: (error, {
      annotations
    }, context) => {
      var _error$body$message, _error$body;
      toasts.addError(new Error((_error$body$message = (_error$body = error.body) === null || _error$body === void 0 ? void 0 : _error$body.message) !== null && _error$body$message !== void 0 ? _error$body$message : error.message), {
        title: _i18n.i18n.translate('xpack.observability.delete.annotation', {
          defaultMessage: 'Something went wrong while deleting annotation {message}',
          values: {
            message: annotations.map(annotation => {
              var _annotation$annotatio, _annotation$annotatio2;
              return (_annotation$annotatio = (_annotation$annotatio2 = annotation.annotation) === null || _annotation$annotatio2 === void 0 ? void 0 : _annotation$annotatio2.title) !== null && _annotation$annotatio !== void 0 ? _annotation$annotatio : annotation.message;
            }).join(', ')
          }
        })
      });
    }
  });
}