"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InternalRelatedAlerts = InternalRelatedAlerts;
exports.RelatedAlerts = RelatedAlerts;
var _react = _interopRequireWildcard(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _eui = require("@elastic/eui");
var _observabilityGetPaddedAlertTimeRangeUtil = require("@kbn/observability-get-padded-alert-time-range-util");
var _ruleDataUtils = require("@kbn/rule-data-utils");
var _alertsGrouping = require("@kbn/alerts-grouping");
var _constants = require("../../../../common/constants");
var _get_related_alerts_query = require("../../../../common/utils/alerting/get_related_alerts_query");
var _state_container = require("../../../components/alert_search_bar/containers/state_container");
var _alert_search_bar_with_url_sync = require("../../../components/alert_search_bar/alert_search_bar_with_url_sync");
var _render_group_panel = require("../../../components/alerts_table/grouping/render_group_panel");
var _get_group_stats = require("../../../components/alerts_table/grouping/get_group_stats");
var _get_aggregations_by_grouping_field = require("../../../components/alerts_table/grouping/get_aggregations_by_grouping_field");
var _constants2 = require("../../../components/alerts_table/grouping/constants");
var _constants3 = require("../../../components/alert_search_bar/constants");
var _containers = require("../../../components/alert_search_bar/containers");
var _constants4 = require("../../../constants");
var _use_plugin_context = require("../../../hooks/use_plugin_context");
var _kibana_react = require("../../../utils/kibana_react");
var _build_es_query = require("../../../utils/build_es_query");
var _merge_bool_queries = require("../../alerts/helpers/merge_bool_queries");
var _illustration_product_no_results_magnifying_glass = _interopRequireDefault(require("./assets/illustration_product_no_results_magnifying_glass.svg"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ALERTS_PER_PAGE = 50;
const RELATED_ALERTS_SEARCH_BAR_ID = 'related-alerts-search-bar-o11y';
const ALERTS_TABLE_ID = 'xpack.observability.related.alerts.table';
const defaultState = {
  ..._state_container.DEFAULT_STATE,
  status: 'active'
};
const DEFAULT_FILTERS = [];
function InternalRelatedAlerts({
  alert
}) {
  var _ALERT_STATUS_FILTER$, _alertSearchBarStateP;
  const kibanaServices = (0, _kibana_react.useKibana)().services;
  const {
    http,
    notifications,
    dataViews,
    triggersActionsUi: {
      alertsTableConfigurationRegistry,
      getAlertsStateTable: AlertsStateTable
    }
  } = kibanaServices;
  const {
    observabilityRuleTypeRegistry
  } = (0, _use_plugin_context.usePluginContext)();
  const alertSearchBarStateProps = (0, _containers.useAlertSearchBarStateContainer)(_constants4.SEARCH_BAR_URL_STORAGE_KEY, {
    replace: false
  });
  const [esQuery, setEsQuery] = (0, _react.useState)();
  const alertStart = alert === null || alert === void 0 ? void 0 : alert.fields[_ruleDataUtils.ALERT_START];
  const alertEnd = alert === null || alert === void 0 ? void 0 : alert.fields[_ruleDataUtils.ALERT_END];
  const alertId = alert === null || alert === void 0 ? void 0 : alert.fields[_ruleDataUtils.ALERT_UUID];
  const tags = alert === null || alert === void 0 ? void 0 : alert.fields[_ruleDataUtils.TAGS];
  const groups = alert === null || alert === void 0 ? void 0 : alert.fields[_ruleDataUtils.ALERT_GROUP];
  const ruleId = alert === null || alert === void 0 ? void 0 : alert.fields[_ruleDataUtils.ALERT_RULE_UUID];
  const sharedFields = (0, _get_related_alerts_query.getSharedFields)(alert === null || alert === void 0 ? void 0 : alert.fields);
  const kuery = (0, _get_related_alerts_query.getRelatedAlertKuery)({
    tags,
    groups,
    ruleId,
    sharedFields
  });
  const defaultQuery = (0, _react.useRef)([{
    query: `not kibana.alert.uuid: ${alertId}`,
    language: 'kuery'
  }]);
  (0, _react.useEffect)(() => {
    if (alertStart) {
      const defaultTimeRange = (0, _observabilityGetPaddedAlertTimeRangeUtil.getPaddedAlertTimeRange)(alertStart, alertEnd);
      alertSearchBarStateProps.onRangeFromChange(defaultTimeRange.from);
      alertSearchBarStateProps.onRangeToChange(defaultTimeRange.to);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [alertStart, alertEnd]);
  if (!kuery || !alert) return /*#__PURE__*/_react.default.createElement(EmptyState, null);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "m"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_alert_search_bar_with_url_sync.ObservabilityAlertSearchbarWithUrlSync, {
    appName: RELATED_ALERTS_SEARCH_BAR_ID,
    onEsQueryChange: setEsQuery,
    urlStorageKey: _constants4.SEARCH_BAR_URL_STORAGE_KEY,
    defaultSearchQueries: defaultQuery.current,
    defaultState: {
      ...defaultState,
      kuery
    }
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, esQuery && /*#__PURE__*/_react.default.createElement(_alertsGrouping.AlertsGrouping, {
    featureIds: _constants.observabilityAlertFeatureIds,
    defaultFilters: (_ALERT_STATUS_FILTER$ = _constants3.ALERT_STATUS_FILTER[alertSearchBarStateProps.status]) !== null && _ALERT_STATUS_FILTER$ !== void 0 ? _ALERT_STATUS_FILTER$ : DEFAULT_FILTERS,
    from: alertSearchBarStateProps.rangeFrom,
    to: alertSearchBarStateProps.rangeTo,
    globalFilters: (_alertSearchBarStateP = alertSearchBarStateProps.filters) !== null && _alertSearchBarStateP !== void 0 ? _alertSearchBarStateP : DEFAULT_FILTERS,
    globalQuery: {
      query: alertSearchBarStateProps.kuery,
      language: 'kuery'
    },
    groupingId: _constants4.RELATED_ALERTS_TABLE_CONFIG_ID,
    defaultGroupingOptions: _constants2.DEFAULT_GROUPING_OPTIONS,
    getAggregationsByGroupingField: _get_aggregations_by_grouping_field.getAggregationsByGroupingField,
    renderGroupPanel: _render_group_panel.renderGroupPanel,
    getGroupStats: _get_group_stats.getGroupStats,
    services: {
      notifications,
      dataViews,
      http
    }
  }, groupingFilters => {
    const groupQuery = (0, _build_es_query.buildEsQuery)({
      filters: groupingFilters
    });
    return /*#__PURE__*/_react.default.createElement(AlertsStateTable, {
      id: ALERTS_TABLE_ID,
      featureIds: _constants.observabilityAlertFeatureIds,
      configurationId: _constants4.RELATED_ALERTS_TABLE_CONFIG_ID,
      query: (0, _merge_bool_queries.mergeBoolQueries)(esQuery, groupQuery),
      showAlertStatusWithFlapping: true,
      initialPageSize: ALERTS_PER_PAGE,
      cellContext: {
        observabilityRuleTypeRegistry
      },
      alertsTableConfigurationRegistry: alertsTableConfigurationRegistry
    });
  })));
}
const heights = {
  tall: 490,
  short: 250
};
const panelStyle = {
  maxWidth: 500
};
function EmptyState() {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    color: "subdued",
    "data-test-subj": "relatedAlertsTabEmptyState"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    style: {
      height: heights.tall
    },
    alignItems: "center",
    justifyContent: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasBorder: true,
    style: panelStyle
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, null, /*#__PURE__*/_react.default.createElement("h3", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.observability.pages.alertDetails.relatedAlerts.empty.title",
    defaultMessage: "Problem loading related alerts"
  }))), /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.observability.pages.alertDetails.relatedAlerts.empty.description",
    defaultMessage: "Due to an unexpected error, no related alerts can be found."
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiImage, {
    style: {
      width: 200,
      height: 148
    },
    size: "200",
    alt: "",
    url: _illustration_product_no_results_magnifying_glass.default
  })))))));
}
function RelatedAlerts(props) {
  return /*#__PURE__*/_react.default.createElement(_containers.Provider, {
    value: _containers.alertSearchBarStateContainer
  }, /*#__PURE__*/_react.default.createElement(InternalRelatedAlerts, props));
}