"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFetchInvestigationsByAlert = useFetchInvestigationsByAlert;
var _reactQuery = require("@tanstack/react-query");
var _kibana_react = require("../../../utils/kibana_react");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useFetchInvestigationsByAlert({
  alertId
}) {
  const {
    http,
    notifications: {
      toasts
    },
    investigate: investigatePlugin
  } = (0, _kibana_react.useKibana)().services;
  const {
    isInitialLoading,
    isLoading,
    isError,
    isSuccess,
    isRefetching,
    data
  } = (0, _reactQuery.useQuery)({
    queryKey: ['fetchInvestigationsByAlert', alertId],
    queryFn: async ({
      signal
    }) => {
      return await http.get('/api/observability/investigations', {
        query: {
          alertId
        },
        version: '2023-10-31',
        signal
      });
    },
    cacheTime: 0,
    refetchOnWindowFocus: false,
    retry: (failureCount, error) => {
      if (String(error) === 'Error: Forbidden') {
        return false;
      }
      return failureCount < 3;
    },
    onError: error => {
      toasts.addError(error, {
        title: 'Something went wrong while fetching Investigations'
      });
    },
    enabled: Boolean(investigatePlugin)
  });
  return {
    data,
    isInitialLoading,
    isLoading,
    isRefetching,
    isSuccess,
    isError
  };
}