"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.analyzeDocuments = analyzeDocuments;
var _lodash = require("lodash");
var _merge_sample_documents_with_field_caps = require("@kbn/observability-utils-common/llm/log_analysis/merge_sample_documents_with_field_caps");
var _kql_query = require("../es/queries/kql_query");
var _range_query = require("../es/queries/range_query");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

async function analyzeDocuments({
  esClient,
  kuery,
  start,
  end,
  index
}) {
  const [fieldCaps, hits] = await Promise.all([esClient.fieldCaps('get_field_caps_for_document_analysis', {
    index,
    fields: '*',
    index_filter: {
      bool: {
        filter: (0, _range_query.rangeQuery)(start, end)
      }
    }
  }), esClient.search('get_document_samples', {
    index,
    size: 1000,
    track_total_hits: true,
    query: {
      bool: {
        must: [...(0, _kql_query.kqlQuery)(kuery), ...(0, _range_query.rangeQuery)(start, end)],
        should: [{
          function_score: {
            functions: [{
              random_score: {}
            }]
          }
        }]
      }
    },
    sort: {
      _score: {
        order: 'desc'
      }
    },
    _source: false,
    fields: ['*']
  }).then(response => ({
    hits: response.hits.hits.map(hit => (0, _lodash.mapValues)(hit.fields, value => value.length === 1 ? value[0] : value)),
    total: response.hits.total
  }))]);
  const analysis = (0, _merge_sample_documents_with_field_caps.mergeSampleDocumentsWithFieldCaps)({
    samples: hits.hits,
    total: hits.total.value,
    fieldCaps: Object.entries(fieldCaps.fields).map(([name, specs]) => {
      return {
        name,
        esTypes: Object.keys(specs)
      };
    })
  });
  return analysis;
}