"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PresentationPanelHeader = void 0;
var _eui = require("@elastic/eui");
var _classnames = _interopRequireDefault(require("classnames"));
var _react = _interopRequireDefault(require("react"));
var _presentation_panel_strings = require("../presentation_panel_strings");
var _presentation_panel_title = require("./presentation_panel_title");
var _use_presentation_panel_header_actions = require("./use_presentation_panel_header_actions");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const PresentationPanelHeader = ({
  api,
  viewMode,
  headerId,
  getActions,
  hideTitle,
  panelTitle,
  panelDescription,
  showBadges = true,
  showNotifications = true
}) => {
  const {
    notificationElements,
    badgeElements
  } = (0, _use_presentation_panel_header_actions.usePresentationPanelHeaderActions)(showNotifications, showBadges, api, getActions);
  const showPanelBar = !hideTitle && panelTitle || badgeElements.length > 0 || notificationElements.length > 0;
  if (!showPanelBar) return null;
  const ariaLabel = (0, _presentation_panel_strings.getAriaLabelForTitle)(showPanelBar ? panelTitle : undefined);
  const ariaLabelElement = /*#__PURE__*/_react.default.createElement(_eui.EuiScreenReaderOnly, null, /*#__PURE__*/_react.default.createElement("span", {
    id: headerId
  }, ariaLabel));
  const headerClasses = (0, _classnames.default)('embPanel__header', {
    'embPanel--dragHandle': viewMode === 'edit',
    'embPanel__header--floater': !showPanelBar
  });
  const titleClasses = (0, _classnames.default)('embPanel__title', {
    'embPanel--dragHandle': viewMode === 'edit'
  });
  return /*#__PURE__*/_react.default.createElement("figcaption", {
    className: headerClasses,
    "data-test-subj": `embeddablePanelHeading-${(panelTitle || '').replace(/\s/g, '')}`
  }, /*#__PURE__*/_react.default.createElement("h2", {
    "data-test-subj": "dashboardPanelTitle",
    className: titleClasses
  }, ariaLabelElement, /*#__PURE__*/_react.default.createElement(_presentation_panel_title.PresentationPanelTitle, {
    api: api,
    viewMode: viewMode,
    hideTitle: hideTitle,
    panelTitle: panelTitle,
    panelDescription: panelDescription
  }), showBadges && badgeElements), showNotifications && notificationElements);
};
exports.PresentationPanelHeader = PresentationPanelHeader;