"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PresentationPanelHoverActions = void 0;
var _i18n = require("@kbn/i18n");
var _classnames = _interopRequireDefault(require("classnames"));
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _public = require("@kbn/ui-actions-plugin/public");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _rxjs = require("rxjs");
var _uiTheme = require("@kbn/ui-theme");
var _react2 = require("@emotion/react");
var _kibana_services = require("../../kibana_services");
var _panel_actions = require("../../panel_actions");
var _presentation_panel_strings = require("../presentation_panel_strings");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const DASHED_OUTLINE = `1px dashed ${_uiTheme.euiThemeVars.euiColorMediumShade}`;
const SOLID_OUTLINE = `1px solid ${_uiTheme.euiThemeVars.euiBorderColor}`;
const QUICK_ACTION_IDS = {
  edit: ['editPanel', 'ACTION_CONFIGURE_IN_LENS', 'ACTION_CUSTOMIZE_PANEL', 'ACTION_OPEN_IN_DISCOVER', 'ACTION_VIEW_SAVED_SEARCH'],
  view: ['ACTION_OPEN_IN_DISCOVER', 'ACTION_VIEW_SAVED_SEARCH', 'openInspector', 'togglePanel']
};
const ALLOWED_NOTIFICATIONS = ['ACTION_FILTERS_NOTIFICATION'];
const ALL_ROUNDED_CORNERS = `
  border-radius: ${_uiTheme.euiThemeVars.euiBorderRadius};
`;
const TOP_ROUNDED_CORNERS = `
  border-top-left-radius: ${_uiTheme.euiThemeVars.euiBorderRadius};
  border-top-right-radius: ${_uiTheme.euiThemeVars.euiBorderRadius};
  border-bottom: 0px;
`;
const createClickHandler = (action, context) => event => {
  if (event.currentTarget instanceof HTMLAnchorElement) {
    // from react-router's <Link/>
    if (!event.defaultPrevented &&
    // onClick prevented default
    event.button === 0 && (
    // ignore everything but left clicks
    !event.currentTarget.target || event.currentTarget.target === '_self') &&
    // let browser handle "target=_blank" etc.
    !(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey) // ignore clicks with modifier keys
    ) {
      event.preventDefault();
    }
  }
  event.currentTarget.blur();
  action.execute(context);
};
const PresentationPanelHoverActions = ({
  api,
  index,
  getActions,
  actionPredicate,
  children,
  className,
  viewMode,
  showNotifications = true,
  showBorder
}) => {
  var _api$parentApi;
  const [quickActions, setQuickActions] = (0, _react.useState)([]);
  const [contextMenuPanels, setContextMenuPanels] = (0, _react.useState)([]);
  const [showNotification, setShowNotification] = (0, _react.useState)(false);
  const [isContextMenuOpen, setIsContextMenuOpen] = (0, _react.useState)(false);
  const [notifications, setNotifications] = (0, _react.useState)([]);
  const hoverActionsRef = (0, _react.useRef)(null);
  const anchorRef = (0, _react.useRef)(null);
  const leftHoverActionsRef = (0, _react.useRef)(null);
  const rightHoverActionsRef = (0, _react.useRef)(null);
  const [combineHoverActions, setCombineHoverActions] = (0, _react.useState)(false);
  const [borderStyles, setBorderStyles] = (0, _react.useState)(TOP_ROUNDED_CORNERS);
  const updateCombineHoverActions = () => {
    var _rightHoverActionsRef, _rightHoverActionsRef2, _leftHoverActionsRef$, _leftHoverActionsRef$2, _rightHoverActionsRef3, _rightHoverActionsRef4;
    if (!hoverActionsRef.current || !anchorRef.current) return;
    const anchorBox = anchorRef.current.getBoundingClientRect();
    const anchorLeft = anchorBox.left;
    const anchorTop = anchorBox.top;
    const anchorWidth = anchorRef.current.offsetWidth;
    const hoverActionsWidth = ((_rightHoverActionsRef = (_rightHoverActionsRef2 = rightHoverActionsRef.current) === null || _rightHoverActionsRef2 === void 0 ? void 0 : _rightHoverActionsRef2.offsetWidth) !== null && _rightHoverActionsRef !== void 0 ? _rightHoverActionsRef : 0) + ((_leftHoverActionsRef$ = (_leftHoverActionsRef$2 = leftHoverActionsRef.current) === null || _leftHoverActionsRef$2 === void 0 ? void 0 : _leftHoverActionsRef$2.offsetWidth) !== null && _leftHoverActionsRef$ !== void 0 ? _leftHoverActionsRef$ : 0) + parseInt(_uiTheme.euiThemeVars.euiSize, 10) * 2;
    const hoverActionsHeight = (_rightHoverActionsRef3 = (_rightHoverActionsRef4 = rightHoverActionsRef.current) === null || _rightHoverActionsRef4 === void 0 ? void 0 : _rightHoverActionsRef4.offsetHeight) !== null && _rightHoverActionsRef3 !== void 0 ? _rightHoverActionsRef3 : 0;

    // Left align hover actions when they would get cut off by the right edge of the window
    if (anchorLeft - (hoverActionsWidth - anchorWidth) <= parseInt(_uiTheme.euiThemeVars.euiSize, 10)) {
      hoverActionsRef.current.style.removeProperty('right');
      hoverActionsRef.current.style.setProperty('left', '0');
    } else {
      hoverActionsRef.current.style.removeProperty('left');
      hoverActionsRef.current.style.setProperty('right', '0');
    }
    if (anchorRef.current && rightHoverActionsRef.current) {
      const shouldCombine = anchorWidth < hoverActionsWidth;
      const willGetCutOff = anchorTop < hoverActionsHeight;
      if (shouldCombine !== combineHoverActions) {
        setCombineHoverActions(shouldCombine);
      }
      if (willGetCutOff) {
        hoverActionsRef.current.style.setProperty('position', 'absolute');
        hoverActionsRef.current.style.setProperty('top', `-${_uiTheme.euiThemeVars.euiSizeS}`);
      } else if (shouldCombine) {
        hoverActionsRef.current.style.setProperty('top', `-${_uiTheme.euiThemeVars.euiSizeL}`);
      } else {
        hoverActionsRef.current.style.removeProperty('position');
        hoverActionsRef.current.style.removeProperty('top');
      }
      if (shouldCombine || willGetCutOff) {
        setBorderStyles(ALL_ROUNDED_CORNERS);
      } else {
        setBorderStyles(TOP_ROUNDED_CORNERS);
      }
    }
  };
  const [defaultTitle, title, description, hidePanelTitle, hasLockedHoverActions, parentHideTitle, parentViewMode] = (0, _presentationPublishing.useBatchedOptionalPublishingSubjects)(api === null || api === void 0 ? void 0 : api.defaultPanelTitle, api === null || api === void 0 ? void 0 : api.panelTitle, api === null || api === void 0 ? void 0 : api.panelDescription, api === null || api === void 0 ? void 0 : api.hidePanelTitle, api === null || api === void 0 ? void 0 : api.hasLockedHoverActions$, api === null || api === void 0 ? void 0 : (_api$parentApi = api.parentApi) === null || _api$parentApi === void 0 ? void 0 : _api$parentApi.hidePanelTitle,
  /**
   * View mode changes often have the biggest influence over which actions will be compatible,
   * so we build and update all actions when the view mode changes. This is temporary, as these
   * actions should eventually all be Frequent Compatibility Change Actions which can track their
   * own dependencies.
   */
  (0, _presentationPublishing.getViewModeSubject)(api !== null && api !== void 0 ? api : undefined));
  const hideTitle = hidePanelTitle || parentHideTitle;
  const showDescription = description && (!title || hideTitle);
  const quickActionIds = (0, _react.useMemo)(() => QUICK_ACTION_IDS[parentViewMode === 'edit' ? 'edit' : 'view'], [parentViewMode]);
  const onClose = (0, _react.useCallback)(() => {
    setIsContextMenuOpen(false);
    if ((0, _presentationPublishing.apiCanLockHoverActions)(api)) {
      api === null || api === void 0 ? void 0 : api.lockHoverActions(false);
    }
  }, [api]);
  (0, _react.useEffect)(() => {
    if (!api) return;
    let canceled = false;
    const apiContext = {
      embeddable: api
    };
    const subscriptions = new _rxjs.Subscription();
    const handleActionCompatibilityChange = (type, isCompatible, action) => {
      if (canceled) return;
      (type === 'quickActions' ? setQuickActions : setNotifications)(currentActions => {
        const newActions = currentActions === null || currentActions === void 0 ? void 0 : currentActions.filter(current => current.id !== action.id);
        if (isCompatible) return [...newActions, action];
        return newActions;
      });
    };
    (async () => {
      // subscribe to any frequently changing context menu actions
      const frequentlyChangingActions = _kibana_services.uiActions.getFrequentlyChangingActionsForTrigger(_panel_actions.CONTEXT_MENU_TRIGGER, apiContext);
      for (const frequentlyChangingAction of frequentlyChangingActions) {
        if (quickActionIds.includes(frequentlyChangingAction.id)) {
          subscriptions.add(frequentlyChangingAction.subscribeToCompatibilityChanges(apiContext, (isCompatible, action) => handleActionCompatibilityChange('quickActions', isCompatible, action)));
        }
      }

      // subscribe to any frequently changing notification actions
      const frequentlyChangingNotifications = _kibana_services.uiActions.getFrequentlyChangingActionsForTrigger(_panel_actions.PANEL_NOTIFICATION_TRIGGER, apiContext);
      for (const frequentlyChangingNotification of frequentlyChangingNotifications) {
        if (ALLOWED_NOTIFICATIONS.includes(frequentlyChangingNotification.id)) {
          subscriptions.add(frequentlyChangingNotification.subscribeToCompatibilityChanges(apiContext, (isCompatible, action) => handleActionCompatibilityChange('notifications', isCompatible, action)));
        }
      }
    })();
    return () => {
      canceled = true;
      subscriptions.unsubscribe();
    };
  }, [api, quickActionIds]);
  (0, _react.useEffect)(() => {
    if (!api) return;
    let canceled = false;
    const apiContext = {
      embeddable: api
    };
    (async _api$disabledActionId => {
      let compatibleActions = await (async _await$uiActions$getT => {
        if (getActions) return await getActions(_panel_actions.CONTEXT_MENU_TRIGGER, apiContext);
        return (_await$uiActions$getT = await _kibana_services.uiActions.getTriggerCompatibleActions(_panel_actions.CONTEXT_MENU_TRIGGER, {
          embeddable: api
        })) !== null && _await$uiActions$getT !== void 0 ? _await$uiActions$getT : [];
      })();
      if (canceled) return;
      const disabledActions = (_api$disabledActionId = api.disabledActionIds) === null || _api$disabledActionId === void 0 ? void 0 : _api$disabledActionId.value;
      if (disabledActions) {
        compatibleActions = compatibleActions.filter(action => disabledActions.indexOf(action.id) === -1);
      }
      if (actionPredicate) {
        compatibleActions = compatibleActions.filter(({
          id
        }) => actionPredicate(id));
      }
      compatibleActions.sort(({
        order: orderA
      }, {
        order: orderB
      }) => (orderB || 0) - (orderA || 0));
      const contextMenuActions = compatibleActions.filter(({
        id
      }) => !quickActionIds.includes(id));
      const menuPanels = await (0, _public.buildContextMenuForActions)({
        actions: contextMenuActions.map(action => ({
          action,
          context: apiContext,
          trigger: _panel_actions.contextMenuTrigger
        })),
        closeMenu: onClose
      });
      setContextMenuPanels(menuPanels);
      setShowNotification(contextMenuActions.some(action => action.showNotification));
      setQuickActions(compatibleActions.filter(({
        id
      }) => quickActionIds.includes(id)));
    })();
    return () => {
      canceled = true;
    };
  }, [actionPredicate, api, getActions, isContextMenuOpen, onClose, parentViewMode, quickActionIds]);
  const quickActionElements = (0, _react.useMemo)(() => {
    if (!api || quickActions.length < 1) return [];
    const apiContext = {
      embeddable: api,
      trigger: _panel_actions.contextMenuTrigger
    };
    return quickActions.sort(({
      order: orderA
    }, {
      order: orderB
    }) => {
      const orderComparison = (orderB || 0) - (orderA || 0);
      return orderComparison;
    }).map(action => {
      const name = action.getDisplayName(apiContext);
      const iconType = action.getIconType(apiContext);
      const id = action.id;
      return {
        iconType,
        'data-test-subj': `embeddablePanelAction-${action.id}`,
        onClick: createClickHandler(action, apiContext),
        name,
        id
      };
    });
  }, [api, quickActions]);
  const notificationElements = (0, _react.useMemo)(() => {
    if (!showNotifications || !api) return [];
    return notifications === null || notifications === void 0 ? void 0 : notifications.map(notification => {
      let notificationComponent = notification.MenuItem ? ( /*#__PURE__*/_react.default.createElement(notification.MenuItem, {
        key: notification.id,
        context: {
          embeddable: api,
          trigger: _panel_actions.panelNotificationTrigger
        }
      })) : /*#__PURE__*/_react.default.createElement(_eui.EuiNotificationBadge, {
        "data-test-subj": `embeddablePanelNotification-${notification.id}`,
        key: notification.id,
        style: {
          marginTop: _uiTheme.euiThemeVars.euiSizeXS,
          marginRight: _uiTheme.euiThemeVars.euiSizeXS
        },
        onClick: () => notification.execute({
          embeddable: api,
          trigger: _panel_actions.panelNotificationTrigger
        })
      }, notification.getDisplayName({
        embeddable: api,
        trigger: _panel_actions.panelNotificationTrigger
      }));
      if (notification.getDisplayNameTooltip) {
        const tooltip = notification.getDisplayNameTooltip({
          embeddable: api,
          trigger: _panel_actions.panelNotificationTrigger
        });
        if (tooltip) {
          notificationComponent = /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
            position: "top",
            delay: "regular",
            content: tooltip,
            key: notification.id
          }, notificationComponent);
        }
      }
      return notificationComponent;
    });
  }, [api, notifications, showNotifications]);
  const contextMenuClasses = (0, _classnames.default)({
    // eslint-disable-next-line @typescript-eslint/naming-convention
    embPanel__optionsMenuPopover: true,
    'embPanel__optionsMenuPopover-notification': showNotification
  });
  const ContextMenuButton = /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
    color: "text",
    "data-test-subj": "embeddablePanelToggleMenuIcon",
    "aria-label": (0, _presentation_panel_strings.getContextMenuAriaLabel)(title, index),
    onClick: () => {
      setIsContextMenuOpen(!isContextMenuOpen);
      if ((0, _presentationPublishing.apiCanLockHoverActions)(api)) {
        api.lockHoverActions(!hasLockedHoverActions);
      }
    },
    iconType: "boxesVertical"
  });
  const dragHandle = /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: "move",
    color: "text",
    className: `${viewMode === 'edit' ? 'embPanel--dragHandle' : ''}`,
    "aria-label": _i18n.i18n.translate('presentationPanel.dragHandle', {
      defaultMessage: 'Move panel'
    }),
    "data-test-subj": "embeddablePanelDragHandle",
    css: (0, _react2.css)`
        margin: ${_uiTheme.euiThemeVars.euiSizeXS};
      `
  });
  const hasHoverActions = quickActionElements.length || contextMenuPanels.lastIndexOf.length;
  return /*#__PURE__*/_react.default.createElement("div", {
    onMouseOver: updateCombineHoverActions,
    onFocus: updateCombineHoverActions,
    ref: anchorRef,
    className: (0, _classnames.default)('embPanel__hoverActionsAnchor', {
      'embPanel__hoverActionsAnchor--lockHoverActions': hasLockedHoverActions
    }),
    "data-test-embeddable-id": api === null || api === void 0 ? void 0 : api.uuid,
    "data-test-subj": `embeddablePanelHoverActions-${(title || defaultTitle || '').replace(/\s/g, '')}`,
    css: (0, _react2.css)`
        border-radius: ${_uiTheme.euiThemeVars.euiBorderRadius};
        position: relative;
        height: 100%;

        .embPanel {
          ${showBorder ? `
              outline: ${viewMode === 'edit' ? DASHED_OUTLINE : SOLID_OUTLINE};
            ` : ''}
        }

        .embPanel__hoverActions {
          opacity: 0;
          padding: calc(${_uiTheme.euiThemeVars.euiSizeXS} - 1px);
          display: flex;
          flex-wrap: nowrap;

          background-color: ${_uiTheme.euiThemeVars.euiColorEmptyShade};
          height: ${_uiTheme.euiThemeVars.euiSizeXL};

          pointer-events: all; // Re-enable pointer-events for hover actions
        }

        &:hover,
        &:focus-within,
        &.embPanel__hoverActionsAnchor--lockHoverActions {
          .embPanel {
            outline: ${viewMode === 'edit' ? DASHED_OUTLINE : SOLID_OUTLINE};
            z-index: ${_uiTheme.euiThemeVars.euiZLevel2};
          }
          .embPanel__hoverActionsWrapper {
            z-index: ${_uiTheme.euiThemeVars.euiZLevel9};
            top: -${_uiTheme.euiThemeVars.euiSizeXL};

            .embPanel__hoverActions {
              opacity: 1;
            }
          }
        }
      `
  }, children, api ? /*#__PURE__*/_react.default.createElement("div", {
    ref: hoverActionsRef,
    className: "embPanel__hoverActionsWrapper",
    css: (0, _react2.css)`
            height: ${_uiTheme.euiThemeVars.euiSizeXL};
            position: absolute;
            top: 0;
            display: flex;
            justify-content: space-between;
            padding: 0 ${_uiTheme.euiThemeVars.euiSize};
            flex-wrap: nowrap;
            min-width: 100%;
            z-index: -1;
            pointer-events: none; // Prevent hover actions wrapper from blocking interactions with other panels
          `
  }, viewMode === 'edit' && !combineHoverActions ? /*#__PURE__*/_react.default.createElement("div", {
    ref: leftHoverActionsRef,
    "data-test-subj": "embPanel__hoverActions__left",
    className: (0, _classnames.default)('embPanel__hoverActions', 'embPanel__hoverActionsLeft', className),
    css: (0, _react2.css)`
                border: ${viewMode === 'edit' ? DASHED_OUTLINE : SOLID_OUTLINE};
                ${borderStyles}
              `
  }, dragHandle) : /*#__PURE__*/_react.default.createElement("div", null) // necessary for the right hover actions to align correctly when left hover actions are not present
  , hasHoverActions ? /*#__PURE__*/_react.default.createElement("div", {
    ref: rightHoverActionsRef,
    "data-test-subj": "embPanel__hoverActions__right",
    className: (0, _classnames.default)('embPanel__hoverActions', 'embPanel__hoverActionsRight', className),
    css: (0, _react2.css)`
                border: ${viewMode === 'edit' ? DASHED_OUTLINE : SOLID_OUTLINE};
                ${borderStyles}
              `
  }, viewMode === 'edit' && combineHoverActions && dragHandle, showNotifications && notificationElements, showDescription && /*#__PURE__*/_react.default.createElement(_eui.EuiIconTip, {
    title: !hideTitle ? title || undefined : undefined,
    content: description,
    delay: "regular",
    position: "top",
    anchorClassName: "embPanel__descriptionTooltipAnchor",
    "data-test-subj": "embeddablePanelDescriptionTooltip",
    type: "iInCircle"
  }), quickActionElements.map(({
    iconType,
    'data-test-subj': dataTestSubj,
    onClick,
    name
  }, i) => /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
    key: `main_action_${dataTestSubj}_${api === null || api === void 0 ? void 0 : api.uuid}`,
    content: name
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
    iconType: iconType,
    color: "text",
    onClick: onClick,
    "data-test-subj": dataTestSubj,
    "aria-label": name
  }))), contextMenuPanels.length ? /*#__PURE__*/_react.default.createElement(_eui.EuiPopover, {
    repositionOnScroll: true,
    panelPaddingSize: "none",
    anchorPosition: "downRight",
    button: ContextMenuButton,
    isOpen: isContextMenuOpen,
    className: contextMenuClasses,
    closePopover: onClose,
    "data-test-subj": isContextMenuOpen ? 'embeddablePanelContextMenuOpen' : 'embeddablePanelContextMenuClosed',
    focusTrapProps: {
      closeOnMouseup: true,
      clickOutsideDisables: false,
      onClickOutside: onClose
    }
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenu, {
    "data-test-subj": "presentationPanelContextMenuItems",
    initialPanelId: 'mainMenu',
    panels: contextMenuPanels
  })) : null) : null) : null);
};
exports.PresentationPanelHoverActions = PresentationPanelHoverActions;