"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerInstallationRoutes = void 0;
var _installation = require("../../common/http_api/installation");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const registerInstallationRoutes = ({
  router,
  getServices
}) => {
  router.get({
    path: _installation.INSTALLATION_STATUS_API_PATH,
    validate: false,
    options: {
      access: 'internal'
    },
    security: {
      authz: {
        requiredPrivileges: ['manage_llm_product_doc']
      }
    }
  }, async (ctx, req, res) => {
    const {
      installClient,
      documentationManager
    } = getServices();
    const installStatus = await installClient.getInstallationStatus();
    const {
      status: overallStatus
    } = await documentationManager.getStatus();
    return res.ok({
      body: {
        perProducts: installStatus,
        overall: overallStatus
      }
    });
  });
  router.post({
    path: _installation.INSTALL_ALL_API_PATH,
    validate: false,
    options: {
      access: 'internal',
      timeout: {
        idleSocket: 20 * 60 * 1000
      } // install can take time.
    },
    security: {
      authz: {
        requiredPrivileges: ['manage_llm_product_doc']
      }
    }
  }, async (ctx, req, res) => {
    const {
      documentationManager
    } = getServices();
    await documentationManager.install({
      request: req,
      force: false,
      wait: true
    });

    // check status after installation in case of failure
    const {
      status
    } = await documentationManager.getStatus();
    return res.ok({
      body: {
        installed: status === 'installed'
      }
    });
  });
  router.post({
    path: _installation.UNINSTALL_ALL_API_PATH,
    validate: false,
    options: {
      access: 'internal'
    },
    security: {
      authz: {
        requiredPrivileges: ['manage_llm_product_doc']
      }
    }
  }, async (ctx, req, res) => {
    const {
      documentationManager
    } = getServices();
    await documentationManager.uninstall({
      request: req,
      wait: true
    });
    return res.ok({
      body: {
        success: true
      }
    });
  });
};
exports.registerInstallationRoutes = registerInstallationRoutes;