"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ProductDocInstallClient = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _coreSavedObjectsServer = require("@kbn/core-saved-objects-server");
var _productDocCommon = require("@kbn/product-doc-common");
var _consts = require("../../../common/consts");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

class ProductDocInstallClient {
  constructor({
    soClient
  }) {
    (0, _defineProperty2.default)(this, "soClient", void 0);
    this.soClient = soClient;
  }
  async getInstallationStatus() {
    const response = await this.soClient.find({
      type: _consts.productDocInstallStatusSavedObjectTypeName,
      perPage: 100
    });
    const installStatus = Object.values(_productDocCommon.DocumentationProduct).reduce((memo, product) => {
      memo[product] = {
        status: 'uninstalled'
      };
      return memo;
    }, {});
    response.saved_objects.forEach(({
      attributes
    }) => {
      installStatus[attributes.product_name] = {
        status: attributes.installation_status,
        version: attributes.product_version
      };
    });
    return installStatus;
  }
  async setInstallationStarted(fields) {
    const {
      productName,
      productVersion
    } = fields;
    const objectId = getObjectIdFromProductName(productName);
    const attributes = {
      product_name: productName,
      product_version: productVersion,
      installation_status: 'installing',
      last_installation_failure_reason: ''
    };
    await this.soClient.update(_consts.productDocInstallStatusSavedObjectTypeName, objectId, attributes, {
      upsert: attributes
    });
  }
  async setInstallationSuccessful(productName, indexName) {
    const objectId = getObjectIdFromProductName(productName);
    await this.soClient.update(_consts.productDocInstallStatusSavedObjectTypeName, objectId, {
      installation_status: 'installed',
      index_name: indexName
    });
  }
  async setInstallationFailed(productName, failureReason) {
    const objectId = getObjectIdFromProductName(productName);
    await this.soClient.update(_consts.productDocInstallStatusSavedObjectTypeName, objectId, {
      installation_status: 'error',
      last_installation_failure_reason: failureReason
    });
  }
  async setUninstalled(productName) {
    const objectId = getObjectIdFromProductName(productName);
    try {
      await this.soClient.update(_consts.productDocInstallStatusSavedObjectTypeName, objectId, {
        installation_status: 'uninstalled',
        last_installation_failure_reason: ''
      });
    } catch (e) {
      if (!_coreSavedObjectsServer.SavedObjectsErrorHelpers.isNotFoundError(e)) {
        throw e;
      }
    }
  }
}
exports.ProductDocInstallClient = ProductDocInstallClient;
const getObjectIdFromProductName = productName => `kb-product-doc-${productName}-status`.toLowerCase();