"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.waitUntilModelDeployed = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const waitUntilModelDeployed = async ({
  modelId,
  client,
  log,
  maxRetries = 20,
  delay = 2000
}) => {
  for (let i = 0; i < maxRetries; i++) {
    var _statsRes$trained_mod;
    const statsRes = await client.ml.getTrainedModelsStats({
      model_id: modelId
    });
    const deploymentStats = (_statsRes$trained_mod = statsRes.trained_model_stats[0]) === null || _statsRes$trained_mod === void 0 ? void 0 : _statsRes$trained_mod.deployment_stats;
    // @ts-expect-error wrong client types
    if (!deploymentStats || deploymentStats.nodes.length === 0) {
      log.debug(`ML model [${modelId}] was not deployed - attempt ${i + 1} of ${maxRetries}`);
      await sleep(delay);
      continue;
    }
    return;
  }
  throw new Error(`Timeout waiting for ML model ${modelId} to be deployed`);
};
exports.waitUntilModelDeployed = waitUntilModelDeployed;
const sleep = ms => new Promise(resolve => setTimeout(resolve, ms));