"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createIndex = void 0;
var _consts = require("../../../../common/consts");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const createIndex = async ({
  esClient,
  indexName,
  mappings,
  log
}) => {
  log.debug(`Creating index ${indexName}`);
  overrideInferenceId(mappings, _consts.internalElserInferenceId);
  await esClient.indices.create({
    index: indexName,
    mappings,
    settings: {
      number_of_shards: 1,
      auto_expand_replicas: '0-1'
    }
  });
};
exports.createIndex = createIndex;
const overrideInferenceId = (mappings, inferenceId) => {
  const recursiveOverride = current => {
    if ('type' in current && current.type === 'semantic_text') {
      current.inference_id = inferenceId;
    }
    if ('properties' in current && current.properties) {
      for (const prop of Object.values(current.properties)) {
        recursiveOverride(prop);
      }
    }
  };
  recursiveOverride(mappings);
};