"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetchArtifactVersions = void 0;
var _nodeFetch = _interopRequireDefault(require("node-fetch"));
var _xml2js = require("xml2js");
var _productDocCommon = require("@kbn/product-doc-common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const fetchArtifactVersions = async ({
  artifactRepositoryUrl
}) => {
  const res = await (0, _nodeFetch.default)(`${artifactRepositoryUrl}?max-keys=1000`);
  const xml = await res.text();
  return new Promise((resolve, reject) => {
    (0, _xml2js.parseString)(xml, (err, result) => {
      var _result$ListBucketRes, _result$ListBucketRes2;
      if (err) {
        reject(err);
      }

      // 6 artifacts per minor stack version means we have a few decades before facing this problem
      if ((_result$ListBucketRes = result.ListBucketResult.IsTruncated) !== null && _result$ListBucketRes !== void 0 && _result$ListBucketRes.includes('true')) {
        throw new Error('bucket content is truncated, cannot retrieve all versions');
      }
      const allowedProductNames = Object.values(_productDocCommon.DocumentationProduct);
      const record = {};
      allowedProductNames.forEach(product => {
        record[product] = [];
      });
      (_result$ListBucketRes2 = result.ListBucketResult.Contents) === null || _result$ListBucketRes2 === void 0 ? void 0 : _result$ListBucketRes2.forEach(contentEntry => {
        const artifactName = contentEntry.Key[0];
        const parsed = (0, _productDocCommon.parseArtifactName)(artifactName);
        if (parsed) {
          const {
            productName,
            productVersion
          } = parsed;
          record[productName].push(productVersion);
        }
      });
      resolve(record);
    });
  });
};
exports.fetchArtifactVersions = fetchArtifactVersions;