"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.scheduleEnsureUpToDateTask = exports.registerEnsureUpToDateTaskDefinition = exports.ENSURE_DOC_UP_TO_DATE_TASK_TYPE = exports.ENSURE_DOC_UP_TO_DATE_TASK_ID = void 0;
var _utils = require("./utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ENSURE_DOC_UP_TO_DATE_TASK_TYPE = exports.ENSURE_DOC_UP_TO_DATE_TASK_TYPE = 'ProductDocBase:EnsureUpToDate';
const ENSURE_DOC_UP_TO_DATE_TASK_ID = exports.ENSURE_DOC_UP_TO_DATE_TASK_ID = 'ProductDocBase:EnsureUpToDate';
const registerEnsureUpToDateTaskDefinition = ({
  getServices,
  taskManager
}) => {
  taskManager.registerTaskDefinitions({
    [ENSURE_DOC_UP_TO_DATE_TASK_TYPE]: {
      title: 'Ensure product documentation up to date task',
      timeout: '10m',
      maxAttempts: 3,
      createTaskRunner: context => {
        return {
          async run() {
            const {
              packageInstaller
            } = getServices();
            return packageInstaller.ensureUpToDate({});
          }
        };
      },
      stateSchemaByVersion: {}
    }
  });
};
exports.registerEnsureUpToDateTaskDefinition = registerEnsureUpToDateTaskDefinition;
const scheduleEnsureUpToDateTask = async ({
  taskManager,
  logger
}) => {
  try {
    await taskManager.ensureScheduled({
      id: ENSURE_DOC_UP_TO_DATE_TASK_ID,
      taskType: ENSURE_DOC_UP_TO_DATE_TASK_TYPE,
      params: {},
      state: {},
      scope: ['productDoc']
    });
    await taskManager.runSoon(ENSURE_DOC_UP_TO_DATE_TASK_ID);
    logger.info(`Task ${ENSURE_DOC_UP_TO_DATE_TASK_ID} scheduled to run soon`);
  } catch (e) {
    if (!(0, _utils.isTaskCurrentlyRunningError)(e)) {
      throw e;
    }
  }
  return ENSURE_DOC_UP_TO_DATE_TASK_ID;
};
exports.scheduleEnsureUpToDateTask = scheduleEnsureUpToDateTask;