"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.scheduleInstallAllTask = exports.registerInstallAllTaskDefinition = exports.INSTALL_ALL_TASK_TYPE = exports.INSTALL_ALL_TASK_ID = void 0;
var _utils = require("./utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const INSTALL_ALL_TASK_TYPE = exports.INSTALL_ALL_TASK_TYPE = 'ProductDocBase:InstallAll';
const INSTALL_ALL_TASK_ID = exports.INSTALL_ALL_TASK_ID = 'ProductDocBase:InstallAll';
const registerInstallAllTaskDefinition = ({
  getServices,
  taskManager
}) => {
  taskManager.registerTaskDefinitions({
    [INSTALL_ALL_TASK_TYPE]: {
      title: 'Install all product documentation artifacts',
      timeout: '10m',
      maxAttempts: 3,
      createTaskRunner: context => {
        return {
          async run() {
            const {
              packageInstaller
            } = getServices();
            return packageInstaller.installAll({});
          }
        };
      },
      stateSchemaByVersion: {}
    }
  });
};
exports.registerInstallAllTaskDefinition = registerInstallAllTaskDefinition;
const scheduleInstallAllTask = async ({
  taskManager,
  logger
}) => {
  try {
    await taskManager.ensureScheduled({
      id: INSTALL_ALL_TASK_ID,
      taskType: INSTALL_ALL_TASK_TYPE,
      params: {},
      state: {},
      scope: ['productDoc']
    });
    await taskManager.runSoon(INSTALL_ALL_TASK_ID);
    logger.info(`Task ${INSTALL_ALL_TASK_ID} scheduled to run soon`);
  } catch (e) {
    if (!(0, _utils.isTaskCurrentlyRunningError)(e)) {
      throw e;
    }
  }
  return INSTALL_ALL_TASK_ID;
};
exports.scheduleInstallAllTask = scheduleInstallAllTask;