"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.scheduleUninstallAllTask = exports.registerUninstallAllTaskDefinition = exports.UNINSTALL_ALL_TASK_TYPE = exports.UNINSTALL_ALL_TASK_ID = void 0;
var _utils = require("./utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const UNINSTALL_ALL_TASK_TYPE = exports.UNINSTALL_ALL_TASK_TYPE = 'ProductDocBase:UninstallAll';
const UNINSTALL_ALL_TASK_ID = exports.UNINSTALL_ALL_TASK_ID = 'ProductDocBase:UninstallAll';
const registerUninstallAllTaskDefinition = ({
  getServices,
  taskManager
}) => {
  taskManager.registerTaskDefinitions({
    [UNINSTALL_ALL_TASK_TYPE]: {
      title: 'Uninstall all product documentation artifacts',
      timeout: '10m',
      maxAttempts: 3,
      createTaskRunner: context => {
        return {
          async run() {
            const {
              packageInstaller
            } = getServices();
            return packageInstaller.uninstallAll();
          }
        };
      },
      stateSchemaByVersion: {}
    }
  });
};
exports.registerUninstallAllTaskDefinition = registerUninstallAllTaskDefinition;
const scheduleUninstallAllTask = async ({
  taskManager,
  logger
}) => {
  try {
    await taskManager.ensureScheduled({
      id: UNINSTALL_ALL_TASK_ID,
      taskType: UNINSTALL_ALL_TASK_TYPE,
      params: {},
      state: {},
      scope: ['productDoc']
    });
    await taskManager.runSoon(UNINSTALL_ALL_TASK_ID);
    logger.info(`Task ${UNINSTALL_ALL_TASK_ID} scheduled to run soon`);
  } catch (e) {
    if (!(0, _utils.isTaskCurrentlyRunningError)(e)) {
      throw e;
    }
  }
  return UNINSTALL_ALL_TASK_ID;
};
exports.scheduleUninstallAllTask = scheduleUninstallAllTask;