"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAlertSummaryRoute = void 0;
var _boom = _interopRequireDefault(require("@hapi/boom"));
var t = _interopRequireWildcard(require("io-ts"));
var _securitysolutionEsUtils = require("@kbn/securitysolution-es-utils");
var _moment = _interopRequireDefault(require("moment"));
var _constants = require("../../common/constants");
var _route_validation = require("./utils/route_validation");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getAlertSummaryRoute = router => {
  router.post({
    path: `${_constants.BASE_RAC_ALERTS_API_PATH}/_alert_summary`,
    validate: {
      body: (0, _route_validation.buildRouteValidation)(t.intersection([t.exact(t.type({
        gte: t.string,
        lte: t.string,
        featureIds: t.array(t.string)
      })), t.exact(t.partial({
        fixed_interval: t.string,
        filter: t.array(t.object)
      }))]))
    },
    security: {
      authz: {
        requiredPrivileges: ['rac']
      }
    },
    options: {
      access: 'internal'
    }
  }, async (context, request, response) => {
    try {
      const racContext = await context.rac;
      const alertsClient = await racContext.getAlertsClient();
      const {
        gte,
        lte,
        featureIds,
        filter,
        fixed_interval: fixedInterval
      } = request.body;
      if (!((0, _moment.default)(gte, 'YYYY-MM-DDTHH:mm:ss.SSSZ', true).isValid() && (0, _moment.default)(lte, 'YYYY-MM-DDTHH:mm:ss.SSSZ', true).isValid())) {
        throw _boom.default.badRequest('gte and/or lte are not following the UTC format');
      }
      if (fixedInterval && (fixedInterval === null || fixedInterval === void 0 ? void 0 : fixedInterval.match(/^\d{1,6}['s','m','h','d']$/)) == null) {
        throw _boom.default.badRequest(`fixed_interval (value: ${fixedInterval}) is not following the expected format 1s, 1m, 1h, 1d with at most 6 digits`);
      }
      const aggs = await alertsClient.getAlertSummary({
        gte,
        lte,
        featureIds,
        filter: filter,
        fixedInterval
      });
      return response.ok({
        body: aggs
      });
    } catch (exc) {
      const err = (0, _securitysolutionEsUtils.transformError)(exc);
      const contentType = {
        'content-type': 'application/json'
      };
      const defaultedHeaders = {
        ...contentType
      };
      return response.customError({
        headers: defaultedHeaders,
        statusCode: err.statusCode,
        body: {
          message: err.message,
          attributes: {
            success: false
          }
        }
      });
    }
  });
};
exports.getAlertSummaryRoute = getAlertSummaryRoute;