"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Result = exports.DEFAULT_VISIBLE_FIELDS = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _results_fields = require("./results_fields");
require("./result.scss");
var _rich_result_header = require("./rich_result_header");
var _result_header = require("./result_header");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const DEFAULT_VISIBLE_FIELDS = exports.DEFAULT_VISIBLE_FIELDS = 3;
const Result = ({
  metaData,
  fields,
  defaultVisibleFields = DEFAULT_VISIBLE_FIELDS,
  compactCard = true,
  showScore = false,
  onDocumentClick,
  onDocumentDelete
}) => {
  var _metaData$title, _metaData$title2;
  const [isExpanded, setIsExpanded] = (0, _react.useState)(false);
  const tooltipText = fields.length <= defaultVisibleFields ? _i18n.i18n.translate('searchIndexDocuments.result.expandTooltip.allVisible', {
    defaultMessage: 'All fields are visible'
  }) : isExpanded ? _i18n.i18n.translate('searchIndexDocuments.result.expandTooltip.showFewer', {
    defaultMessage: 'Show {amount} fewer fields',
    values: {
      amount: fields.length - defaultVisibleFields
    }
  }) : _i18n.i18n.translate('searchIndexDocuments.result.expandTooltip.showMore', {
    defaultMessage: 'Show {amount} more fields',
    values: {
      amount: fields.length - defaultVisibleFields
    }
  });
  const toolTipContent = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, tooltipText);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiSplitPanel.Outer, {
    hasBorder: true,
    "data-test-subj": "search-index-documents-result"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSplitPanel.Inner, {
    paddingSize: "m",
    color: "plain",
    className: "resultHeaderContainer"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "none",
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, compactCard && /*#__PURE__*/_react.default.createElement(_result_header.ResultHeader, {
    title: (_metaData$title = metaData.title) !== null && _metaData$title !== void 0 ? _metaData$title : _i18n.i18n.translate('searchIndexDocuments.result.title.id', {
      defaultMessage: 'Document id: {id}',
      values: {
        id: metaData.id
      }
    }),
    metaData: metaData
  }), !compactCard && /*#__PURE__*/_react.default.createElement(_rich_result_header.RichResultHeader, {
    showScore: showScore,
    title: (_metaData$title2 = metaData.title) !== null && _metaData$title2 !== void 0 ? _metaData$title2 : _i18n.i18n.translate('searchIndexDocuments.result.title.id', {
      defaultMessage: 'Document id: {id}',
      values: {
        id: metaData.id
      }
    }),
    onTitleClick: onDocumentClick,
    metaData: {
      ...metaData,
      onDocumentDelete
    }
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
    position: "left",
    content: toolTipContent
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
    size: "xs",
    iconType: isExpanded ? 'fold' : 'unfold',
    color: isExpanded ? 'danger' : 'primary',
    "data-test-subj": isExpanded ? 'documentShowLessFields' : 'documentShowMoreFields',
    onClick: e => {
      e.stopPropagation();
      setIsExpanded(!isExpanded);
    },
    "aria-label": tooltipText
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, {
    margin: "none"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSplitPanel.Inner, {
    paddingSize: "m"
  }, /*#__PURE__*/_react.default.createElement(_results_fields.ResultFields, {
    documentId: metaData.id,
    isExpanded: isExpanded,
    fields: isExpanded ? fields : fields.slice(0, defaultVisibleFields)
  })));
};
exports.Result = Result;