"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ResultField = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _constants = require("./constants");
var _result_field_value = require("./result_field_value");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const iconMap = {
  boolean: 'tokenBoolean',
  date: 'tokenDate',
  date_range: 'tokenDate',
  dense_vector: 'tokenVectorDense',
  double: 'tokenNumber',
  double_range: 'tokenDate',
  flattened: 'tokenObject',
  float: 'tokenNumber',
  float_range: 'tokenNumber',
  geo_point: 'tokenGeo',
  geo_shape: 'tokenGeo',
  half_float: 'tokenNumber',
  histogram: 'tokenHistogram',
  integer: 'tokenNumber',
  integer_range: 'tokenNumber',
  ip: 'tokenIp',
  ip_range: 'tokenIp',
  join: 'tokenJoin',
  keyword: 'tokenKeyword',
  long: 'tokenNumber',
  long_range: 'tokenNumber',
  nested: 'tokenObject',
  object: 'tokenObject',
  percolator: 'tokenPercolator',
  rank_feature: 'tokenRankFeature',
  rank_features: 'tokenRankFeatures',
  scaled_float: 'tokenNumber',
  search_as_you_type: 'tokenSearchType',
  semantic_text: 'tokenSemanticText',
  shape: 'tokenShape',
  short: 'tokenNumber',
  sparse_vector: 'tokenVectorSparse',
  text: 'tokenString',
  token_count: 'tokenTokenCount',
  unsigned_long: 'tokenNumber'
};
const defaultToken = 'questionInCircle';
const ResultField = ({
  iconType,
  fieldName,
  fieldValue,
  fieldType = 'object',
  isExpanded
}) => {
  const shouldTruncate = !isExpanded || _constants.PERMANENTLY_TRUNCATED_FIELDS.includes(fieldType);
  const [isPopoverOpen, setIsPopoverOpen] = (0, _react.useState)(false);
  const fieldTypeLabel = _i18n.i18n.translate('searchIndexDocuments.result.fieldTypeAriaLabel', {
    defaultMessage: 'This field is of the type {fieldType}',
    values: {
      fieldType
    }
  });
  return /*#__PURE__*/_react.default.createElement(_eui.EuiTableRow, {
    className: "resultField"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTableRowCell, {
    className: "resultFieldRowCell",
    valign: "middle",
    truncateText: !isExpanded
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "row",
    alignItems: "center",
    gutterSize: "xs",
    justifyContent: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiPopover, {
    button: /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
      "aria-label": _i18n.i18n.translate('searchIndexDocuments.result.fieldTypeButtonAriaLabel', {
        defaultMessage: "Show this field's type"
      }),
      onClick: () => setIsPopoverOpen(!isPopoverOpen),
      iconType: iconType || (fieldType ? iconMap[fieldType] : defaultToken)
    }),
    isOpen: isPopoverOpen
  }, fieldTypeLabel)), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s",
    color: "default"
  }, fieldName)))), /*#__PURE__*/_react.default.createElement(_eui.EuiTableRowCell, {
    className: "resultFieldRowCell",
    truncateText: shouldTruncate,
    valign: "middle"
  }, /*#__PURE__*/_react.default.createElement(_result_field_value.ResultFieldValue, {
    fieldValue: fieldValue,
    fieldType: fieldType,
    isExpanded: isExpanded
  })));
};
exports.ResultField = ResultField;