"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchStart = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _constants = require("../../analytics/constants");
var _use_usage_tracker = require("../../hooks/use_usage_tracker");
var _indices = require("../../utils/indices");
var _language = require("../../utils/language");
var _create_index = require("./create_index");
var _create_index_code_view = require("../shared/create_index_code_view");
var _types = require("../../types");
var _create_index_panel = require("../shared/create_index_panel");
var _use_kibana = require("../../hooks/use_kibana");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function initCreateIndexState() {
  const defaultIndexName = (0, _indices.generateRandomIndexName)();
  return {
    indexName: defaultIndexName,
    defaultIndexName,
    codingLanguage: (0, _language.getDefaultCodingLanguage)()
  };
}
const ElasticsearchStart = ({
  userPrivileges
}) => {
  const {
    application
  } = (0, _use_kibana.useKibana)().services;
  const [createIndexView, setCreateIndexViewMode] = (0, _react.useState)((userPrivileges === null || userPrivileges === void 0 ? void 0 : userPrivileges.privileges.canCreateIndex) === false ? _types.CreateIndexViewMode.Code : _types.CreateIndexViewMode.UI);
  const [formState, setFormState] = (0, _react.useState)(initCreateIndexState);
  const usageTracker = (0, _use_usage_tracker.useUsageTracker)();
  (0, _react.useEffect)(() => {
    usageTracker.load(_constants.AnalyticsEvents.startPageOpened);
  }, [usageTracker]);
  (0, _react.useEffect)(() => {
    if (userPrivileges === undefined) return;
    if (userPrivileges.privileges.canCreateIndex === false) {
      setCreateIndexViewMode(_types.CreateIndexViewMode.Code);
    }
  }, [userPrivileges]);
  const onChangeView = (0, _react.useCallback)(id => {
    switch (id) {
      case _types.CreateIndexViewMode.UI:
        usageTracker.click(_constants.AnalyticsEvents.startPageShowCreateIndexUIClick);
        setCreateIndexViewMode(_types.CreateIndexViewMode.UI);
        return;
      case _types.CreateIndexViewMode.Code:
        usageTracker.click(_constants.AnalyticsEvents.startPageShowCodeClick);
        setCreateIndexViewMode(_types.CreateIndexViewMode.Code);
        return;
    }
  }, [usageTracker]);
  const onChangeCodingLanguage = (0, _react.useCallback)(language => {
    setFormState({
      ...formState,
      codingLanguage: language
    });
    usageTracker.count([_constants.AnalyticsEvents.startCreateIndexLanguageSelect, `${_constants.AnalyticsEvents.startCreateIndexLanguageSelect}_${language}`]);
  }, [usageTracker, formState, setFormState]);
  const onClose = (0, _react.useCallback)(() => {
    application.navigateToApp('management', {
      deepLinkId: 'index_management'
    });
  }, [application]);
  return /*#__PURE__*/_react.default.createElement(_create_index_panel.CreateIndexPanel, {
    title: _i18n.i18n.translate('xpack.searchIndices.startPage.createIndex.title', {
      defaultMessage: 'Create your first index'
    }),
    createIndexView: createIndexView,
    onChangeView: onChangeView,
    onClose: onClose,
    showSkip: true,
    showCallouts: true
  }, createIndexView === _types.CreateIndexViewMode.UI && /*#__PURE__*/_react.default.createElement(_create_index.CreateIndexUIView, {
    userPrivileges: userPrivileges,
    formState: formState,
    setFormState: setFormState
  }), createIndexView === _types.CreateIndexViewMode.Code && /*#__PURE__*/_react.default.createElement(_create_index_code_view.CreateIndexCodeView, {
    selectedLanguage: formState.codingLanguage,
    indexName: formState.indexName,
    changeCodingLanguage: onChangeCodingLanguage,
    canCreateApiKey: userPrivileges === null || userPrivileges === void 0 ? void 0 : userPrivileges.privileges.canCreateApiKeys,
    analyticsEvents: {
      runInConsole: _constants.AnalyticsEvents.startCreateIndexRunInConsole,
      installCommands: _constants.AnalyticsEvents.startCreateIndexCodeCopyInstall,
      createIndex: _constants.AnalyticsEvents.startCreateIndexCodeCopy
    }
  }));
};
exports.ElasticsearchStart = ElasticsearchStart;