"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerIndicesRoutes = registerIndicesRoutes;
var _configSchema = require("@kbn/config-schema");
var _i18n = require("@kbn/i18n");
var _routes = require("../../common/routes");
var _indices = require("../lib/indices");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function registerIndicesRoutes(router, logger) {
  router.post({
    path: _routes.POST_CREATE_INDEX_ROUTE,
    validate: {
      body: _configSchema.schema.object({
        indexName: _configSchema.schema.string()
      })
    },
    options: {
      access: 'internal'
    }
  }, async (context, request, response) => {
    const core = await context.core;
    const client = core.elasticsearch.client.asCurrentUser;
    const data = request.body;
    try {
      const body = await (0, _indices.createIndex)(client, logger, data);
      return response.ok({
        body,
        headers: {
          'content-type': 'application/json'
        }
      });
    } catch (e) {
      var _e$meta, _e$meta$body, _e$meta$body$error, _e$meta2, _e$meta3;
      switch (e === null || e === void 0 ? void 0 : (_e$meta = e.meta) === null || _e$meta === void 0 ? void 0 : (_e$meta$body = _e$meta.body) === null || _e$meta$body === void 0 ? void 0 : (_e$meta$body$error = _e$meta$body.error) === null || _e$meta$body$error === void 0 ? void 0 : _e$meta$body$error.type) {
        case 'resource_already_exists_exception':
          return response.conflict({
            body: {
              message: e.message
            }
          });
      }
      return response.customError({
        statusCode: e !== null && e !== void 0 && e.meta && (_e$meta2 = e.meta) !== null && _e$meta2 !== void 0 && _e$meta2.statusCode ? (_e$meta3 = e.meta) === null || _e$meta3 === void 0 ? void 0 : _e$meta3.statusCode : 500,
        body: {
          message: _i18n.i18n.translate('xpack.searchIndices.server.createIndex.errorMessage', {
            defaultMessage: 'Failed to create index due to an exception.\n{errorMessage}',
            values: {
              errorMessage: e.message
            }
          })
        }
      });
    }
  });
}