"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ServiceProvider = exports.SERVICE_PROVIDERS = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _mlTrainedModelsUtils = require("@kbn/ml-trained-models-utils");
var _elastic = _interopRequireDefault(require("../../../../assets/images/providers/elastic.svg"));
var _hugging_face = _interopRequireDefault(require("../../../../assets/images/providers/hugging_face.svg"));
var _cohere = _interopRequireDefault(require("../../../../assets/images/providers/cohere.svg"));
var _open_ai = _interopRequireDefault(require("../../../../assets/images/providers/open_ai.svg"));
var _azure_ai_studio = _interopRequireDefault(require("../../../../assets/images/providers/azure_ai_studio.svg"));
var _azure_open_ai = _interopRequireDefault(require("../../../../assets/images/providers/azure_open_ai.svg"));
var _google_ai_studio = _interopRequireDefault(require("../../../../assets/images/providers/google_ai_studio.svg"));
var _mistral = _interopRequireDefault(require("../../../../assets/images/providers/mistral.svg"));
var _amazon_bedrock = _interopRequireDefault(require("../../../../assets/images/providers/amazon_bedrock.svg"));
var _alibaba_cloud_ai_search = _interopRequireDefault(require("../../../../assets/images/providers/alibaba_cloud_ai_search.svg"));
var _watsonx_ai = _interopRequireDefault(require("../../../../assets/images/providers/watsonx_ai.svg"));
var _types = require("../../types");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SERVICE_PROVIDERS = exports.SERVICE_PROVIDERS = {
  [_types.ServiceProviderKeys['alibabacloud-ai-search']]: {
    icon: _alibaba_cloud_ai_search.default,
    name: 'AlibabaCloud AI Search'
  },
  [_types.ServiceProviderKeys.amazonbedrock]: {
    icon: _amazon_bedrock.default,
    name: 'Amazon Bedrock'
  },
  [_types.ServiceProviderKeys.azureaistudio]: {
    icon: _azure_ai_studio.default,
    name: 'Azure AI Studio'
  },
  [_types.ServiceProviderKeys.azureopenai]: {
    icon: _azure_open_ai.default,
    name: 'Azure OpenAI'
  },
  [_types.ServiceProviderKeys.cohere]: {
    icon: _cohere.default,
    name: 'Cohere'
  },
  [_types.ServiceProviderKeys.elasticsearch]: {
    icon: _elastic.default,
    name: 'Elasticsearch'
  },
  [_types.ServiceProviderKeys.elser]: {
    icon: _elastic.default,
    name: 'Elasticsearch'
  },
  [_types.ServiceProviderKeys.googleaistudio]: {
    icon: _google_ai_studio.default,
    name: 'Google AI Studio'
  },
  [_types.ServiceProviderKeys.hugging_face]: {
    icon: _hugging_face.default,
    name: 'Hugging Face'
  },
  [_types.ServiceProviderKeys.mistral]: {
    icon: _mistral.default,
    name: 'Mistral'
  },
  [_types.ServiceProviderKeys.openai]: {
    icon: _open_ai.default,
    name: 'OpenAI'
  },
  [_types.ServiceProviderKeys.watsonxai]: {
    icon: _watsonx_ai.default,
    name: 'WatsonxAI'
  }
};
const ServiceProvider = ({
  providerEndpoint
}) => {
  const {
    service
  } = providerEndpoint;
  const provider = SERVICE_PROVIDERS[service];
  return provider ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xs",
    direction: "row",
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 0
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    "data-test-subj": `table-column-service-provider-${service}`,
    type: provider.icon,
    style: {
      marginRight: '8px'
    }
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xs",
    direction: "column"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s",
    color: "subdued"
  }, provider.name)), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(EndpointModelInfo, {
    providerEndpoint: providerEndpoint
  }))))) : /*#__PURE__*/_react.default.createElement("span", null, service);
};
exports.ServiceProvider = ServiceProvider;
const EndpointModelInfo = ({
  providerEndpoint
}) => {
  var _ELASTIC_MODEL_DEFINI, _ELASTIC_MODEL_DEFINI2;
  const serviceSettings = providerEndpoint.service_settings;
  const modelId = 'model_id' in serviceSettings ? serviceSettings.model_id : 'model' in serviceSettings ? serviceSettings.model : undefined;
  const isEligibleForMITBadge = modelId && ((_ELASTIC_MODEL_DEFINI = _mlTrainedModelsUtils.ELASTIC_MODEL_DEFINITIONS[modelId]) === null || _ELASTIC_MODEL_DEFINI === void 0 ? void 0 : _ELASTIC_MODEL_DEFINI.license) === 'MIT';
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xs",
    direction: "column"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xs",
    direction: "row"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 0
  }, modelId && /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s",
    color: "subdued"
  }, modelId)), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 0
  }, isEligibleForMITBadge ? /*#__PURE__*/_react.default.createElement(_eui.EuiBadge, {
    color: "hollow",
    iconType: "popout",
    iconSide: "right",
    href: (_ELASTIC_MODEL_DEFINI2 = _mlTrainedModelsUtils.ELASTIC_MODEL_DEFINITIONS[modelId].licenseUrl) !== null && _ELASTIC_MODEL_DEFINI2 !== void 0 ? _ELASTIC_MODEL_DEFINI2 : '',
    target: "_blank",
    "data-test-subj": 'mit-license-badge'
  }, i18n.MIT_LICENSE) : null, ' '))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, endpointModelAtrributes(providerEndpoint)));
};
function endpointModelAtrributes(endpoint) {
  switch (endpoint.service) {
    case _types.ServiceProviderKeys.hugging_face:
      return huggingFaceAttributes(endpoint);
    case _types.ServiceProviderKeys.azureaistudio:
      return azureOpenAIStudioAttributes(endpoint);
    case _types.ServiceProviderKeys.azureopenai:
      return azureOpenAIAttributes(endpoint);
    default:
      return null;
  }
}
function huggingFaceAttributes(endpoint) {
  const serviceSettings = endpoint.service_settings;
  const url = 'url' in serviceSettings ? serviceSettings.url : null;
  return url;
}
function azureOpenAIStudioAttributes(endpoint) {
  const serviceSettings = endpoint.service_settings;
  return 'provider' in serviceSettings ? serviceSettings === null || serviceSettings === void 0 ? void 0 : serviceSettings.provider : undefined;
}
function azureOpenAIAttributes(endpoint) {
  const serviceSettings = endpoint.service_settings;
  return 'resource_name' in serviceSettings ? serviceSettings.resource_name : undefined;
}