"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FeaturePrivilegeCasesBuilder = void 0;
var _lodash = require("lodash");
var _feature_privilege_builder = require("./feature_privilege_builder");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * If you add a new operation type (all, push, update, etc) you should also
 * extend the mapping here x-pack/plugins/features/server/feature_privilege_iterator/feature_privilege_iterator.ts
 *
 * Also if you add a new operation (createCase, updateCase, etc) here you'll likely also need to make changes here:
 * x-pack/plugins/cases/server/authorization/index.ts and here x-pack/plugins/cases/server/connectors/cases/utils.ts
 */

const pushOperations = ['pushCase'];
const createOperations = ['createCase'];
const readOperations = ['getCase', 'getComment', 'getTags', 'getReporters', 'getUserActions', 'findConfigurations'];
// Update operations do not currently include the ability to re-open a case
const updateOperations = ['updateCase', 'updateComment'];
const deleteOperations = ['deleteCase', 'deleteComment'];
const settingsOperations = ['createConfiguration', 'updateConfiguration'];
const createCommentOperations = ['createComment'];
const reopenOperations = ['reopenCase'];
const allOperations = [...pushOperations, ...createOperations, ...readOperations, ...updateOperations, ...deleteOperations, ...settingsOperations, ...createCommentOperations, ...reopenOperations];
class FeaturePrivilegeCasesBuilder extends _feature_privilege_builder.BaseFeaturePrivilegeBuilder {
  getActions(privilegeDefinition, feature) {
    var _privilegeDefinition$, _privilegeDefinition$2, _privilegeDefinition$3, _privilegeDefinition$4, _privilegeDefinition$5, _privilegeDefinition$6, _privilegeDefinition$7, _privilegeDefinition$8, _privilegeDefinition$9;
    const getCasesPrivilege = (operations, owners = []) => {
      return owners.flatMap(owner => operations.map(operation => this.actions.cases.get(owner, operation)));
    };
    return (0, _lodash.uniq)([...getCasesPrivilege(allOperations, (_privilegeDefinition$ = privilegeDefinition.cases) === null || _privilegeDefinition$ === void 0 ? void 0 : _privilegeDefinition$.all), ...getCasesPrivilege(pushOperations, (_privilegeDefinition$2 = privilegeDefinition.cases) === null || _privilegeDefinition$2 === void 0 ? void 0 : _privilegeDefinition$2.push), ...getCasesPrivilege(createOperations, (_privilegeDefinition$3 = privilegeDefinition.cases) === null || _privilegeDefinition$3 === void 0 ? void 0 : _privilegeDefinition$3.create), ...getCasesPrivilege(readOperations, (_privilegeDefinition$4 = privilegeDefinition.cases) === null || _privilegeDefinition$4 === void 0 ? void 0 : _privilegeDefinition$4.read), ...getCasesPrivilege(updateOperations, (_privilegeDefinition$5 = privilegeDefinition.cases) === null || _privilegeDefinition$5 === void 0 ? void 0 : _privilegeDefinition$5.update), ...getCasesPrivilege(deleteOperations, (_privilegeDefinition$6 = privilegeDefinition.cases) === null || _privilegeDefinition$6 === void 0 ? void 0 : _privilegeDefinition$6.delete), ...getCasesPrivilege(settingsOperations, (_privilegeDefinition$7 = privilegeDefinition.cases) === null || _privilegeDefinition$7 === void 0 ? void 0 : _privilegeDefinition$7.settings), ...getCasesPrivilege(createCommentOperations, (_privilegeDefinition$8 = privilegeDefinition.cases) === null || _privilegeDefinition$8 === void 0 ? void 0 : _privilegeDefinition$8.createComment), ...getCasesPrivilege(reopenOperations, (_privilegeDefinition$9 = privilegeDefinition.cases) === null || _privilegeDefinition$9 === void 0 ? void 0 : _privilegeDefinition$9.reopenCase)]);
  }
}
exports.FeaturePrivilegeCasesBuilder = FeaturePrivilegeCasesBuilder;