"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Client = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _coreHttpCommon = require("@kbn/core-http-common");
var _shared = require("@kbn/openapi-common/shared");
var _securitysolutionUtils = require("@kbn/securitysolution-utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/*
 * NOTICE: Do not edit this file manually.
 * This file is automatically generated by the OpenAPI Generator, @kbn/openapi-generator.
 *
 * info:
 *   title: API client for quickstart
 *   version: Bundle (no version)
 */

class Client {
  constructor(options) {
    (0, _defineProperty2.default)(this, "kbnClient", void 0);
    (0, _defineProperty2.default)(this, "log", void 0);
    this.kbnClient = options.kbnClient;
    this.log = options.log;
  }
  /**
    * Migrations favor data integrity over shard size. Consequently, unused or orphaned indices are artifacts of
  the migration process. A successful migration will result in both the old and new indices being present.
  As such, the old, orphaned index can (and likely should) be deleted.
  While you can delete these indices manually,
  the endpoint accomplishes this task by applying a deletion policy to the relevant index, causing it to be deleted
  after 30 days. It also deletes other artifacts specific to the migration implementation.
     */
  async alertsMigrationCleanup(props) {
    this.log.info(`${new Date().toISOString()} Calling API AlertsMigrationCleanup`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/migration',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async applyEntityEngineDataviewIndices() {
    this.log.info(`${new Date().toISOString()} Calling API ApplyEntityEngineDataviewIndices`);
    return this.kbnClient.request({
      path: '/api/entity_store/engines/apply_dataview_indices',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async assetCriticalityGetPrivileges() {
    this.log.info(`${new Date().toISOString()} Calling API AssetCriticalityGetPrivileges`);
    return this.kbnClient.request({
      path: '/internal/asset_criticality/privileges',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Ensures that the packages needed for prebuilt detection rules to work are installed and up to date
   */
  async bootstrapPrebuiltRules() {
    this.log.info(`${new Date().toISOString()} Calling API BootstrapPrebuiltRules`);
    return this.kbnClient.request({
      path: '/internal/detection_engine/prebuilt_rules/_bootstrap',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Create new detection rules in bulk.
   */
  async bulkCreateRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API BulkCreateRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_bulk_create',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Delete detection rules in bulk.
   */
  async bulkDeleteRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API BulkDeleteRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_bulk_delete',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Deletes multiple rules.
   */
  async bulkDeleteRulesPost(props) {
    this.log.info(`${new Date().toISOString()} Calling API BulkDeleteRulesPost`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_bulk_delete',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Update specific fields of existing detection rules using the `rule_id` or `id` field.
   */
  async bulkPatchRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API BulkPatchRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_bulk_update',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PATCH',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Update multiple detection rules using the `rule_id` or `id` field. The original rules are replaced, and all unspecified fields are deleted.
  > info
  > You cannot modify the `id` or `rule_id` values.
     */
  async bulkUpdateRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API BulkUpdateRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_bulk_update',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PUT',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Bulk upsert up to 1000 asset criticality records, creating or updating them as needed.
   */
  async bulkUpsertAssetCriticalityRecords(props) {
    this.log.info(`${new Date().toISOString()} Calling API BulkUpsertAssetCriticalityRecords`);
    return this.kbnClient.request({
      path: '/api/asset_criticality/bulk',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Retrieves a clean draft timeline. If a draft timeline does not exist, it is created and returned.
     */
  async cleanDraftTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API CleanDraftTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline/_draft',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Cleaning up the the Risk Engine by removing the indices, mapping and transforms
   */
  async cleanUpRiskEngine() {
    this.log.info(`${new Date().toISOString()} Calling API CleanUpRiskEngine`);
    return this.kbnClient.request({
      path: '/api/risk_score/engine/dangerously_delete_data',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Copies and returns a timeline or timeline template.
     */
  async copyTimeline(props) {
    this.log.info(`${new Date().toISOString()} Calling API CopyTimeline`);
    return this.kbnClient.request({
      path: '/api/timeline/_copy',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async createAlertsIndex() {
    this.log.info(`${new Date().toISOString()} Calling API CreateAlertsIndex`);
    return this.kbnClient.request({
      path: '/api/detection_engine/index',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Initiate a migration of detection alerts.
  Migrations are initiated per index. While the process is neither destructive nor interferes with existing data, it may be resource-intensive. As such, it is recommended that you plan your migrations accordingly.
     */
  async createAlertsMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API CreateAlertsMigration`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/migration',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Create or update a criticality record for a specific asset.
   */
  async createAssetCriticalityRecord(props) {
    this.log.info(`${new Date().toISOString()} Calling API CreateAssetCriticalityRecord`);
    return this.kbnClient.request({
      path: '/api/asset_criticality',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Create a new detection rule.
   */
  async createRule(props) {
    this.log.info(`${new Date().toISOString()} Calling API CreateRule`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Creates a new SIEM rules migration using the original vendor rules provided
   */
  async createRuleMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API CreateRuleMigration`);
    return this.kbnClient.request({
      path: '/internal/siem_migrations/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async createTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API CreateTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async createUpdateProtectionUpdatesNote(props) {
    this.log.info(`${new Date().toISOString()} Calling API CreateUpdateProtectionUpdatesNote`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/endpoint/protection_updates_note/{package_policy_id}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async deleteAlertsIndex() {
    this.log.info(`${new Date().toISOString()} Calling API DeleteAlertsIndex`);
    return this.kbnClient.request({
      path: '/api/detection_engine/index',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Delete the asset criticality record for a specific asset if it exists.
   */
  async deleteAssetCriticalityRecord(props) {
    this.log.info(`${new Date().toISOString()} Calling API DeleteAssetCriticalityRecord`);
    return this.kbnClient.request({
      path: '/api/asset_criticality',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async deleteEntityEngine(props) {
    this.log.info(`${new Date().toISOString()} Calling API DeleteEntityEngine`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/entity_store/engines/{entityType}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async deleteNote(props) {
    this.log.info(`${new Date().toISOString()} Calling API DeleteNote`);
    return this.kbnClient.request({
      path: '/api/note',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Delete a detection rule using the `rule_id` or `id` field.
   */
  async deleteRule(props) {
    this.log.info(`${new Date().toISOString()} Calling API DeleteRule`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async deleteTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API DeleteTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'DELETE',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Calculates and persists Risk Scores for an entity, returning the calculated risk score.
   */
  async deprecatedTriggerRiskScoreCalculation(props) {
    this.log.info(`${new Date().toISOString()} Calling API DeprecatedTriggerRiskScoreCalculation`);
    return this.kbnClient.request({
      path: '/api/risk_scores/calculation/entity',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async disableRiskEngine() {
    this.log.info(`${new Date().toISOString()} Calling API DisableRiskEngine`);
    return this.kbnClient.request({
      path: '/internal/risk_score/engine/disable',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async enableRiskEngine() {
    this.log.info(`${new Date().toISOString()} Calling API EnableRiskEngine`);
    return this.kbnClient.request({
      path: '/internal/risk_score/engine/enable',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Run a shell command on an endpoint.
   */
  async endpointExecuteAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointExecuteAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/execute',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Download a file from an endpoint.
   */
  async endpointFileDownload(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointFileDownload`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/endpoint/action/{action_id}/file/{file_id}/download', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get information for the specified file using the file ID.
   */
  async endpointFileInfo(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointFileInfo`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/endpoint/action/{action_id}/file/{file_id}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get the details of a response action using the action ID.
   */
  async endpointGetActionsDetails(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointGetActionsDetails`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/endpoint/action/{action_id}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get a list of all response actions.
   */
  async endpointGetActionsList(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointGetActionsList`);
    return this.kbnClient.request({
      path: '/api/endpoint/action',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get a response actions state, which reports whether encryption is enabled.
   */
  async endpointGetActionsState() {
    this.log.info(`${new Date().toISOString()} Calling API EndpointGetActionsState`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/state',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get the status of response actions for the specified agent IDs.
   */
  async endpointGetActionsStatus(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointGetActionsStatus`);
    return this.kbnClient.request({
      path: '/api/endpoint/action_status',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get a file from an endpoint.
   */
  async endpointGetFileAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointGetFileAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/get_file',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get a list of all processes running on an endpoint.
   */
  async endpointGetProcessesAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointGetProcessesAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/running_procs',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Isolate an endpoint from the network. The endpoint remains isolated until it's released.
   */
  async endpointIsolateAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointIsolateAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/isolate',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Isolate an endpoint from the network.
  > info
  > This URL will return a 308 permanent redirect to `POST <kibana host>:<port>/api/endpoint/action/isolate`.
     */
  async endpointIsolateRedirect(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointIsolateRedirect`);
    return this.kbnClient.request({
      path: '/api/endpoint/isolate',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Terminate a running process on an endpoint.
   */
  async endpointKillProcessAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointKillProcessAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/kill_process',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Scan a specific file or directory on an endpoint for malware.
   */
  async endpointScanAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointScanAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/scan',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Suspend a running process on an endpoint.
   */
  async endpointSuspendProcessAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointSuspendProcessAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/suspend_process',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Release an isolated endpoint, allowing it to rejoin a network.
   */
  async endpointUnisolateAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointUnisolateAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/unisolate',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Release an isolated endpoint, allowing it to rejoin a network.
  > info
  > This URL will return a 308 permanent redirect to `POST <kibana host>:<port>/api/endpoint/action/unisolate`.
     */
  async endpointUnisolateRedirect(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointUnisolateRedirect`);
    return this.kbnClient.request({
      path: '/api/endpoint/unisolate',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Upload a file to an endpoint.
   */
  async endpointUploadAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API EndpointUploadAction`);
    return this.kbnClient.request({
      path: '/api/endpoint/action/upload',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async entityStoreGetPrivileges() {
    this.log.info(`${new Date().toISOString()} Calling API EntityStoreGetPrivileges`);
    return this.kbnClient.request({
      path: '/internal/entity_store/privileges',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Export detection rules to an `.ndjson` file. The following configuration items are also included in the `.ndjson` file:
  - Actions
  - Exception lists
  > info
  > You cannot export prebuilt rules.
     */
  async exportRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API ExportRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_export',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body,
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async exportTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API ExportTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline/_export',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body,
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Finalize successful migrations of detection alerts. This replaces the original index's alias with the successfully migrated index's alias.
  The endpoint is idempotent; therefore, it can safely be used to poll a given migration and, upon completion,
  finalize it.
     */
  async finalizeAlertsMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API FinalizeAlertsMigration`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/finalize_migration',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * List asset criticality records, paging, sorting and filtering as needed.
   */
  async findAssetCriticalityRecords(props) {
    this.log.info(`${new Date().toISOString()} Calling API FindAssetCriticalityRecords`);
    return this.kbnClient.request({
      path: '/api/asset_criticality/list',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieve a paginated list of detection rules. By default, the first page is returned, with 20 results per page.
   */
  async findRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API FindRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_find',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getAgentPolicySummary(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetAgentPolicySummary`);
    return this.kbnClient.request({
      path: '/api/endpoint/policy/summaries',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieves the rule migrations stats for all migrations stored in the system
   */
  async getAllStatsRuleMigration() {
    this.log.info(`${new Date().toISOString()} Calling API GetAllStatsRuleMigration`);
    return this.kbnClient.request({
      path: '/internal/siem_migrations/rules/stats',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Get the criticality record for a specific asset.
   */
  async getAssetCriticalityRecord(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetAssetCriticalityRecord`);
    return this.kbnClient.request({
      path: '/api/asset_criticality',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getAssetCriticalityStatus() {
    this.log.info(`${new Date().toISOString()} Calling API GetAssetCriticalityStatus`);
    return this.kbnClient.request({
      path: '/internal/asset_criticality/status',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getDraftTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetDraftTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline/_draft',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getEndpointMetadataList(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetEndpointMetadataList`);
    return this.kbnClient.request({
      path: '/api/endpoint/metadata',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getEndpointSuggestions(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetEndpointSuggestions`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/endpoint/suggestions/{suggestion_type}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getEntityEngine(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetEntityEngine`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/entity_store/engines/{entityType}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getEntityEngineStats(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetEntityEngineStats`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/entity_store/engines/{entityType}/stats', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Gets notes
   */
  async getNotes(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetNotes`);
    return this.kbnClient.request({
      path: '/api/note',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getPolicyResponse(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetPolicyResponse`);
    return this.kbnClient.request({
      path: '/api/endpoint/policy_response',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getProtectionUpdatesNote(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetProtectionUpdatesNote`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/endpoint/protection_updates_note/{package_policy_id}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Returns the status of both the legacy transform-based risk engine, as well as the new risk engine
   */
  async getRiskEngineStatus() {
    this.log.info(`${new Date().toISOString()} Calling API GetRiskEngineStatus`);
    return this.kbnClient.request({
      path: '/internal/risk_score/engine/status',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getRuleExecutionEvents(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetRuleExecutionEvents`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/detection_engine/rules/{ruleId}/execution/events', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'PUT',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getRuleExecutionResults(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetRuleExecutionResults`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/detection_engine/rules/{ruleId}/execution/results', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'PUT',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieves the rule documents stored in the system given the rule migration id
   */
  async getRuleMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetRuleMigration`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/siem_migrations/rules/{migration_id}', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieves resources for an existing SIEM rules migration
   */
  async getRuleMigrationResources(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetRuleMigrationResources`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/siem_migrations/rules/{migration_id}/resources', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieves the stats of a SIEM rules migration using the migration id provided
   */
  async getRuleMigrationStats(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetRuleMigrationStats`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/siem_migrations/rules/{migration_id}/stats', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getTimeline(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetTimeline`);
    return this.kbnClient.request({
      path: '/api/timeline',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async getTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API GetTimelines`);
    return this.kbnClient.request({
      path: '/api/timelines',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Import detection rules from an `.ndjson` file, including actions and exception lists. The request must include:
  - The `Content-Type: multipart/form-data` HTTP header.
  - A link to the `.ndjson` file containing the rules.
     */
  async importRules(props) {
    this.log.info(`${new Date().toISOString()} Calling API ImportRules`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_import',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.attachment,
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async importTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API ImportTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline/_import',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async initEntityEngine(props) {
    this.log.info(`${new Date().toISOString()} Calling API InitEntityEngine`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/entity_store/engines/{entityType}/init', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Initializes the Risk Engine by creating the necessary indices and mappings, removing old transforms, and starting the new risk engine
   */
  async initRiskEngine() {
    this.log.info(`${new Date().toISOString()} Calling API InitRiskEngine`);
    return this.kbnClient.request({
      path: '/internal/risk_score/engine/init',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Install and update all Elastic prebuilt detection rules and Timelines.
   */
  async installPrebuiltRulesAndTimelines() {
    this.log.info(`${new Date().toISOString()} Calling API InstallPrebuiltRulesAndTimelines`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/prepackaged',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PUT'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async installPrepackedTimelines(props) {
    this.log.info(`${new Date().toISOString()} Calling API InstallPrepackedTimelines`);
    return this.kbnClient.request({
      path: '/api/timeline/_prepackaged',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async internalUploadAssetCriticalityRecords(props) {
    this.log.info(`${new Date().toISOString()} Calling API InternalUploadAssetCriticalityRecords`);
    return this.kbnClient.request({
      path: '/internal/asset_criticality/upload_csv',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.attachment
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * List entities records, paging, sorting and filtering as needed.
   */
  async listEntities(props) {
    this.log.info(`${new Date().toISOString()} Calling API ListEntities`);
    return this.kbnClient.request({
      path: '/api/entity_store/entities/list',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async listEntityEngines() {
    this.log.info(`${new Date().toISOString()} Calling API ListEntityEngines`);
    return this.kbnClient.request({
      path: '/api/entity_store/engines',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Update specific fields of an existing detection rule using the `rule_id` or `id` field.
   */
  async patchRule(props) {
    this.log.info(`${new Date().toISOString()} Calling API PatchRule`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PATCH',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Updates an existing timeline. This API is used to update the title, description, date range, pinned events, pinned queries, and/or pinned saved queries of an existing timeline.
   */
  async patchTimeline(props) {
    this.log.info(`${new Date().toISOString()} Calling API PatchTimeline`);
    return this.kbnClient.request({
      path: '/api/timeline',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PATCH',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Apply a bulk action, such as bulk edit, duplicate, or delete, to multiple detection rules. The bulk action is applied to all rules that match the query or to the rules listed by their IDs.
   */
  async performRulesBulkAction(props) {
    this.log.info(`${new Date().toISOString()} Calling API PerformRulesBulkAction`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/_bulk_action',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body,
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async persistFavoriteRoute(props) {
    this.log.info(`${new Date().toISOString()} Calling API PersistFavoriteRoute`);
    return this.kbnClient.request({
      path: '/api/timeline/_favorite',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PATCH',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async persistNoteRoute(props) {
    this.log.info(`${new Date().toISOString()} Calling API PersistNoteRoute`);
    return this.kbnClient.request({
      path: '/api/note',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PATCH',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async persistPinnedEventRoute(props) {
    this.log.info(`${new Date().toISOString()} Calling API PersistPinnedEventRoute`);
    return this.kbnClient.request({
      path: '/api/pinned_event',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PATCH',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Calculates and returns a list of Risk Scores, sorted by identifier_type and risk score.
   */
  async previewRiskScore(props) {
    this.log.info(`${new Date().toISOString()} Calling API PreviewRiskScore`);
    return this.kbnClient.request({
      path: '/internal/risk_score/preview',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async readAlertsIndex() {
    this.log.info(`${new Date().toISOString()} Calling API ReadAlertsIndex`);
    return this.kbnClient.request({
      path: '/api/detection_engine/index',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieve indices that contain detection alerts of a particular age, along with migration information for each of those indices.
   */
  async readAlertsMigrationStatus(props) {
    this.log.info(`${new Date().toISOString()} Calling API ReadAlertsMigrationStatus`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/migration_status',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieve the status of all Elastic prebuilt detection rules and Timelines.
   */
  async readPrebuiltRulesAndTimelinesStatus() {
    this.log.info(`${new Date().toISOString()} Calling API ReadPrebuiltRulesAndTimelinesStatus`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/prepackaged/_status',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Retrieves whether or not the user is authenticated, and the user's Kibana
  space and index privileges, which determine if the user can create an
  index for the Elastic Security alerts generated by
  detection engine rules.
     */
  async readPrivileges() {
    this.log.info(`${new Date().toISOString()} Calling API ReadPrivileges`);
    return this.kbnClient.request({
      path: '/api/detection_engine/privileges',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async readRiskEngineSettings() {
    this.log.info(`${new Date().toISOString()} Calling API ReadRiskEngineSettings`);
    return this.kbnClient.request({
      path: '/internal/risk_score/engine/settings',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Retrieve a detection rule using the `rule_id` or `id` field.
   */
  async readRule(props) {
    this.log.info(`${new Date().toISOString()} Calling API ReadRule`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * List all unique tags from all detection rules.
   */
  async readTags() {
    this.log.info(`${new Date().toISOString()} Calling API ReadTags`);
    return this.kbnClient.request({
      path: '/api/detection_engine/tags',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async resolveTimeline(props) {
    this.log.info(`${new Date().toISOString()} Calling API ResolveTimeline`);
    return this.kbnClient.request({
      path: '/api/timeline/resolve',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'GET',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async riskEngineGetPrivileges() {
    this.log.info(`${new Date().toISOString()} Calling API RiskEngineGetPrivileges`);
    return this.kbnClient.request({
      path: '/internal/risk_engine/privileges',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'GET'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async rulePreview(props) {
    this.log.info(`${new Date().toISOString()} Calling API RulePreview`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules/preview',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body,
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async scheduleRiskEngineNow() {
    this.log.info(`${new Date().toISOString()} Calling API ScheduleRiskEngineNow`);
    return this.kbnClient.request({
      path: '/api/risk_score/engine/schedule_now',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Find and/or aggregate detection alerts that match the given query.
   */
  async searchAlerts(props) {
    this.log.info(`${new Date().toISOString()} Calling API SearchAlerts`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/search',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Assign users to detection alerts, and unassign them from alerts.
  > info
  > You cannot add and remove the same assignee in the same request.
     */
  async setAlertAssignees(props) {
    this.log.info(`${new Date().toISOString()} Calling API SetAlertAssignees`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/assignees',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Set the status of one or more detection alerts.
   */
  async setAlertsStatus(props) {
    this.log.info(`${new Date().toISOString()} Calling API SetAlertsStatus`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/status',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * And tags to detection alerts, and remove them from alerts.
  > info
  > You cannot add and remove the same alert tag in the same request.
     */
  async setAlertTags(props) {
    this.log.info(`${new Date().toISOString()} Calling API SetAlertTags`);
    return this.kbnClient.request({
      path: '/api/detection_engine/signals/tags',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async startEntityEngine(props) {
    this.log.info(`${new Date().toISOString()} Calling API StartEntityEngine`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/entity_store/engines/{entityType}/start', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Starts a SIEM rules migration using the migration id provided
   */
  async startRuleMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API StartRuleMigration`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/siem_migrations/rules/{migration_id}/start', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'PUT',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async stopEntityEngine(props) {
    this.log.info(`${new Date().toISOString()} Calling API StopEntityEngine`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/api/entity_store/engines/{entityType}/stop', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'POST'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Stops a running SIEM rules migration using the migration id provided
   */
  async stopRuleMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API StopRuleMigration`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/siem_migrations/rules/{migration_id}/stop', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'PUT'
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Suggests user profiles.
   */
  async suggestUserProfiles(props) {
    this.log.info(`${new Date().toISOString()} Calling API SuggestUserProfiles`);
    return this.kbnClient.request({
      path: '/internal/detection_engine/users/_find',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      query: props.query
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Calculates and persists Risk Scores for an entity, returning the calculated risk score.
   */
  async triggerRiskScoreCalculation(props) {
    this.log.info(`${new Date().toISOString()} Calling API TriggerRiskScoreCalculation`);
    return this.kbnClient.request({
      path: '/internal/risk_score/calculation/entity',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
    * Update a detection rule using the `rule_id` or `id` field. The original rule is replaced, and all unspecified fields are deleted.
  > info
  > You cannot modify the `id` or `rule_id` values.
     */
  async updateRule(props) {
    this.log.info(`${new Date().toISOString()} Calling API UpdateRule`);
    return this.kbnClient.request({
      path: '/api/detection_engine/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '2023-10-31'
      },
      method: 'PUT',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Updates rules migrations attributes
   */
  async updateRuleMigration(props) {
    this.log.info(`${new Date().toISOString()} Calling API UpdateRuleMigration`);
    return this.kbnClient.request({
      path: '/internal/siem_migrations/rules',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'PUT',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  async uploadAssetCriticalityRecords(props) {
    this.log.info(`${new Date().toISOString()} Calling API UploadAssetCriticalityRecords`);
    return this.kbnClient.request({
      path: '/api/asset_criticality/upload_csv',
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.attachment
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
  /**
   * Creates or updates resources for an existing SIEM rules migration
   */
  async upsertRuleMigrationResources(props) {
    this.log.info(`${new Date().toISOString()} Calling API UpsertRuleMigrationResources`);
    return this.kbnClient.request({
      path: (0, _shared.replaceParams)('/internal/siem_migrations/rules/{migration_id}/resources', props.params),
      headers: {
        [_coreHttpCommon.ELASTIC_HTTP_VERSION_HEADER]: '1'
      },
      method: 'POST',
      body: props.body
    }).catch(_securitysolutionUtils.catchAxiosErrorFormatAndThrow);
  }
}
exports.Client = Client;