"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleMigrationTranslationResultEnum = exports.RuleMigrationTranslationResult = exports.RuleMigrationTaskStats = exports.RuleMigrationStatusEnum = exports.RuleMigrationStatus = exports.RuleMigrationResourceTypeEnum = exports.RuleMigrationResourceType = exports.RuleMigrationResourceData = exports.RuleMigrationResource = exports.RuleMigrationData = exports.RuleMigrationComments = exports.RuleMigrationAllTaskStats = exports.RuleMigration = exports.OriginalRuleVendor = exports.OriginalRule = exports.ElasticRulePartial = exports.ElasticRule = void 0;
var _zod = require("@kbn/zod");
var _common = require("./common.gen");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/*
 * NOTICE: Do not edit this file manually.
 * This file is automatically generated by the OpenAPI Generator, @kbn/openapi-generator.
 *
 * info:
 *   title: SIEM Rule Migration components
 *   version: not applicable
 */

/**
 * The original rule vendor identifier.
 */

const OriginalRuleVendor = exports.OriginalRuleVendor = _zod.z.literal('splunk');

/**
 * The original rule to migrate.
 */

const OriginalRule = exports.OriginalRule = _zod.z.object({
  /**
   * The original rule id.
   */
  id: _common.NonEmptyString,
  /**
   * The original rule vendor identifier.
   */
  vendor: OriginalRuleVendor,
  /**
   * The original rule name.
   */
  title: _zod.z.string(),
  /**
   * The original rule description.
   */
  description: _zod.z.string(),
  /**
   * The original rule query.
   */
  query: _zod.z.string(),
  /**
   * The original rule query language.
   */
  query_language: _zod.z.string(),
  /**
   * The original rule Mitre Attack technique IDs.
   */
  mitre_attack_ids: _zod.z.array(_zod.z.string()).optional()
});

/**
 * The migrated elastic rule.
 */

const ElasticRule = exports.ElasticRule = _zod.z.object({
  /**
   * The migrated rule title.
   */
  title: _zod.z.string(),
  /**
   * The migrated rule description.
   */
  description: _zod.z.string().optional(),
  /**
   * The migrated rule severity.
   */
  severity: _zod.z.string().optional(),
  /**
   * The translated elastic query.
   */
  query: _zod.z.string().optional(),
  /**
   * The translated elastic query language.
   */
  query_language: _zod.z.literal('esql').optional(),
  /**
   * The Elastic prebuilt rule id matched.
   */
  prebuilt_rule_id: _common.NonEmptyString.optional(),
  /**
   * The Elastic rule id installed as a result.
   */
  id: _common.NonEmptyString.optional()
});

/**
 * The partial version of the migrated elastic rule.
 */

const ElasticRulePartial = exports.ElasticRulePartial = ElasticRule.partial();

/**
 * The rule translation result.
 */

const RuleMigrationTranslationResult = exports.RuleMigrationTranslationResult = _zod.z.enum(['full', 'partial', 'untranslatable']);
const RuleMigrationTranslationResultEnum = exports.RuleMigrationTranslationResultEnum = RuleMigrationTranslationResult.enum;

/**
 * The status of the rule migration process.
 */

const RuleMigrationStatus = exports.RuleMigrationStatus = _zod.z.enum(['pending', 'processing', 'completed', 'failed']);
const RuleMigrationStatusEnum = exports.RuleMigrationStatusEnum = RuleMigrationStatus.enum;

/**
 * The comments for the migration including a summary from the LLM in markdown.
 */

const RuleMigrationComments = exports.RuleMigrationComments = _zod.z.array(_zod.z.string());

/**
 * The rule migration document object.
 */

const RuleMigrationData = exports.RuleMigrationData = _zod.z.object({
  /**
   * The moment of creation
   */
  '@timestamp': _zod.z.string(),
  /**
   * The migration id.
   */
  migration_id: _common.NonEmptyString,
  /**
   * The username of the user who created the migration.
   */
  created_by: _common.NonEmptyString,
  /**
   * The original rule to migrate.
   */
  original_rule: OriginalRule,
  /**
   * The migrated elastic rule.
   */
  elastic_rule: ElasticRule.optional(),
  /**
   * The rule translation result.
   */
  translation_result: RuleMigrationTranslationResult.optional(),
  /**
   * The status of the rule migration process.
   */
  status: RuleMigrationStatus.default('pending'),
  /**
   * The comments for the migration including a summary from the LLM in markdown.
   */
  comments: RuleMigrationComments.optional(),
  /**
   * The moment of the last update
   */
  updated_at: _zod.z.string().optional(),
  /**
   * The user who last updated the migration
   */
  updated_by: _zod.z.string().optional()
});

/**
 * The rule migration document object.
 */

const RuleMigration = exports.RuleMigration = _zod.z.object({
  /**
   * The rule migration id
   */
  id: _common.NonEmptyString
}).merge(RuleMigrationData);

/**
 * The rule migration task stats object.
 */

const RuleMigrationTaskStats = exports.RuleMigrationTaskStats = _zod.z.object({
  /**
   * Indicates if the migration task status.
   */
  status: _zod.z.enum(['ready', 'running', 'stopped', 'finished']),
  /**
   * The rules migration stats.
   */
  rules: _zod.z.object({
    /**
     * The total number of rules to migrate.
     */
    total: _zod.z.number().int(),
    /**
     * The number of rules that are pending migration.
     */
    pending: _zod.z.number().int(),
    /**
     * The number of rules that are being migrated.
     */
    processing: _zod.z.number().int(),
    /**
     * The number of rules that have been migrated successfully.
     */
    completed: _zod.z.number().int(),
    /**
     * The number of rules that have failed migration.
     */
    failed: _zod.z.number().int()
  }),
  /**
   * The moment of the last update.
   */
  last_updated_at: _zod.z.string().optional()
});
const RuleMigrationAllTaskStats = exports.RuleMigrationAllTaskStats = _zod.z.array(RuleMigrationTaskStats.merge(_zod.z.object({
  /**
   * The migration id
   */
  migration_id: _common.NonEmptyString
})));

/**
 * The type of the rule migration resource.
 */

const RuleMigrationResourceType = exports.RuleMigrationResourceType = _zod.z.enum(['macro', 'list']);
const RuleMigrationResourceTypeEnum = exports.RuleMigrationResourceTypeEnum = RuleMigrationResourceType.enum;

/**
 * The rule migration resource data provided by the vendor.
 */

const RuleMigrationResourceData = exports.RuleMigrationResourceData = _zod.z.object({
  type: RuleMigrationResourceType,
  /**
   * The resource name identifier.
   */
  name: _zod.z.string(),
  /**
   * The resource content value.
   */
  content: _zod.z.string(),
  /**
   * The resource arbitrary metadata.
   */
  metadata: _zod.z.object({}).optional()
});

/**
 * The rule migration resource document object.
 */

const RuleMigrationResource = exports.RuleMigrationResource = RuleMigrationResourceData.merge(_zod.z.object({
  /**
   * The rule resource migration id
   */
  id: _common.NonEmptyString,
  /**
   * The migration id
   */
  migration_id: _common.NonEmptyString,
  /**
   * The moment of the last update
   */
  updated_at: _zod.z.string().optional(),
  /**
   * The user who last updated the resource
   */
  updated_by: _zod.z.string().optional()
}));