"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.enhanceActionWithTelemetry = void 0;
var _telemetry = require("../../common/lib/telemetry");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const enhanceActionWithTelemetry = (action, services) => {
  const {
    telemetry
  } = services;
  const {
    execute,
    ...rest
  } = action;
  const enhancedExecute = context => {
    telemetry.reportEvent(_telemetry.AppEventTypes.CellActionClicked, {
      actionId: rest.id,
      displayName: rest.getDisplayName(context),
      fieldName: context.data.map(({
        field
      }) => field.name).join(', '),
      metadata: context.metadata
    });
    return execute(context);
  };
  return {
    ...rest,
    execute: enhancedExecute
  };
};
exports.enhanceActionWithTelemetry = enhanceActionWithTelemetry;