"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SettingsModal = void 0;
var _eui = require("@elastic/eui");
var _elasticAssistant = require("@kbn/elastic-assistant");
var _react = _interopRequireWildcard(require("react"));
var _useLocalStorage = _interopRequireDefault(require("react-use/lib/useLocalStorage"));
var _alerts_settings = require("./alerts_settings");
var _use_space_id = require("../../../../common/hooks/use_space_id");
var _footer = require("./footer");
var _is_tour_enabled = require("./is_tour_enabled");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SettingsModalComponent = ({
  connectorId,
  isLoading,
  localStorageAttackDiscoveryMaxAlerts,
  setLocalStorageAttackDiscoveryMaxAlerts
}) => {
  var _useSpaceId;
  const spaceId = (_useSpaceId = (0, _use_space_id.useSpaceId)()) !== null && _useSpaceId !== void 0 ? _useSpaceId : 'default';
  const modalTitleId = (0, _eui.useGeneratedHtmlId)();
  const [maxAlerts, setMaxAlerts] = (0, _react.useState)(localStorageAttackDiscoveryMaxAlerts !== null && localStorageAttackDiscoveryMaxAlerts !== void 0 ? localStorageAttackDiscoveryMaxAlerts : `${_elasticAssistant.DEFAULT_ATTACK_DISCOVERY_MAX_ALERTS}`);
  const [isModalVisible, setIsModalVisible] = (0, _react.useState)(false);
  const showModal = (0, _react.useCallback)(() => {
    setMaxAlerts(localStorageAttackDiscoveryMaxAlerts !== null && localStorageAttackDiscoveryMaxAlerts !== void 0 ? localStorageAttackDiscoveryMaxAlerts : `${_elasticAssistant.DEFAULT_ATTACK_DISCOVERY_MAX_ALERTS}`);
    setIsModalVisible(true);
  }, [localStorageAttackDiscoveryMaxAlerts]);
  const closeModal = (0, _react.useCallback)(() => setIsModalVisible(false), []);
  const onReset = (0, _react.useCallback)(() => setMaxAlerts(`${_elasticAssistant.DEFAULT_ATTACK_DISCOVERY_MAX_ALERTS}`), []);
  const onSave = (0, _react.useCallback)(() => {
    setLocalStorageAttackDiscoveryMaxAlerts(maxAlerts);
    closeModal();
  }, [closeModal, maxAlerts, setLocalStorageAttackDiscoveryMaxAlerts]);
  const [showSettingsTour, setShowSettingsTour] = (0, _useLocalStorage.default)(`${_elasticAssistant.DEFAULT_ASSISTANT_NAMESPACE}.${_elasticAssistant.ATTACK_DISCOVERY_STORAGE_KEY}.${spaceId}.${_elasticAssistant.SHOW_SETTINGS_TOUR_LOCAL_STORAGE_KEY}.v8.16`, true);
  const onTourFinished = (0, _react.useCallback)(() => setShowSettingsTour(() => false), [setShowSettingsTour]);
  const [tourDelayElapsed, setTourDelayElapsed] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    // visible EuiTourStep anchors don't follow the button when the layout changes (i.e. when the connectors finish loading)
    const timeout = setTimeout(() => setTourDelayElapsed(true), 10000);
    return () => clearTimeout(timeout);
  }, []);
  const onSettingsClicked = (0, _react.useCallback)(() => {
    showModal();
    setShowSettingsTour(() => false);
  }, [setShowSettingsTour, showModal]);
  const SettingsButton = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
    content: i18n.SETTINGS
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
    "aria-label": i18n.SETTINGS,
    "data-test-subj": "settings",
    iconType: "gear",
    onClick: onSettingsClicked
  })), [onSettingsClicked]);
  const isTourEnabled = (0, _is_tour_enabled.getIsTourEnabled)({
    connectorId,
    isLoading,
    tourDelayElapsed,
    showSettingsTour
  });
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, isTourEnabled ? /*#__PURE__*/_react.default.createElement(_eui.EuiTourStep, {
    anchorPosition: "downCenter",
    content: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement("span", null, i18n.ATTACK_DISCOVERY_SENDS_MORE_ALERTS), /*#__PURE__*/_react.default.createElement("br", null), /*#__PURE__*/_react.default.createElement("span", null, i18n.CONFIGURE_YOUR_SETTINGS_HERE)))),
    isStepOpen: showSettingsTour,
    minWidth: 300,
    onFinish: onTourFinished,
    step: 1,
    stepsTotal: 1,
    subtitle: i18n.RECENT_ATTACK_DISCOVERY_IMPROVEMENTS,
    title: i18n.SEND_MORE_ALERTS
  }, SettingsButton) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, SettingsButton), isModalVisible && /*#__PURE__*/_react.default.createElement(_eui.EuiModal, {
    "aria-labelledby": modalTitleId,
    "data-test-subj": "modal",
    onClose: closeModal
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiModalHeader, null, /*#__PURE__*/_react.default.createElement(_eui.EuiModalHeaderTitle, {
    id: modalTitleId
  }, i18n.SETTINGS)), /*#__PURE__*/_react.default.createElement(_eui.EuiModalBody, null, /*#__PURE__*/_react.default.createElement(_alerts_settings.AlertsSettings, {
    maxAlerts: maxAlerts,
    setMaxAlerts: setMaxAlerts
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiModalFooter, null, /*#__PURE__*/_react.default.createElement(_footer.Footer, {
    closeModal: closeModal,
    onReset: onReset,
    onSave: onSave
  }))));
};
SettingsModalComponent.displayName = 'SettingsModal';
const SettingsModal = exports.SettingsModal = /*#__PURE__*/_react.default.memo(SettingsModalComponent);