"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AttackDiscoveryTab = void 0;
var _elasticAssistantCommon = require("@kbn/elastic-assistant-common");
var _eui = require("@elastic/eui");
var _react = require("@emotion/react");
var _react2 = _interopRequireWildcard(require("react"));
var _attack_chain = require("./attack/attack_chain");
var _investigate_in_timeline_button = require("../../../../../../common/components/event_details/investigate_in_timeline_button");
var _actions = require("../../../../../../detections/components/alerts_table/actions");
var _helpers = require("../../../../../helpers");
var _attack_discovery_markdown_formatter = require("../../../attack_discovery_markdown_formatter");
var i18n = _interopRequireWildcard(require("./translations"));
var _view_in_ai_assistant = require("../../view_in_ai_assistant");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const AttackDiscoveryTabComponent = ({
  attackDiscovery,
  replacements,
  showAnonymized = false
}) => {
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const {
    detailsMarkdown,
    summaryMarkdown
  } = (0, _react2.useMemo)(() => attackDiscovery, [attackDiscovery]);
  const summaryMarkdownWithReplacements = (0, _react2.useMemo)(() => (0, _elasticAssistantCommon.replaceAnonymizedValuesWithOriginalValues)({
    messageContent: summaryMarkdown,
    replacements: replacements !== null && replacements !== void 0 ? replacements : {}
  }), [replacements, summaryMarkdown]);
  const detailsMarkdownWithReplacements = (0, _react2.useMemo)(() => (0, _elasticAssistantCommon.replaceAnonymizedValuesWithOriginalValues)({
    messageContent: detailsMarkdown,
    replacements: replacements !== null && replacements !== void 0 ? replacements : {}
  }), [detailsMarkdown, replacements]);
  const tacticMetadata = (0, _react2.useMemo)(() => (0, _helpers.getTacticMetadata)(attackDiscovery), [attackDiscovery]);
  const originalAlertIds = (0, _react2.useMemo)(() => attackDiscovery.alertIds.map(id => {
    var _replacements$id;
    return (_replacements$id = replacements === null || replacements === void 0 ? void 0 : replacements[id]) !== null && _replacements$id !== void 0 ? _replacements$id : id;
  }), [attackDiscovery.alertIds, replacements]);
  const filters = (0, _react2.useMemo)(() => (0, _actions.buildAlertsKqlFilter)('_id', originalAlertIds), [originalAlertIds]);
  return /*#__PURE__*/_react2.default.createElement("div", {
    "data-test-subj": "attackDiscoveryTab"
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiTitle, {
    "data-test-subj": "summaryTitle",
    size: "xs"
  }, /*#__PURE__*/_react2.default.createElement("h2", null, i18n.SUMMARY)), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react2.default.createElement(_attack_discovery_markdown_formatter.AttackDiscoveryMarkdownFormatter, {
    disableActions: showAnonymized,
    markdown: showAnonymized ? summaryMarkdown : summaryMarkdownWithReplacements
  }), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react2.default.createElement(_eui.EuiTitle, {
    "data-test-subj": "detailsTitle",
    size: "xs"
  }, /*#__PURE__*/_react2.default.createElement("h2", null, i18n.DETAILS)), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react2.default.createElement(_attack_discovery_markdown_formatter.AttackDiscoveryMarkdownFormatter, {
    disableActions: showAnonymized,
    markdown: showAnonymized ? detailsMarkdown : detailsMarkdownWithReplacements
  }), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, null), tacticMetadata.length > 0 && /*#__PURE__*/_react2.default.createElement(_react2.default.Fragment, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiTitle, {
    "data-test-subj": "attackChainTitle",
    size: "xs"
  }, /*#__PURE__*/_react2.default.createElement("h2", null, i18n.ATTACK_CHAIN)), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react2.default.createElement(_attack_chain.AttackChain, {
    attackDiscovery: attackDiscovery
  }), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, {
    size: "l"
  })), /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center",
    gutterSize: "none"
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react2.default.createElement(_view_in_ai_assistant.ViewInAiAssistant, {
    attackDiscovery: attackDiscovery,
    replacements: replacements
  })), /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, {
    css: (0, _react.css)`
            margin-left: ${euiTheme.size.m};
            margin-top: ${euiTheme.size.xs};
          `,
    grow: false
  }, /*#__PURE__*/_react2.default.createElement(_investigate_in_timeline_button.InvestigateInTimelineButton, {
    asEmptyButton: true,
    dataProviders: null,
    filters: filters
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center",
    "data-test-subj": "investigateInTimelineButton",
    gutterSize: "xs"
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiIcon, {
    "data-test-subj": "timelineIcon",
    type: "timeline"
  })), /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, {
    "data-test-subj": "investigateInTimelineLabel",
    grow: false
  }, i18n.INVESTIGATE_IN_TIMELINE))))), /*#__PURE__*/_react2.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }));
};
AttackDiscoveryTabComponent.displayName = 'AttackDiscoveryTab';
const AttackDiscoveryTab = exports.AttackDiscoveryTab = /*#__PURE__*/_react2.default.memo(AttackDiscoveryTabComponent);