"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Results = void 0;
var _eui = require("@elastic/eui");
var _elasticAssistant = require("@kbn/elastic-assistant");
var _react = _interopRequireDefault(require("react"));
var _attack_discovery_panel = require("./attack_discovery_panel");
var _empty_states = require("./empty_states");
var _show_empty_states = require("./empty_states/helpers/show_empty_states");
var _helpers = require("../helpers");
var _summary = require("./summary");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ResultsComponent = ({
  aiConnectorsCount,
  alertsContextCount,
  alertsCount,
  attackDiscoveriesCount,
  connectorId,
  failureReason,
  isLoading,
  isLoadingPost,
  localStorageAttackDiscoveryMaxAlerts,
  onGenerate,
  onToggleShowAnonymized,
  selectedConnectorAttackDiscoveries,
  selectedConnectorLastUpdated,
  selectedConnectorReplacements,
  showAnonymized
}) => {
  if ((0, _show_empty_states.showEmptyStates)({
    aiConnectorsCount,
    alertsContextCount,
    attackDiscoveriesCount,
    connectorId,
    failureReason,
    isLoading
  })) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "xxl"
    }), /*#__PURE__*/_react.default.createElement(_empty_states.EmptyStates, {
      aiConnectorsCount: aiConnectorsCount,
      alertsContextCount: alertsContextCount,
      attackDiscoveriesCount: attackDiscoveriesCount,
      failureReason: failureReason,
      connectorId: connectorId,
      isLoading: isLoading || isLoadingPost,
      onGenerate: onGenerate,
      upToAlertsCount: Number(localStorageAttackDiscoveryMaxAlerts !== null && localStorageAttackDiscoveryMaxAlerts !== void 0 ? localStorageAttackDiscoveryMaxAlerts : _elasticAssistant.DEFAULT_ATTACK_DISCOVERY_MAX_ALERTS)
    }));
  }
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, (0, _helpers.showSummary)(attackDiscoveriesCount) && /*#__PURE__*/_react.default.createElement(_summary.Summary, {
    alertsCount: alertsCount,
    attackDiscoveriesCount: attackDiscoveriesCount,
    lastUpdated: selectedConnectorLastUpdated,
    onToggleShowAnonymized: onToggleShowAnonymized,
    showAnonymized: showAnonymized
  }), selectedConnectorAttackDiscoveries.map((attackDiscovery, i) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, {
    key: attackDiscovery.id
  }, /*#__PURE__*/_react.default.createElement(_attack_discovery_panel.AttackDiscoveryPanel, {
    attackDiscovery: attackDiscovery,
    initialIsOpen: (0, _helpers.getInitialIsOpen)(i),
    showAnonymized: showAnonymized,
    replacements: selectedConnectorReplacements
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }))));
};
ResultsComponent.displayName = 'Results';
const Results = exports.Results = /*#__PURE__*/_react.default.memo(ResultsComponent);