"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AlertsPreview = void 0;
var _react = _interopRequireWildcard(require("react"));
var _lodash = require("lodash");
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var _securitySolutionDistributionBar = require("@kbn/security-solution-distribution-bar");
var _cloudSecurityPostureCommon = require("@kbn/cloud-security-posture-common");
var _cloudSecurityPosture = require("@kbn/cloud-security-posture");
var _use_misconfiguration_preview = require("@kbn/cloud-security-posture/src/hooks/use_misconfiguration_preview");
var _use_vulnerabilities_preview = require("@kbn/cloud-security-posture/src/hooks/use_vulnerabilities_preview");
var _expandableFlyout = require("@kbn/expandable-flyout");
var _expandable_panel = require("../../../flyout/shared/components/expandable_panel");
var _helpers = require("../../../detections/components/alerts_kpis/severity_level_panel/helpers");
var _search_strategy = require("../../../../common/search_strategy");
var _use_risk_score = require("../../../entity_analytics/api/hooks/use_risk_score");
var _common = require("../../../entity_analytics/common");
var _host_details_left = require("../../../flyout/entity_details/host_details_left");
var _left_panel_header = require("../../../flyout/entity_details/shared/components/left_panel/left_panel_header");
var _user_details_left = require("../../../flyout/entity_details/user_details_left");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const AlertsCount = ({
  alertsTotal,
  euiTheme
}) => {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "none"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("h1", {
    "data-test-subj": 'securitySolutionFlyoutInsightsAlertsCount'
  }, (0, _cloudSecurityPostureCommon.getAbbreviatedNumber)(alertsTotal)))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "m",
    css: {
      fontWeight: euiTheme.font.weight.semiBold
    }
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.flyout.right.insights.alerts.alertsCountDescription",
    defaultMessage: "Alerts"
  })))));
};
const AlertsPreview = ({
  alertsData,
  fieldName,
  name,
  isPreviewMode
}) => {
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const severityMap = new Map();
  Object.keys(alertsData || {}).forEach(status => {
    var _alertsData$status;
    if (alertsData !== null && alertsData !== void 0 && (_alertsData$status = alertsData[status]) !== null && _alertsData$status !== void 0 && _alertsData$status.severities) {
      var _alertsData$status2;
      alertsData === null || alertsData === void 0 ? void 0 : (_alertsData$status2 = alertsData[status]) === null || _alertsData$status2 === void 0 ? void 0 : _alertsData$status2.severities.forEach(severity => {
        const currentSeverity = severityMap.get(severity.key) || 0;
        severityMap.set(severity.key, currentSeverity + severity.value);
      });
    }
  });
  const alertStats = Array.from(severityMap, ([key, count]) => ({
    key: (0, _lodash.capitalize)(key),
    count,
    color: (0, _helpers.getSeverityColor)(key)
  }));
  const totalAlertsCount = alertStats.reduce((total, item) => total + item.count, 0);
  const {
    data
  } = (0, _use_misconfiguration_preview.useMisconfigurationPreview)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)(fieldName, name),
    sort: [],
    enabled: true,
    pageSize: 1,
    ignore_unavailable: true
  });
  const isUsingHostName = fieldName === 'host.name';
  const passedFindings = (data === null || data === void 0 ? void 0 : data.count.passed) || 0;
  const failedFindings = (data === null || data === void 0 ? void 0 : data.count.failed) || 0;
  const hasMisconfigurationFindings = passedFindings > 0 || failedFindings > 0;
  const {
    data: vulnerabilitiesData
  } = (0, _use_vulnerabilities_preview.useVulnerabilitiesPreview)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)('host.name', name),
    sort: [],
    enabled: true,
    pageSize: 1
  });
  const {
    CRITICAL = 0,
    HIGH = 0,
    MEDIUM = 0,
    LOW = 0,
    NONE = 0
  } = (vulnerabilitiesData === null || vulnerabilitiesData === void 0 ? void 0 : vulnerabilitiesData.count) || {};
  const hasVulnerabilitiesFindings = (0, _cloudSecurityPosture.hasVulnerabilitiesData)({
    critical: CRITICAL,
    high: HIGH,
    medium: MEDIUM,
    low: LOW,
    none: NONE
  });
  const buildFilterQuery = (0, _react.useMemo)(() => isUsingHostName ? (0, _search_strategy.buildHostNamesFilter)([name]) : (0, _search_strategy.buildUserNamesFilter)([name]), [isUsingHostName, name]);
  const riskScoreState = (0, _use_risk_score.useRiskScore)({
    riskEntity: isUsingHostName ? _search_strategy.RiskScoreEntity.host : _search_strategy.RiskScoreEntity.user,
    filterQuery: buildFilterQuery,
    onlyLatest: false,
    pagination: _common.FIRST_RECORD_PAGINATION
  });
  const {
    data: hostRisk
  } = riskScoreState;
  const riskData = hostRisk === null || hostRisk === void 0 ? void 0 : hostRisk[0];
  const isRiskScoreExist = isUsingHostName ? !!(riskData !== null && riskData !== void 0 && riskData.host.risk) : !!(riskData !== null && riskData !== void 0 && riskData.user.risk);
  const hasNonClosedAlerts = totalAlertsCount > 0;
  const {
    openLeftPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const goToEntityInsightTab = (0, _react.useCallback)(() => {
    openLeftPanel({
      id: isUsingHostName ? _host_details_left.HostDetailsPanelKey : _user_details_left.UserDetailsPanelKey,
      params: isUsingHostName ? {
        name,
        isRiskScoreExist,
        hasMisconfigurationFindings,
        hasVulnerabilitiesFindings,
        hasNonClosedAlerts,
        path: {
          tab: _left_panel_header.EntityDetailsLeftPanelTab.CSP_INSIGHTS,
          subTab: _left_panel_header.CspInsightLeftPanelSubTab.ALERTS
        }
      } : {
        user: {
          name
        },
        isRiskScoreExist,
        hasMisconfigurationFindings,
        hasNonClosedAlerts,
        path: {
          tab: _left_panel_header.EntityDetailsLeftPanelTab.CSP_INSIGHTS,
          subTab: _left_panel_header.CspInsightLeftPanelSubTab.ALERTS
        }
      }
    });
  }, [hasMisconfigurationFindings, hasNonClosedAlerts, hasVulnerabilitiesFindings, isRiskScoreExist, isUsingHostName, name, openLeftPanel]);
  const link = (0, _react.useMemo)(() => !isPreviewMode ? {
    callback: goToEntityInsightTab,
    tooltip: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.flyout.right.insights.alerts.alertsTooltip",
      defaultMessage: "Show all alerts"
    })
  } : undefined, [isPreviewMode, goToEntityInsightTab]);
  return /*#__PURE__*/_react.default.createElement(_expandable_panel.ExpandablePanel, {
    header: {
      iconType: !isPreviewMode && hasNonClosedAlerts ? 'arrowStart' : '',
      title: /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        size: "xs",
        css: {
          fontWeight: euiTheme.font.weight.bold
        }
      }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.flyout.right.insights.alerts.alertsTitle",
        defaultMessage: "Alerts"
      })),
      link: totalAlertsCount > 0 ? link : undefined
    },
    "data-test-subj": 'securitySolutionFlyoutInsightsAlerts'
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "none"
  }, /*#__PURE__*/_react.default.createElement(AlertsCount, {
    alertsTotal: totalAlertsCount,
    euiTheme: euiTheme
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 2
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "none"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_securitySolutionDistributionBar.DistributionBar, {
    stats: alertStats.reverse(),
    "data-test-subj": "AlertsPreviewDistributionBarTestId"
  }))))));
};
exports.AlertsPreview = AlertsPreview;