"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AlertsDetailsTable = void 0;
var _react = _interopRequireWildcard(require("react"));
var _lodash = require("lodash");
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _securitySolutionDistributionBar = require("@kbn/security-solution-distribution-bar");
var _ui_metrics = require("@kbn/cloud-security-posture-common/utils/ui_metrics");
var _analytics = require("@kbn/analytics");
var _helpers = require("@kbn/cloud-security-posture-common/utils/helpers");
var _expandableFlyout = require("@kbn/expandable-flyout");
var _securitysolutionDataTable = require("@kbn/securitysolution-data-table");
var _translations = require("../../../overview/components/detection_response/translations");
var _use_navigate_to_alerts_page_with_filters = require("../../../common/hooks/use_navigate_to_alerts_page_with_filters");
var _panel_keys = require("../../../flyout/document_details/shared/constants/panel_keys");
var _use_global_time = require("../../../common/containers/use_global_time");
var _use_query = require("../../../detections/containers/detection_engine/alerts/use_query");
var _constants = require("../../../detections/containers/detection_engine/alerts/constants");
var _use_signal_index = require("../../../detections/containers/detection_engine/alerts/use_signal_index");
var _helpers2 = require("../../../detections/components/alerts_kpis/severity_level_panel/helpers");
var _severity_badge = require("../../../common/components/severity_badge");
var _constants2 = require("../../../flyout/document_details/preview/constants");
var _types = require("../../../../common/types");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const AlertsDetailsTable = exports.AlertsDetailsTable = /*#__PURE__*/(0, _react.memo)(({
  fieldName,
  queryName
}) => {
  var _data$hits, _data$hits$hits;
  (0, _react.useEffect)(() => {
    _ui_metrics.uiMetricService.trackUiMetric(_analytics.METRIC_TYPE.COUNT, _ui_metrics.ENTITY_FLYOUT_EXPAND_MISCONFIGURATION_VIEW_VISITS);
  }, []);
  const [pageIndex, setPageIndex] = (0, _react.useState)(0);
  const [pageSize, setPageSize] = (0, _react.useState)(10);
  const alertsPagination = alerts => {
    let pageOfItems;
    if (!pageIndex && !pageSize) {
      pageOfItems = alerts;
    } else {
      const startIndex = pageIndex * pageSize;
      pageOfItems = alerts === null || alerts === void 0 ? void 0 : alerts.slice(startIndex, Math.min(startIndex + pageSize, alerts === null || alerts === void 0 ? void 0 : alerts.length));
    }
    return {
      pageOfItems,
      totalItemCount: alerts === null || alerts === void 0 ? void 0 : alerts.length
    };
  };
  const {
    to,
    from
  } = (0, _use_global_time.useGlobalTime)();
  const {
    signalIndexName
  } = (0, _use_signal_index.useSignalIndex)();
  const {
    data
  } = (0, _use_query.useQueryAlerts)({
    query: (0, _helpers.buildEntityAlertsQuery)(fieldName, to, from, queryName, 500),
    queryName: _constants.ALERTS_QUERY_NAMES.BY_RULE_BY_STATUS,
    indexName: signalIndexName
  });
  const alertDataResults = data === null || data === void 0 ? void 0 : (_data$hits = data.hits) === null || _data$hits === void 0 ? void 0 : (_data$hits$hits = _data$hits.hits) === null || _data$hits$hits === void 0 ? void 0 : _data$hits$hits.map(item => {
    var _item$fields, _item$fields$_id, _item$fields2, _item$fields2$_index, _item$fields3, _item$fields3$kibana, _item$fields4, _item$fields4$kibana, _item$fields5, _item$fields5$kibana, _item$fields6, _item$fields6$kibana;
    return {
      id: (_item$fields = item.fields) === null || _item$fields === void 0 ? void 0 : (_item$fields$_id = _item$fields._id) === null || _item$fields$_id === void 0 ? void 0 : _item$fields$_id[0],
      index: (_item$fields2 = item.fields) === null || _item$fields2 === void 0 ? void 0 : (_item$fields2$_index = _item$fields2._index) === null || _item$fields2$_index === void 0 ? void 0 : _item$fields2$_index[0],
      ruleName: (_item$fields3 = item.fields) === null || _item$fields3 === void 0 ? void 0 : (_item$fields3$kibana = _item$fields3['kibana.alert.rule.name']) === null || _item$fields3$kibana === void 0 ? void 0 : _item$fields3$kibana[0],
      ruleUuid: (_item$fields4 = item.fields) === null || _item$fields4 === void 0 ? void 0 : (_item$fields4$kibana = _item$fields4['kibana.alert.rule.uuid']) === null || _item$fields4$kibana === void 0 ? void 0 : _item$fields4$kibana[0],
      severity: (_item$fields5 = item.fields) === null || _item$fields5 === void 0 ? void 0 : (_item$fields5$kibana = _item$fields5['kibana.alert.severity']) === null || _item$fields5$kibana === void 0 ? void 0 : _item$fields5$kibana[0],
      status: (_item$fields6 = item.fields) === null || _item$fields6 === void 0 ? void 0 : (_item$fields6$kibana = _item$fields6['kibana.alert.workflow_status']) === null || _item$fields6$kibana === void 0 ? void 0 : _item$fields6$kibana[0]
    };
  });
  const severitiesMap = (alertDataResults === null || alertDataResults === void 0 ? void 0 : alertDataResults.map(item => item.severity)) || [];
  const alertStats = Object.entries(severitiesMap.reduce((acc, item) => {
    acc[item] = (acc[item] || 0) + 1;
    return acc;
  }, {})).map(([key, count]) => ({
    key: (0, _lodash.capitalize)(key),
    count,
    color: (0, _helpers2.getSeverityColor)(key)
  }));
  const {
    pageOfItems,
    totalItemCount
  } = alertsPagination(alertDataResults || []);
  const pagination = {
    pageIndex,
    pageSize,
    totalItemCount,
    pageSizeOptions: [10, 25, 100]
  };
  const onTableChange = ({
    page
  }) => {
    if (page) {
      const {
        index,
        size
      } = page;
      setPageIndex(index);
      setPageSize(size);
    }
  };
  const {
    openPreviewPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const handleOnEventAlertDetailPanelOpened = (0, _react.useCallback)((eventId, indexName, tableId) => {
    openPreviewPanel({
      id: _panel_keys.DocumentDetailsPreviewPanelKey,
      params: {
        id: eventId,
        indexName,
        scopeId: tableId,
        isPreviewMode: true,
        banner: _constants2.ALERT_PREVIEW_BANNER
      }
    });
  }, [openPreviewPanel]);
  const tableId = _securitysolutionDataTable.TableId.alertsOnRuleDetailsPage;
  const columns = [{
    field: 'id',
    name: '',
    width: '5%',
    render: (id, alert) => /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
      onClick: () => handleOnEventAlertDetailPanelOpened(id, alert.index, tableId)
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      type: 'expand'
    }))
  }, {
    field: 'ruleName',
    render: ruleName => /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, ruleName),
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.alerts.table.ruleNameColumnName', {
      defaultMessage: 'Rule'
    }),
    width: '55%'
  }, {
    field: 'severity',
    render: severity => /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, /*#__PURE__*/_react.default.createElement(_severity_badge.SeverityBadge, {
      value: severity,
      "data-test-subj": "severityPropertyValue"
    })),
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.alerts.table.severityColumnName', {
      defaultMessage: 'Severity'
    }),
    width: '20%'
  }, {
    field: 'status',
    render: status => /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, (0, _lodash.capitalize)(status)),
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.alerts.table.statusColumnName', {
      defaultMessage: 'Status'
    }),
    width: '20%'
  }];
  const openAlertsPageWithFilters = (0, _use_navigate_to_alerts_page_with_filters.useNavigateToAlertsPageWithFilters)();
  const openAlertsInAlertsPage = (0, _react.useCallback)(() => openAlertsPageWithFilters([{
    title: fieldName === 'host.name' ? _translations.OPEN_IN_ALERTS_TITLE_HOSTNAME : _translations.OPEN_IN_ALERTS_TITLE_USERNAME,
    selectedOptions: [queryName],
    fieldName
  }, {
    title: _translations.OPEN_IN_ALERTS_TITLE_STATUS,
    selectedOptions: [_types.FILTER_OPEN, _types.FILTER_ACKNOWLEDGED],
    fieldName: 'kibana.alert.workflow_status'
  }], true), [fieldName, openAlertsPageWithFilters, queryName]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasShadow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
    onClick: () => openAlertsInAlertsPage()
  }, /*#__PURE__*/_react.default.createElement("h1", {
    "data-test-subj": 'securitySolutionFlyoutInsightsAlertsCount'
  }, _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.alerts.tableTitle', {
    defaultMessage: 'Alerts '
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: 'popout'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xl"
  }), /*#__PURE__*/_react.default.createElement(_securitySolutionDistributionBar.DistributionBar, {
    stats: alertStats.reverse()
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiBasicTable, {
    items: pageOfItems || [],
    rowHeader: "result",
    columns: columns,
    pagination: pagination,
    onChange: onTableChange,
    "data-test-subj": 'securitySolutionFlyoutMisconfigurationFindingsTable'
  })));
});
AlertsDetailsTable.displayName = 'AlertsDetailsTable';