"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EntityInsight = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _react2 = require("@emotion/react");
var _i18nReact = require("@kbn/i18n-react");
var _use_misconfiguration_preview = require("@kbn/cloud-security-posture/src/hooks/use_misconfiguration_preview");
var _cloudSecurityPostureCommon = require("@kbn/cloud-security-posture-common");
var _use_vulnerabilities_preview = require("@kbn/cloud-security-posture/src/hooks/use_vulnerabilities_preview");
var _cloudSecurityPosture = require("@kbn/cloud-security-posture");
var _types = require("../../../common/types");
var _misconfiguration_preview = require("./misconfiguration/misconfiguration_preview");
var _vulnerabilities_preview = require("./vulnerabilities/vulnerabilities_preview");
var _alerts_preview = require("./alerts/alerts_preview");
var _use_global_time = require("../../common/containers/use_global_time");
var _types2 = require("../../overview/components/detection_response/alerts_by_status/types");
var _use_alerts_by_status = require("../../overview/components/detection_response/alerts_by_status/use_alerts_by_status");
var _use_signal_index = require("../../detections/containers/detection_engine/alerts/use_signal_index");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const EntityInsight = ({
  name,
  fieldName,
  isPreviewMode
}) => {
  var _filteredAlertsData$o, _filteredAlertsData$a;
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const insightContent = [];
  const {
    data: dataMisconfiguration
  } = (0, _use_misconfiguration_preview.useMisconfigurationPreview)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)(fieldName, name),
    sort: [],
    enabled: true,
    pageSize: 1
  });
  const passedFindings = (dataMisconfiguration === null || dataMisconfiguration === void 0 ? void 0 : dataMisconfiguration.count.passed) || 0;
  const failedFindings = (dataMisconfiguration === null || dataMisconfiguration === void 0 ? void 0 : dataMisconfiguration.count.failed) || 0;
  const hasMisconfigurationFindings = passedFindings > 0 || failedFindings > 0;
  const {
    data
  } = (0, _use_vulnerabilities_preview.useVulnerabilitiesPreview)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)(fieldName, name),
    sort: [],
    enabled: true,
    pageSize: 1
  });
  const {
    CRITICAL = 0,
    HIGH = 0,
    MEDIUM = 0,
    LOW = 0,
    NONE = 0
  } = (data === null || data === void 0 ? void 0 : data.count) || {};
  const hasVulnerabilitiesFindings = (0, _cloudSecurityPosture.hasVulnerabilitiesData)({
    critical: CRITICAL,
    high: HIGH,
    medium: MEDIUM,
    low: LOW,
    none: NONE
  });
  const isVulnerabilitiesFindingForHost = hasVulnerabilitiesFindings && fieldName === 'host.name';
  const {
    signalIndexName
  } = (0, _use_signal_index.useSignalIndex)();
  const entityFilter = (0, _react.useMemo)(() => ({
    field: fieldName,
    value: name
  }), [fieldName, name]);
  const {
    to,
    from
  } = (0, _use_global_time.useGlobalTime)();
  const {
    items: alertsData
  } = (0, _use_alerts_by_status.useAlertsByStatus)({
    entityFilter,
    signalIndexName,
    queryId: isPreviewMode ? `${_types2.DETECTION_RESPONSE_ALERTS_BY_STATUS_ID}ALERTS_PREVIEW_TRUE` : `${_types2.DETECTION_RESPONSE_ALERTS_BY_STATUS_ID}ALERTS_PREVIEW_FALSE`,
    to,
    from
  });
  const filteredAlertsData = alertsData ? Object.fromEntries(Object.entries(alertsData).filter(([key]) => key !== _types.FILTER_CLOSED)) : {};
  const alertsOpenCount = (filteredAlertsData === null || filteredAlertsData === void 0 ? void 0 : (_filteredAlertsData$o = filteredAlertsData.open) === null || _filteredAlertsData$o === void 0 ? void 0 : _filteredAlertsData$o.total) || 0;
  const alertsAcknowledgedCount = (filteredAlertsData === null || filteredAlertsData === void 0 ? void 0 : (_filteredAlertsData$a = filteredAlertsData.acknowledged) === null || _filteredAlertsData$a === void 0 ? void 0 : _filteredAlertsData$a.total) || 0;
  const alertsCount = alertsOpenCount + alertsAcknowledgedCount;
  if (alertsCount > 0) {
    insightContent.push( /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_alerts_preview.AlertsPreview, {
      alertsData: filteredAlertsData,
      fieldName: fieldName,
      name: name,
      isPreviewMode: isPreviewMode
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "s"
    })));
  }
  if (hasMisconfigurationFindings) insightContent.push( /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_misconfiguration_preview.MisconfigurationsPreview, {
    name: name,
    fieldName: fieldName,
    hasNonClosedAlerts: alertsCount > 0,
    isPreviewMode: isPreviewMode
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  })));
  if (isVulnerabilitiesFindingForHost && hasVulnerabilitiesFindings) insightContent.push( /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_vulnerabilities_preview.VulnerabilitiesPreview, {
    name: name,
    isPreviewMode: isPreviewMode,
    hasNonClosedAlerts: alertsCount > 0
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  })));
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, (insightContent.length > 0 || hasMisconfigurationFindings || isVulnerabilitiesFindingForHost && hasVulnerabilitiesFindings) && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiAccordion, {
    initialIsOpen: true,
    id: "entityInsight-accordion",
    "data-test-subj": "entityInsightTestSubj",
    buttonProps: {
      'data-test-subj': 'entityInsight-accordion-button',
      css: (0, _react2.css)`
                color: ${euiTheme.colors.primary};
              `
    },
    buttonContent: /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
      size: "xs"
    }, /*#__PURE__*/_react.default.createElement("h3", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.flyout.entityDetails.insightsTitle",
      defaultMessage: "Insights"
    })))
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), insightContent), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, null)));
};
exports.EntityInsight = EntityInsight;