"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStyle = exports.disableHoverActions = exports.ProviderContentWrapper = exports.DraggableWrapper = exports.DragEffects = exports.ConditionalPortal = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _eui = require("@elastic/eui");
var _securitysolutionTGrid = require("@kbn/securitysolution-t-grid");
var _react = _interopRequireWildcard(require("react"));
var _dnd = require("@hello-pangea/dnd");
var _reactRedux = require("react-redux");
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _securitysolutionDataTable = require("@kbn/securitysolution-data-table");
var _drag_and_drop = require("../../store/drag_and_drop");
var _constants = require("../../../timelines/components/row_renderers_browser/constants");
var _truncatable_text = require("../truncatable_text");
var _cell_actions_wrapper = require("./cell_actions_wrapper");
var _helpers = require("./helpers");
var _provider_container = require("./provider_container");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

// As right now, we do not know what we want there, we will keep it as a placeholder
const DragEffects = exports.DragEffects = _styledComponents.default.div``;
DragEffects.displayName = 'DragEffects';

/**
 * Wraps the `@hello-pangea/dnd` error boundary. See also:
 * https://github.com/atlassian/react-beautiful-dnd/blob/v12.0.0/docs/guides/setup-problem-detection-and-error-recovery.md
 *
 * NOTE: This extends from `PureComponent` because, at the time of this
 * writing, there's no hook equivalent for `componentDidCatch`, per
 * https://reactjs.org/docs/hooks-faq.html#do-hooks-cover-all-use-cases-for-classes
 */
class DragDropErrorBoundary extends _react.default.PureComponent {
  componentDidCatch() {
    this.forceUpdate(); // required for recovery
  }
  render() {
    return this.props.children;
  }
}
const Wrapper = _styledComponents.default.div`
  display: inline-block;
  max-width: 100%;

  [data-rbd-placeholder-context-id] {
    display: none !important;
  }

  ${({
  disabled
}) => disabled && `
    [data-rbd-draggable-id]:hover,
    .euiBadge:hover,
    .euiBadge__text:hover {
      cursor: default;
    }
  `}
`;
Wrapper.displayName = 'Wrapper';
const ProviderContentWrapper = exports.ProviderContentWrapper = _styledComponents.default.span`
  > span.euiToolTipAnchor {
    display: block; /* allow EuiTooltip content to be truncatable */
  }

  > span.euiToolTipAnchor.eui-textTruncate {
    display: inline-block; /* do not override display when a tooltip is truncated via eui-textTruncate */
  }
`;
const disableHoverActions = timelineId => [_securitysolutionDataTable.TableId.rulePreview, _constants.ROW_RENDERER_BROWSER_EXAMPLE_TIMELINE_ID].includes(timelineId !== null && timelineId !== void 0 ? timelineId : '');

/**
 * Wraps a draggable component to handle registration / unregistration of the
 * data provider associated with the item being dropped
 */
exports.disableHoverActions = disableHoverActions;
const getStyle = (style, snapshot) => {
  if (!snapshot.isDropAnimating) {
    return style;
  }
  return {
    ...style,
    transitionDuration: '0.00000001s' // cannot be 0, but can be a very short duration
  };
};
exports.getStyle = getStyle;
const DraggableOnWrapper = /*#__PURE__*/_react.default.memo(({
  dataProvider,
  render,
  scopeId,
  truncate,
  hideTopN
}) => {
  const [providerRegistered, setProviderRegistered] = (0, _react.useState)(false);
  const isDisabled = dataProvider.id.includes(`-${_constants.ROW_RENDERER_BROWSER_EXAMPLE_TIMELINE_ID}-`);
  const dispatch = (0, _reactRedux.useDispatch)();
  const registerProvider = (0, _react.useCallback)(() => {
    if (!isDisabled) {
      dispatch(_drag_and_drop.dragAndDropActions.registerProvider({
        provider: dataProvider
      }));
      setProviderRegistered(true);
    }
  }, [isDisabled, dispatch, dataProvider]);
  const unRegisterProvider = (0, _react.useCallback)(() => providerRegistered && dispatch(_drag_and_drop.dragAndDropActions.unRegisterProvider({
    id: dataProvider.id
  })), [providerRegistered, dispatch, dataProvider.id]);
  (0, _react.useEffect)(() => () => {
    unRegisterProvider();
  }, [unRegisterProvider]);
  const RenderClone = (0, _react.useCallback)((provided, snapshot) => /*#__PURE__*/_react.default.createElement(ConditionalPortal, {
    registerProvider: registerProvider
  }, /*#__PURE__*/_react.default.createElement("div", (0, _extends2.default)({}, provided.draggableProps, provided.dragHandleProps, {
    style: getStyle(provided.draggableProps.style, snapshot),
    ref: provided.innerRef,
    "data-test-subj": "providerContainer",
    tabIndex: -1
  }), /*#__PURE__*/_react.default.createElement(ProviderContentWrapper, {
    "data-test-subj": `draggable-content-${dataProvider.queryMatch.field}`
  }, render(dataProvider, provided, snapshot)))), [dataProvider, registerProvider, render]);
  const DraggableContent = (0, _react.useCallback)((provided, snapshot) => /*#__PURE__*/_react.default.createElement(_provider_container.ProviderContainer, (0, _extends2.default)({}, provided.draggableProps, provided.dragHandleProps, {
    ref: e => {
      provided.innerRef(e);
    },
    "data-test-subj": "providerContainer",
    isDragging: snapshot.isDragging,
    registerProvider: registerProvider,
    tabIndex: -1
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiScreenReaderOnly, {
    "data-test-subj": "screenReaderOnlyField"
  }, /*#__PURE__*/_react.default.createElement("p", null, dataProvider.queryMatch.field)), truncate && !snapshot.isDragging ? /*#__PURE__*/_react.default.createElement(_truncatable_text.TruncatableText, {
    "data-test-subj": "draggable-truncatable-content"
  }, render(dataProvider, provided, snapshot)) : /*#__PURE__*/_react.default.createElement(ProviderContentWrapper, {
    "data-test-subj": `draggable-content-${dataProvider.queryMatch.field}`
  }, render(dataProvider, provided, snapshot)), !snapshot.isDragging && /*#__PURE__*/_react.default.createElement(_eui.EuiScreenReaderOnly, {
    "data-test-subj": "draggableKeyboardInstructionsNotDragging"
  }, /*#__PURE__*/_react.default.createElement("p", null, i18n.DRAGGABLE_KEYBOARD_INSTRUCTIONS_NOT_DRAGGING_SCREEN_READER_ONLY))), [dataProvider, registerProvider, render, truncate]);
  const DroppableContent = (0, _react.useCallback)(droppableProvided => /*#__PURE__*/_react.default.createElement("div", (0, _extends2.default)({
    ref: droppableProvided.innerRef
  }, droppableProvided.droppableProps), /*#__PURE__*/_react.default.createElement("div", {
    className: _securitysolutionTGrid.DRAGGABLE_KEYBOARD_WRAPPER_CLASS_NAME,
    "data-test-subj": "draggableWrapperKeyboardHandler",
    role: "button",
    tabIndex: 0
  }, /*#__PURE__*/_react.default.createElement(_dnd.Draggable, {
    draggableId: (0, _helpers.getDraggableId)(dataProvider.id),
    index: 0,
    key: (0, _helpers.getDraggableId)(dataProvider.id),
    isDragDisabled: isDisabled
  }, DraggableContent)), droppableProvided.placeholder), [DraggableContent, dataProvider.id, isDisabled]);
  const content = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement(Wrapper, {
    "data-test-subj": "draggableWrapperDiv",
    disabled: isDisabled
  }, /*#__PURE__*/_react.default.createElement(DragDropErrorBoundary, null, /*#__PURE__*/_react.default.createElement(_dnd.Droppable, {
    isDropDisabled: true,
    droppableId: (0, _helpers.getDroppableId)(dataProvider.id),
    renderClone: RenderClone
  }, DroppableContent))), [DroppableContent, RenderClone, dataProvider.id, isDisabled]);
  if (isDisabled) return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, content);
  return /*#__PURE__*/_react.default.createElement(_cell_actions_wrapper.CellActionsWrapper, {
    dataProvider: dataProvider,
    scopeId: scopeId,
    hideTopN: hideTopN
  }, content);
});
DraggableOnWrapper.displayName = 'DraggableOnWrapper';
const DraggableWrapper = exports.DraggableWrapper = /*#__PURE__*/_react.default.memo(({
  dataProvider,
  isDraggable = false,
  render,
  scopeId,
  truncate,
  hideTopN
}) => {
  const content = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement("div", {
    tabIndex: -1,
    "data-provider-id": (0, _helpers.getDraggableId)(dataProvider.id)
  }, truncate ? /*#__PURE__*/_react.default.createElement(_truncatable_text.TruncatableText, {
    "data-test-subj": "render-truncatable-content"
  }, render(dataProvider, null, {
    isDragging: false,
    isDropAnimating: false,
    isClone: false,
    dropAnimation: null,
    draggingOver: null,
    combineWith: null,
    combineTargetFor: null,
    mode: null
  })) : /*#__PURE__*/_react.default.createElement(ProviderContentWrapper, {
    "data-test-subj": `render-content-${dataProvider.queryMatch.field}`
  }, render(dataProvider, null, {
    isDragging: false,
    isDropAnimating: false,
    isClone: false,
    dropAnimation: null,
    draggingOver: null,
    combineWith: null,
    combineTargetFor: null,
    mode: null
  }))), [dataProvider, render, truncate]);
  if (!isDraggable) {
    if (disableHoverActions(scopeId)) {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, content);
    }
    return /*#__PURE__*/_react.default.createElement(_cell_actions_wrapper.CellActionsWrapper, {
      dataProvider: dataProvider,
      scopeId: scopeId,
      hideTopN: hideTopN
    }, content);
  }
  return /*#__PURE__*/_react.default.createElement(DraggableOnWrapper, {
    dataProvider: dataProvider,
    render: render,
    scopeId: scopeId,
    truncate: truncate
  });
});
DraggableWrapper.displayName = 'DraggableWrapper';
/**
 * Conditionally wraps children in an EuiPortal to ensure drag offsets are correct when dragging
 * from containers that have css transforms
 *
 * See: https://github.com/atlassian/react-beautiful-dnd/issues/499
 */

const ConditionalPortal = exports.ConditionalPortal = /*#__PURE__*/_react.default.memo(({
  children,
  registerProvider
}) => {
  (0, _react.useEffect)(() => {
    registerProvider();
  }, [registerProvider]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
});
ConditionalPortal.displayName = 'ConditionalPortal';