"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDataViewListItems = useDataViewListItems;
var _react = require("react");
var _use_app_toasts = require("../../../../common/hooks/use_app_toasts");
var _kibana = require("../../../../common/lib/kibana");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Fetches known Kibana data views from the Data View Service.
 */
function useDataViewListItems() {
  const {
    data: {
      dataViews: dataViewsService
    }
  } = (0, _kibana.useKibana)().services;
  const {
    addError
  } = (0, _use_app_toasts.useAppToasts)();
  const [isFetching, setIsFetching] = (0, _react.useState)(false);
  const [dataViews, setDataViews] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    setIsFetching(true);
    (async () => {
      try {
        setDataViews(await dataViewsService.getIdsWithTitle(true));
      } catch (e) {
        addError(e, {
          title: i18n.DATA_VIEWS_FETCH_ERROR
        });
      } finally {
        setIsFetching(false);
      }
    })();
  }, [dataViewsService, addError]);
  return {
    data: dataViews,
    isFetching
  };
}