"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LoggedRequestsItem = void 0;
var _react = _interopRequireDefault(require("react"));
var _css = require("@emotion/css");
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var i18n = _interopRequireWildcard(require("./translations"));
var _formatted_date = require("../../../../common/components/formatted_date");
var _optimized_accordion = require("./optimized_accordion");
var _use_accordion_styling = require("./use_accordion_styling");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const LoggedRequestsItemComponent = ({
  startedAt,
  duration,
  requests
}) => {
  const paddingLarge = (0, _eui.useEuiPaddingSize)('l');
  const cssStyles = (0, _use_accordion_styling.useAccordionStyling)();
  return /*#__PURE__*/_react.default.createElement(_optimized_accordion.OptimizedAccordion, {
    "data-test-subj": "preview-logged-requests-item-accordion",
    buttonContent: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, startedAt ? /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.detectionEngine.queryPreview.loggedRequestItemAccordionButtonLabel",
      defaultMessage: "Rule execution started at {time}.",
      values: {
        time: /*#__PURE__*/_react.default.createElement(_formatted_date.PreferenceFormattedDate, {
          value: new Date(startedAt)
        })
      }
    }) : i18n.LOGGED_REQUEST_ITEM_ACCORDION_UNKNOWN_TIME_BUTTON, `[${duration}ms]`),
    id: `ruleExecution-${startedAt}`,
    css: (0, _css.css)`
        margin-left: ${paddingLarge};
        ${cssStyles}
      `
  }, (requests !== null && requests !== void 0 ? requests : []).map((request, key) => {
    var _request$description;
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      key: key,
      css: (0, _css.css)`
            padding-left: ${paddingLarge};
          `
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "l"
    }), /*#__PURE__*/_react.default.createElement("span", {
      "data-test-subj": "preview-logged-request-description"
    }, (_request$description = request === null || request === void 0 ? void 0 : request.description) !== null && _request$description !== void 0 ? _request$description : null, " ", request !== null && request !== void 0 && request.duration ? `[${request.duration}ms]` : null), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "s"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiCodeBlock, {
      language: "json",
      isCopyable: true,
      overflowHeight: 300,
      isVirtualized: true,
      "data-test-subj": "preview-logged-request-code-block"
    }, request.request));
  }));
};
const LoggedRequestsItem = exports.LoggedRequestsItem = /*#__PURE__*/_react.default.memo(LoggedRequestsItemComponent);
LoggedRequestsItem.displayName = 'LoggedRequestsItem';