"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pickFieldValueForVersion = pickFieldValueForVersion;
exports.stringifyToSortedJson = void 0;
var _jsonStableStringify = _interopRequireDefault(require("json-stable-stringify"));
var _constants = require("../versions_picker/constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Picks the field value for a given version either from a three-way diff object or from a user-set resolved value.
 *
 * @param version - The version for which the field value is to be picked.
 * @param fieldThreeWayDiff - The three-way diff object containing the field values for different versions.
 * @param resolvedValue - A value field will be upgraded to.
 * @returns - The field value for the specified version
 */
function pickFieldValueForVersion(version, fieldThreeWayDiff, resolvedValue) {
  if (version === _constants.Version.Final) {
    return resolvedValue;
  }
  const versionFieldToPick = `${version}_version`;
  return fieldThreeWayDiff[versionFieldToPick];
}

/**
 * Stringifies a field value to an alphabetically sorted JSON string.
 */
const stringifyToSortedJson = fieldValue => {
  if (fieldValue === undefined) {
    return '';
  }
  if (typeof fieldValue === 'string') {
    return fieldValue;
  }
  return (0, _jsonStableStringify.default)(fieldValue, {
    space: 2
  });
};
exports.stringifyToSortedJson = stringifyToSortedJson;