"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleUpgradeCallout = RuleUpgradeCallout;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _prebuilt_rule_upgrade = require("../../../../../model/prebuilt_rule_upgrade");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function RuleUpgradeCallout({
  ruleUpgradeState
}) {
  const fieldsUpgradeState = ruleUpgradeState.fieldsUpgradeState;
  const {
    numOfNonSolvableConflicts,
    numOfSolvableConflicts
  } = (0, _react.useMemo)(() => {
    let numOfFieldsWithNonSolvableConflicts = 0;
    let numOfFieldsWithSolvableConflicts = 0;
    for (const fieldName of Object.keys(fieldsUpgradeState)) {
      if (fieldsUpgradeState[fieldName] === _prebuilt_rule_upgrade.FieldUpgradeState.NonSolvableConflict) {
        numOfFieldsWithNonSolvableConflicts++;
      }
      if (fieldsUpgradeState[fieldName] === _prebuilt_rule_upgrade.FieldUpgradeState.SolvableConflict) {
        numOfFieldsWithSolvableConflicts++;
      }
    }
    return {
      numOfNonSolvableConflicts: numOfFieldsWithNonSolvableConflicts,
      numOfSolvableConflicts: numOfFieldsWithSolvableConflicts
    };
  }, [fieldsUpgradeState]);
  if (numOfNonSolvableConflicts > 0) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      title: i18n.RULE_HAS_NON_SOLVABLE_CONFLICTS(numOfNonSolvableConflicts),
      iconType: "warning",
      color: "danger",
      size: "s"
    }, /*#__PURE__*/_react.default.createElement("p", null, i18n.RULE_HAS_NON_SOLVABLE_CONFLICTS_DESCRIPTION));
  }
  if (numOfSolvableConflicts > 0) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      title: i18n.RULE_HAS_SOLVABLE_CONFLICTS(numOfSolvableConflicts),
      iconType: "warning",
      color: "warning",
      size: "s"
    }, /*#__PURE__*/_react.default.createElement("p", null, i18n.RULE_HAS_SOLVABLE_CONFLICTS_DESCRIPTION));
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: i18n.RULE_IS_READY_FOR_UPGRADE,
    iconType: "checkInCircleFilled",
    color: "success",
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("p", null, i18n.RULE_IS_READY_FOR_UPGRADE_DESCRIPTION));
}