"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleFieldEditFormWrapper = RuleFieldEditFormWrapper;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _shared_imports = require("../../../../../../../shared_imports");
var _final_side_context = require("../../final_side/final_side_context");
var _diffable_rule_context = require("../../diffable_rule_context");
var i18n = _interopRequireWildcard(require("../../translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * RuleFieldEditFormWrapper component manages form state and renders "Save" and "Cancel" buttons.
 *
 * @param {Object} props - Component props.
 * @param {React.ComponentType} props.component - Field component to be wrapped.
 * @param {FormSchema} props.ruleFieldFormSchema - Configuration schema for the field.
 * @param {Function} props.deserializer - Deserializer prepares initial form data. It converts field value from a DiffableRule format to a format used by the form.
 * @param {Function} props.serializer - Serializer prepares form data for submission. It converts form data back to a DiffableRule format.
 */
function RuleFieldEditFormWrapper({
  component: FieldComponent,
  ruleFieldFormSchema,
  deserializer,
  serializer
}) {
  const {
    fieldName,
    setReadOnlyMode
  } = (0, _final_side_context.useFinalSideContext)();
  const {
    finalDiffableRule,
    setRuleFieldResolvedValue
  } = (0, _diffable_rule_context.useDiffableRuleContext)();
  const deserialize = (0, _react.useCallback)(defaultValue => deserializer ? deserializer(defaultValue, finalDiffableRule) : defaultValue, [deserializer, finalDiffableRule]);
  const handleSubmit = (0, _react.useCallback)(async (formData, isValid) => {
    if (!isValid) {
      return;
    }
    setRuleFieldResolvedValue({
      ruleId: finalDiffableRule.rule_id,
      fieldName: fieldName,
      resolvedValue: formData[fieldName]
    });
    setReadOnlyMode();
  }, [fieldName, finalDiffableRule.rule_id, setReadOnlyMode, setRuleFieldResolvedValue]);
  const {
    form
  } = (0, _shared_imports.useForm)({
    schema: ruleFieldFormSchema,
    defaultValue: getDefaultValue(fieldName, finalDiffableRule),
    deserializer: deserialize,
    serializer,
    onSubmit: handleSubmit
  });

  // form.isValid has `undefined` value until all fields are dirty.
  // Run the validation upfront to visualize form validity state.
  (0, _react.useEffect)(() => {
    form.validate();
  }, [form]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "flexEnd"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    iconType: "cross",
    onClick: setReadOnlyMode
  }, i18n.CANCEL_BUTTON_LABEL), /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    iconType: "save",
    onClick: form.submit,
    disabled: !form.isValid
  }, i18n.SAVE_BUTTON_LABEL)), /*#__PURE__*/_react.default.createElement(_shared_imports.Form, {
    form: form
  }, /*#__PURE__*/_react.default.createElement(FieldComponent, {
    finalDiffableRule: finalDiffableRule,
    setFieldValue: form.setFieldValue,
    resetForm: form.reset
  })));
}
function getDefaultValue(fieldName, finalDiffableRule) {
  return {
    [fieldName]: finalDiffableRule[fieldName]
  };
}