"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUpgradeSecurityPackages = exports.useIsUpgradingSecurityPackages = void 0;
var _reactQuery = require("@tanstack/react-query");
var _react = require("react");
var _use_bootstrap_prebuilt_rules = require("../api/hooks/use_bootstrap_prebuilt_rules");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Install or upgrade the security packages (endpoint and prebuilt rules)
 */
const useUpgradeSecurityPackages = () => {
  const {
    mutate: bootstrapPrebuiltRules
  } = (0, _use_bootstrap_prebuilt_rules.useBootstrapPrebuiltRulesMutation)();
  (0, _react.useEffect)(() => {
    bootstrapPrebuiltRules();
  }, [bootstrapPrebuiltRules]);
};

/**
 * @returns true if the security packages are being installed or upgraded
 */
exports.useUpgradeSecurityPackages = useUpgradeSecurityPackages;
const useIsUpgradingSecurityPackages = () => {
  const bootstrappingRules = (0, _reactQuery.useIsMutating)({
    mutationKey: _use_bootstrap_prebuilt_rules.BOOTSTRAP_PREBUILT_RULES_KEY
  });
  return bootstrappingRules > 0;
};
exports.useIsUpgradingSecurityPackages = useIsUpgradingSecurityPackages;