"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUpgradePrebuiltRulesTableContext = exports.UpgradePrebuiltRulesTableContextProvider = exports.PREBUILT_RULE_UPDATE_FLYOUT_ANCHOR = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _fields = require("../../../../rule_management/model/prebuilt_rule_upgrade/fields");
var _use_is_prebuilt_rules_customization_enabled = require("../../../../rule_management/hooks/use_is_prebuilt_rules_customization_enabled");
var _use_app_toasts = require("../../../../../common/hooks/use_app_toasts");
var _rule_upgrade_conflicts_resolver_tab = require("../../../../rule_management/components/rule_details/three_way_diff/rule_upgrade_conflicts_resolver_tab");
var _per_field_rule_diff_tab = require("../../../../rule_management/components/rule_details/per_field_rule_diff_tab");
var _use_upgrade_security_packages = require("../../../../rule_management/logic/use_upgrade_security_packages");
var _invariant = require("../../../../../../common/utils/invariant");
var _use_perform_rule_upgrade = require("../../../../rule_management/logic/prebuilt_rules/use_perform_rule_upgrade");
var _use_prebuilt_rules_upgrade_review = require("../../../../rule_management/logic/prebuilt_rules/use_prebuilt_rules_upgrade_review");
var _use_filter_prebuilt_rules_to_upgrade = require("./use_filter_prebuilt_rules_to_upgrade");
var _rule_details_flyout = require("../../../../rule_management/components/rule_details/rule_details_flyout");
var _rule_diff_tab = require("../../../../rule_management/components/rule_details/rule_diff_tab");
var _field_upgrade_state = require("../../../../rule_management/model/prebuilt_rule_upgrade/field_upgrade_state");
var _use_rule_preview_flyout = require("../use_rule_preview_flyout");
var _ml_job_upgrade_modal = require("./modals/ml_job_upgrade_modal");
var _upgrade_conflicts_modal = require("./modals/upgrade_conflicts_modal");
var _use_prebuilt_rules_upgrade_state = require("./use_prebuilt_rules_upgrade_state");
var _use_upgrade_modals = require("./use_upgrade_modals");
var ruleDetailsI18n = _interopRequireWildcard(require("../../../../rule_management/components/rule_details/translations"));
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const PREBUILT_RULE_UPDATE_FLYOUT_ANCHOR = exports.PREBUILT_RULE_UPDATE_FLYOUT_ANCHOR = 'updatePrebuiltRulePreview';
const UpgradePrebuiltRulesTableContext = /*#__PURE__*/(0, _react.createContext)(null);
const UpgradePrebuiltRulesTableContextProvider = ({
  children
}) => {
  const isPrebuiltRulesCustomizationEnabled = (0, _use_is_prebuilt_rules_customization_enabled.useIsPrebuiltRulesCustomizationEnabled)();
  const [loadingRules, setLoadingRules] = (0, _react.useState)([]);
  const [filterOptions, setFilterOptions] = (0, _react.useState)({
    filter: '',
    tags: [],
    ruleSource: []
  });
  const {
    addError
  } = (0, _use_app_toasts.useAppToasts)();
  const isUpgradingSecurityPackages = (0, _use_upgrade_security_packages.useIsUpgradingSecurityPackages)();
  const {
    data: {
      rules: ruleUpgradeInfos,
      stats: {
        tags
      }
    } = {
      rules: [],
      stats: {
        tags: []
      }
    },
    refetch,
    dataUpdatedAt,
    isFetched,
    isLoading,
    isRefetching
  } = (0, _use_prebuilt_rules_upgrade_review.usePrebuiltRulesUpgradeReview)({
    refetchInterval: false,
    // Disable automatic refetching since request is expensive
    keepPreviousData: true // Use this option so that the state doesn't jump between "success" and "loading" on page change
  });
  const filteredRuleUpgradeInfos = (0, _use_filter_prebuilt_rules_to_upgrade.useFilterPrebuiltRulesToUpgrade)({
    filterOptions,
    rules: ruleUpgradeInfos
  });
  const {
    rulesUpgradeState,
    setRuleFieldResolvedValue
  } = (0, _use_prebuilt_rules_upgrade_state.usePrebuiltRulesUpgradeState)(filteredRuleUpgradeInfos);
  const {
    isVisible: isLegacyMLJobsModalVisible,
    legacyJobsInstalled,
    confirmLegacyMLJobs,
    handleConfirm: handleLegacyMLJobsConfirm,
    handleCancel: handleLegacyMLJobsCancel,
    loadingJobs
  } = (0, _use_upgrade_modals.useMlJobUpgradeModal)();
  const {
    isVisible: isConflictsModalVisible,
    confirmConflictsUpgrade,
    handleConfirm: handleConflictsConfirm,
    handleCancel: handleConflictsCancel
  } = (0, _use_upgrade_modals.useUpgradeConflictsModal)();
  const shouldConfirmMLJobs = legacyJobsInstalled.length > 0;
  const {
    mutateAsync: upgradeSpecificRulesRequest
  } = (0, _use_perform_rule_upgrade.usePerformUpgradeSpecificRules)({
    pickVersion: isPrebuiltRulesCustomizationEnabled ? 'MERGED' : 'TARGET'
  });
  const upgradeRules = (0, _react.useCallback)(async ruleIds => {
    const conflictRuleIdsSet = new Set(isPrebuiltRulesCustomizationEnabled ? ruleIds.filter(ruleId => rulesUpgradeState[ruleId].diff.num_fields_with_conflicts > 0 && rulesUpgradeState[ruleId].hasUnresolvedConflicts) : []);
    const ruleUpgradeSpecifiers = ruleIds.filter(ruleId => !conflictRuleIdsSet.has(ruleId)).map(ruleId => {
      var _rulesUpgradeState$ru, _rulesUpgradeState$ru2;
      return {
        rule_id: ruleId,
        version: (_rulesUpgradeState$ru = (_rulesUpgradeState$ru2 = rulesUpgradeState[ruleId].diff.fields.version) === null || _rulesUpgradeState$ru2 === void 0 ? void 0 : _rulesUpgradeState$ru2.target_version) !== null && _rulesUpgradeState$ru !== void 0 ? _rulesUpgradeState$ru : rulesUpgradeState[ruleId].current_rule.version,
        revision: rulesUpgradeState[ruleId].revision,
        fields: isPrebuiltRulesCustomizationEnabled ? constructRuleFieldsToUpgrade(rulesUpgradeState[ruleId]) : undefined
      };
    });
    setLoadingRules(prev => [...prev, ...ruleUpgradeSpecifiers.map(x => x.rule_id)]);
    try {
      // Handle MLJobs modal
      if (shouldConfirmMLJobs && !(await confirmLegacyMLJobs())) {
        return;
      }
      if (isPrebuiltRulesCustomizationEnabled && conflictRuleIdsSet.size > 0 && !(await confirmConflictsUpgrade())) {
        return;
      }
      await upgradeSpecificRulesRequest(ruleUpgradeSpecifiers);
    } catch (err) {
      addError(err, {
        title: i18n.UPDATE_ERROR
      });
    } finally {
      const upgradedRuleIdsSet = new Set(ruleUpgradeSpecifiers.map(x => x.rule_id));
      setLoadingRules(prev => prev.filter(id => !upgradedRuleIdsSet.has(id)));
    }
  }, [confirmLegacyMLJobs, confirmConflictsUpgrade, shouldConfirmMLJobs, rulesUpgradeState, upgradeSpecificRulesRequest, isPrebuiltRulesCustomizationEnabled, addError]);
  const ruleActionsFactory = (0, _react.useCallback)((rule, closeRulePreview) => {
    var _rulesUpgradeState$ru3;
    return /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      disabled: loadingRules.includes(rule.rule_id) || isRefetching || isUpgradingSecurityPackages || ((_rulesUpgradeState$ru3 = rulesUpgradeState[rule.rule_id]) === null || _rulesUpgradeState$ru3 === void 0 ? void 0 : _rulesUpgradeState$ru3.hasUnresolvedConflicts),
      onClick: () => {
        upgradeRules([rule.rule_id]);
        closeRulePreview();
      },
      fill: true,
      "data-test-subj": "updatePrebuiltRuleFromFlyoutButton"
    }, i18n.UPDATE_BUTTON_LABEL);
  }, [rulesUpgradeState, loadingRules, isRefetching, isUpgradingSecurityPackages, upgradeRules]);
  const extraTabsFactory = (0, _react.useCallback)(rule => {
    const ruleUpgradeState = rulesUpgradeState[rule.rule_id];
    if (!ruleUpgradeState) {
      return [];
    }
    const jsonViewUpdates = {
      id: 'jsonViewUpdates',
      name: /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
        position: "top",
        content: i18n.UPDATE_FLYOUT_JSON_VIEW_TOOLTIP_DESCRIPTION
      }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, ruleDetailsI18n.JSON_VIEW_UPDATES_TAB_LABEL)),
      content: /*#__PURE__*/_react.default.createElement(_rule_details_flyout.TabContentPadding, null, /*#__PURE__*/_react.default.createElement(_rule_diff_tab.RuleDiffTab, {
        oldRule: ruleUpgradeState.current_rule,
        newRule: ruleUpgradeState.target_rule
      }))
    };
    if (isPrebuiltRulesCustomizationEnabled) {
      return [{
        id: 'updates',
        name: /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
          position: "top",
          content: i18n.UPDATE_FLYOUT_PER_FIELD_TOOLTIP_DESCRIPTION
        }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, ruleDetailsI18n.UPDATES_TAB_LABEL)),
        content: /*#__PURE__*/_react.default.createElement(_rule_details_flyout.TabContentPadding, null, /*#__PURE__*/_react.default.createElement(_rule_upgrade_conflicts_resolver_tab.RuleUpgradeConflictsResolverTab, {
          ruleUpgradeState: ruleUpgradeState,
          setRuleFieldResolvedValue: setRuleFieldResolvedValue
        }))
      }, jsonViewUpdates];
    }
    return [{
      id: 'updates',
      name: /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
        position: "top",
        content: i18n.UPDATE_FLYOUT_PER_FIELD_TOOLTIP_DESCRIPTION
      }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, ruleDetailsI18n.UPDATES_TAB_LABEL)),
      content: /*#__PURE__*/_react.default.createElement(_rule_details_flyout.TabContentPadding, null, /*#__PURE__*/_react.default.createElement(_per_field_rule_diff_tab.PerFieldRuleDiffTab, {
        ruleDiff: ruleUpgradeState.diff
      }))
    }, jsonViewUpdates];
  }, [rulesUpgradeState, setRuleFieldResolvedValue, isPrebuiltRulesCustomizationEnabled]);
  const filteredRules = (0, _react.useMemo)(() => filteredRuleUpgradeInfos.map(rule => rule.target_rule), [filteredRuleUpgradeInfos]);
  const {
    rulePreviewFlyout,
    openRulePreview
  } = (0, _use_rule_preview_flyout.useRulePreviewFlyout)({
    rules: filteredRules,
    ruleActionsFactory,
    extraTabsFactory,
    flyoutProps: {
      id: PREBUILT_RULE_UPDATE_FLYOUT_ANCHOR,
      dataTestSubj: PREBUILT_RULE_UPDATE_FLYOUT_ANCHOR
    }
  });
  const actions = (0, _react.useMemo)(() => ({
    reFetchRules: refetch,
    upgradeRules,
    setFilterOptions,
    openRulePreview
  }), [refetch, upgradeRules, openRulePreview]);
  const providerValue = (0, _react.useMemo)(() => {
    return {
      state: {
        ruleUpgradeInfos,
        rulesUpgradeState,
        hasRulesToUpgrade: isFetched && ruleUpgradeInfos.length > 0,
        filterOptions,
        tags,
        isFetched,
        isLoading: isLoading || loadingJobs,
        isRefetching,
        isUpgradingSecurityPackages,
        loadingRules,
        lastUpdated: dataUpdatedAt,
        isPrebuiltRulesCustomizationEnabled
      },
      actions
    };
  }, [ruleUpgradeInfos, rulesUpgradeState, filterOptions, tags, isFetched, isLoading, loadingJobs, isRefetching, isUpgradingSecurityPackages, loadingRules, dataUpdatedAt, actions, isPrebuiltRulesCustomizationEnabled]);
  return /*#__PURE__*/_react.default.createElement(UpgradePrebuiltRulesTableContext.Provider, {
    value: providerValue
  }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, isLegacyMLJobsModalVisible && /*#__PURE__*/_react.default.createElement(_ml_job_upgrade_modal.MlJobUpgradeModal, {
    jobs: legacyJobsInstalled,
    onCancel: handleLegacyMLJobsCancel,
    onConfirm: handleLegacyMLJobsConfirm
  }), isConflictsModalVisible && /*#__PURE__*/_react.default.createElement(_upgrade_conflicts_modal.UpgradeConflictsModal, {
    onCancel: handleConflictsCancel,
    onConfirm: handleConflictsConfirm
  }), children, rulePreviewFlyout));
};
exports.UpgradePrebuiltRulesTableContextProvider = UpgradePrebuiltRulesTableContextProvider;
const useUpgradePrebuiltRulesTableContext = () => {
  const rulesTableContext = (0, _react.useContext)(UpgradePrebuiltRulesTableContext);
  (0, _invariant.invariant)(rulesTableContext, 'useUpgradePrebuiltRulesTableContext should be used inside UpgradePrebuiltRulesTableContextProvider');
  return rulesTableContext;
};
exports.useUpgradePrebuiltRulesTableContext = useUpgradePrebuiltRulesTableContext;
function constructRuleFieldsToUpgrade(ruleUpgradeState) {
  const finalRule = ruleUpgradeState.finalRule;
  const ruleFieldsToUpgrade = {};
  for (const fieldName of Object.keys(ruleUpgradeState.fieldsUpgradeState)) {
    const fieldUpgradeState = ruleUpgradeState.fieldsUpgradeState[fieldName];
    if (!(0, _fields.isNonUpgradeableFieldName)(fieldName) && fieldUpgradeState === _field_upgrade_state.FieldUpgradeState.Accepted) {
      (0, _invariant.invariant)(fieldName in finalRule, `Ready to upgrade field "${fieldName}" is not found in final rule`);
      ruleFieldsToUpgrade[fieldName] = {
        pick_version: 'RESOLVED',
        resolved_value: finalRule[fieldName]
      };
    }
  }
  return ruleFieldsToUpgrade;
}