"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleCustomizationFilterPopover = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _logic = require("../../../../rule_management/logic");
var i18n = _interopRequireWildcard(require("../../../../../detections/pages/detection_engine/rules/translations"));
var _toggle_selected_group = require("../../../../../common/components/ml_popover/jobs_table/filters/toggle_selected_group");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const RULE_CUSTOMIZATION_POPOVER_WIDTH = 200;
const RuleCustomizationFilterPopoverComponent = ({
  selectedRuleSource,
  onSelectedRuleSourceChanged
}) => {
  const [isRuleCustomizationPopoverOpen, setIsRuleCustomizationPopoverOpen] = (0, _react.useState)(false);
  const selectableOptions = (0, _react.useMemo)(() => [{
    label: i18n.MODIFIED_LABEL,
    key: _logic.RuleCustomizationEnum.customized,
    checked: selectedRuleSource.includes(_logic.RuleCustomizationEnum.customized) ? 'on' : undefined
  }, {
    label: i18n.UNMODIFIED_LABEL,
    key: _logic.RuleCustomizationEnum.not_customized,
    checked: selectedRuleSource.includes(_logic.RuleCustomizationEnum.not_customized) ? 'on' : undefined
  }], [selectedRuleSource]);
  const handleSelectableOptionsChange = (newOptions, _, changedOption) => {
    var _changedOption$key;
    (0, _toggle_selected_group.toggleSelectedGroup)((_changedOption$key = changedOption.key) !== null && _changedOption$key !== void 0 ? _changedOption$key : '', selectedRuleSource, onSelectedRuleSourceChanged);
  };
  const triggerButton = /*#__PURE__*/_react.default.createElement(_eui.EuiFilterButton, {
    grow: true,
    iconType: "arrowDown",
    onClick: () => setIsRuleCustomizationPopoverOpen(!isRuleCustomizationPopoverOpen),
    numFilters: selectableOptions.length,
    isSelected: isRuleCustomizationPopoverOpen,
    hasActiveFilters: selectedRuleSource.length > 0,
    numActiveFilters: selectedRuleSource.length,
    "data-test-subj": "rule-customization-filter-popover-button"
  }, i18n.RULE_SOURCE);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPopover, {
    ownFocus: true,
    button: triggerButton,
    isOpen: isRuleCustomizationPopoverOpen,
    closePopover: () => setIsRuleCustomizationPopoverOpen(!isRuleCustomizationPopoverOpen),
    panelPaddingSize: "none",
    repositionOnScroll: true,
    panelProps: {
      'data-test-subj': 'rule-customization-filter-popover'
    }
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSelectable, {
    options: selectableOptions,
    onChange: handleSelectableOptionsChange
  }, list => /*#__PURE__*/_react.default.createElement("div", {
    style: {
      width: RULE_CUSTOMIZATION_POPOVER_WIDTH
    }
  }, list)));
};
const RuleCustomizationFilterPopover = exports.RuleCustomizationFilterPopover = /*#__PURE__*/_react.default.memo(RuleCustomizationFilterPopoverComponent);