"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFilterPrebuiltRulesToUpgrade = void 0;
var _react = require("react");
var _types = require("../../../../rule_management/logic/types");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const useFilterPrebuiltRulesToUpgrade = ({
  rules,
  filterOptions
}) => {
  const filteredRules = (0, _react.useMemo)(() => {
    const {
      filter,
      tags,
      ruleSource
    } = filterOptions;
    return rules.filter(ruleInfo => {
      if (filter && !ruleInfo.current_rule.name.toLowerCase().includes(filter.toLowerCase())) {
        return false;
      }
      if (tags && tags.length > 0) {
        return tags.every(tag => ruleInfo.current_rule.tags.includes(tag));
      }
      if (ruleSource && ruleSource.length > 0) {
        if (ruleSource.includes(_types.RuleCustomizationEnum.customized) && ruleSource.includes(_types.RuleCustomizationEnum.not_customized)) {
          return true;
        } else if (ruleSource.includes(_types.RuleCustomizationEnum.customized) && ruleInfo.current_rule.rule_source.type === 'external') {
          return ruleInfo.current_rule.rule_source.is_customized;
        } else if (ruleSource.includes(_types.RuleCustomizationEnum.not_customized) && ruleInfo.current_rule.rule_source.type === 'external') {
          return ruleInfo.current_rule.rule_source.is_customized === false;
        }
      }
      return true;
    });
  }, [filterOptions, rules]);
  return filteredRules;
};
exports.useFilterPrebuiltRulesToUpgrade = useFilterPrebuiltRulesToUpgrade;