"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePrebuiltRulesUpgradeState = usePrebuiltRulesUpgradeState;
var _react = require("react");
var _use_is_prebuilt_rules_customization_enabled = require("../../../../rule_management/hooks/use_is_prebuilt_rules_customization_enabled");
var _prebuilt_rule_upgrade = require("../../../../rule_management/model/prebuilt_rule_upgrade");
var _detection_engine = require("../../../../../../common/api/detection_engine");
var _convert_rule_to_diffable = require("../../../../../../common/detection_engine/prebuilt_rules/diff/convert_rule_to_diffable");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function usePrebuiltRulesUpgradeState(ruleUpgradeInfos) {
  const isPrebuiltRulesCustomizationEnabled = (0, _use_is_prebuilt_rules_customization_enabled.useIsPrebuiltRulesCustomizationEnabled)();
  const [rulesResolvedConflicts, setRulesResolvedConflicts] = (0, _react.useState)({});
  const setRuleFieldResolvedValue = (0, _react.useCallback)((...[params]) => {
    setRulesResolvedConflicts(prevRulesResolvedConflicts => {
      var _prevRulesResolvedCon;
      return {
        ...prevRulesResolvedConflicts,
        [params.ruleId]: {
          ...((_prevRulesResolvedCon = prevRulesResolvedConflicts[params.ruleId]) !== null && _prevRulesResolvedCon !== void 0 ? _prevRulesResolvedCon : {}),
          [params.fieldName]: params.resolvedValue
        }
      };
    });
  }, []);
  const rulesUpgradeState = (0, _react.useMemo)(() => {
    const state = {};
    for (const ruleUpgradeInfo of ruleUpgradeInfos) {
      var _rulesResolvedConflic, _rulesResolvedConflic2, _rulesResolvedConflic3;
      state[ruleUpgradeInfo.rule_id] = {
        ...ruleUpgradeInfo,
        finalRule: calcFinalDiffableRule(ruleUpgradeInfo, (_rulesResolvedConflic = rulesResolvedConflicts[ruleUpgradeInfo.rule_id]) !== null && _rulesResolvedConflic !== void 0 ? _rulesResolvedConflic : {}),
        fieldsUpgradeState: calcFieldsState(ruleUpgradeInfo.diff.fields, (_rulesResolvedConflic2 = rulesResolvedConflicts[ruleUpgradeInfo.rule_id]) !== null && _rulesResolvedConflic2 !== void 0 ? _rulesResolvedConflic2 : {}),
        hasUnresolvedConflicts: isPrebuiltRulesCustomizationEnabled ? getUnacceptedConflictsCount(ruleUpgradeInfo.diff.fields, (_rulesResolvedConflic3 = rulesResolvedConflicts[ruleUpgradeInfo.rule_id]) !== null && _rulesResolvedConflic3 !== void 0 ? _rulesResolvedConflic3 : {}) > 0 : false
      };
    }
    return state;
  }, [ruleUpgradeInfos, rulesResolvedConflicts, isPrebuiltRulesCustomizationEnabled]);
  return {
    rulesUpgradeState,
    setRuleFieldResolvedValue
  };
}
function calcFinalDiffableRule(ruleUpgradeInfo, ruleResolvedConflicts) {
  return {
    ...(0, _convert_rule_to_diffable.convertRuleToDiffable)(ruleUpgradeInfo.target_rule),
    ...convertRuleFieldsDiffToDiffable(ruleUpgradeInfo.diff.fields),
    ...ruleResolvedConflicts
  };
}

/**
 * Assembles a `DiffableRule` from rule fields diff `merged_version`s.
 */
function convertRuleFieldsDiffToDiffable(ruleFieldsDiff) {
  const mergeVersionRule = {};
  for (const fieldName of Object.keys(ruleFieldsDiff)) {
    mergeVersionRule[fieldName] = ruleFieldsDiff[fieldName].merged_version;
  }
  return mergeVersionRule;
}
function calcFieldsState(ruleFieldsDiff, ruleResolvedConflicts) {
  const fieldsState = {};
  for (const fieldName of Object.keys(ruleFieldsDiff)) {
    switch (ruleFieldsDiff[fieldName].conflict) {
      case _detection_engine.ThreeWayDiffConflict.NONE:
        fieldsState[fieldName] = _prebuilt_rule_upgrade.FieldUpgradeState.Accepted;
        break;
      case _detection_engine.ThreeWayDiffConflict.SOLVABLE:
        fieldsState[fieldName] = _prebuilt_rule_upgrade.FieldUpgradeState.SolvableConflict;
        break;
      case _detection_engine.ThreeWayDiffConflict.NON_SOLVABLE:
        fieldsState[fieldName] = _prebuilt_rule_upgrade.FieldUpgradeState.NonSolvableConflict;
        break;
    }
  }
  for (const fieldName of Object.keys(ruleResolvedConflicts)) {
    fieldsState[fieldName] = _prebuilt_rule_upgrade.FieldUpgradeState.Accepted;
  }
  return fieldsState;
}
function getUnacceptedConflictsCount(ruleFieldsDiff, ruleResolvedConflicts) {
  const fieldNames = Object.keys(ruleFieldsDiff);
  const fieldNamesWithConflict = fieldNames.filter(fieldName => ruleFieldsDiff[fieldName].conflict !== _detection_engine.ThreeWayDiffConflict.NONE);
  const fieldNamesWithConflictSet = new Set(fieldNamesWithConflict);
  for (const resolvedConflictField of Object.keys(ruleResolvedConflicts)) {
    if (fieldNamesWithConflictSet.has(resolvedConflictField)) {
      fieldNamesWithConflictSet.delete(resolvedConflictField);
    }
  }
  return fieldNamesWithConflictSet.size;
}