"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AlertsByRule = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _ruleDataUtils = require("@kbn/rule-data-utils");
var _securitysolutionDataTable = require("@kbn/securitysolution-data-table");
var _formatted_number = require("../../../../common/components/formatted_number");
var _draggables = require("../../../../common/components/draggables");
var _translations = require("../../alerts_table/translations");
var _translations2 = require("../alerts_count_panel/translations");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const Wrapper = _styledComponents.default.div`
  margin-top: -${({
  theme
}) => theme.eui.euiSizeM};
`;
const TableWrapper = _styledComponents.default.div`
  height: 178px;
`;
const COLUMNS = [{
  field: 'rule',
  name: _translations.ALERTS_HEADERS_RULE_NAME,
  'data-test-subj': 'alert-by-rule-table-rule-name',
  truncateText: true,
  render: rule => /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "xs",
    className: "eui-textTruncate"
  }, /*#__PURE__*/_react.default.createElement(_draggables.DefaultDraggable, {
    isDraggable: false,
    field: _ruleDataUtils.ALERT_RULE_NAME,
    hideTopN: true,
    id: `alert-detection-draggable-${rule}`,
    value: rule,
    queryValue: rule,
    tooltipContent: null,
    truncate: true,
    scopeId: _securitysolutionDataTable.TableId.alertsOnAlertsPage
  }))
}, {
  field: 'value',
  name: _translations2.COUNT_TABLE_TITLE,
  dataType: 'number',
  sortable: true,
  'data-test-subj': 'alert-by-rule-table-count',
  render: count => /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    grow: false,
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement(_formatted_number.FormattedCount, {
    count: count
  })),
  width: '22%'
}];
const SORTING = {
  sort: {
    field: 'value',
    direction: 'desc'
  }
};
const PAGINATION = {
  pageSize: 25,
  showPerPageOptions: false
};
const AlertsByRule = ({
  data,
  isLoading
}) => {
  return /*#__PURE__*/_react.default.createElement(Wrapper, {
    "data-test-subj": "alerts-by-rule"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement(TableWrapper, {
    className: "eui-yScroll"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiInMemoryTable, {
    "data-test-subj": "alerts-by-rule-table",
    columns: COLUMNS,
    items: data,
    loading: isLoading,
    sorting: SORTING,
    pagination: PAGINATION
  })));
};
exports.AlertsByRule = AlertsByRule;
AlertsByRule.displayName = 'AlertsByRule';