"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EntityStoreDashboardPanels = exports.EnableEntityStore = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var _entity_analytics = require("../../../../../common/api/entity_analytics");
var _search_strategy = require("../../../../../common/search_strategy");
var _entities_list = require("../entities_list");
var _use_entity_store = require("../hooks/use_entity_store");
var _enablement_modal = require("./enablement_modal");
var _entity_analytics_risk_score = require("../../entity_analytics_risk_score");
var _use_init_risk_engine_mutation = require("../../../api/hooks/use_init_risk_engine_mutation");
var _use_entity_engine_status = require("../hooks/use_entity_engine_status");
var _entity_store_dashboard = _interopRequireDefault(require("../../../images/entity_store_dashboard.png"));
var _translations = require("../translations");
var _use_risk_engine_status = require("../../../api/hooks/use_risk_engine_status");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const EntityStoreDashboardPanelsComponent = () => {
  const [modal, setModalState] = (0, _react.useState)({
    visible: false
  });
  const [riskEngineInitializing, setRiskEngineInitializing] = (0, _react.useState)(false);
  const entityStore = (0, _use_entity_engine_status.useEntityEngineStatus)();
  const riskEngineStatus = (0, _use_risk_engine_status.useRiskEngineStatus)();
  const {
    enable: enableStore,
    query
  } = (0, _use_entity_store.useEntityStoreEnablement)();
  const {
    mutate: initRiskEngine
  } = (0, _use_init_risk_engine_mutation.useInitRiskEngineMutation)();
  const callouts = entityStore.errors.map(err => /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.enablement.errors.title",
      defaultMessage: 'An error occurred during entity store resource initialization'
    }),
    color: "danger",
    iconType: "error"
  }, /*#__PURE__*/_react.default.createElement("p", null, err === null || err === void 0 ? void 0 : err.message)));
  const enableEntityStore = enable => () => {
    setModalState({
      visible: false
    });
    if (enable.riskScore) {
      const options = {
        onSuccess: () => {
          setRiskEngineInitializing(false);
          if (enable.entityStore) {
            enableStore();
          }
        }
      };
      setRiskEngineInitializing(true);
      initRiskEngine(undefined, options);
      return;
    }
    if (enable.entityStore) {
      enableStore();
    }
  };
  if (query.error) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.entityAnalytics.entityStore.enablement.errors.queryErrorTitle",
        defaultMessage: 'There was a problem initializing the entity store'
      }),
      color: "danger",
      iconType: "error"
    }, /*#__PURE__*/_react.default.createElement("p", null, query.error.body.message)), callouts);
  }
  if (entityStore.status === 'loading') {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
      hasBorder: true
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
      icon: /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingSpinner, {
        size: "xl"
      }),
      title: /*#__PURE__*/_react.default.createElement("h2", null, _translations.ENABLEMENT_INITIALIZING_ENTITY_STORE)
    }));
  }
  if (entityStore.status === 'installing') {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
      hasBorder: true
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
      icon: /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingLogo, {
        logo: "logoElastic",
        size: "xl"
      }),
      title: /*#__PURE__*/_react.default.createElement("h2", null, _translations.ENABLEMENT_INITIALIZING_ENTITY_STORE),
      body: /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.entityAnalytics.entityStore.enablement.initializing.description",
        defaultMessage: "This can take up to 5 minutes."
      }))
    }));
  }

  // TODO Rename variable because the Risk score could be installed but disabled
  const isRiskScoreAvailable = riskEngineStatus.data && riskEngineStatus.data.risk_engine_status !== _entity_analytics.RiskEngineStatusEnum.NOT_INSTALLED;
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    "data-test-subj": "entityStorePanelsGroup"
  }, entityStore.status === 'error' && isRiskScoreAvailable && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, callouts, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entity_analytics_risk_score.EntityAnalyticsRiskScores, {
    riskEntity: _search_strategy.RiskScoreEntity.user
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entity_analytics_risk_score.EntityAnalyticsRiskScores, {
    riskEntity: _search_strategy.RiskScoreEntity.host
  }))), entityStore.status === 'error' && !isRiskScoreAvailable && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, callouts, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(EnableEntityStore, {
    onEnable: () => setModalState({
      visible: true
    }),
    loadingRiskEngine: riskEngineInitializing,
    enablements: "riskScore"
  }))), entityStore.status === 'enabled' && isRiskScoreAvailable && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entity_analytics_risk_score.EntityAnalyticsRiskScores, {
    riskEntity: _search_strategy.RiskScoreEntity.user
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entity_analytics_risk_score.EntityAnalyticsRiskScores, {
    riskEntity: _search_strategy.RiskScoreEntity.host
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entities_list.EntitiesList, null))), entityStore.status === 'enabled' && !isRiskScoreAvailable && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(EnableEntityStore, {
    onEnable: () => setModalState({
      visible: true
    }),
    loadingRiskEngine: riskEngineInitializing,
    enablements: "riskScore"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entities_list.EntitiesList, null))), (entityStore.status === 'not_installed' || entityStore.status === 'stopped') && !isRiskScoreAvailable &&
  /*#__PURE__*/
  // TODO: Move modal inside EnableEntityStore component, eliminating the onEnable prop in favour of forwarding the riskScoreEnabled status
  _react.default.createElement(EnableEntityStore, {
    enablements: "both",
    onEnable: () => setModalState({
      visible: true
    }),
    loadingRiskEngine: riskEngineInitializing
  }), (entityStore.status === 'not_installed' || entityStore.status === 'stopped') && isRiskScoreAvailable && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(EnableEntityStore, {
    enablements: "store",
    onEnable: () => setModalState({
      visible: true
    })
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entity_analytics_risk_score.EntityAnalyticsRiskScores, {
    riskEntity: _search_strategy.RiskScoreEntity.user
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_entity_analytics_risk_score.EntityAnalyticsRiskScores, {
    riskEntity: _search_strategy.RiskScoreEntity.host
  }))), /*#__PURE__*/_react.default.createElement(_enablement_modal.EntityStoreEnablementModal, {
    visible: modal.visible,
    toggle: visible => setModalState({
      visible
    }),
    enableStore: enableEntityStore,
    riskScore: {
      disabled: isRiskScoreAvailable,
      checked: !isRiskScoreAvailable
    },
    entityStore: {
      disabled: entityStore.status === 'enabled',
      checked: entityStore.status !== 'enabled'
    }
  }));
};
const EnableEntityStore = ({
  onEnable,
  enablements,
  loadingRiskEngine
}) => {
  const title = enablements === 'store' ? _translations.ENABLE_ENTITY_STORE_TITLE : enablements === 'riskScore' ? _translations.ENABLE_RISK_SCORE_TITLE : _translations.ENABLE_ALL_TITLE;
  const body = enablements === 'store' ? _translations.ENABLEMENT_DESCRIPTION_ENTITY_STORE_ONLY : enablements === 'riskScore' ? _translations.ENABLEMENT_DESCRIPTION_RISK_ENGINE_ONLY : _translations.ENABLEMENT_DESCRIPTION_BOTH;
  if (loadingRiskEngine) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
      hasBorder: true
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
      icon: /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingLogo, {
        logo: "logoElastic",
        size: "xl"
      }),
      title: /*#__PURE__*/_react.default.createElement("h2", null, _translations.ENABLEMENT_INITIALIZING_RISK_ENGINE)
    }));
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
    css: {
      minWidth: '100%'
    },
    hasBorder: true,
    layout: "horizontal",
    className: "eui-fullWidth",
    title: /*#__PURE__*/_react.default.createElement("h2", null, title),
    body: /*#__PURE__*/_react.default.createElement("p", null, body),
    actions: /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
      content: title
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      color: "primary",
      fill: true,
      onClick: onEnable,
      "data-test-subj": `enable_entity_store_btn`
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.enablement.enableButton",
      defaultMessage: "Enable"
    }))),
    icon: /*#__PURE__*/_react.default.createElement(_eui.EuiImage, {
      size: "l",
      hasShadow: true,
      src: _entity_store_dashboard.default,
      alt: title
    })
  });
};
exports.EnableEntityStore = EnableEntityStore;
const EntityStoreDashboardPanels = exports.EntityStoreDashboardPanels = /*#__PURE__*/_react.default.memo(EntityStoreDashboardPanelsComponent);
EntityStoreDashboardPanels.displayName = 'EntityStoreDashboardPanels';