"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EntityStoreEnablementModal = void 0;
var _eui = require("@elastic/eui");
var _react = require("@emotion/react");
var _react2 = _interopRequireWildcard(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _translations = require("../../../../common/translations");
var _translations2 = require("../translations");
var _use_entity_engine_privileges = require("../hooks/use_entity_engine_privileges");
var _missing_privileges_callout = require("./missing_privileges_callout");
var _use_missing_risk_engine_privileges = require("../../../hooks/use_missing_risk_engine_privileges");
var _risk_engine_privileges_callout = require("../../risk_engine_privileges_callout");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const EntityStoreEnablementModal = ({
  visible,
  toggle,
  enableStore,
  riskScore,
  entityStore
}) => {
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const [enablements, setEnablements] = (0, _react2.useState)({
    riskScore: !!riskScore.checked,
    entityStore: !!entityStore.checked
  });
  const {
    data: entityEnginePrivileges,
    isLoading: isLoadingEntityEnginePrivileges
  } = (0, _use_entity_engine_privileges.useEntityEnginePrivileges)();
  const riskEnginePrivileges = (0, _use_missing_risk_engine_privileges.useMissingRiskEnginePrivileges)();
  const enablementOptions = enablements.riskScore || enablements.entityStore;
  if (!visible) {
    return null;
  }
  const proceedWarning = /*#__PURE__*/_react2.default.createElement(_eui.EuiCallOut, {
    size: "s",
    color: "danger",
    css: (0, _react.css)`
        border-radius: ${euiTheme.border.radius.medium};
      `
  }, /*#__PURE__*/_react2.default.createElement("p", null, _translations2.ENABLEMENT_WARNING_SELECT_TO_PROCEED));
  return /*#__PURE__*/_react2.default.createElement(_eui.EuiModal, {
    onClose: () => toggle(false)
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiModalHeader, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiModalHeaderTitle, null, /*#__PURE__*/_react2.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.enablements.modal.title",
    defaultMessage: "Entity Analytics Enablement"
  }))), /*#__PURE__*/_react2.default.createElement(_eui.EuiModalBody, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
    direction: "column"
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiSwitch, {
    label: /*#__PURE__*/_react2.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.enablements.modal.risk",
      defaultMessage: "Risk Score"
    }),
    checked: enablements.riskScore,
    disabled: riskScore.disabled || !riskEnginePrivileges.isLoading && !(riskEnginePrivileges !== null && riskEnginePrivileges !== void 0 && riskEnginePrivileges.hasAllRequiredPrivileges),
    onChange: () => setEnablements(prev => ({
      ...prev,
      riskScore: !prev.riskScore
    }))
  })), !riskEnginePrivileges.isLoading && !riskEnginePrivileges.hasAllRequiredPrivileges && /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react2.default.createElement(_risk_engine_privileges_callout.RiskEnginePrivilegesCallOut, {
    privileges: riskEnginePrivileges
  })), /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiText, null, _translations2.ENABLEMENT_DESCRIPTION_RISK_ENGINE_ONLY)), /*#__PURE__*/_react2.default.createElement(_eui.EuiHorizontalRule, {
    margin: "none"
  }), /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "flexStart"
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiSwitch, {
    label: /*#__PURE__*/_react2.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.enablements.modal.store",
      defaultMessage: "Entity Store"
    }),
    checked: enablements.entityStore,
    disabled: entityStore.disabled || !isLoadingEntityEnginePrivileges && !(entityEnginePrivileges !== null && entityEnginePrivileges !== void 0 && entityEnginePrivileges.has_all_required),
    onChange: () => setEnablements(prev => ({
      ...prev,
      entityStore: !prev.entityStore
    }))
  }), /*#__PURE__*/_react2.default.createElement(_eui.EuiToolTip, {
    content: _translations.TECHNICAL_PREVIEW_TOOLTIP
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiBetaBadge, {
    label: _translations.TECHNICAL_PREVIEW
  })))), !entityEnginePrivileges || entityEnginePrivileges.has_all_required ? null : /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react2.default.createElement(_missing_privileges_callout.MissingPrivilegesCallout, {
    privileges: entityEnginePrivileges
  })), /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiText, null, _translations2.ENABLEMENT_DESCRIPTION_ENTITY_STORE_ONLY)))), /*#__PURE__*/_react2.default.createElement(_eui.EuiModalFooter, null, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "flexEnd",
    alignItems: "center"
  }, !enablementOptions ? /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, null, proceedWarning) : null, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
    direction: "row",
    justifyContent: "flexEnd"
  }, /*#__PURE__*/_react2.default.createElement(_eui.EuiButtonEmpty, {
    onClick: () => toggle(false)
  }, 'Cancel'), /*#__PURE__*/_react2.default.createElement(_eui.EuiButton, {
    onClick: enableStore(enablements),
    fill: true,
    isDisabled: !enablementOptions,
    "aria-disabled": !enablementOptions
  }, /*#__PURE__*/_react2.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.enablements.modal.enable",
    defaultMessage: "Enable"
  })))))));
};
exports.EntityStoreEnablementModal = EntityStoreEnablementModal;