"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEntitiesListColumns = void 0;
var _expandableFlyout = require("@kbn/expandable-flyout");
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _user_right = require("../../../../flyout/entity_details/user_right");
var _host_right = require("../../../../flyout/entity_details/host_right");
var _formatted_date = require("../../../../common/components/formatted_date");
var _common = require("../../severity/common");
var _empty_value = require("../../../../common/components/empty_value");
var _constants = require("../constants");
var _helpers = require("../helpers");
var _translations = require("../../asset_criticality/translations");
var _common2 = require("../../../common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const useEntitiesListColumns = () => {
  const {
    openRightPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  return [{
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.actionsColumn.title",
      defaultMessage: "Actions"
    }),
    render: record => {
      const value = record.entity.name;
      const onClick = () => {
        const id = (0, _helpers.isUserEntity)(record) ? _user_right.UserPanelKey : _host_right.HostPanelKey;
        const params = {
          [(0, _helpers.isUserEntity)(record) ? 'userName' : 'hostName']: value,
          contextID: _constants.ENTITIES_LIST_TABLE_ID,
          scopeId: _constants.ENTITIES_LIST_TABLE_ID
        };
        openRightPanel({
          id,
          params
        });
      };
      if (!value) {
        return null;
      }
      return /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
        iconType: "expand",
        onClick: onClick,
        "aria-label": _i18n.i18n.translate('xpack.securitySolution.entityAnalytics.entityStore.entitiesList.entityPreview.ariaLabel', {
          defaultMessage: 'Preview entity with name {name}',
          values: {
            name: value
          }
        })
      });
    },
    width: '5%'
  }, {
    field: 'entity.name',
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.nameColumn.title",
      defaultMessage: "Name"
    }),
    sortable: true,
    truncateText: {
      lines: 2
    },
    render: (_, record) => {
      return /*#__PURE__*/_react.default.createElement("span", null, (0, _helpers.isUserEntity)(record) ? /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
        type: "user"
      }) : /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
        type: "storage"
      }), /*#__PURE__*/_react.default.createElement("span", {
        css: {
          paddingLeft: euiTheme.size.s
        }
      }, record.entity.name));
    },
    width: '25%'
  }, {
    field: 'entity.source',
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.sourceColumn.title",
      defaultMessage: "Source"
    }),
    width: '25%',
    truncateText: {
      lines: 2
    },
    render: source => {
      if (source != null) {
        return (0, _helpers.sourceFieldToText)(source);
      }
      return (0, _empty_value.getEmptyTagValue)();
    }
  }, {
    field: 'asset.criticality',
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.criticalityColumn.title",
      defaultMessage: "Criticality"
    }),
    width: '10%',
    render: criticality => {
      if (criticality != null) {
        return /*#__PURE__*/_react.default.createElement("span", null, _translations.CRITICALITY_LEVEL_TITLE[criticality]);
      }
      return (0, _empty_value.getEmptyTagValue)();
    }
  }, {
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.riskScoreColumn.title",
      defaultMessage: "Risk score"
    }),
    width: '10%',
    render: entity => {
      var _entity$user, _entity$user$risk, _entity$host, _entity$host$risk;
      const riskScore = (0, _helpers.isUserEntity)(entity) ? (_entity$user = entity.user) === null || _entity$user === void 0 ? void 0 : (_entity$user$risk = _entity$user.risk) === null || _entity$user$risk === void 0 ? void 0 : _entity$user$risk.calculated_score_norm : (_entity$host = entity.host) === null || _entity$host === void 0 ? void 0 : (_entity$host$risk = _entity$host.risk) === null || _entity$host$risk === void 0 ? void 0 : _entity$host$risk.calculated_score_norm;
      if (riskScore != null) {
        return /*#__PURE__*/_react.default.createElement("span", {
          "data-test-subj": "risk-score-truncate",
          title: `${riskScore}`
        }, (0, _common2.formatRiskScore)(riskScore));
      }
      return (0, _empty_value.getEmptyTagValue)();
    }
  }, {
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.riskLevelColumn.title",
      defaultMessage: "Risk Level"
    }),
    width: '10%',
    render: entity => {
      var _entity$user2, _entity$user2$risk, _entity$host2, _entity$host2$risk;
      const riskLevel = (0, _helpers.isUserEntity)(entity) ? (_entity$user2 = entity.user) === null || _entity$user2 === void 0 ? void 0 : (_entity$user2$risk = _entity$user2.risk) === null || _entity$user2$risk === void 0 ? void 0 : _entity$user2$risk.calculated_level : (_entity$host2 = entity.host) === null || _entity$host2 === void 0 ? void 0 : (_entity$host2$risk = _entity$host2.risk) === null || _entity$host2$risk === void 0 ? void 0 : _entity$host2$risk.calculated_level;
      if (riskLevel != null) {
        return /*#__PURE__*/_react.default.createElement(_common.RiskScoreLevel, {
          severity: riskLevel
        });
      }
      return (0, _empty_value.getEmptyTagValue)();
    }
  }, {
    field: '@timestamp',
    name: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStore.entitiesList.lastUpdateColumn.title",
      defaultMessage: "Last Update"
    }),
    sortable: true,
    render: lastUpdate => {
      return /*#__PURE__*/_react.default.createElement(_formatted_date.FormattedRelativePreferenceDate, {
        value: lastUpdate
      });
    },
    width: '15%'
  }];
};
exports.useEntitiesListColumns = useEntitiesListColumns;