"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEntityEngineStatus = exports.ENTITY_STORE_ENGINE_STATUS = void 0;
var _reactQuery = require("@tanstack/react-query");
var _entity_store = require("../../../api/entity_store");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ENTITY_STORE_ENGINE_STATUS = exports.ENTITY_STORE_ENGINE_STATUS = 'ENTITY_STORE_ENGINE_STATUS';
const useEntityEngineStatus = (opts = {}) => {
  var _data$engines$filter$, _data$engines4;
  // QUESTION: Maybe we should have an `EnablementStatus` API route for this?
  const {
    listEntityEngines
  } = (0, _entity_store.useEntityStoreRoutes)();
  const {
    isLoading,
    data
  } = (0, _reactQuery.useQuery)({
    queryKey: [ENTITY_STORE_ENGINE_STATUS],
    queryFn: () => listEntityEngines(),
    refetchInterval: opts.polling,
    enabled: !opts.disabled
  });
  const status = ((_data$engines, _data$engines2, _data$engines3) => {
    if ((data === null || data === void 0 ? void 0 : data.count) === 0) {
      return 'not_installed';
    }
    if (data !== null && data !== void 0 && (_data$engines = data.engines) !== null && _data$engines !== void 0 && _data$engines.some(engine => engine.status === 'error')) {
      return 'error';
    }
    if (data !== null && data !== void 0 && (_data$engines2 = data.engines) !== null && _data$engines2 !== void 0 && _data$engines2.every(engine => engine.status === 'stopped')) {
      return 'stopped';
    }
    if (data !== null && data !== void 0 && (_data$engines3 = data.engines) !== null && _data$engines3 !== void 0 && _data$engines3.some(engine => engine.status === 'installing')) {
      return 'installing';
    }
    if (isLoading) {
      return 'loading';
    }
    if (!data) {
      return 'error';
    }
    return 'enabled';
  })();
  const errors = (_data$engines$filter$ = data === null || data === void 0 ? void 0 : (_data$engines4 = data.engines) === null || _data$engines4 === void 0 ? void 0 : _data$engines4.filter(engine => engine.status === 'error').map(engine => engine.error)) !== null && _data$engines$filter$ !== void 0 ? _data$engines$filter$ : [];
  return {
    status,
    errors
  };
};
exports.useEntityEngineStatus = useEntityEngineStatus;