"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStopEntityEngineMutation = exports.useInvalidateEntityEngineStatusQuery = exports.useInitEntityEngineMutation = exports.useEntityStoreEnablement = exports.useDeleteEntityEngineMutation = exports.STOP_ENTITY_ENGINE_STATUS_KEY = exports.INIT_ENTITY_ENGINE_STATUS_KEY = exports.DELETE_ENTITY_ENGINE_STATUS_KEY = void 0;
var _reactQuery = require("@tanstack/react-query");
var _react = require("react");
var _kibana_react = require("../../../../common/lib/kibana/kibana_react");
var _entity_store = require("../../../api/entity_store");
var _use_entity_engine_status = require("./use_entity_engine_status");
var _telemetry = require("../../../../common/lib/telemetry");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ENTITY_STORE_ENABLEMENT_INIT = 'ENTITY_STORE_ENABLEMENT_INIT';
const useEntityStoreEnablement = () => {
  const [polling, setPolling] = (0, _react.useState)(false);
  const {
    telemetry
  } = (0, _kibana_react.useKibana)().services;
  (0, _use_entity_engine_status.useEntityEngineStatus)({
    disabled: !polling,
    polling: data => {
      const shouldStopPolling = (data === null || data === void 0 ? void 0 : data.engines) && data.engines.length > 0 && data.engines.every(engine => engine.status === 'started');
      if (shouldStopPolling) {
        setPolling(false);
        return false;
      }
      return 5000;
    }
  });
  const {
    initEntityStore
  } = (0, _entity_store.useEntityStoreRoutes)();
  const {
    refetch: initialize,
    ...query
  } = (0, _reactQuery.useQuery)({
    queryKey: [ENTITY_STORE_ENABLEMENT_INIT],
    queryFn: async () => initEntityStore('user').then(usr => initEntityStore('host').then(host => [usr, host])),
    enabled: false
  });
  const enable = (0, _react.useCallback)(() => {
    telemetry === null || telemetry === void 0 ? void 0 : telemetry.reportEvent(_telemetry.EntityEventTypes.EntityStoreDashboardInitButtonClicked, {
      timestamp: new Date().toISOString()
    });
    return initialize().then(() => setPolling(true));
  }, [initialize, telemetry]);
  return {
    enable,
    query
  };
};
exports.useEntityStoreEnablement = useEntityStoreEnablement;
const INIT_ENTITY_ENGINE_STATUS_KEY = exports.INIT_ENTITY_ENGINE_STATUS_KEY = ['POST', 'INIT_ENTITY_ENGINE'];
const useInvalidateEntityEngineStatusQuery = () => {
  const queryClient = (0, _reactQuery.useQueryClient)();
  return (0, _react.useCallback)(() => {
    queryClient.invalidateQueries([_use_entity_engine_status.ENTITY_STORE_ENGINE_STATUS], {
      refetchType: 'active'
    });
  }, [queryClient]);
};
exports.useInvalidateEntityEngineStatusQuery = useInvalidateEntityEngineStatusQuery;
const useInitEntityEngineMutation = options => {
  const {
    telemetry
  } = (0, _kibana_react.useKibana)().services;
  const invalidateEntityEngineStatusQuery = useInvalidateEntityEngineStatusQuery();
  const {
    initEntityStore
  } = (0, _entity_store.useEntityStoreRoutes)();
  return (0, _reactQuery.useMutation)(() => {
    telemetry === null || telemetry === void 0 ? void 0 : telemetry.reportEvent(_telemetry.EntityEventTypes.EntityStoreEnablementToggleClicked, {
      timestamp: new Date().toISOString(),
      action: 'start'
    });
    return initEntityStore('user').then(usr => initEntityStore('host').then(host => [usr, host]));
  }, {
    ...options,
    mutationKey: INIT_ENTITY_ENGINE_STATUS_KEY,
    onSettled: (...args) => {
      invalidateEntityEngineStatusQuery();
      if (options !== null && options !== void 0 && options.onSettled) {
        options.onSettled(...args);
      }
    }
  });
};
exports.useInitEntityEngineMutation = useInitEntityEngineMutation;
const STOP_ENTITY_ENGINE_STATUS_KEY = exports.STOP_ENTITY_ENGINE_STATUS_KEY = ['POST', 'STOP_ENTITY_ENGINE'];
const useStopEntityEngineMutation = options => {
  const {
    telemetry
  } = (0, _kibana_react.useKibana)().services;
  const invalidateEntityEngineStatusQuery = useInvalidateEntityEngineStatusQuery();
  const {
    stopEntityStore
  } = (0, _entity_store.useEntityStoreRoutes)();
  return (0, _reactQuery.useMutation)(() => {
    telemetry === null || telemetry === void 0 ? void 0 : telemetry.reportEvent(_telemetry.EntityEventTypes.EntityStoreEnablementToggleClicked, {
      timestamp: new Date().toISOString(),
      action: 'stop'
    });
    return stopEntityStore('user').then(usr => stopEntityStore('host').then(host => [usr, host]));
  }, {
    ...options,
    mutationKey: STOP_ENTITY_ENGINE_STATUS_KEY,
    onSettled: (...args) => {
      invalidateEntityEngineStatusQuery();
      if (options !== null && options !== void 0 && options.onSettled) {
        options.onSettled(...args);
      }
    }
  });
};
exports.useStopEntityEngineMutation = useStopEntityEngineMutation;
const DELETE_ENTITY_ENGINE_STATUS_KEY = exports.DELETE_ENTITY_ENGINE_STATUS_KEY = ['POST', 'STOP_ENTITY_ENGINE'];
const useDeleteEntityEngineMutation = options => {
  const invalidateEntityEngineStatusQuery = useInvalidateEntityEngineStatusQuery();
  const {
    deleteEntityEngine
  } = (0, _entity_store.useEntityStoreRoutes)();
  return (0, _reactQuery.useMutation)(() => deleteEntityEngine('user', true).then(usr => deleteEntityEngine('host', true).then(host => [usr, host])), {
    ...options,
    mutationKey: DELETE_ENTITY_ENGINE_STATUS_KEY,
    onSettled: (...args) => {
      invalidateEntityEngineStatusQuery();
      if (options !== null && options !== void 0 && options.onSettled) {
        options.onSettled(...args);
      }
    }
  });
};
exports.useDeleteEntityEngineMutation = useDeleteEntityEngineMutation;