"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EntityStoreManagementPage = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _use_entity_engine_status = require("../components/entity_store/hooks/use_entity_engine_status");
var _use_experimental_features = require("../../common/hooks/use_experimental_features");
var _asset_criticality = require("../../../common/entity_analytics/asset_criticality");
var _kibana = require("../../common/lib/kibana");
var _asset_criticality_file_uploader = require("../components/asset_criticality_file_uploader/asset_criticality_file_uploader");
var _use_asset_criticality = require("../components/asset_criticality/use_asset_criticality");
var _helper_hooks = require("../../helper_hooks");
var _use_entity_store = require("../components/entity_store/hooks/use_entity_store");
var _translations = require("../../common/translations");
var _use_entity_engine_privileges = require("../components/entity_store/hooks/use_entity_engine_privileges");
var _missing_privileges_callout = require("../components/entity_store/components/missing_privileges_callout");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const entityStoreEnabledStatuses = ['enabled'];
const switchDisabledStatuses = ['error', 'loading', 'installing'];
const entityStoreInstallingStatuses = ['installing', 'loading'];
const EntityStoreManagementPage = () => {
  const hasEntityAnalyticsCapability = (0, _helper_hooks.useHasSecurityCapability)('entity-analytics');
  const isEntityStoreFeatureFlagDisabled = (0, _use_experimental_features.useIsExperimentalFeatureEnabled)('entityStoreDisabled');
  const {
    data: assetCriticalityPrivileges,
    error: assetCriticalityPrivilegesError,
    isLoading: assetCriticalityIsLoading
  } = (0, _use_asset_criticality.useAssetCriticalityPrivileges)('AssetCriticalityUploadPage');
  const hasAssetCriticalityWritePermissions = assetCriticalityPrivileges === null || assetCriticalityPrivileges === void 0 ? void 0 : assetCriticalityPrivileges.has_write_permissions;
  const [polling, setPolling] = (0, _react.useState)(false);
  const entityStoreStatus = (0, _use_entity_engine_status.useEntityEngineStatus)({
    disabled: false,
    polling: !polling ? undefined : data => {
      const shouldStopPolling = (data === null || data === void 0 ? void 0 : data.engines) && data.engines.length > 0 && data.engines.every(engine => engine.status === 'started');
      if (shouldStopPolling) {
        setPolling(false);
        return false;
      }
      return 1000;
    }
  });
  const initEntityEngineMutation = (0, _use_entity_store.useInitEntityEngineMutation)();
  const stopEntityEngineMutation = (0, _use_entity_store.useStopEntityEngineMutation)();
  const deleteEntityEngineMutation = (0, _use_entity_store.useDeleteEntityEngineMutation)({
    onSuccess: () => {
      closeClearModal();
    }
  });
  const [isClearModalVisible, setIsClearModalVisible] = (0, _react.useState)(false);
  const closeClearModal = (0, _react.useCallback)(() => setIsClearModalVisible(false), []);
  const showClearModal = (0, _react.useCallback)(() => setIsClearModalVisible(true), []);
  const onSwitchClick = (0, _react.useCallback)(() => {
    if (switchDisabledStatuses.includes(entityStoreStatus.status)) {
      return;
    }
    if (entityStoreEnabledStatuses.includes(entityStoreStatus.status)) {
      stopEntityEngineMutation.mutate();
    } else {
      setPolling(true);
      initEntityEngineMutation.mutate();
    }
  }, [initEntityEngineMutation, stopEntityEngineMutation, entityStoreStatus]);
  const {
    data: privileges
  } = (0, _use_entity_engine_privileges.useEntityEnginePrivileges)();
  if (assetCriticalityIsLoading) {
    // Wait for permission before rendering content to avoid flickering
    return null;
  }
  const AssetCriticalityIssueCallout = () => {
    var _assetCriticalityPriv;
    const errorMessage = (_assetCriticalityPriv = assetCriticalityPrivilegesError === null || assetCriticalityPrivilegesError === void 0 ? void 0 : assetCriticalityPrivilegesError.body.message) !== null && _assetCriticalityPriv !== void 0 ? _assetCriticalityPriv : /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.advancedSettingDisabledMessage",
      defaultMessage: "The don't have privileges to access Asset Criticality feature. Contact your administrator for further assistance."
    });
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.unavailable",
        defaultMessage: "Asset criticality CSV file upload functionality unavailable."
      }),
      color: "primary",
      iconType: "iInCircle"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, errorMessage)));
  };
  const ClearEntityDataPanel = () => {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
      paddingSize: "l",
      grow: false,
      color: "subdued",
      borderRadius: "none",
      hasShadow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, /*#__PURE__*/_react.default.createElement("h3", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clearEntityData",
      defaultMessage: "Clear entity data"
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "s"
    }), /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clearEntityData",
      defaultMessage: `Remove all extracted entity data from the store. This action will
            permanently delete persisted user and host records, and data will no longer be available for analysis.
            Proceed with caution, as this cannot be undone. Note that this operation will not delete source data,
            Entity risk scores, or Asset Criticality assignments.`
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      color: "danger",
      iconType: "trash",
      onClick: () => {
        showClearModal();
      }
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clear",
      defaultMessage: "Clear"
    }))), isClearModalVisible && /*#__PURE__*/_react.default.createElement(_eui.EuiConfirmModal, {
      isLoading: deleteEntityEngineMutation.isLoading,
      title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clearEntitiesModal.title",
        defaultMessage: "Clear Entity data?"
      }),
      onCancel: closeClearModal,
      onConfirm: () => {
        deleteEntityEngineMutation.mutate();
      },
      cancelButtonText: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clearEntitiesModal.close",
        defaultMessage: "Close"
      }),
      confirmButtonText: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clearEntitiesModal.clearAllEntities",
        defaultMessage: "Clear All Entities"
      }),
      buttonColor: "danger",
      defaultFocusedButton: "confirm"
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.clearConfirmation",
      defaultMessage: 'This will delete all Security Entity store records. Source data, Entity risk scores, and Asset criticality assignments are unaffected by this action. This operation cannot be undone.'
    })));
  };
  const FileUploadSection = () => {
    if (!hasEntityAnalyticsCapability || (assetCriticalityPrivilegesError === null || assetCriticalityPrivilegesError === void 0 ? void 0 : assetCriticalityPrivilegesError.body.status_code) === 403) {
      return /*#__PURE__*/_react.default.createElement(AssetCriticalityIssueCallout, null);
    }
    if (!hasAssetCriticalityWritePermissions) {
      return /*#__PURE__*/_react.default.createElement(InsufficientAssetCriticalityPrivilegesCallout, null);
    }
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: 3
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
      size: "s"
    }, /*#__PURE__*/_react.default.createElement("h2", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.subTitle",
      defaultMessage: "Import entities using a text file"
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.description",
      defaultMessage: "Bulk assign asset criticality by importing a CSV, TXT, or TSV file exported from your asset management tools. This ensures data accuracy and reduces manual input errors."
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "s"
    }), /*#__PURE__*/_react.default.createElement(_asset_criticality_file_uploader.AssetCriticalityFileUploader, null));
  };
  const canDeleteEntityEngine = !['not_installed', 'loading', 'installing'].includes(entityStoreStatus.status);
  const isMutationLoading = initEntityEngineMutation.isLoading || stopEntityEngineMutation.isLoading || deleteEntityEngineMutation.isLoading;
  const callouts = entityStoreStatus.errors.map(error => /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.errors.title",
      defaultMessage: 'An error occurred during entity store resource initialization'
    }),
    color: "danger",
    iconType: "alert"
  }, /*#__PURE__*/_react.default.createElement("p", null, error.message)));
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiPageHeader, {
    "data-test-subj": "entityStoreManagementPage",
    pageTitle: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.title",
      defaultMessage: "Entity Store"
    }), ' ', /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
      content: _translations.TECHNICAL_PREVIEW_TOOLTIP
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiBetaBadge, {
      label: _translations.TECHNICAL_PREVIEW
    }))),
    alignItems: "center",
    rightSideItems: !isEntityStoreFeatureFlagDisabled && privileges !== null && privileges !== void 0 && privileges.has_all_required ? [/*#__PURE__*/_react.default.createElement(EnablementButton, {
      isLoading: isMutationLoading || entityStoreInstallingStatuses.includes(entityStoreStatus.status),
      isDisabled: isMutationLoading || switchDisabledStatuses.includes(entityStoreStatus.status),
      onSwitch: onSwitchClick,
      status: entityStoreStatus.status
    })] : []
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.subTitle",
    defaultMessage: "Store host and user entities observed in events."
  })), isEntityStoreFeatureFlagDisabled && /*#__PURE__*/_react.default.createElement(EntityStoreFeatureFlagNotAvailableCallout, null), !privileges || privileges.has_all_required ? null : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_missing_privileges_callout.MissingPrivilegesCallout, {
    privileges: privileges
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, null), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    gutterSize: "xl"
  }, /*#__PURE__*/_react.default.createElement(FileUploadSection, null), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 2
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column"
  }, initEntityEngineMutation.isError && /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.errors.initErrorTitle",
      defaultMessage: 'There was a problem initializing the entity store'
    }),
    color: "danger",
    iconType: "alert"
  }, /*#__PURE__*/_react.default.createElement("p", null, initEntityEngineMutation.error.body.message)), deleteEntityEngineMutation.isError && /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.errors.deleteErrorTitle",
      defaultMessage: 'There was a problem deleting the entity store'
    }),
    color: "danger",
    iconType: "alert"
  }, /*#__PURE__*/_react.default.createElement("p", null, deleteEntityEngineMutation.error.body.message)), callouts, /*#__PURE__*/_react.default.createElement(WhatIsAssetCriticalityPanel, null), !isEntityStoreFeatureFlagDisabled && (privileges === null || privileges === void 0 ? void 0 : privileges.has_all_required) && canDeleteEntityEngine && /*#__PURE__*/_react.default.createElement(ClearEntityDataPanel, null)))));
};
exports.EntityStoreManagementPage = EntityStoreManagementPage;
EntityStoreManagementPage.displayName = 'EntityStoreManagementPage';
const WhatIsAssetCriticalityPanel = () => {
  const {
    docLinks
  } = (0, _kibana.useKibana)().services;
  const entityAnalyticsLinks = docLinks.links.securitySolution.entityAnalytics;
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasBorder: true,
    paddingSize: "l",
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.information.intro",
    defaultMessage: "As part of importing entities using a text file, you are also able to set Asset Criticality for the imported Entities."
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center",
    gutterSize: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: "questionInCircle",
    size: "xl"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xxs"
  }, /*#__PURE__*/_react.default.createElement("h3", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.information.title",
    defaultMessage: "What is asset criticality?"
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.information.description",
    defaultMessage: "Asset criticality allows you to classify entities based on their importance and impact on business operations. Use asset criticality to guide prioritization for alert triaging, threat-hunting, and investigation activities."
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, null), /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xxs"
  }, /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.information.usefulLinks",
    defaultMessage: "Useful links"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
    target: "_blank",
    rel: "noopener nofollow noreferrer",
    href: entityAnalyticsLinks.assetCriticality
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.documentationLink",
    defaultMessage: "Asset criticality documentation"
  })));
};
const EntityStoreFeatureFlagNotAvailableCallout = () => {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.entityStoreManagementPage.featureFlagDisabled",
      defaultMessage: "Entity Store capabilities not available"
    }),
    color: "primary",
    iconType: "iInCircle"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.entityStoreManagementPage.featureFlagDisabledDescription",
    defaultMessage: "The full capabilities of the Entity Store have been disabled in this environment. Contact your administrator for further assistance."
  }))));
};
const EntityStoreHealth = ({
  currentEntityStoreStatus
}) => {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiHealth, {
    textSize: "m",
    color: entityStoreEnabledStatuses.includes(currentEntityStoreStatus) ? 'success' : 'subdued'
  }, entityStoreEnabledStatuses.includes(currentEntityStoreStatus) ? 'On' : 'Off');
};
const EnablementButton = ({
  isLoading,
  isDisabled,
  status,
  onSwitch
}) => {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center"
  }, isLoading && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingSpinner, {
    "data-test-subj": "entity-store-status-loading",
    size: "m"
  })), /*#__PURE__*/_react.default.createElement(EntityStoreHealth, {
    currentEntityStoreStatus: status
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    showLabel: false,
    label: "",
    onChange: onSwitch,
    "data-test-subj": "entity-store-switch",
    checked: entityStoreEnabledStatuses.includes(status),
    disabled: isDisabled
  }));
};
const InsufficientAssetCriticalityPrivilegesCallout = () => {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.noPermissionTitle",
      defaultMessage: "Insufficient index privileges to perform CSV upload"
    }),
    color: "primary",
    iconType: "iInCircle"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.entityAnalytics.assetCriticalityUploadPage.missingPermissionsCallout.description",
    defaultMessage: "Write permission is required for the {index} index pattern in order to access this functionality. Contact your administrator for further assistance.",
    values: {
      index: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, _asset_criticality.ASSET_CRITICALITY_INDEX_PATTERN)
    }
  })));
};