"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SessionView = exports.SESSION_VIEW_ID = void 0;
var _react = _interopRequireWildcard(require("react"));
var _expandableFlyout = require("@kbn/expandable-flyout");
var _eui = require("@elastic/eui");
var _field_names = require("../../shared/constants/field_names");
var _utils = require("../../shared/utils");
var _test_ids = require("./test_ids");
var _helpers = require("../../../../helpers");
var _containers = require("../../../../sourcerer/containers");
var _panel_keys = require("../../shared/constants/panel_keys");
var _kibana = require("../../../../common/lib/kibana");
var _context = require("../../shared/context");
var _model = require("../../../../sourcerer/store/model");
var _helpers2 = require("../../../../timelines/containers/helpers");
var _constants = require("../../preview/constants");
var _use_license = require("../../../../common/hooks/use_license");
var _use_session_preview = require("../../right/hooks/use_session_preview");
var _session_view_no_data_message = require("../../shared/components/session_view_no_data_message");
var _telemetry = require("../../../../common/lib/telemetry");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SESSION_VIEW_ID = exports.SESSION_VIEW_ID = 'session-view';

/**
 * Session view displayed in the document details expandable flyout left section under the Visualize tab
 */
const SessionView = () => {
  const {
    sessionView,
    telemetry
  } = (0, _kibana.useKibana)().services;
  const {
    getFieldsData,
    indexName,
    scopeId,
    dataFormattedForFieldBrowser
  } = (0, _context.useDocumentDetailsContext)();
  const sessionViewConfig = (0, _use_session_preview.useSessionPreview)({
    getFieldsData,
    dataFormattedForFieldBrowser
  });
  const isEnterprisePlus = (0, _use_license.useLicense)().isEnterprise();
  const isEnabled = sessionViewConfig && isEnterprisePlus;
  const ancestorIndex = (0, _utils.getField)(getFieldsData(_field_names.ANCESTOR_INDEX)); // e.g in case of alert, we want to grab it's origin index
  const sessionEntityId = (0, _utils.getField)(getFieldsData(_field_names.ENTRY_LEADER_ENTITY_ID)) || '';
  const sessionStartTime = (0, _utils.getField)(getFieldsData(_field_names.ENTRY_LEADER_START)) || '';
  const index = ancestorIndex || indexName;
  const sourcererScope = (0, _react.useMemo)(() => {
    if ((0, _helpers.isActiveTimeline)(scopeId)) {
      return _model.SourcererScopeName.timeline;
    } else if (_helpers2.detectionsTimelineIds.includes(scopeId)) {
      return _model.SourcererScopeName.detections;
    } else {
      return _model.SourcererScopeName.default;
    }
  }, [scopeId]);
  const {
    selectedPatterns
  } = (0, _containers.useSourcererDataView)(sourcererScope);
  const eventDetailsIndex = (0, _react.useMemo)(() => selectedPatterns.join(','), [selectedPatterns]);
  const {
    openPreviewPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const openAlertDetailsPreview = (0, _react.useCallback)((eventId, onClose) => {
    openPreviewPanel({
      id: _panel_keys.DocumentDetailsPreviewPanelKey,
      params: {
        id: eventId,
        indexName: eventDetailsIndex,
        scopeId,
        banner: _constants.ALERT_PREVIEW_BANNER,
        isPreviewMode: true
      }
    });
    telemetry.reportEvent(_telemetry.DocumentEventTypes.DetailsFlyoutOpened, {
      location: scopeId,
      panel: 'preview'
    });
  }, [openPreviewPanel, eventDetailsIndex, scopeId, telemetry]);
  return isEnabled ? /*#__PURE__*/_react.default.createElement("div", {
    "data-test-subj": _test_ids.SESSION_VIEW_TEST_ID
  }, sessionView.getSessionView({
    index,
    sessionEntityId,
    sessionStartTime,
    isFullScreen: true,
    loadAlertDetails: openAlertDetailsPreview
  })) : /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasShadow: false
  }, /*#__PURE__*/_react.default.createElement(_session_view_no_data_message.SessionViewNoDataMessage, {
    isEnterprisePlus: isEnterprisePlus,
    hasSessionViewConfig: sessionViewConfig !== null
  }));
};
exports.SessionView = SessionView;
SessionView.displayName = 'SessionView';