"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GraphPreviewContainer = void 0;
var _react = _interopRequireDefault(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _context = require("../../shared/context");
var _test_ids = require("./test_ids");
var _graph_preview = require("./graph_preview");
var _use_fetch_graph_data = require("../hooks/use_fetch_graph_data");
var _use_graph_preview = require("../hooks/use_graph_preview");
var _expandable_panel = require("../../../shared/components/expandable_panel");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Graph preview under Overview, Visualizations. It shows a graph representation of entities.
 */
const GraphPreviewContainer = () => {
  const {
    dataAsNestedObject,
    getFieldsData
  } = (0, _context.useDocumentDetailsContext)();
  const {
    eventIds,
    timestamp = new Date().toISOString(),
    isAuditLog
  } = (0, _use_graph_preview.useGraphPreview)({
    getFieldsData,
    ecsData: dataAsNestedObject
  });

  // TODO: default start and end might not capture the original event
  const {
    isLoading,
    isError,
    data
  } = (0, _use_fetch_graph_data.useFetchGraphData)({
    req: {
      query: {
        eventIds,
        start: `${timestamp}||-30m`,
        end: `${timestamp}||+30m`
      }
    },
    options: {
      enabled: isAuditLog,
      refetchOnWindowFocus: false
    }
  });
  return isAuditLog && /*#__PURE__*/_react.default.createElement(_expandable_panel.ExpandablePanel, {
    header: {
      title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.securitySolution.flyout.right.visualizations.graphPreview.graphPreviewTitle",
        defaultMessage: "Graph preview"
      }),
      iconType: 'indexMapping'
    },
    "data-test-subj": _test_ids.GRAPH_PREVIEW_TEST_ID,
    content: !isLoading && !isError ? {
      paddingSize: 'none'
    } : undefined
  }, /*#__PURE__*/_react.default.createElement(_graph_preview.GraphPreview, {
    isLoading: isLoading,
    isError: isError,
    data: data
  }));
};
exports.GraphPreviewContainer = GraphPreviewContainer;
GraphPreviewContainer.displayName = 'GraphPreviewContainer';