"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.HeaderActions = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _elasticAssistant = require("@kbn/elastic-assistant");
var _use_get_flyout_link = require("../hooks/use_get_flyout_link");
var _use_basic_data_from_details_data = require("../../shared/hooks/use_basic_data_from_details_data");
var _use_assistant = require("../hooks/use_assistant");
var _translations = require("../../../../common/components/event_details/translations");
var _context = require("../../shared/context");
var _test_ids = require("./test_ids");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Actions displayed in the header menu in the right section of alerts flyout
 */
const HeaderActions = exports.HeaderActions = /*#__PURE__*/(0, _react.memo)(() => {
  const {
    dataFormattedForFieldBrowser,
    eventId,
    indexName
  } = (0, _context.useDocumentDetailsContext)();
  const {
    isAlert,
    timestamp
  } = (0, _use_basic_data_from_details_data.useBasicDataFromDetailsData)(dataFormattedForFieldBrowser);
  const alertDetailsLink = (0, _use_get_flyout_link.useGetFlyoutLink)({
    eventId,
    indexName,
    timestamp
  });
  const showShareAlertButton = isAlert && alertDetailsLink;
  const {
    showAssistant,
    promptContextId
  } = (0, _use_assistant.useAssistant)({
    dataFormattedForFieldBrowser,
    isAlert
  });
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "row",
    justifyContent: "flexEnd",
    alignItems: "center",
    gutterSize: "none",
    responsive: false
  }, showAssistant && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_elasticAssistant.NewChatByTitle, {
    conversationTitle: isAlert ? _translations.ALERT_SUMMARY_CONVERSATION_ID : _translations.EVENT_SUMMARY_CONVERSATION_ID,
    promptContextId: promptContextId,
    iconOnly: true
  })), showShareAlertButton && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiToolTip, {
    content: _i18n.i18n.translate('xpack.securitySolution.flyout.right.header.shareButtonToolTip', {
      defaultMessage: 'Share alert'
    })
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiCopy, {
    textToCopy: alertDetailsLink
  }, copy => /*#__PURE__*/_react.default.createElement(_eui.EuiButtonIcon, {
    iconType: 'share',
    color: 'text',
    "aria-label": _i18n.i18n.translate('xpack.securitySolution.flyout.right.header.shareButtonAriaLabel', {
      defaultMessage: 'Share alert'
    }),
    "data-test-subj": _test_ids.SHARE_BUTTON_TEST_ID,
    onClick: copy,
    onKeyDown: copy
  })))));
});
HeaderActions.displayName = 'HeaderActions';