"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.HighlightedFieldsCell = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _expandableFlyout = require("@kbn/expandable-flyout");
var _get_agent_type_for_agent_id_field = require("../../../../common/lib/endpoint/utils/get_agent_type_for_agent_id_field");
var _agent_status = require("../../../../common/components/endpoint/agents/agent_status");
var _context = require("../../shared/context");
var _constants = require("../../../../timelines/components/timeline/body/renderers/constants");
var _use_experimental_features = require("../../../../common/hooks/use_experimental_features");
var _panel_keys = require("../../shared/constants/panel_keys");
var _left = require("../../left");
var _entities_details = require("../../left/components/entities_details");
var _test_ids = require("./test_ids");
var _preview_link = require("../../../shared/components/preview_link");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Renders a component in the highlighted fields table cell based on the field name
 */
const HighlightedFieldsCell = ({
  values,
  field,
  originalField = ''
}) => {
  const {
    scopeId,
    eventId,
    indexName
  } = (0, _context.useDocumentDetailsContext)();
  const {
    openLeftPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const isPreviewEnabled = !(0, _use_experimental_features.useIsExperimentalFeatureEnabled)('entityAlertPreviewDisabled');
  const goToInsightsEntities = (0, _react.useCallback)(() => {
    openLeftPanel({
      id: _panel_keys.DocumentDetailsLeftPanelKey,
      path: {
        tab: _left.LeftPanelInsightsTab,
        subTab: _entities_details.ENTITIES_TAB_ID
      },
      params: {
        id: eventId,
        indexName,
        scopeId
      }
    });
  }, [eventId, indexName, openLeftPanel, scopeId]);
  const agentType = (0, _react.useMemo)(() => {
    return (0, _get_agent_type_for_agent_id_field.getAgentTypeForAgentIdField)(originalField);
  }, [originalField]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, values != null && values.map((value, i) => {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false,
      key: `${i}-${value}`,
      "data-test-subj": `${value}-${_test_ids.HIGHLIGHTED_FIELDS_CELL_TEST_ID}`
    }, isPreviewEnabled && (0, _preview_link.hasPreview)(field) ? /*#__PURE__*/_react.default.createElement(_preview_link.PreviewLink, {
      field: field,
      value: value,
      scopeId: scopeId,
      "data-test-subj": _test_ids.HIGHLIGHTED_FIELDS_LINKED_CELL_TEST_ID
    }) : (0, _preview_link.hasPreview)(field) ? /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
      onClick: goToInsightsEntities,
      "data-test-subj": _test_ids.HIGHLIGHTED_FIELDS_LINKED_CELL_TEST_ID
    }, value) : field === _constants.AGENT_STATUS_FIELD_NAME ? /*#__PURE__*/_react.default.createElement(_agent_status.AgentStatus, {
      agentId: String(value !== null && value !== void 0 ? value : ''),
      agentType: agentType,
      "data-test-subj": _test_ids.HIGHLIGHTED_FIELDS_AGENT_STATUS_CELL_TEST_ID
    }) : /*#__PURE__*/_react.default.createElement("span", {
      "data-test-subj": _test_ids.HIGHLIGHTED_FIELDS_BASIC_CELL_TEST_ID
    }, value));
  }));
};
exports.HighlightedFieldsCell = HighlightedFieldsCell;