"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RelatedAlertsByAncestry = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _correlations_details = require("../../left/components/correlations_details");
var _use_fetch_related_alerts_by_ancestry = require("../../shared/hooks/use_fetch_related_alerts_by_ancestry");
var _insights_summary_row = require("./insights_summary_row");
var _test_ids = require("./test_ids");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Show related alerts by ancestry in summary row
 */
const RelatedAlertsByAncestry = ({
  documentId,
  indices,
  scopeId
}) => {
  const {
    loading,
    error,
    dataCount
  } = (0, _use_fetch_related_alerts_by_ancestry.useFetchRelatedAlertsByAncestry)({
    documentId,
    indices,
    scopeId
  });
  const text = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.securitySolution.flyout.right.insights.correlations.ancestryAlertsLabel",
    defaultMessage: "{count, plural, one {Alert} other {Alerts}} related by ancestry",
    values: {
      count: dataCount
    }
  }), [dataCount]);
  return /*#__PURE__*/_react.default.createElement(_insights_summary_row.InsightsSummaryRow, {
    loading: loading,
    error: error,
    text: text,
    value: dataCount,
    expandedSubTab: _correlations_details.CORRELATIONS_TAB_ID,
    "data-test-subj": _test_ids.CORRELATIONS_RELATED_ALERTS_BY_ANCESTRY_TEST_ID,
    key: `correlation-row-${text}`
  });
};
exports.RelatedAlertsByAncestry = RelatedAlertsByAncestry;
RelatedAlertsByAncestry.displayName = 'RelatedAlertsByAncestry';