"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PanelFooter = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireWildcard(require("react"));
var _expandableFlyout = require("@kbn/expandable-flyout");
var _eui = require("@elastic/eui");
var _fp = require("lodash/fp");
var _test_ids = require("./test_ids");
var _get_event_details_field_values = require("../../../common/lib/endpoint/utils/get_event_details_field_values");
var _take_action_dropdown = require("./components/take_action_dropdown");
var _alert_context_menu = require("../../../detections/components/alerts_table/timeline_actions/alert_context_menu");
var _event_filters_flyout = require("../../../management/pages/event_filters/view/components/event_filters_flyout");
var _osquery_flyout = require("../../../detections/components/osquery/osquery_flyout");
var _context = require("../shared/context");
var _use_host_isolation = require("../shared/hooks/use_host_isolation");
var _panel_keys = require("../shared/constants/panel_keys");
var _use_refetch_by_scope = require("./hooks/use_refetch_by_scope");
var _use_add_exception_flyout = require("../../../detections/components/alerts_table/timeline_actions/use_add_exception_flyout");
var _helpers = require("../../../helpers");
var _use_event_filter_modal = require("../../../detections/components/alerts_table/timeline_actions/use_event_filter_modal");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Bottom section of the flyout that contains the take action button
 */
const PanelFooter = ({
  isPreview
}) => {
  var _dataAsNestedObject$k2;
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  // we need this flyout to be above the timeline flyout (which has a z-index of 1002)
  const flyoutZIndex = (0, _react.useMemo)(() => ({
    style: `z-index: ${euiTheme.levels.flyout + 3}`
  }), [euiTheme]);
  const {
    closeFlyout,
    openRightPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const {
    eventId,
    indexName,
    dataFormattedForFieldBrowser,
    dataAsNestedObject,
    refetchFlyoutData,
    scopeId
  } = (0, _context.useDocumentDetailsContext)();

  // host isolation interaction
  const {
    isHostIsolationPanelOpen,
    showHostIsolationPanel
  } = (0, _use_host_isolation.useHostIsolation)();
  const showHostIsolationPanelCallback = (0, _react.useCallback)(action => {
    showHostIsolationPanel(action);
    openRightPanel({
      id: _panel_keys.DocumentDetailsIsolateHostPanelKey,
      params: {
        id: eventId,
        indexName,
        scopeId,
        isolateAction: action
      }
    });
  }, [eventId, indexName, openRightPanel, scopeId, showHostIsolationPanel]);
  const {
    refetch: refetchAll
  } = (0, _use_refetch_by_scope.useRefetchByScope)({
    scopeId
  });

  // exception interaction
  const ruleIndexRaw = (0, _react.useMemo)(() => {
    var _find$values, _find, _find2;
    return (_find$values = (_find = (0, _fp.find)({
      category: 'signal',
      field: 'signal.rule.index'
    }, dataFormattedForFieldBrowser)) === null || _find === void 0 ? void 0 : _find.values) !== null && _find$values !== void 0 ? _find$values : (_find2 = (0, _fp.find)({
      category: 'kibana',
      field: 'kibana.alert.rule.parameters.index'
    }, dataFormattedForFieldBrowser)) === null || _find2 === void 0 ? void 0 : _find2.values;
  }, [dataFormattedForFieldBrowser]);
  const ruleIndex = (0, _react.useMemo)(() => Array.isArray(ruleIndexRaw) ? ruleIndexRaw : undefined, [ruleIndexRaw]);
  const ruleDataViewIdRaw = (0, _react.useMemo)(() => {
    var _find$values2, _find3, _find4;
    return (_find$values2 = (_find3 = (0, _fp.find)({
      category: 'signal',
      field: 'signal.rule.data_view_id'
    }, dataFormattedForFieldBrowser)) === null || _find3 === void 0 ? void 0 : _find3.values) !== null && _find$values2 !== void 0 ? _find$values2 : (_find4 = (0, _fp.find)({
      category: 'kibana',
      field: 'kibana.alert.rule.parameters.data_view_id'
    }, dataFormattedForFieldBrowser)) === null || _find4 === void 0 ? void 0 : _find4.values;
  }, [dataFormattedForFieldBrowser]);
  const ruleDataViewId = (0, _react.useMemo)(() => Array.isArray(ruleDataViewIdRaw) ? ruleDataViewIdRaw[0] : undefined, [ruleDataViewIdRaw]);
  const alertSummaryData = (0, _react.useMemo)(() => [{
    category: 'signal',
    field: 'signal.rule.id',
    name: 'ruleId'
  }, {
    category: 'signal',
    field: 'signal.rule.rule_id',
    name: 'ruleRuleId'
  }, {
    category: 'signal',
    field: 'signal.rule.name',
    name: 'ruleName'
  }, {
    category: 'signal',
    field: 'kibana.alert.workflow_status',
    name: 'alertStatus'
  }, {
    category: '_id',
    field: '_id',
    name: 'eventId'
  }].reduce((acc, curr) => ({
    ...acc,
    [curr.name]: (0, _get_event_details_field_values.getAlertDetailsFieldValue)({
      category: curr.category,
      field: curr.field
    }, dataFormattedForFieldBrowser)
  }), {}), [dataFormattedForFieldBrowser]);
  const {
    exceptionFlyoutType,
    openAddExceptionFlyout,
    onAddExceptionTypeClick,
    onAddExceptionCancel,
    onAddExceptionConfirm
  } = (0, _use_add_exception_flyout.useExceptionFlyout)({
    refetch: refetchAll,
    isActiveTimelines: (0, _helpers.isActiveTimeline)(scopeId)
  });

  // event filter interaction
  const {
    closeAddEventFilterModal,
    isAddEventFilterModalOpen,
    onAddEventFilterClick
  } = (0, _use_event_filter_modal.useEventFilterModal)();

  // osquery interaction
  const [isOsqueryFlyoutOpenWithAgentId, setOsqueryFlyoutOpenWithAgentId] = (0, _react.useState)(null);
  const closeOsqueryFlyout = (0, _react.useCallback)(() => {
    setOsqueryFlyoutOpenWithAgentId(null);
  }, [setOsqueryFlyoutOpenWithAgentId]);
  const alertId = (0, _react.useMemo)(() => {
    var _dataAsNestedObject$k;
    return dataAsNestedObject !== null && dataAsNestedObject !== void 0 && (_dataAsNestedObject$k = dataAsNestedObject.kibana) !== null && _dataAsNestedObject$k !== void 0 && _dataAsNestedObject$k.alert ? dataAsNestedObject === null || dataAsNestedObject === void 0 ? void 0 : dataAsNestedObject._id : null;
  }, [dataAsNestedObject === null || dataAsNestedObject === void 0 ? void 0 : dataAsNestedObject._id, dataAsNestedObject === null || dataAsNestedObject === void 0 ? void 0 : (_dataAsNestedObject$k2 = dataAsNestedObject.kibana) === null || _dataAsNestedObject$k2 === void 0 ? void 0 : _dataAsNestedObject$k2.alert]);
  if (isPreview) return null;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutFooter, {
    "data-test-subj": _test_ids.FLYOUT_FOOTER_TEST_ID
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    color: "transparent"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "flexEnd"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, dataAsNestedObject && /*#__PURE__*/_react.default.createElement(_take_action_dropdown.TakeActionDropdown, {
    dataFormattedForFieldBrowser: dataFormattedForFieldBrowser,
    dataAsNestedObject: dataAsNestedObject,
    handleOnEventClosed: closeFlyout,
    isHostIsolationPanelOpen: isHostIsolationPanelOpen,
    onAddEventFilterClick: onAddEventFilterClick,
    onAddExceptionTypeClick: onAddExceptionTypeClick,
    onAddIsolationStatusClick: showHostIsolationPanelCallback,
    refetchFlyoutData: refetchFlyoutData,
    refetch: refetchAll,
    scopeId: scopeId,
    onOsqueryClick: setOsqueryFlyoutOpenWithAgentId
  }))))), openAddExceptionFlyout && alertSummaryData.ruleId != null && alertSummaryData.ruleRuleId != null && alertSummaryData.eventId != null && /*#__PURE__*/_react.default.createElement(_alert_context_menu.AddExceptionFlyoutWrapper, (0, _extends2.default)({}, alertSummaryData, {
    ruleIndices: ruleIndex,
    ruleDataViewId: ruleDataViewId,
    exceptionListType: exceptionFlyoutType,
    onCancel: onAddExceptionCancel,
    onConfirm: onAddExceptionConfirm
  })), isAddEventFilterModalOpen && dataAsNestedObject != null && /*#__PURE__*/_react.default.createElement(_event_filters_flyout.EventFiltersFlyout, {
    data: dataAsNestedObject,
    onCancel: closeAddEventFilterModal
    // EUI TODO: This z-index override of EuiOverlayMask is a workaround, and ideally should be resolved with a cleaner UI/UX flow long-term
    ,
    maskProps: flyoutZIndex // we need this flyout to be above the timeline flyout (which has a z-index of 1002)
  }), isOsqueryFlyoutOpenWithAgentId && dataAsNestedObject != null && /*#__PURE__*/_react.default.createElement(_osquery_flyout.OsqueryFlyout, {
    agentId: isOsqueryFlyoutOpenWithAgentId,
    defaultValues: alertId ? {
      alertIds: [alertId]
    } : undefined,
    onClose: closeOsqueryFlyout,
    ecsData: dataAsNestedObject
  }));
};
exports.PanelFooter = PanelFooter;
PanelFooter.displayName = 'PanelFooter';