"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFetchGraphData = void 0;
var _reactQuery = require("@tanstack/react-query");
var _react = require("react");
var _constants = require("../../../../../common/constants");
var _kibana = require("../../../../common/lib/kibana");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Interface for the input parameters of the useFetchGraphData hook.
 */

/**
 * Interface for the result of the useFetchGraphData hook.
 */

/**
 * Hook to fetch event's graph visualization data.
 *
 * @param params - The input parameters for the hook.
 * @returns The result of the hook.
 */
const useFetchGraphData = ({
  req,
  options
}) => {
  var _options$enabled, _options$refetchOnWin;
  const {
    eventIds,
    start,
    end,
    esQuery
  } = req.query;
  const http = (0, _kibana.useHttp)();
  const QUERY_KEY = (0, _react.useMemo)(() => ['useFetchGraphData', eventIds, start, end, esQuery], [end, esQuery, eventIds, start]);
  const {
    isLoading,
    isError,
    data
  } = (0, _reactQuery.useQuery)(QUERY_KEY, () => {
    return http.post(_constants.EVENT_GRAPH_VISUALIZATION_API, {
      version: '1',
      body: JSON.stringify(req)
    });
  }, {
    enabled: (_options$enabled = options === null || options === void 0 ? void 0 : options.enabled) !== null && _options$enabled !== void 0 ? _options$enabled : true,
    refetchOnWindowFocus: (_options$refetchOnWin = options === null || options === void 0 ? void 0 : options.refetchOnWindowFocus) !== null && _options$refetchOnWin !== void 0 ? _options$refetchOnWin : true
  });
  return {
    isLoading,
    isError,
    data
  };
};
exports.useFetchGraphData = useFetchGraphData;