"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFieldFromBrowserField = exports.getColumns = exports.TableTab = exports.FIELD = void 0;
var _react = _interopRequireWildcard(require("react"));
var _fp = require("lodash/fp");
var _memoizeOne = _interopRequireDefault(require("memoize-one"));
var _react2 = require("@emotion/react");
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _securitysolutionDataTable = require("@kbn/securitysolution-data-table");
var _public = require("@kbn/triggers-actions-ui-plugin/public");
var _table_field_name_cell = require("../components/table_field_name_cell");
var _table_field_value_cell = require("../components/table_field_value_cell");
var _test_ids = require("./test_ids");
var _source = require("../../../../common/containers/source");
var _use_selector = require("../../../../common/hooks/use_selector");
var _defaults = require("../../../../timelines/store/defaults");
var _store = require("../../../../timelines/store");
var _cell_actions = require("../../shared/components/cell_actions");
var _context = require("../../shared/context");
var _helpers = require("../../../../helpers");
var _use_basic_data_from_details_data = require("../../shared/hooks/use_basic_data_from_details_data");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const COUNT_PER_PAGE_OPTIONS = [25, 50, 100];
const PLACEHOLDER = _i18n.i18n.translate('xpack.securitySolution.flyout.table.filterPlaceholderLabel', {
  defaultMessage: 'Filter by field or value...'
});
const FIELD = exports.FIELD = _i18n.i18n.translate('xpack.securitySolution.flyout.table.fieldCellLabel', {
  defaultMessage: 'Field'
});
const VALUE = _i18n.i18n.translate('xpack.securitySolution.flyout.table.valueCellLabel', {
  defaultMessage: 'Value'
});

/**
 * Defines the behavior of the search input that appears above the table of data
 */
const search = {
  box: {
    incremental: true,
    placeholder: PLACEHOLDER,
    schema: true,
    'data-test-subj': _test_ids.TABLE_TAB_SEARCH_INPUT_TEST_ID
  }
};

/**
 * Retrieve the correct field from the BrowserField
 */
const getFieldFromBrowserField = exports.getFieldFromBrowserField = (0, _memoizeOne.default)((field, browserFields) => {
  var _browserFields$catego, _browserFields$catego2;
  const category = (0, _public.getCategory)(field);
  return (_browserFields$catego = browserFields[category]) === null || _browserFields$catego === void 0 ? void 0 : (_browserFields$catego2 = _browserFields$catego.fields) === null || _browserFields$catego2 === void 0 ? void 0 : _browserFields$catego2[field];
}, (newArgs, lastArgs) => newArgs[0] === lastArgs[0]);
const getColumns = ({
  browserFields,
  eventId,
  scopeId,
  getLinkValue,
  ruleId,
  isPreview
}) => [{
  field: 'field',
  name: /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("strong", null, FIELD)),
  width: '30%',
  render: (field, data) => {
    return /*#__PURE__*/_react.default.createElement(_table_field_name_cell.TableFieldNameCell, {
      dataType: data.type,
      field: field
    });
  }
}, {
  field: 'values',
  name: /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("strong", null, VALUE)),
  width: '70%',
  render: (values, data) => {
    const fieldFromBrowserField = getFieldFromBrowserField(data.field, browserFields);
    return /*#__PURE__*/_react.default.createElement(_cell_actions.CellActions, {
      field: data.field,
      value: values,
      isObjectArray: data.isObjectArray
    }, /*#__PURE__*/_react.default.createElement(_table_field_value_cell.TableFieldValueCell, {
      scopeId: scopeId,
      data: data,
      eventId: eventId,
      fieldFromBrowserField: fieldFromBrowserField,
      getLinkValue: getLinkValue,
      ruleId: ruleId,
      isPreview: isPreview,
      values: values
    }));
  }
}];

/**
 * Table view displayed in the document details expandable flyout right section Table tab
 */
exports.getColumns = getColumns;
const TableTab = exports.TableTab = /*#__PURE__*/(0, _react.memo)(() => {
  const smallFontSize = (0, _eui.useEuiFontSize)('xs').fontSize;
  const {
    browserFields,
    dataFormattedForFieldBrowser,
    eventId,
    scopeId,
    isPreview
  } = (0, _context.useDocumentDetailsContext)();
  const {
    ruleId
  } = (0, _use_basic_data_from_details_data.useBasicDataFromDetailsData)(dataFormattedForFieldBrowser);
  const [pagination, setPagination] = (0, _react.useState)({
    pageIndex: 0
  });
  const onTableChange = (0, _react.useCallback)(({
    page: {
      index
    }
  }) => {
    setPagination({
      pageIndex: index
    });
  }, []);
  const getScope = (0, _react.useMemo)(() => {
    if ((0, _helpers.isTimelineScope)(scopeId)) {
      return _store.timelineSelectors.getTimelineByIdSelector();
    } else if ((0, _helpers.isInTableScope)(scopeId)) {
      return _securitysolutionDataTable.dataTableSelectors.getTableByIdSelector();
    }
  }, [scopeId]);
  const defaults = (0, _react.useMemo)(() => (0, _helpers.isTimelineScope)(scopeId) ? _defaults.timelineDefaults : _securitysolutionDataTable.tableDefaults, [scopeId]);
  const columnHeaders = (0, _use_selector.useDeepEqualSelector)(state => {
    var _ref;
    const {
      columns
    } = (_ref = getScope && getScope(state, scopeId)) !== null && _ref !== void 0 ? _ref : defaults;
    return columns;
  });
  const fieldsByName = (0, _react.useMemo)(() => (0, _source.getAllFieldsByName)(browserFields), [browserFields]);
  const items = (0, _react.useMemo)(() => (0, _fp.sortBy)(['field'], dataFormattedForFieldBrowser).map((item, i) => ({
    ...item,
    ...fieldsByName[item.field],
    valuesConcatenated: item.values != null ? item.values.join() : '',
    ariaRowindex: i + 1
  })), [dataFormattedForFieldBrowser, fieldsByName]);
  const getLinkValue = (0, _react.useCallback)(field => {
    const columnHeader = columnHeaders.find(col => col.id === field);
    if (!columnHeader || !columnHeader.linkField) {
      return null;
    }
    const linkFieldData = (dataFormattedForFieldBrowser !== null && dataFormattedForFieldBrowser !== void 0 ? dataFormattedForFieldBrowser : []).find(d => d.field === columnHeader.linkField);
    const linkFieldValue = (0, _fp.getOr)(null, 'originalValue', linkFieldData);
    return Array.isArray(linkFieldValue) ? linkFieldValue[0] : linkFieldValue;
  }, [dataFormattedForFieldBrowser, columnHeaders]);

  // forces the rows of the table to render smaller fonts
  const onSetRowProps = (0, _react.useCallback)(({
    field
  }) => ({
    className: 'flyout-table-row-small-font',
    'data-test-subj': `flyout-table-row-${field}`
  }), []);
  const columns = (0, _react.useMemo)(() => getColumns({
    browserFields,
    eventId,
    scopeId,
    getLinkValue,
    ruleId,
    isPreview
  }), [browserFields, eventId, scopeId, getLinkValue, ruleId, isPreview]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiInMemoryTable, {
    items: items,
    itemId: "field",
    columns: columns,
    onTableChange: onTableChange,
    pagination: {
      ...pagination,
      pageSizeOptions: COUNT_PER_PAGE_OPTIONS
    },
    rowProps: onSetRowProps,
    search: search,
    sorting: false,
    "data-test-subj": _test_ids.TABLE_TAB_CONTENT_TEST_ID,
    css: (0, _react2.css)`
        .euiTableRow {
          font-size: ${smallFontSize};
        }
      `
  });
});
TableTab.displayName = 'TableTab';