"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MisconfigurationsInsight = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var _css = require("@emotion/css");
var _use_misconfiguration_preview = require("@kbn/cloud-security-posture/src/hooks/use_misconfiguration_preview");
var _cloudSecurityPostureCommon = require("@kbn/cloud-security-posture-common");
var _ui_metrics = require("@kbn/cloud-security-posture-common/utils/ui_metrics");
var _analytics = require("@kbn/analytics");
var _insight_distribution_bar = require("./insight_distribution_bar");
var _misconfiguration_preview = require("../../../../cloud_security_posture/components/misconfiguration/misconfiguration_preview");
var _formatted_number = require("../../../../common/components/formatted_number");
var _preview_link = require("../../../shared/components/preview_link");
var _context = require("../context");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/*
 * Displays a distribution bar with the count of total misconfigurations for a given entity
 */
const MisconfigurationsInsight = ({
  name,
  fieldName,
  direction,
  'data-test-subj': dataTestSubj,
  telemetrySuffix
}) => {
  const {
    scopeId,
    isPreview
  } = (0, _context.useDocumentDetailsContext)();
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const {
    data
  } = (0, _use_misconfiguration_preview.useMisconfigurationPreview)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)(fieldName, name),
    sort: [],
    enabled: true,
    pageSize: 1
  });
  (0, _react.useEffect)(() => {
    _ui_metrics.uiMetricService.trackUiMetric(_analytics.METRIC_TYPE.COUNT, `${_ui_metrics.MISCONFIGURATION_INSIGHT}-${telemetrySuffix}`);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const passedFindings = (data === null || data === void 0 ? void 0 : data.count.passed) || 0;
  const failedFindings = (data === null || data === void 0 ? void 0 : data.count.failed) || 0;
  const totalFindings = (0, _react.useMemo)(() => passedFindings + failedFindings, [passedFindings, failedFindings]);
  const hasMisconfigurationFindings = totalFindings > 0;
  const misconfigurationsStats = (0, _react.useMemo)(() => (0, _misconfiguration_preview.getFindingsStats)(passedFindings, failedFindings), [passedFindings, failedFindings]);
  const count = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement("div", {
    css: (0, _css.css)`
          margin-top: ${euiTheme.size.xs};
          margin-bottom: ${euiTheme.size.xs};
        `
  }, /*#__PURE__*/_react.default.createElement(_preview_link.PreviewLink, {
    field: fieldName,
    value: name,
    scopeId: scopeId,
    isPreview: isPreview,
    "data-test-subj": `${dataTestSubj}-count`
  }, /*#__PURE__*/_react.default.createElement(_formatted_number.FormattedCount, {
    count: totalFindings
  }))), [totalFindings, fieldName, name, scopeId, isPreview, dataTestSubj, euiTheme.size]);
  if (!hasMisconfigurationFindings) return null;
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    "data-test-subj": dataTestSubj
  }, /*#__PURE__*/_react.default.createElement(_insight_distribution_bar.InsightDistributionBar, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.insights.misconfigurationsTitle",
      defaultMessage: "Misconfigurations:"
    }),
    stats: misconfigurationsStats,
    count: count,
    direction: direction,
    "data-test-subj": `${dataTestSubj}-distribution-bar`
  }));
};
exports.MisconfigurationsInsight = MisconfigurationsInsight;
MisconfigurationsInsight.displayName = 'MisconfigurationsInsight';