"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAlertPrevalenceFromProcessTree = useAlertPrevalenceFromProcessTree;
var _reactQuery = require("@tanstack/react-query");
var _react = require("react");
var _use_alert_document_analyzer_schema = require("./use_alert_document_analyzer_schema");
var _use_timeline_data_filters = require("../../../../timelines/containers/use_timeline_data_filters");
var _kibana = require("../../../../common/lib/kibana");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Fetches the alert prevalence from the process tree
 */
function useAlertPrevalenceFromProcessTree({
  documentId,
  isActiveTimeline,
  indices
}) {
  const http = (0, _kibana.useHttp)();
  const {
    selectedPatterns
  } = (0, _use_timeline_data_filters.useTimelineDataFilters)(isActiveTimeline);
  const alertAndOriginalIndices = (0, _react.useMemo)(() => [...new Set(selectedPatterns.concat(indices))], [indices, selectedPatterns]);
  const {
    loading,
    id,
    schema,
    agentId
  } = (0, _use_alert_document_analyzer_schema.useAlertDocumentAnalyzerSchema)({
    documentId,
    indices: alertAndOriginalIndices
  });
  const query = (0, _reactQuery.useQuery)(['getAlertPrevalenceFromProcessTree', id], () => {
    return http.post(`/api/endpoint/resolver/tree`, {
      body: JSON.stringify({
        schema,
        ancestors: 200,
        descendants: 500,
        indexPatterns: alertAndOriginalIndices,
        nodes: [id],
        includeHits: true,
        agentId
      })
    });
  }, {
    enabled: schema !== null && id !== null
  });
  if (query.isLoading || loading) {
    return {
      loading: true,
      error: false,
      alertIds: undefined,
      statsNodes: undefined
    };
  } else if (query.data) {
    return {
      loading: false,
      error: false,
      alertIds: query.data.alertIds,
      statsNodes: query.data.statsNodes
    };
  } else {
    return {
      loading: false,
      error: true,
      alertIds: undefined,
      statsNodes: undefined
    };
  }
}