"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useHostIsolation = void 0;
var _react = require("react");
var _endpoint = require("../../../../common/components/endpoint");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const initialState = {
  isHostIsolationPanelOpen: false,
  isIsolateActionSuccessBannerVisible: false
};
function reducer(state, action) {
  switch (action.type) {
    case 'setIsHostIsolationPanel':
      return {
        ...state,
        isHostIsolationPanelOpen: action.isHostIsolationPanelOpen
      };
    case 'setIsIsolateActionSuccessBannerVisible':
      return {
        ...state,
        isIsolateActionSuccessBannerVisible: action.isIsolateActionSuccessBannerVisible
      };
    default:
      throw new Error();
  }
}
/**
 * Hook that returns the information for a parent to render the host isolation panel in the flyout
 */
const useHostIsolation = () => {
  const [{
    isHostIsolationPanelOpen,
    isIsolateActionSuccessBannerVisible
  }, dispatch] = (0, _react.useReducer)(reducer, initialState);
  const showHostIsolationPanel = (0, _react.useCallback)(action => {
    if (action === 'isolateHost' || action === 'unisolateHost') {
      dispatch({
        type: 'setIsHostIsolationPanel',
        isHostIsolationPanelOpen: true
      });
    }
  }, []);
  const caseDetailsRefresh = (0, _endpoint.useWithCaseDetailsRefresh)();
  const handleIsolationActionSuccess = (0, _react.useCallback)(() => {
    dispatch({
      type: 'setIsIsolateActionSuccessBannerVisible',
      isIsolateActionSuccessBannerVisible: true
    });

    // If a case details refresh ref is defined, then refresh actions and comments
    if (caseDetailsRefresh) {
      caseDetailsRefresh.refreshCase();
    }
  }, [caseDetailsRefresh]);
  return (0, _react.useMemo)(() => ({
    isHostIsolationPanelOpen,
    isIsolateActionSuccessBannerVisible,
    handleIsolationActionSuccess,
    showHostIsolationPanel
  }), [isHostIsolationPanelOpen, isIsolateActionSuccessBannerVisible, handleIsolationActionSuccess, showHostIsolationPanel]);
};
exports.useHostIsolation = useHostIsolation;