"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useNavigateToAnalyzer = void 0;
var _react = require("react");
var _expandableFlyout = require("@kbn/expandable-flyout");
var _kibana = require("../../../../common/lib/kibana");
var _use_which_flyout = require("./use_which_flyout");
var _analyze_graph = require("../../left/components/analyze_graph");
var _panel_keys = require("../constants/panel_keys");
var _flyouts = require("../constants/flyouts");
var _helpers = require("../../../../helpers");
var _telemetry = require("../../../../common/lib/telemetry");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Hook that returns the a callback to navigate to the analyzer in the flyout
 */
const useNavigateToAnalyzer = ({
  isFlyoutOpen,
  eventId,
  indexName,
  scopeId
}) => {
  var _useWhichFlyout;
  const {
    telemetry
  } = (0, _kibana.useKibana)().services;
  const {
    openLeftPanel,
    openPreviewPanel,
    openFlyout
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  let key = (_useWhichFlyout = (0, _use_which_flyout.useWhichFlyout)()) !== null && _useWhichFlyout !== void 0 ? _useWhichFlyout : 'memory';
  if (!isFlyoutOpen) {
    key = (0, _helpers.isTimelineScope)(scopeId) ? _flyouts.Flyouts.timeline : _flyouts.Flyouts.securitySolution;
  }
  const right = (0, _react.useMemo)(() => ({
    id: _panel_keys.DocumentDetailsRightPanelKey,
    params: {
      id: eventId,
      indexName,
      scopeId
    }
  }), [eventId, indexName, scopeId]);
  const left = (0, _react.useMemo)(() => ({
    id: _panel_keys.DocumentDetailsLeftPanelKey,
    params: {
      id: eventId,
      indexName,
      scopeId
    },
    path: {
      tab: 'visualize',
      subTab: _analyze_graph.ANALYZE_GRAPH_ID
    }
  }), [eventId, indexName, scopeId]);
  const preview = (0, _react.useMemo)(() => ({
    id: _panel_keys.DocumentDetailsAnalyzerPanelKey,
    params: {
      resolverComponentInstanceID: `${key}-${scopeId}`,
      banner: _analyze_graph.ANALYZER_PREVIEW_BANNER
    }
  }), [key, scopeId]);
  const navigateToAnalyzer = (0, _react.useCallback)(() => {
    if (isFlyoutOpen) {
      openLeftPanel(left);
      openPreviewPanel(preview);
      telemetry.reportEvent(_telemetry.DocumentEventTypes.DetailsFlyoutTabClicked, {
        location: scopeId,
        panel: 'left',
        tabId: 'visualize'
      });
    } else {
      openFlyout({
        right,
        left,
        preview
      });
      telemetry.reportEvent(_telemetry.DocumentEventTypes.DetailsFlyoutOpened, {
        location: scopeId,
        panel: 'left'
      });
    }
  }, [openFlyout, openLeftPanel, openPreviewPanel, right, left, preview, scopeId, telemetry, isFlyoutOpen]);
  return (0, _react.useMemo)(() => ({
    navigateToAnalyzer
  }), [navigateToAnalyzer]);
};
exports.useNavigateToAnalyzer = useNavigateToAnalyzer;