"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hasPreview = exports.PreviewLink = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _expandableFlyout = require("@kbn/expandable-flyout");
var _network = require("../../../../common/search_strategy/security_solution/network");
var _table_field_name_cell = require("../../document_details/right/components/table_field_name_cell");
var _constants = require("../../../timelines/components/timeline/body/renderers/constants");
var _kibana = require("../../../common/lib/kibana");
var _test_ids = require("../../document_details/shared/components/test_ids");
var _host_right = require("../../entity_details/host_right");
var _host_entity_overview = require("../../document_details/right/components/host_entity_overview");
var _user_right = require("../../entity_details/user_right");
var _user_entity_overview = require("../../document_details/right/components/user_entity_overview");
var _network_details = require("../../network_details");
var _right = require("../../rule_details/right");
var _telemetry = require("../../../common/lib/telemetry");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const PREVIEW_FIELDS = [_constants.HOST_NAME_FIELD_NAME, _constants.USER_NAME_FIELD_NAME, _constants.SIGNAL_RULE_NAME_FIELD_NAME];

// Helper function to check if the field has a preview link
const hasPreview = field => {
  var _getEcsField;
  return PREVIEW_FIELDS.includes(field) || ((_getEcsField = (0, _table_field_name_cell.getEcsField)(field)) === null || _getEcsField === void 0 ? void 0 : _getEcsField.type) === _constants.IP_FIELD_TYPE;
};
exports.hasPreview = hasPreview;
// Helper get function to get the preview parameters
const getPreviewParams = (value, field, scopeId, ruleId) => {
  var _getEcsField2;
  if (((_getEcsField2 = (0, _table_field_name_cell.getEcsField)(field)) === null || _getEcsField2 === void 0 ? void 0 : _getEcsField2.type) === _constants.IP_FIELD_TYPE) {
    return {
      id: _network_details.NetworkPanelKey,
      params: {
        ip: value,
        flowTarget: field.includes(_network.FlowTargetSourceDest.destination) ? _network.FlowTargetSourceDest.destination : _network.FlowTargetSourceDest.source,
        banner: _network_details.NETWORK_PREVIEW_BANNER
      }
    };
  }
  if (field === _constants.SIGNAL_RULE_NAME_FIELD_NAME && !ruleId) {
    return null;
  }
  switch (field) {
    case _constants.HOST_NAME_FIELD_NAME:
      return {
        id: _host_right.HostPreviewPanelKey,
        params: {
          hostName: value,
          scopeId,
          banner: _host_entity_overview.HOST_PREVIEW_BANNER
        }
      };
    case _constants.USER_NAME_FIELD_NAME:
      return {
        id: _user_right.UserPreviewPanelKey,
        params: {
          userName: value,
          scopeId,
          banner: _user_entity_overview.USER_PREVIEW_BANNER
        }
      };
    case _constants.SIGNAL_RULE_NAME_FIELD_NAME:
      return {
        id: _right.RulePreviewPanelKey,
        params: {
          ruleId,
          banner: _right.RULE_PREVIEW_BANNER,
          isPreviewMode: true
        }
      };
    default:
      return null;
  }
};
/**
 * Renders a preview link for entities and ip addresses
 */
const PreviewLink = ({
  field,
  value,
  scopeId,
  ruleId,
  isPreview,
  children,
  'data-test-subj': dataTestSubj = _test_ids.FLYOUT_PREVIEW_LINK_TEST_ID
}) => {
  const {
    openPreviewPanel
  } = (0, _expandableFlyout.useExpandableFlyoutApi)();
  const {
    telemetry
  } = (0, _kibana.useKibana)().services;
  const onClick = (0, _react.useCallback)(() => {
    const previewParams = getPreviewParams(value, field, scopeId, ruleId);
    if (previewParams) {
      openPreviewPanel({
        id: previewParams.id,
        params: previewParams.params
      });
      telemetry.reportEvent(_telemetry.DocumentEventTypes.DetailsFlyoutOpened, {
        location: scopeId,
        panel: 'preview'
      });
    }
  }, [field, scopeId, value, telemetry, openPreviewPanel, ruleId]);

  // If the field is not previewable, do not render link
  if (!hasPreview(field)) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children !== null && children !== void 0 ? children : value);
  }

  // If the field is rule.id, and the ruleId is not provided or currently in rule preview, do not render link
  if (field === _constants.SIGNAL_RULE_NAME_FIELD_NAME && (!ruleId || isPreview)) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children !== null && children !== void 0 ? children : value);
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
    onClick: onClick,
    "data-test-subj": dataTestSubj
  }, children !== null && children !== void 0 ? children : value);
};
exports.PreviewLink = PreviewLink;