"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PackageListGrid = exports.IntegrationsCardGridTabsComponent = exports.IntegrationsCardGridTabs = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _lodash = require("lodash");
var _react2 = require("@emotion/react");
var _with_lazy_hook = require("../../../../../common/components/with_lazy_hook");
var _use_stored_state = require("../../../../hooks/use_stored_state");
var _onboarding_context = require("../../../onboarding_context");
var _constants = require("./constants");
var _integration_tabs_configs = require("./integration_tabs_configs");
var _use_integration_card_list = require("./use_integration_card_list");
var _types = require("./types");
var _integration_card_top_callout = require("./callouts/integration_card_top_callout");
var _telemetry = require("../../../../common/lib/telemetry");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const emptyStateStyles = {
  paddingTop: '16px'
};
const PackageListGrid = exports.PackageListGrid = /*#__PURE__*/(0, _react.lazy)(async () => ({
  default: await Promise.resolve().then(() => _interopRequireWildcard(require('@kbn/fleet-plugin/public'))).then(module => module.PackageList()).then(pkg => pkg.PackageListGrid)
}));
const IntegrationsCardGridTabsComponent = exports.IntegrationsCardGridTabsComponent = /*#__PURE__*/_react.default.memo(({
  installedIntegrationsCount,
  isAgentRequired,
  useAvailablePackages
}) => {
  var _selectedTab$overflow, _selectedTab$category2;
  const {
    spaceId
  } = (0, _onboarding_context.useOnboardingContext)();
  const scrollElement = (0, _react.useRef)(null);
  const [toggleIdSelected, setSelectedTabIdToStorage] = (0, _use_stored_state.useStoredIntegrationTabId)(spaceId, _constants.DEFAULT_TAB.id);
  const [searchTermFromStorage, setSearchTermToStorage] = (0, _use_stored_state.useStoredIntegrationSearchTerm)(spaceId);
  const onTabChange = (0, _react.useCallback)(stringId => {
    var _scrollElement$curren, _scrollElement$curren2;
    const id = stringId;
    const trackId = `${_constants.TELEMETRY_INTEGRATION_TAB}_${id}`;
    (_scrollElement$curren = scrollElement.current) === null || _scrollElement$curren === void 0 ? void 0 : (_scrollElement$curren2 = _scrollElement$curren.scrollTo) === null || _scrollElement$curren2 === void 0 ? void 0 : _scrollElement$curren2.call(_scrollElement$curren, 0, 0);
    setSelectedTabIdToStorage(id);
    (0, _telemetry.trackOnboardingLinkClick)(trackId);
  }, [setSelectedTabIdToStorage]);
  const {
    filteredCards,
    isLoading,
    searchTerm,
    setCategory,
    setSearchTerm,
    setSelectedSubCategory
  } = useAvailablePackages({
    prereleaseIntegrationsEnabled: false
  });
  const selectedTab = (0, _react.useMemo)(() => _integration_tabs_configs.INTEGRATION_TABS_BY_ID[toggleIdSelected], [toggleIdSelected]);
  const onSearchTermChanged = (0, _react.useCallback)(searchQuery => {
    setSearchTerm(searchQuery);
    // Search term is preserved across VISIBLE tabs
    // As we want user to be able to see the same search results when coming back from Fleet
    if (selectedTab.showSearchTools) {
      setSearchTermToStorage(searchQuery);
    }
  }, [selectedTab.showSearchTools, setSearchTerm, setSearchTermToStorage]);
  (0, _react.useEffect)(() => {
    var _selectedTab$category;
    setCategory((_selectedTab$category = selectedTab.category) !== null && _selectedTab$category !== void 0 ? _selectedTab$category : '');
    setSelectedSubCategory(selectedTab.subCategory);
    if (!selectedTab.showSearchTools) {
      // If search box are not shown, clear the search term to avoid unexpected filtering
      onSearchTermChanged('');
    }
    if (selectedTab.showSearchTools && searchTermFromStorage && toggleIdSelected !== _types.IntegrationTabId.recommended) {
      setSearchTerm(searchTermFromStorage);
    }
  }, [onSearchTermChanged, searchTermFromStorage, selectedTab.category, selectedTab.showSearchTools, selectedTab.subCategory, setCategory, setSearchTerm, setSelectedSubCategory, toggleIdSelected]);
  const list = (0, _use_integration_card_list.useIntegrationCardList)({
    integrationsList: filteredCards,
    featuredCardIds: selectedTab.featuredCardIds
  });
  if (isLoading) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiSkeletonText, {
      "data-test-subj": "loadingPackages",
      isLoading: true,
      lines: _constants.LOADING_SKELETON_TEXT_LINES
    });
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    className: "step-paragraph",
    gutterSize: selectedTab.showSearchTools ? 'm' : 'none',
    css: (0, _react2.css)`
          height: ${selectedTab.showSearchTools ? _constants.WITH_SEARCH_BOX_HEIGHT : _constants.WITHOUT_SEARCH_BOX_HEIGHT};
        `
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonGroup, {
    buttonSize: "compressed",
    color: "primary",
    idSelected: toggleIdSelected,
    isFullWidth: true,
    legend: "Categories",
    onChange: onTabChange,
    options: _integration_tabs_configs.INTEGRATION_TABS,
    type: "single"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    css: (0, _react2.css)`
            overflow-y: ${(_selectedTab$overflow = selectedTab.overflow) !== null && _selectedTab$overflow !== void 0 ? _selectedTab$overflow : 'auto'};
          `,
    grow: 1,
    id: _constants.SCROLL_ELEMENT_ID,
    ref: scrollElement
  }, /*#__PURE__*/_react.default.createElement(_react.Suspense, {
    fallback: /*#__PURE__*/_react.default.createElement(_eui.EuiSkeletonText, {
      isLoading: true,
      lines: _constants.LOADING_SKELETON_TEXT_LINES
    })
  }, /*#__PURE__*/_react.default.createElement(PackageListGrid, {
    callout: /*#__PURE__*/_react.default.createElement(_integration_card_top_callout.IntegrationCardTopCallout, {
      isAgentRequired: isAgentRequired,
      installedIntegrationsCount: installedIntegrationsCount,
      selectedTabId: toggleIdSelected
    }),
    calloutTopSpacerSize: "m",
    categories: _constants.SEARCH_FILTER_CATEGORIES // We do not want to show categories and subcategories as the search bar filter
    ,
    emptyStateStyles: emptyStateStyles,
    list: list,
    scrollElementId: _constants.SCROLL_ELEMENT_ID,
    searchTerm: searchTerm,
    selectedCategory: (_selectedTab$category2 = selectedTab.category) !== null && _selectedTab$category2 !== void 0 ? _selectedTab$category2 : '',
    selectedSubCategory: selectedTab.subCategory,
    setCategory: setCategory,
    setSearchTerm: onSearchTermChanged,
    setUrlandPushHistory: _lodash.noop,
    setUrlandReplaceHistory: _lodash.noop,
    showCardLabels: false,
    showControls: false,
    showSearchTools: selectedTab.showSearchTools,
    sortByFeaturedIntegrations: selectedTab.sortByFeaturedIntegrations,
    spacer: false
  }))));
});
IntegrationsCardGridTabsComponent.displayName = 'IntegrationsCardGridTabsComponent';
const IntegrationsCardGridTabs = exports.IntegrationsCardGridTabs = (0, _with_lazy_hook.withLazyHook)(IntegrationsCardGridTabsComponent, () => Promise.resolve().then(() => _interopRequireWildcard(require('@kbn/fleet-plugin/public'))).then(module => module.AvailablePackagesHook()), /*#__PURE__*/_react.default.createElement(_eui.EuiSkeletonText, {
  "data-test-subj": "loadingPackages",
  isLoading: true,
  lines: _constants.LOADING_SKELETON_TEXT_LINES
}));
IntegrationsCardGridTabs.displayName = 'IntegrationsCardGridTabs';