"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkIntegrationsCardComplete = void 0;
var _public = require("@kbn/fleet-plugin/public");
var _i18n = require("@kbn/i18n");
var _rxjs = require("rxjs");
var _constants = require("./constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const checkIntegrationsCardComplete = async services => {
  var _packageData$items, _agentsData$rawRespon, _agentsData$rawRespon2;
  const packageData = await services.http.get(_public.EPM_API_ROUTES.INSTALL_BY_UPLOAD_PATTERN, {
    version: '2023-10-31'
  }).catch(err => {
    services.notifications.toasts.addError(err, {
      title: _i18n.i18n.translate('xpack.securitySolution.onboarding.integrationsCard.checkComplete.fetchIntegrations.errorTitle', {
        defaultMessage: 'Error fetching integrations data'
      })
    });
    return {
      items: []
    };
  });
  const agentsData = await (0, _rxjs.lastValueFrom)(services.data.search.search({
    params: {
      index: _constants.AGENT_INDEX,
      body: {
        size: 1
      }
    }
  })).catch(err => {
    services.notifications.toasts.addError(err, {
      title: _i18n.i18n.translate('xpack.securitySolution.onboarding.integrationsCard.checkComplete.fetchAgents.errorTitle', {
        defaultMessage: 'Error fetching agents data'
      })
    });
    return {
      rawResponse: {
        hits: {
          total: 0
        }
      }
    };
  });
  const installed = packageData === null || packageData === void 0 ? void 0 : (_packageData$items = packageData.items) === null || _packageData$items === void 0 ? void 0 : _packageData$items.filter(pkg => pkg.status === _public.installationStatuses.Installed || pkg.status === _public.installationStatuses.InstallFailed);
  const isComplete = installed && installed.length > 0;
  const agentsDataAvailable = !!(agentsData !== null && agentsData !== void 0 && (_agentsData$rawRespon = agentsData.rawResponse) !== null && _agentsData$rawRespon !== void 0 && (_agentsData$rawRespon2 = _agentsData$rawRespon.hits) !== null && _agentsData$rawRespon2 !== void 0 && _agentsData$rawRespon2.total);
  const isAgentRequired = isComplete && !agentsDataAvailable;
  const completeBadgeText = _i18n.i18n.translate('xpack.securitySolution.onboarding.integrationsCard.badge.completeText', {
    defaultMessage: '{count} {count, plural, one {integration} other {integrations}} added',
    values: {
      count: installed.length
    }
  });
  if (!isComplete) {
    return {
      isComplete,
      metadata: {
        installedIntegrationsCount: 0,
        isAgentRequired: false
      }
    };
  }
  return {
    isComplete,
    completeBadgeText,
    metadata: {
      installedIntegrationsCount: installed.length,
      isAgentRequired
    }
  };
};
exports.checkIntegrationsCardComplete = checkIntegrationsCardComplete;