"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useIntegrationCardList = void 0;
var _react = require("react");
var _securitySolutionNavigation = require("@kbn/security-solution-navigation");
var _kibana = require("../../../../../common/lib/kibana");
var _constants = require("../../../../../../common/constants");
var _constants2 = require("./constants");
var _telemetry = require("../../../../common/lib/telemetry");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const addPathParamToUrl = (url, onboardingLink) => {
  const encoded = encodeURIComponent(onboardingLink);
  const paramsString = `${_constants2.ONBOARDING_LINK}=${encoded}&${_constants2.ONBOARDING_APP_ID}=${_constants.APP_UI_ID}`;
  if (url.indexOf('?') >= 0) {
    return `${url}&${paramsString}`;
  }
  return `${url}?${paramsString}`;
};
const extractFeaturedCards = (filteredCards, featuredCardIds) => {
  return filteredCards.reduce((acc, card) => {
    if (featuredCardIds.includes(card.id)) {
      acc.push(card);
    }
    return acc;
  }, []);
};
const getFilteredCards = ({
  featuredCardIds,
  getAppUrl,
  installedIntegrationList,
  integrationsList,
  navigateTo
}) => {
  const securityIntegrationsList = integrationsList.map(card => addSecuritySpecificProps({
    navigateTo,
    getAppUrl,
    card,
    installedIntegrationList
  }));
  if (!featuredCardIds) {
    return {
      featuredCards: [],
      integrationCards: securityIntegrationsList
    };
  }
  const featuredCards = extractFeaturedCards(securityIntegrationsList, featuredCardIds);
  return {
    featuredCards,
    integrationCards: securityIntegrationsList
  };
};
const addSecuritySpecificProps = ({
  navigateTo,
  getAppUrl,
  card
}) => {
  const onboardingLink = getAppUrl({
    appId: _securitySolutionNavigation.SECURITY_UI_APP_ID,
    path: _constants.ONBOARDING_PATH
  });
  const integrationRootUrl = getAppUrl({
    appId: _constants2.INTEGRATION_APP_ID
  });
  const state = {
    onCancelNavigateTo: [_constants.APP_UI_ID, {
      path: _constants.ONBOARDING_PATH
    }],
    onCancelUrl: onboardingLink,
    onSaveNavigateTo: [_constants.APP_UI_ID, {
      path: _constants.ONBOARDING_PATH
    }]
  };
  const url = card.url.indexOf(_constants.APP_INTEGRATIONS_PATH) >= 0 && onboardingLink ? addPathParamToUrl(card.url, onboardingLink) : card.url;
  return {
    ...card,
    titleLineClamp: _constants2.CARD_TITLE_LINE_CLAMP,
    descriptionLineClamp: _constants2.CARD_DESCRIPTION_LINE_CLAMP,
    maxCardHeight: _constants2.MAX_CARD_HEIGHT_IN_PX,
    showInstallationStatus: true,
    url,
    onCardClick: () => {
      const trackId = `${_constants2.TELEMETRY_INTEGRATION_CARD}_${card.id}`;
      (0, _telemetry.trackOnboardingLinkClick)(trackId);
      if (url.startsWith(_constants.APP_INTEGRATIONS_PATH)) {
        navigateTo({
          appId: _constants2.INTEGRATION_APP_ID,
          path: url.slice(integrationRootUrl.length),
          state
        });
      } else if (url.startsWith('http') || url.startsWith('https')) {
        window.open(url, '_blank');
      } else {
        navigateTo({
          url,
          state
        });
      }
    }
  };
};
const useIntegrationCardList = ({
  integrationsList,
  featuredCardIds
}) => {
  const {
    navigateTo,
    getAppUrl
  } = (0, _kibana.useNavigation)();
  const {
    featuredCards,
    integrationCards
  } = (0, _react.useMemo)(() => getFilteredCards({
    navigateTo,
    getAppUrl,
    integrationsList,
    featuredCardIds
  }), [navigateTo, getAppUrl, integrationsList, featuredCardIds]);
  if (featuredCardIds && featuredCardIds.length > 0) {
    return featuredCards;
  }
  return integrationCards !== null && integrationCards !== void 0 ? integrationCards : [];
};
exports.useIntegrationCardList = useIntegrationCardList;