"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useBodyConfig = void 0;
var _useObservable = _interopRequireDefault(require("react-use/lib/useObservable"));
var _react = require("react");
var _capabilities = require("../../../../common/lib/capabilities");
var _kibana_react = require("../../../../common/lib/kibana/kibana_react");
var _body_config = require("../body_config");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Hook that filters the config based on the user's capabilities and license
 */
const useBodyConfig = () => {
  const {
    application,
    licensing
  } = (0, _kibana_react.useKibana)().services;
  const license = (0, _useObservable.default)(licensing.license$);
  const filteredBodyConfig = (0, _react.useMemo)(() => {
    // Return empty array when the license is not defined. It should always become defined at some point.
    // This exit case prevents code dependant on the cards config (like completion checks) from running multiple times.
    if (!license) {
      return [];
    }
    return _body_config.bodyConfig.reduce((filteredGroups, group) => {
      const filteredCards = group.cards.filter(card => {
        if (card.capabilities) {
          const cardHasCapabilities = (0, _capabilities.hasCapabilities)(application.capabilities, card.capabilities);
          if (!cardHasCapabilities) {
            return false;
          }
        }
        if (card.licenseType) {
          const cardHasLicense = license.hasAtLeast(card.licenseType);
          if (!cardHasLicense) {
            return false;
          }
        }
        return true;
      });
      if (filteredCards.length > 0) {
        filteredGroups.push({
          ...group,
          cards: filteredCards
        });
      }
      return filteredGroups;
    }, []);
  }, [license, application.capabilities]);
  return filteredBodyConfig;
};
exports.useBodyConfig = useBodyConfig;