"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useExpandedCard = void 0;
var _react = require("react");
var _reactRouterDom = require("react-router-dom");
var _use_stored_state = require("../../../hooks/use_stored_state");
var _onboarding_card_panel = require("../onboarding_card_panel.styles");
var _onboarding_context = require("../../onboarding_context");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const HEADER_OFFSET = 40;
const scrollToCard = cardId => {
  setTimeout(() => {
    const element = document.getElementById(cardId);
    if (element) {
      element.focus({
        preventScroll: true
      });
      window.scrollTo({
        top: element.offsetTop - HEADER_OFFSET,
        behavior: 'smooth'
      });
    }
  }, _onboarding_card_panel.HEIGHT_ANIMATION_DURATION);
};
const setHash = cardId => {
  history.replaceState(null, '', cardId == null ? ' ' : `#${cardId}`);
};

/**
 * This hook manages the expanded card id state in the LocalStorage and the hash in the URL.
 */
const useExpandedCard = () => {
  const {
    spaceId,
    reportCardOpen
  } = (0, _onboarding_context.useOnboardingContext)();
  const [expandedCardId, setStorageExpandedCardId] = (0, _use_stored_state.useStoredExpandedCardId)(spaceId);
  const location = (0, _reactRouterDom.useLocation)();
  const [documentReadyState, setReadyState] = (0, _react.useState)(document.readyState);
  (0, _react.useEffect)(() => {
    const readyStateListener = () => setReadyState(document.readyState);
    document.addEventListener('readystatechange', readyStateListener);
    return () => document.removeEventListener('readystatechange', readyStateListener);
  }, []);

  // This effect implements auto-scroll in the initial render, further changes in the hash should not trigger this effect
  (0, _react.useEffect)(() => {
    if (documentReadyState !== 'complete') return; // Wait for page to finish loading before scrolling
    let cardIdFromHash = location.hash.split('?')[0].replace('#', '');
    if (!cardIdFromHash) {
      if (expandedCardId == null) return;
      // If the hash is empty, but it is defined the storage we use the storage value
      cardIdFromHash = expandedCardId;
      setHash(cardIdFromHash);
    }

    // If the hash is defined and different from the storage, the hash takes precedence
    if (expandedCardId !== cardIdFromHash) {
      setStorageExpandedCardId(cardIdFromHash);
      reportCardOpen(cardIdFromHash, {
        auto: true
      });
    }
    scrollToCard(cardIdFromHash);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [documentReadyState]);
  const setExpandedCardId = (0, _react.useCallback)((cardId, options) => {
    setStorageExpandedCardId(cardId);
    setHash(cardId);
    if (cardId != null) {
      reportCardOpen(cardId);
      if (options !== null && options !== void 0 && options.scroll) {
        scrollToCard(cardId);
      }
    }
  }, [setStorageExpandedCardId, reportCardOpen]);
  return {
    expandedCardId,
    setExpandedCardId
  };
};
exports.useExpandedCard = useExpandedCard;