"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useOnboardingContext = exports.OnboardingContextProvider = void 0;
var _react = _interopRequireWildcard(require("react"));
var _kibana_react = require("../../common/lib/kibana/kibana_react");
var _telemetry = require("../../common/lib/telemetry");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const OnboardingContext = /*#__PURE__*/(0, _react.createContext)(null);
const OnboardingContextProvider = exports.OnboardingContextProvider = /*#__PURE__*/_react.default.memo(({
  children,
  spaceId
}) => {
  const {
    telemetry
  } = (0, _kibana_react.useKibana)().services;
  const value = (0, _react.useMemo)(() => ({
    spaceId,
    reportCardOpen: (cardId, {
      auto = false
    } = {}) => {
      telemetry.reportEvent(_telemetry.OnboardingHubEventTypes.OnboardingHubStepOpen, {
        stepId: cardId,
        trigger: auto ? 'navigation' : 'click'
      });
    },
    reportCardComplete: (cardId, {
      auto = false
    } = {}) => {
      telemetry.reportEvent(_telemetry.OnboardingHubEventTypes.OnboardingHubStepFinished, {
        stepId: cardId,
        trigger: auto ? 'auto_check' : 'click'
      });
    },
    reportCardLinkClicked: (cardId, linkId) => {
      telemetry.reportEvent(_telemetry.OnboardingHubEventTypes.OnboardingHubStepLinkClicked, {
        originStepId: cardId,
        stepLinkId: linkId
      });
    }
  }), [spaceId, telemetry]);
  return /*#__PURE__*/_react.default.createElement(OnboardingContext.Provider, {
    value: value
  }, children);
});
OnboardingContextProvider.displayName = 'OnboardingContextProvider';
const useOnboardingContext = () => {
  const context = (0, _react.useContext)(OnboardingContext);
  if (!context) {
    throw new Error('No OnboardingContext found. Please wrap the application with OnboardingProvider');
  }
  return context;
};
exports.useOnboardingContext = useOnboardingContext;