"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OnboardingHeader = void 0;
var _react = _interopRequireDefault(require("react"));
var _eui = require("@elastic/eui");
var _hooks = require("../../../common/lib/kibana/hooks");
var _onboarding_header = require("./onboarding_header.styles");
var _header_rocket = _interopRequireDefault(require("./images/header_rocket.png"));
var _header_rocket_dark = _interopRequireDefault(require("./images/header_rocket_dark.png"));
var _teammates_card = require("./cards/teammates_card");
var _video_card = require("./cards/video_card");
var _demo_card = require("./cards/demo_card");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const OnboardingHeader = exports.OnboardingHeader = /*#__PURE__*/_react.default.memo(() => {
  const currentUser = (0, _hooks.useCurrentUser)();
  const {
    colorMode
  } = (0, _eui.useEuiTheme)();
  const isDarkMode = colorMode === _eui.COLOR_MODES_STANDARD.dark;
  const styles = (0, _onboarding_header.useOnboardingHeaderStyles)();

  // Full name could be null, user name should always exist
  const currentUserName = (currentUser === null || currentUser === void 0 ? void 0 : currentUser.fullName) || (currentUser === null || currentUser === void 0 ? void 0 : currentUser.username);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "center",
    alignItems: "center",
    className: styles
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiImage, {
    src: isDarkMode ? _header_rocket_dark.default : _header_rocket.default,
    size: 128,
    alt: i18n.GET_STARTED_DATA_INGESTION_HUB_SUBTITLE
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false,
    className: "onboardingHeaderTitleWrapper"
  }, currentUserName && /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs",
    className: "onboardingHeaderGreetings"
  }, /*#__PURE__*/_react.default.createElement("span", null, i18n.GET_STARTED_PAGE_TITLE(currentUserName))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "l"
  }, /*#__PURE__*/_react.default.createElement("h1", null, i18n.GET_STARTED_DATA_INGESTION_HUB_SUBTITLE)), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "m",
    color: "subdued"
  }, /*#__PURE__*/_react.default.createElement("span", null, i18n.GET_STARTED_DATA_INGESTION_HUB_DESCRIPTION)))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xxl"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "center",
    alignItems: "center",
    wrap: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_video_card.VideoCard, {
    isDarkMode: isDarkMode
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_teammates_card.TeammatesCard, {
    isDarkMode: isDarkMode
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_demo_card.DemoCard, {
    isDarkMode: isDarkMode
  }))));
});
OnboardingHeader.displayName = 'OnboardingHeader';