"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStoredIsAVCBannerDismissed = exports.useStoredIntegrationTabId = exports.useStoredIntegrationSearchTerm = exports.useStoredExpandedCardId = exports.useStoredCompletedCardIds = void 0;
var _useLocalStorage = _interopRequireDefault(require("react-use/lib/useLocalStorage"));
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const LocalStorageKey = {
  avcBannerDismissed: 'ONBOARDING_HUB.AVC_BANNER_DISMISSED',
  videoVisited: 'ONBOARDING_HUB.VIDEO_VISITED',
  completeCards: 'ONBOARDING_HUB.COMPLETE_CARDS',
  expandedCard: 'ONBOARDING_HUB.EXPANDED_CARD',
  selectedIntegrationTabId: 'ONBOARDING_HUB.SELECTED_INTEGRATION_TAB_ID',
  IntegrationSearchTerm: 'ONBOARDING_HUB.INTEGRATION_SEARCH_TERM',
  IntegrationScrollTop: 'ONBOARDING_HUB.INTEGRATION_SCROLL_TOP'
};

/**
 * Wrapper hook for useLocalStorage, but always returns the default value when not defined instead of `undefined`.
 */
const useDefinedLocalStorage = (key, defaultValue) => {
  const [value, setValue] = (0, _useLocalStorage.default)(key, defaultValue);
  return [value !== null && value !== void 0 ? value : defaultValue, setValue];
};

/**
 * Stores the AVC banner dismissed state
 */
const useStoredIsAVCBannerDismissed = () => useDefinedLocalStorage(LocalStorageKey.avcBannerDismissed, false);

/**
 * Stores the completed card IDs per space
 */
exports.useStoredIsAVCBannerDismissed = useStoredIsAVCBannerDismissed;
const useStoredCompletedCardIds = spaceId => useDefinedLocalStorage(`${LocalStorageKey.completeCards}.${spaceId}`, []);

/**
 * Stores the expanded card ID per space
 */
exports.useStoredCompletedCardIds = useStoredCompletedCardIds;
const useStoredExpandedCardId = spaceId => useDefinedLocalStorage(`${LocalStorageKey.expandedCard}.${spaceId}`, null);

/**
 * Stores the selected integration tab ID per space
 */
exports.useStoredExpandedCardId = useStoredExpandedCardId;
const useStoredIntegrationTabId = (spaceId, defaultSelectedTabId) => useDefinedLocalStorage(`${LocalStorageKey.selectedIntegrationTabId}.${spaceId}`, defaultSelectedTabId);

/**
 * Stores the integration search term per space
 */
exports.useStoredIntegrationTabId = useStoredIntegrationTabId;
const useStoredIntegrationSearchTerm = spaceId => useDefinedLocalStorage(`${LocalStorageKey.IntegrationSearchTerm}.${spaceId}`, null);
exports.useStoredIntegrationSearchTerm = useStoredIntegrationSearchTerm;