"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTimelineControlColumn = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireWildcard(require("react"));
var _constants = require("../../../../../../common/constants");
var _use_license = require("../../../../../common/hooks/use_license");
var _model = require("../../../../../sourcerer/store/model");
var _containers = require("../../../../../sourcerer/containers");
var _control_columns = require("../../body/control_columns");
var _header_actions = require("../../../../../common/components/header_actions/header_actions");
var _control_column_cell_render = require("../../unified_components/data_table/control_column_cell_render");
var _use_timeline_columns = require("./use_timeline_columns");
var _use_timeline_unified_data_table_context = require("../../unified_components/data_table/use_timeline_unified_data_table_context");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const EMPTY_STRING_ARRAY = [];
const noOp = () => {};
const noSelectAll = ({
  isSelected
}) => {};
const useTimelineControlColumn = ({
  columns,
  sort,
  timelineId,
  activeTab,
  refetch,
  events,
  pinnedEventIds,
  eventIdToNoteIds,
  onToggleShowNotes
}) => {
  const {
    browserFields
  } = (0, _containers.useSourcererDataView)(_model.SourcererScopeName.timeline);
  const isEnterprisePlus = (0, _use_license.useLicense)().isEnterprise();
  const ACTION_BUTTON_COUNT = (0, _react.useMemo)(() => isEnterprisePlus ? 6 : 5, [isEnterprisePlus]);
  const {
    localColumns
  } = (0, _use_timeline_columns.useTimelineColumns)(columns);
  const RowCellRender = (0, _react.useMemo)(() => function TimelineControlColumnCellRenderer(props) {
    var _events$props$rowInde2;
    const ctx = (0, _use_timeline_unified_data_table_context.useTimelineUnifiedDataTableContext)();
    (0, _react.useEffect)(() => {
      var _ctx$expanded, _events$props$rowInde;
      props.setCellProps({
        className: ((_ctx$expanded = ctx.expanded) === null || _ctx$expanded === void 0 ? void 0 : _ctx$expanded.id) === ((_events$props$rowInde = events[props.rowIndex]) === null || _events$props$rowInde === void 0 ? void 0 : _events$props$rowInde._id) ? 'unifiedDataTable__cell--expanded' : ''
      });
    });

    /*
     * In some cases, when number of events is updated
     * but new table is not yet rendered it can result
     * in the mismatch between the number of events v/s
     * the number of rows in the table currently rendered.
     *
     * */
    if ('rowIndex' in props && props.rowIndex >= events.length) return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null);
    return /*#__PURE__*/_react.default.createElement(_control_column_cell_render.TimelineControlColumnCellRender, {
      rowIndex: props.rowIndex,
      columnId: props.columnId,
      timelineId: timelineId,
      ariaRowindex: props.rowIndex,
      checked: false,
      columnValues: "",
      data: events[props.rowIndex].data,
      ecsData: events[props.rowIndex].ecs,
      loadingEventIds: EMPTY_STRING_ARRAY,
      eventId: (_events$props$rowInde2 = events[props.rowIndex]) === null || _events$props$rowInde2 === void 0 ? void 0 : _events$props$rowInde2._id,
      index: props.rowIndex,
      onEventDetailsPanelOpened: noOp,
      onRowSelected: noOp,
      refetch: refetch,
      showCheckboxes: false,
      setEventsLoading: noOp,
      setEventsDeleted: noOp,
      pinnedEventIds: pinnedEventIds,
      eventIdToNoteIds: eventIdToNoteIds,
      toggleShowNotes: onToggleShowNotes
    });
  }, [events, timelineId, refetch, pinnedEventIds, eventIdToNoteIds, onToggleShowNotes]);

  // We need one less when the unified components are enabled because the document expand is provided by the unified data table
  const UNIFIED_COMPONENTS_ACTION_BUTTON_COUNT = ACTION_BUTTON_COUNT - 1;
  return (0, _react.useMemo)(() => {
    return (0, _control_columns.getDefaultControlColumn)(UNIFIED_COMPONENTS_ACTION_BUTTON_COUNT).map(x => ({
      ...x,
      headerCellRender: function HeaderCellRender(props) {
        return /*#__PURE__*/_react.default.createElement(_header_actions.HeaderActions, (0, _extends2.default)({
          width: x.width,
          browserFields: browserFields,
          columnHeaders: localColumns,
          isEventViewer: false,
          isSelectAllChecked: false,
          onSelectAll: noSelectAll,
          showEventsSelect: false,
          showSelectAllCheckbox: false,
          showFullScreenToggle: false,
          sort: sort,
          tabType: activeTab
        }, props, {
          timelineId: timelineId
        }));
      },
      rowCellRender: _constants.JEST_ENVIRONMENT ? RowCellRender : /*#__PURE__*/_react.default.memo(RowCellRender)
    }));
  }, [UNIFIED_COMPONENTS_ACTION_BUTTON_COUNT, browserFields, localColumns, sort, activeTab, timelineId, RowCellRender]);
};
exports.useTimelineControlColumn = useTimelineControlColumn;