"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NL_TO_ESQL_TOOL = void 0;
var _tools = require("@langchain/core/tools");
var _zod = require("@kbn/zod");
var _rxjs = require("rxjs");
var _server = require("@kbn/inference-plugin/server");
var _common = require("../../../../common");
var _common2 = require("./common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

// select only some properties of AssistantToolParams

const TOOL_NAME = 'NaturalLanguageESQLTool';
const toolDetails = {
  id: 'nl-to-esql-tool',
  name: TOOL_NAME,
  description: `You MUST use the "${TOOL_NAME}" function when the user wants to:
  - breakdown or filter ES|QL queries that are displayed on the current page
  - convert queries from another language to ES|QL
  - asks general questions about ES|QL

  ALWAYS use this tool to generate ES|QL queries or explain anything about the ES|QL query language rather than coming up with your own answer.`
};
const NL_TO_ESQL_TOOL = exports.NL_TO_ESQL_TOOL = {
  ...toolDetails,
  sourceRegister: _common.APP_UI_ID,
  isSupported: params => {
    const {
      inference,
      connectorId
    } = params;
    return inference != null && connectorId != null;
  },
  getTool(params) {
    if (!this.isSupported(params)) return null;
    const {
      connectorId,
      inference,
      logger,
      request,
      isOssModel
    } = params;
    if (inference == null || connectorId == null) return null;
    const callNaturalLanguageToEsql = async question => {
      return (0, _rxjs.lastValueFrom)((0, _server.naturalLanguageToEsql)({
        client: inference.getClient({
          request
        }),
        connectorId,
        input: question,
        ...(isOssModel ? {
          functionCalling: 'simulated'
        } : {}),
        logger
      }));
    };
    return new _tools.DynamicStructuredTool({
      name: toolDetails.name,
      description: toolDetails.description + (isOssModel ? (0, _common2.getPromptSuffixForOssModel)(TOOL_NAME) : ''),
      schema: _zod.z.object({
        question: _zod.z.string().describe(`The user's exact question about ESQL`)
      }),
      func: async input => {
        var _generateEvent$conten;
        const generateEvent = await callNaturalLanguageToEsql(input.question);
        const answer = (_generateEvent$conten = generateEvent.content) !== null && _generateEvent$conten !== void 0 ? _generateEvent$conten : 'An error occurred in the tool';
        logger.debug(`Received response from NL to ESQL tool: ${answer}`);
        return answer;
      },
      tags: ['esql', 'query-generation', 'knowledge-base']
      // TODO: Remove after ZodAny is fixed https://github.com/langchain-ai/langchainjs/blob/main/langchain-core/src/tools.ts
    });
  }
};