"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SECURITY_LABS_KNOWLEDGE_BASE_TOOL = void 0;
var _tools = require("@langchain/core/tools");
var _zod = require("@kbn/zod");
var _constants = require("@kbn/elastic-assistant-plugin/server/routes/knowledge_base/constants");
var _common = require("../../../../common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const toolDetails = {
  description: 'Call this for knowledge from Elastic Security Labs content, which contains information on malware, attack techniques, and more.',
  id: 'security-labs-knowledge-base-tool',
  name: 'SecurityLabsKnowledgeBaseTool'
};
const SECURITY_LABS_KNOWLEDGE_BASE_TOOL = exports.SECURITY_LABS_KNOWLEDGE_BASE_TOOL = {
  ...toolDetails,
  sourceRegister: _common.APP_UI_ID,
  isSupported: params => {
    const {
      kbDataClient,
      isEnabledKnowledgeBase
    } = params;
    return isEnabledKnowledgeBase && kbDataClient != null;
  },
  getTool(params) {
    if (!this.isSupported(params)) return null;
    const {
      kbDataClient
    } = params;
    if (kbDataClient == null) return null;
    return new _tools.DynamicStructuredTool({
      name: toolDetails.name,
      description: toolDetails.description,
      schema: _zod.z.object({
        question: _zod.z.string().describe(`Key terms to retrieve Elastic Security Labs content for, like specific malware names or attack techniques.`)
      }),
      func: async input => {
        const docs = await kbDataClient.getKnowledgeBaseDocumentEntries({
          kbResource: _constants.SECURITY_LABS_RESOURCE,
          query: input.question
        });
        // TODO: Token pruning
        return JSON.stringify(docs).substring(0, 20000);
      },
      tags: ['security-labs', 'knowledge-base']
      // TODO: Remove after ZodAny is fixed https://github.com/langchain-ai/langchainjs/blob/main/langchain-core/src/tools.ts
    });
  }
};