"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getHostPolicyResponseHandler = exports.getAgentPolicySummaryHandler = void 0;
var _error_handler = require("../error_handler");
var _service = require("./service");
var _errors = require("../../errors");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getHostPolicyResponseHandler = function (endpointAppContextServices) {
  const logger = endpointAppContextServices.createLogger('endpointPolicyResponse');
  return async (context, request, response) => {
    const spaceId = (await context.securitySolution).getSpaceId();
    const esClient = (await context.core).elasticsearch.client.asInternalUser;
    const fleetServices = endpointAppContextServices.getInternalFleetServices(spaceId);
    try {
      const agentId = request.query.agentId;
      const doc = await (0, _service.getPolicyResponseByAgentId)(agentId, esClient, fleetServices);
      if (doc) {
        return response.ok({
          body: doc
        });
      }
      logger.debug(`Agent id [${agentId}] has no policy response documents indexed yet`);
      throw new _errors.NotFoundError(`Policy response for endpoint id [${agentId}] not found`);
    } catch (err) {
      return (0, _error_handler.errorHandler)(logger, response, err);
    }
  };
};
exports.getHostPolicyResponseHandler = getHostPolicyResponseHandler;
const getAgentPolicySummaryHandler = function (endpointAppContext) {
  return async (_, request, response) => {
    var _request$query, _request$query2, _request$query3;
    const result = await (0, _service.getAgentPolicySummary)(endpointAppContext, request, request.query.package_name, ((_request$query = request.query) === null || _request$query === void 0 ? void 0 : _request$query.policy_id) || undefined);
    const responseBody = {
      package: request.query.package_name,
      versions_count: {
        ...result
      }
    };
    const body = {
      summary_response: (_request$query2 = request.query) !== null && _request$query2 !== void 0 && _request$query2.policy_id ? {
        ...responseBody,
        ...{
          policy_id: (_request$query3 = request.query) === null || _request$query3 === void 0 ? void 0 : _request$query3.policy_id
        }
      } : responseBody
    };
    return response.ok({
      body
    });
  };
};
exports.getAgentPolicySummaryHandler = getAgentPolicySummaryHandler;