"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handleTree = handleTree;
var _rxjs = require("rxjs");
var _constants = require("../../../../../common/constants");
var _feature_usage = require("../../../services/feature_usage");
var _fetch = require("./utils/fetch");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function handleTree(getRuleRegistry, getLicensing) {
  return async (context, req, res) => {
    const client = (await context.core).elasticsearch.client;
    const licensing = await getLicensing();
    const license = await (0, _rxjs.firstValueFrom)(licensing.license$);
    const hasAccessToInsightsRelatedByProcessAncestry = license.hasAtLeast('platinum');
    const shouldExcludeColdAndFrozenTiers = await (await context.core).uiSettings.client.get(_constants.EXCLUDE_COLD_AND_FROZEN_TIERS_IN_ANALYZER);
    if (hasAccessToInsightsRelatedByProcessAncestry) {
      _feature_usage.featureUsageService.notifyUsage('ALERTS_BY_PROCESS_ANCESTRY');
    }
    const alertsClient = hasAccessToInsightsRelatedByProcessAncestry ? await (await getRuleRegistry()).getRacClientWithRequest(req) : undefined;
    const fetcher = new _fetch.Fetcher(client, alertsClient);
    const body = await fetcher.tree({
      ...req.body,
      shouldExcludeColdAndFrozenTiers
    });
    return res.ok({
      body
    });
  };
}