"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.bootstrapPrebuiltRulesRoute = void 0;
var _securitysolutionEsUtils = require("@kbn/securitysolution-es-utils");
var _prebuilt_rules = require("../../../../../../common/api/detection_engine/prebuilt_rules");
var _utils = require("../../../routes/utils");
var _install_prebuilt_rules_package = require("../install_prebuilt_rules_and_timelines/install_prebuilt_rules_package");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const bootstrapPrebuiltRulesRoute = router => {
  router.versioned.post({
    access: 'internal',
    path: _prebuilt_rules.BOOTSTRAP_PREBUILT_RULES_URL,
    security: {
      authz: {
        requiredPrivileges: ['securitySolution']
      }
    }
  }).addVersion({
    version: '1',
    validate: {}
  }, async (context, _, response) => {
    const siemResponse = (0, _utils.buildSiemResponse)(response);
    try {
      const ctx = await context.resolve(['securitySolution']);
      const securityContext = ctx.securitySolution;
      const config = securityContext.getConfig();
      const results = await Promise.all([(0, _install_prebuilt_rules_package.installPrebuiltRulesPackage)(config, securityContext), (0, _install_prebuilt_rules_package.installEndpointPackage)(config, securityContext)]);
      const responseBody = {
        packages: results.map(result => ({
          name: result.package.name,
          version: result.package.version,
          status: result.status
        }))
      };
      return response.ok({
        body: responseBody
      });
    } catch (err) {
      const error = (0, _securitysolutionEsUtils.transformError)(err);
      return siemResponse.error({
        body: error.message,
        statusCode: error.statusCode
      });
    }
  });
};
exports.bootstrapPrebuiltRulesRoute = bootstrapPrebuiltRulesRoute;