"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUpgradeableRules = void 0;
var _with_security_span = require("../../../../../utils/with_security_span");
var _detection_engine = require("../../../../../../common/api/detection_engine");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getUpgradeableRules = ({
  rawUpgradeableRules,
  currentRules,
  versionSpecifiers,
  mode
}) => {
  return (0, _with_security_span.withSecuritySpanSync)(getUpgradeableRules.name, () => {
    const upgradeableRules = new Map(rawUpgradeableRules.map(_rule => [_rule.current.rule_id, _rule]));
    const fetchErrors = [];
    const skippedRules = [];
    if (mode === _detection_engine.ModeEnum.SPECIFIC_RULES) {
      const installedRuleIds = new Set(currentRules.map(rule => rule.rule_id));
      const upgradeableRuleIds = new Set(rawUpgradeableRules.map(({
        current
      }) => current.rule_id));
      versionSpecifiers === null || versionSpecifiers === void 0 ? void 0 : versionSpecifiers.forEach(rule => {
        var _currentRules$find;
        // Check that the requested rule was found
        if (!installedRuleIds.has(rule.rule_id)) {
          fetchErrors.push({
            error: new Error(`Rule with rule_id "${rule.rule_id}" and version "${rule.version}" not found`),
            item: rule
          });
          return;
        }

        // Check that the requested rule is upgradeable
        if (!upgradeableRuleIds.has(rule.rule_id)) {
          skippedRules.push({
            rule_id: rule.rule_id,
            reason: _detection_engine.SkipRuleUpgradeReasonEnum.RULE_UP_TO_DATE
          });
          return;
        }

        // Check that rule revisions match (no update slipped in since the user reviewed the list)
        const currentRevision = (_currentRules$find = currentRules.find(currentRule => currentRule.rule_id === rule.rule_id)) === null || _currentRules$find === void 0 ? void 0 : _currentRules$find.revision;
        if (rule.revision !== currentRevision) {
          fetchErrors.push({
            error: new Error(`Revision mismatch for rule_id ${rule.rule_id}: expected ${currentRevision}, got ${rule.revision}`),
            item: rule
          });
          // Remove the rule from the list of upgradeable rules
          if (upgradeableRules.has(rule.rule_id)) {
            upgradeableRules.delete(rule.rule_id);
          }
        }
      });
    }
    return {
      upgradeableRules: Array.from(upgradeableRules.values()),
      fetchErrors,
      skippedRules
    };
  });
};
exports.getUpgradeableRules = getUpgradeableRules;