"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.duplicateRule = void 0;
var _uuid = require("uuid");
var _i18n = require("@kbn/i18n");
var _securitysolutionRules = require("@kbn/securitysolution-rules");
var _constants = require("../../../../../../common/constants");
var _rule_actions = require("../../normalization/rule_actions");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const DUPLICATE_TITLE = _i18n.i18n.translate('xpack.securitySolution.detectionEngine.rules.cloneRule.duplicateTitle', {
  defaultMessage: 'Duplicate'
});
const duplicateRule = async ({
  rule
}) => {
  var _rule$systemActions;
  // Generate a new static ruleId
  const ruleId = (0, _uuid.v4)();

  // Duplicated rules are always considered custom rules
  const immutable = false;
  const ruleSource = {
    type: 'internal'
  };
  const actions = (0, _rule_actions.transformToActionFrequency)(rule.actions, rule.throttle);
  return {
    name: `${rule.name} [${DUPLICATE_TITLE}]`,
    tags: rule.tags,
    alertTypeId: _securitysolutionRules.ruleTypeMappings[rule.params.type],
    consumer: _constants.SERVER_APP_ID,
    params: {
      ...rule.params,
      ruleId,
      immutable,
      ruleSource,
      exceptionsList: []
    },
    schedule: rule.schedule,
    enabled: false,
    actions,
    systemActions: (_rule$systemActions = rule.systemActions) !== null && _rule$systemActions !== void 0 ? _rule$systemActions : []
  };
};
exports.duplicateRule = duplicateRule;