"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.calculateIsCustomized = calculateIsCustomized;
var _detection_engine = require("../../../../../../../../common/api/detection_engine");
var _calculate_rule_fields_diff = require("../../../../../prebuilt_rules/logic/diff/calculation/calculate_rule_fields_diff");
var _convert_rule_to_diffable = require("../../../../../../../../common/detection_engine/prebuilt_rules/diff/convert_rule_to_diffable");
var _convert_prebuilt_rule_asset_to_rule_response = require("../../converters/convert_prebuilt_rule_asset_to_rule_response");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function calculateIsCustomized({
  baseRule,
  nextRule,
  isRuleCustomizationEnabled
}) {
  if (!isRuleCustomizationEnabled) {
    // We don't want to accidentally mark rules as customized when customization is disabled.
    return false;
  }
  if (baseRule == null) {
    // If the base version is missing, we consider the rule to be customized
    return true;
  }
  const baseRuleWithDefaults = (0, _convert_prebuilt_rule_asset_to_rule_response.convertPrebuiltRuleAssetToRuleResponse)(baseRule);
  const fieldsDiff = (0, _calculate_rule_fields_diff.calculateRuleFieldsDiff)({
    base_version: _detection_engine.MissingVersion,
    current_version: (0, _convert_rule_to_diffable.convertRuleToDiffable)(baseRuleWithDefaults),
    target_version: (0, _convert_rule_to_diffable.convertRuleToDiffable)(nextRule)
  });
  return Object.values(fieldsDiff).some(diff => diff.has_update);
}