"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.patchRule = void 0;
var _apply_rule_patch = require("../mergers/apply_rule_patch");
var _utils = require("../../../utils/utils");
var _validate = require("../../../utils/validate");
var _convert_alerting_rule_to_rule_response = require("../converters/convert_alerting_rule_to_rule_response");
var _convert_rule_response_to_alerting_rule = require("../converters/convert_rule_response_to_alerting_rule");
var _utils2 = require("../utils");
var _get_rule_by_id_or_rule_id = require("./get_rule_by_id_or_rule_id");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const patchRule = async ({
  actionsClient,
  rulesClient,
  prebuiltRuleAssetClient,
  rulePatch,
  mlAuthz,
  isRuleCustomizationEnabled
}) => {
  var _rulePatch$type;
  const {
    rule_id: ruleId,
    id
  } = rulePatch;
  const existingRule = await (0, _get_rule_by_id_or_rule_id.getRuleByIdOrRuleId)({
    rulesClient,
    ruleId,
    id
  });
  if (existingRule == null) {
    const error = (0, _utils.getIdError)({
      id,
      ruleId
    });
    throw new _utils2.ClientError(error.message, error.statusCode);
  }
  await (0, _utils2.validateMlAuth)(mlAuthz, (_rulePatch$type = rulePatch.type) !== null && _rulePatch$type !== void 0 ? _rulePatch$type : existingRule.type);
  (0, _validate.validateNonCustomizablePatchFields)(rulePatch, existingRule);
  const patchedRule = await (0, _apply_rule_patch.applyRulePatch)({
    prebuiltRuleAssetClient,
    existingRule,
    rulePatch,
    isRuleCustomizationEnabled
  });
  const patchedInternalRule = await rulesClient.update({
    id: existingRule.id,
    data: (0, _convert_rule_response_to_alerting_rule.convertRuleResponseToAlertingRule)(patchedRule, actionsClient)
  });
  const {
    enabled
  } = await (0, _utils2.toggleRuleEnabledOnUpdate)(rulesClient, existingRule, patchedRule);
  return (0, _convert_alerting_rule_to_rule_response.convertAlertingRuleToRuleResponse)({
    ...patchedInternalRule,
    enabled
  });
};
exports.patchRule = patchRule;