"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.calculateRuleSourceFromAsset = void 0;
var _calculate_is_customized = require("../detection_rules_client/mergers/rule_source/calculate_is_customized");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Calculates rule_source for a rule based on two pieces of information:
 * 1. The prebuilt rule asset that matches the specified rule_id and version
 * 2. Whether a prebuilt rule with the specified rule_id is currently installed
 *
 * @param rule The rule for which rule_source is being calculated
 * @param assetWithMatchingVersion The prebuilt rule asset that matches the specified rule_id and version
 * @param isKnownPrebuiltRule Whether a prebuilt rule with the specified rule_id is currently installed
 *
 * @returns The calculated rule_source
 */
const calculateRuleSourceFromAsset = ({
  rule,
  assetWithMatchingVersion,
  isKnownPrebuiltRule,
  isRuleCustomizationEnabled
}) => {
  if (!isKnownPrebuiltRule) {
    return {
      type: 'internal'
    };
  }
  if (assetWithMatchingVersion == null) {
    return {
      type: 'external',
      is_customized: isRuleCustomizationEnabled ? true : false
    };
  }
  const isCustomized = (0, _calculate_is_customized.calculateIsCustomized)({
    baseRule: assetWithMatchingVersion,
    nextRule: rule,
    isRuleCustomizationEnabled
  });
  return {
    type: 'external',
    is_customized: isCustomized
  };
};
exports.calculateRuleSourceFromAsset = calculateRuleSourceFromAsset;