"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.importRulesLegacy = void 0;
var _i18n = require("@kbn/i18n");
var _utils = require("../../../routes/utils");
var _check_rule_exception_references = require("./check_rule_exception_references");
var _gather_referenced_exceptions = require("./gather_referenced_exceptions");
var _errors = require("./errors");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Takes rules to be imported and either creates or updates rules
 * based on user overwrite preferences.
 *
 * @deprecated Use {@link importRules} instead.
 * @param ruleChunks {@link RuleToImport} - rules being imported
 * @param overwriteRules {boolean} - whether to overwrite existing rules
 * with imported rules if their rule_id matches
 * @param detectionRulesClient {object}
 * @returns {Promise} an array of error and success messages from import
 */
const importRulesLegacy = async ({
  ruleChunks,
  overwriteRules,
  detectionRulesClient,
  allowMissingConnectorSecrets,
  savedObjectsClient
}) => {
  const response = [];
  if (ruleChunks.length === 0) {
    return response;
  }
  while (ruleChunks.length) {
    var _ruleChunks$shift;
    const batchParseObjects = (_ruleChunks$shift = ruleChunks.shift()) !== null && _ruleChunks$shift !== void 0 ? _ruleChunks$shift : [];
    const existingLists = await (0, _gather_referenced_exceptions.getReferencedExceptionLists)({
      rules: batchParseObjects,
      savedObjectsClient
    });
    const newImportRuleResponse = await Promise.all(batchParseObjects.reduce((accum, parsedRule) => {
      const importsWorkerPromise = new Promise(async (resolve, reject) => {
        try {
          if (parsedRule.immutable) {
            resolve((0, _utils.createBulkErrorObject)({
              statusCode: 400,
              message: _i18n.i18n.translate('xpack.securitySolution.detectionEngine.rules.importPrebuiltRulesUnsupported', {
                defaultMessage: 'Importing prebuilt rules is not supported. To import this rule as a custom rule, first duplicate the rule and then export it. [rule_id: {ruleId}]',
                values: {
                  ruleId: parsedRule.rule_id
                }
              }),
              ruleId: parsedRule.rule_id
            }));
            return null;
          }
          try {
            const [exceptionErrors, exceptions] = (0, _check_rule_exception_references.checkRuleExceptionReferences)({
              rule: parsedRule,
              existingLists
            });
            const exceptionBulkErrors = exceptionErrors.map(error => (0, _utils.createBulkErrorObject)({
              ruleId: error.error.ruleId,
              statusCode: 400,
              message: error.error.message
            }));
            response.push(...exceptionBulkErrors);
            const importedRule = await detectionRulesClient.importRule({
              ruleToImport: {
                ...parsedRule,
                exceptions_list: [...exceptions]
              },
              overwriteRules,
              allowMissingConnectorSecrets
            });
            resolve({
              rule_id: importedRule.rule_id,
              status_code: 200
            });
          } catch (err) {
            var _ref, _ref2;
            const {
              error,
              statusCode,
              message
            } = err;
            if ((0, _errors.isRuleImportError)(err)) {
              resolve((0, _utils.createBulkErrorObject)({
                message: err.error.message,
                statusCode: (0, _errors.isRuleConflictError)(err) ? 409 : 400,
                ruleId: err.error.ruleId
              }));
              return null;
            }
            resolve((0, _utils.createBulkErrorObject)({
              ruleId: parsedRule.rule_id,
              statusCode: (_ref = statusCode !== null && statusCode !== void 0 ? statusCode : error === null || error === void 0 ? void 0 : error.status_code) !== null && _ref !== void 0 ? _ref : 400,
              message: (_ref2 = message !== null && message !== void 0 ? message : error === null || error === void 0 ? void 0 : error.message) !== null && _ref2 !== void 0 ? _ref2 : 'unknown error'
            }));
          }
        } catch (error) {
          reject(error);
        }
      });
      return [...accum, importsWorkerPromise];
    }, []));
    response.push(...newImportRuleResponse);
  }
  return response;
};
exports.importRulesLegacy = importRulesLegacy;