"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AssetCriticalityEcsMigrationClient = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _asset_criticality_data_client = require("./asset_criticality_data_client");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ECS_MAPPINGS_MIGRATION_QUERY = {
  bool: {
    must_not: {
      exists: {
        field: 'asset.criticality'
      }
    }
  }
};
const PAINLESS_SCRIPT = `
Map asset = new HashMap();
asset.put('criticality', ctx._source.criticality_level);
ctx._source.asset = asset;
if (ctx._source.id_field == 'user.name') {
  Map user = new HashMap();
  user.put('name', ctx._source.id_value);
  user.put('asset', asset);
  ctx._source.user = user;
} else {
  Map host = new HashMap();
  host.put('name', ctx._source.id_value);
  host.put('asset', asset);
  ctx._source.host = host;
}`;
class AssetCriticalityEcsMigrationClient {
  constructor(options) {
    (0, _defineProperty2.default)(this, "assetCriticalityDataClient", void 0);
    (0, _defineProperty2.default)(this, "isEcsMappingsMigrationRequired", async () => {
      const indicesMappings = await this.assetCriticalityDataClient.getIndexMappings();
      return Object.values(indicesMappings).some(({
        mappings
      }) => {
        var _mappings$properties;
        return (mappings === null || mappings === void 0 ? void 0 : (_mappings$properties = mappings.properties) === null || _mappings$properties === void 0 ? void 0 : _mappings$properties.asset) === undefined;
      });
    });
    (0, _defineProperty2.default)(this, "isEcsDataMigrationRequired", async () => {
      const resp = await this.assetCriticalityDataClient.search({
        query: ECS_MAPPINGS_MIGRATION_QUERY,
        size: 1
      });
      return resp.hits.hits.length > 0;
    });
    (0, _defineProperty2.default)(this, "migrateEcsMappings", () => {
      return this.assetCriticalityDataClient.createOrUpdateIndex();
    });
    (0, _defineProperty2.default)(this, "migrateEcsData", abortSignal => {
      return this.options.esClient.updateByQuery({
        index: this.assetCriticalityDataClient.getIndex(),
        conflicts: 'proceed',
        ignore_unavailable: true,
        allow_no_indices: true,
        scroll_size: 10000,
        body: {
          query: ECS_MAPPINGS_MIGRATION_QUERY,
          script: {
            source: PAINLESS_SCRIPT,
            lang: 'painless'
          }
        }
      }, {
        requestTimeout: '5m',
        retryOnTimeout: true,
        maxRetries: 2,
        signal: abortSignal
      });
    });
    this.options = options;
    this.assetCriticalityDataClient = new _asset_criticality_data_client.AssetCriticalityDataClient({
      ...options,
      namespace: '*' // The migration is applied to all spaces
    });
  }
}
exports.AssetCriticalityEcsMigrationClient = AssetCriticalityEcsMigrationClient;