"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.preferNewestValueProcessor = void 0;
var _painless = require("../painless");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * A field retention operator that prefers the newest value of the specified field.
 * If the field is missing or empty, the value from the enrich field is used.
 */
const preferNewestValueProcessor = ({
  field
}, {
  enrichField
}) => {
  const latestField = `ctx.${field}`;
  const historicalField = `${enrichField}.${field}`;
  return {
    set: {
      if: `(${(0, _painless.isFieldMissingOrEmpty)(latestField)}) && !(${(0, _painless.isFieldMissingOrEmpty)(`ctx.${historicalField}`)})`,
      field,
      value: `{{${historicalField}}}`
    }
  };
};
exports.preferNewestValueProcessor = preferNewestValueProcessor;