"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.oldestValue = exports.newestValue = exports.collectValuesWithLength = exports.collectValues = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const collectValues = ({
  field,
  mapping = {
    type: 'keyword'
  },
  sourceField,
  fieldHistoryLength
}) => ({
  field,
  definition: {
    source: sourceField !== null && sourceField !== void 0 ? sourceField : field,
    destination: field,
    aggregation: {
      type: 'terms',
      limit: fieldHistoryLength
    }
  },
  retention_operator: {
    operation: 'collect_values',
    field,
    maxLength: fieldHistoryLength
  },
  mapping
});
exports.collectValues = collectValues;
const collectValuesWithLength = fieldHistoryLength => opts => collectValues({
  ...opts,
  fieldHistoryLength
});
exports.collectValuesWithLength = collectValuesWithLength;
const newestValue = ({
  field,
  mapping = {
    type: 'keyword'
  },
  sourceField
}) => ({
  field,
  definition: {
    source: sourceField !== null && sourceField !== void 0 ? sourceField : field,
    destination: field,
    aggregation: {
      type: 'top_value',
      sort: {
        '@timestamp': 'desc'
      }
    }
  },
  retention_operator: {
    operation: 'prefer_newest_value',
    field
  },
  mapping
});
exports.newestValue = newestValue;
const oldestValue = ({
  field,
  mapping = {
    type: 'keyword'
  },
  sourceField
}) => ({
  field,
  definition: {
    source: sourceField !== null && sourceField !== void 0 ? sourceField : field,
    destination: field,
    aggregation: {
      type: 'top_value',
      sort: {
        '@timestamp': 'asc'
      }
    }
  },
  retention_operator: {
    operation: 'prefer_oldest_value',
    field
  },
  mapping
});
exports.oldestValue = oldestValue;