"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUnitedEntityDefinitionVersion = exports.getUnitedEntityDefinition = exports.getAvailableEntityTypes = void 0;
var _lodash = require("lodash");
var _entity_types = require("./entity_types");
var _united_entity_definition = require("./united_entity_definition");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const unitedDefinitionBuilders = {
  host: _entity_types.getHostUnitedDefinition,
  user: _entity_types.getUserUnitedDefinition
};
const getUnitedEntityDefinition = exports.getUnitedEntityDefinition = (0, _lodash.memoize)(({
  entityType,
  namespace,
  fieldHistoryLength,
  indexPatterns,
  syncDelay,
  frequency
}) => {
  const unitedDefinition = unitedDefinitionBuilders[entityType](fieldHistoryLength);
  unitedDefinition.fields.push(...(0, _entity_types.getCommonUnitedFieldDefinitions)({
    entityType,
    fieldHistoryLength
  }));
  return new _united_entity_definition.UnitedEntityDefinition({
    ...unitedDefinition,
    namespace,
    indexPatterns,
    syncDelay,
    frequency
  });
});
const getUnitedEntityDefinitionVersion = entityType => entityType === 'host' ? _entity_types.HOST_DEFINITION_VERSION : _entity_types.USER_DEFINITION_VERSION;
exports.getUnitedEntityDefinitionVersion = getUnitedEntityDefinitionVersion;
const getAvailableEntityTypes = () => Object.keys(unitedDefinitionBuilders);
exports.getAvailableEntityTypes = getAvailableEntityTypes;