"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UnitedEntityDefinition = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _entitiesSchema = require("@kbn/entities-schema");
var _constants = require("../constants");
var _utils = require("../utils");
var _constants2 = require("./constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

class UnitedEntityDefinition {
  constructor(opts) {
    (0, _defineProperty2.default)(this, "version", void 0);
    (0, _defineProperty2.default)(this, "entityType", void 0);
    (0, _defineProperty2.default)(this, "indexPatterns", void 0);
    (0, _defineProperty2.default)(this, "fields", void 0);
    (0, _defineProperty2.default)(this, "namespace", void 0);
    (0, _defineProperty2.default)(this, "entityManagerDefinition", void 0);
    (0, _defineProperty2.default)(this, "fieldRetentionDefinition", void 0);
    (0, _defineProperty2.default)(this, "indexMappings", void 0);
    (0, _defineProperty2.default)(this, "syncDelay", void 0);
    (0, _defineProperty2.default)(this, "frequency", void 0);
    this.version = opts.version;
    this.entityType = opts.entityType;
    this.indexPatterns = opts.indexPatterns;
    this.fields = opts.fields;
    this.frequency = opts.frequency;
    this.syncDelay = opts.syncDelay;
    this.namespace = opts.namespace;
    this.entityManagerDefinition = this.toEntityManagerDefinition();
    this.fieldRetentionDefinition = this.toFieldRetentionDefinition();
    this.indexMappings = this.toIndexMappings();
  }
  toEntityManagerDefinition() {
    const {
      entityType,
      namespace,
      indexPatterns,
      syncDelay,
      frequency
    } = this;
    const identityField = (0, _utils.getIdentityFieldForEntityType)(this.entityType);
    const metadata = this.fields.filter(field => field.definition).map(field => field.definition); // eslint-disable-line @typescript-eslint/no-non-null-assertion

    return _entitiesSchema.entityDefinitionSchema.parse({
      id: (0, _utils.buildEntityDefinitionId)(entityType, namespace),
      name: `Security '${entityType}' Entity Store Definition`,
      type: entityType,
      indexPatterns,
      identityFields: [identityField],
      displayNameTemplate: `{{${identityField}}}`,
      metadata,
      latest: {
        timestampField: '@timestamp',
        lookbackPeriod: _constants.DEFAULT_LOOKBACK_PERIOD,
        settings: {
          syncDelay,
          frequency
        }
      },
      version: this.version,
      managed: true
    });
  }
  toFieldRetentionDefinition() {
    return {
      entityType: this.entityType,
      matchField: (0, _utils.getIdentityFieldForEntityType)(this.entityType),
      fields: this.fields.filter(field => field.retention_operator !== undefined).map(field => field.retention_operator)
    };
  }
  toIndexMappings() {
    const identityField = (0, _utils.getIdentityFieldForEntityType)(this.entityType);
    const initialMappings = {
      ..._constants2.BASE_ENTITY_INDEX_MAPPING,
      [identityField]: {
        type: 'keyword',
        fields: {
          text: {
            type: 'match_only_text'
          }
        }
      }
    };
    const properties = this.fields.reduce((acc, {
      field,
      mapping
    }) => {
      if (!mapping) {
        return acc;
      }
      acc[field] = mapping;
      return acc;
    }, initialMappings);
    properties[identityField] = {
      type: 'keyword',
      fields: {
        text: {
          type: 'match_only_text'
        }
      }
    };
    return {
      properties
    };
  }
}
exports.UnitedEntityDefinition = UnitedEntityDefinition;