"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isPromiseRejected = exports.isPromiseFulfilled = exports.getIdentityFieldForEntityType = exports.getEntitiesIndexName = exports.getByEntityTypeQuery = exports.buildIndexPatterns = exports.buildEntityDefinitionId = void 0;
var _entitiesSchema = require("@kbn/entities-schema");
var _risk_engine = require("../../../../../common/entity_analytics/risk_engine");
var _asset_criticality = require("../../../../../common/entity_analytics/asset_criticality");
var _saved_object = require("../saved_object");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getIdentityFieldForEntityType = entityType => {
  if (entityType === 'host') return 'host.name';
  return 'user.name';
};
exports.getIdentityFieldForEntityType = getIdentityFieldForEntityType;
const buildIndexPatterns = async (space, appClient, dataViewsService) => {
  const {
    alertsIndex,
    securitySolutionDataViewIndices
  } = await getSecuritySolutionIndices(appClient, dataViewsService);
  return [...securitySolutionDataViewIndices.filter(item => item !== alertsIndex), (0, _asset_criticality.getAssetCriticalityIndex)(space), (0, _risk_engine.getRiskScoreLatestIndex)(space)];
};
exports.buildIndexPatterns = buildIndexPatterns;
const getSecuritySolutionIndices = async (appClient, dataViewsService) => {
  const securitySolutionDataViewId = appClient.getSourcererDataViewId();
  let dataView;
  try {
    dataView = await dataViewsService.get(securitySolutionDataViewId);
  } catch (e) {
    if (e.isBoom && e.output.statusCode === 404) {
      throw new Error(`Data view not found '${securitySolutionDataViewId}'`);
    }
    throw e;
  }
  const dataViewIndexPattern = dataView.getIndexPattern();
  return {
    securitySolutionDataViewIndices: dataViewIndexPattern.split(','),
    alertsIndex: appClient.getAlertsIndex()
  };
};
const getByEntityTypeQuery = entityType => {
  return `${_saved_object.entityEngineDescriptorTypeName}.attributes.type: ${entityType}`;
};
exports.getByEntityTypeQuery = getByEntityTypeQuery;
const getEntitiesIndexName = (entityType, namespace) => (0, _entitiesSchema.entitiesIndexPattern)({
  schemaVersion: _entitiesSchema.ENTITY_SCHEMA_VERSION_V1,
  dataset: _entitiesSchema.ENTITY_LATEST,
  definitionId: buildEntityDefinitionId(entityType, namespace)
});
exports.getEntitiesIndexName = getEntitiesIndexName;
const buildEntityDefinitionId = (entityType, space) => {
  return `security_${entityType}_${space}`;
};
exports.buildEntityDefinitionId = buildEntityDefinitionId;
const isPromiseFulfilled = result => result.status === 'fulfilled';
exports.isPromiseFulfilled = isPromiseFulfilled;
const isPromiseRejected = result => result.status === 'rejected';
exports.isPromiseRejected = isPromiseRejected;