"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getEntityStorePrivileges = void 0;
var _saved_objects = require("@kbn/entityManager-plugin/server/saved_objects");
var _constants = require("../../../../../common/constants");
var _constants2 = require("../../../../../common/entity_analytics/entity_store/constants");
var _check_and_format_privileges = require("../../utils/check_and_format_privileges");
var _saved_object = require("../saved_object");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getEntityStorePrivileges = (request, security, securitySolutionIndices) => {
  // The entity store needs access to all security solution indices
  const indicesPrivileges = securitySolutionIndices.reduce((acc, index) => {
    acc[index] = ['read', 'view_index_metadata'];
    return acc;
  }, {});

  // The entity store has to create the following indices
  indicesPrivileges[_constants2.ENTITY_STORE_INDEX_PATTERN] = ['read', 'manage'];
  indicesPrivileges[_constants.RISK_SCORE_INDEX_PATTERN] = ['read', 'manage'];
  return (0, _check_and_format_privileges.checkAndFormatPrivileges)({
    request,
    security,
    privilegesToCheck: {
      kibana: [security.authz.actions.savedObject.get(_saved_object.entityEngineDescriptorTypeName, 'create'), security.authz.actions.savedObject.get(_saved_objects.SO_ENTITY_DEFINITION_TYPE, 'create')],
      elasticsearch: {
        cluster: _constants2.ENTITY_STORE_REQUIRED_ES_CLUSTER_PRIVILEGES,
        index: indicesPrivileges
      }
    }
  });
};
exports.getEntityStorePrivileges = getEntityStorePrivileges;