"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerSiemRuleMigrationsCreateRoute = void 0;
var _zodHelpers = require("@kbn/zod-helpers");
var _uuid = require("uuid");
var _rule_migration = require("../../../../../common/siem_migrations/model/api/rules/rule_migration.gen");
var _constants = require("../../../../../common/siem_migrations/constants");
var _with_license = require("./util/with_license");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const registerSiemRuleMigrationsCreateRoute = (router, logger) => {
  router.versioned.post({
    path: _constants.SIEM_RULE_MIGRATIONS_PATH,
    access: 'internal',
    security: {
      authz: {
        requiredPrivileges: ['securitySolution']
      }
    }
  }).addVersion({
    version: '1',
    validate: {
      request: {
        body: (0, _zodHelpers.buildRouteValidationWithZod)(_rule_migration.CreateRuleMigrationRequestBody)
      }
    }
  }, (0, _with_license.withLicense)(async (context, req, res) => {
    const originalRules = req.body;
    try {
      const ctx = await context.resolve(['securitySolution']);
      const ruleMigrationsClient = ctx.securitySolution.getSiemRuleMigrationsClient();
      const migrationId = (0, _uuid.v4)();
      const ruleMigrations = originalRules.map(originalRule => ({
        migration_id: migrationId,
        original_rule: originalRule
      }));
      await ruleMigrationsClient.data.rules.create(ruleMigrations);
      return res.ok({
        body: {
          migration_id: migrationId
        }
      });
    } catch (err) {
      logger.error(err);
      return res.badRequest({
        body: err.message
      });
    }
  }));
};
exports.registerSiemRuleMigrationsCreateRoute = registerSiemRuleMigrationsCreateRoute;