"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerSiemRuleMigrationsResourceUpsertRoute = void 0;
var _zodHelpers = require("@kbn/zod-helpers");
var _rule_migration = require("../../../../../../common/siem_migrations/model/api/rules/rule_migration.gen");
var _constants = require("../../../../../../common/siem_migrations/constants");
var _with_license = require("../util/with_license");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const registerSiemRuleMigrationsResourceUpsertRoute = (router, logger) => {
  router.versioned.post({
    path: _constants.SIEM_RULE_MIGRATION_RESOURCES_PATH,
    access: 'internal',
    security: {
      authz: {
        requiredPrivileges: ['securitySolution']
      }
    }
  }).addVersion({
    version: '1',
    validate: {
      request: {
        params: (0, _zodHelpers.buildRouteValidationWithZod)(_rule_migration.UpsertRuleMigrationResourcesRequestParams),
        body: (0, _zodHelpers.buildRouteValidationWithZod)(_rule_migration.UpsertRuleMigrationResourcesRequestBody)
      }
    }
  }, (0, _with_license.withLicense)(async (context, req, res) => {
    const resources = req.body;
    const migrationId = req.params.migration_id;
    try {
      const ctx = await context.resolve(['securitySolution']);
      const ruleMigrationsClient = ctx.securitySolution.getSiemRuleMigrationsClient();
      const ruleMigrations = resources.map(resource => ({
        migration_id: migrationId,
        ...resource
      }));
      await ruleMigrationsClient.data.resources.upsert(ruleMigrations);
      return res.ok({
        body: {
          acknowledged: true
        }
      });
    } catch (err) {
      logger.error(err);
      return res.badRequest({
        body: err.message
      });
    }
  }));
};
exports.registerSiemRuleMigrationsResourceUpsertRoute = registerSiemRuleMigrationsResourceUpsertRoute;