"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerSiemRuleMigrationsStartRoute = void 0;
var _zodHelpers = require("@kbn/zod-helpers");
var _apm = require("@kbn/langchain/server/tracers/apm");
var _langsmith = require("@kbn/langchain/server/tracers/langsmith");
var _rule_migration = require("../../../../../common/siem_migrations/model/api/rules/rule_migration.gen");
var _constants = require("../../../../../common/siem_migrations/constants");
var _with_license = require("./util/with_license");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const registerSiemRuleMigrationsStartRoute = (router, logger) => {
  router.versioned.put({
    path: _constants.SIEM_RULE_MIGRATION_START_PATH,
    access: 'internal',
    security: {
      authz: {
        requiredPrivileges: ['securitySolution']
      }
    }
  }).addVersion({
    version: '1',
    validate: {
      request: {
        params: (0, _zodHelpers.buildRouteValidationWithZod)(_rule_migration.StartRuleMigrationRequestParams),
        body: (0, _zodHelpers.buildRouteValidationWithZod)(_rule_migration.StartRuleMigrationRequestBody)
      }
    }
  }, (0, _with_license.withLicense)(async (context, req, res) => {
    const migrationId = req.params.migration_id;
    const {
      langsmith_options: langsmithOptions,
      connector_id: connectorId
    } = req.body;
    try {
      var _langsmithOptions$pro;
      const ctx = await context.resolve(['core', 'actions', 'alerting', 'securitySolution']);
      const ruleMigrationsClient = ctx.securitySolution.getSiemRuleMigrationsClient();
      const inferenceClient = ctx.securitySolution.getInferenceClient();
      const actionsClient = ctx.actions.getActionsClient();
      const soClient = ctx.core.savedObjects.client;
      const rulesClient = ctx.alerting.getRulesClient();
      const invocationConfig = {
        callbacks: [new _apm.APMTracer({
          projectName: (_langsmithOptions$pro = langsmithOptions === null || langsmithOptions === void 0 ? void 0 : langsmithOptions.project_name) !== null && _langsmithOptions$pro !== void 0 ? _langsmithOptions$pro : 'default'
        }, logger), ...(0, _langsmith.getLangSmithTracer)({
          ...langsmithOptions,
          logger
        })]
      };
      const {
        exists,
        started
      } = await ruleMigrationsClient.task.start({
        migrationId,
        connectorId,
        invocationConfig,
        inferenceClient,
        actionsClient,
        soClient,
        rulesClient
      });
      if (!exists) {
        return res.noContent();
      }
      return res.ok({
        body: {
          started
        }
      });
    } catch (err) {
      logger.error(err);
      return res.badRequest({
        body: err.message
      });
    }
  }));
};
exports.registerSiemRuleMigrationsStartRoute = registerSiemRuleMigrationsStartRoute;