"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerSiemRuleMigrationsStopRoute = void 0;
var _zodHelpers = require("@kbn/zod-helpers");
var _rule_migration = require("../../../../../common/siem_migrations/model/api/rules/rule_migration.gen");
var _constants = require("../../../../../common/siem_migrations/constants");
var _with_license = require("./util/with_license");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const registerSiemRuleMigrationsStopRoute = (router, logger) => {
  router.versioned.put({
    path: _constants.SIEM_RULE_MIGRATION_STOP_PATH,
    access: 'internal',
    security: {
      authz: {
        requiredPrivileges: ['securitySolution']
      }
    }
  }).addVersion({
    version: '1',
    validate: {
      request: {
        params: (0, _zodHelpers.buildRouteValidationWithZod)(_rule_migration.StopRuleMigrationRequestParams)
      }
    }
  }, (0, _with_license.withLicense)(async (context, req, res) => {
    const migrationId = req.params.migration_id;
    try {
      const ctx = await context.resolve(['securitySolution']);
      const ruleMigrationsClient = ctx.securitySolution.getSiemRuleMigrationsClient();
      const {
        exists,
        stopped
      } = await ruleMigrationsClient.task.stop(migrationId);
      if (!exists) {
        return res.noContent();
      }
      return res.ok({
        body: {
          stopped
        }
      });
    } catch (err) {
      logger.error(err);
      return res.badRequest({
        body: err.message
      });
    }
  }));
};
exports.registerSiemRuleMigrationsStopRoute = registerSiemRuleMigrationsStopRoute;