"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleMigrationsDataResourcesClient = void 0;
var _jsSha = require("js-sha256");
var _rule_migrations_data_base_client = require("./rule_migrations_data_base_client");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/* BULK_MAX_SIZE defines the number to break down the bulk operations by.
 * The 500 number was chosen as a reasonable number to avoid large payloads. It can be adjusted if needed.
 */
const BULK_MAX_SIZE = 500;
class RuleMigrationsDataResourcesClient extends _rule_migrations_data_base_client.RuleMigrationsDataBaseClient {
  async upsert(resources) {
    const index = await this.getIndexName();
    let resourcesSlice;
    while ((resourcesSlice = resources.splice(0, BULK_MAX_SIZE)).length > 0) {
      await this.esClient.bulk({
        refresh: 'wait_for',
        operations: resourcesSlice.flatMap(resource => [{
          update: {
            _id: this.createId(resource),
            _index: index
          }
        }, {
          doc: resource,
          doc_as_upsert: true
        }])
      }).catch(error => {
        this.logger.error(`Error upsert resources: ${error.message}`);
        throw error;
      });
    }
  }
  async get(migrationId, type, names) {
    const index = await this.getIndexName();
    const filter = [{
      term: {
        migration_id: migrationId
      }
    }];
    if (type) {
      filter.push({
        term: {
          type
        }
      });
    }
    if (names) {
      filter.push({
        terms: {
          name: names
        }
      });
    }
    const query = {
      bool: {
        filter
      }
    };
    return this.esClient.search({
      index,
      query
    }).then(this.processResponseHits.bind(this)).catch(error => {
      this.logger.error(`Error searching resources: ${error.message}`);
      throw error;
    });
  }
  createId(resource) {
    const key = `${resource.migration_id}-${resource.type}-${resource.name}`;
    return _jsSha.sha256.create().update(key).hex();
  }
}
exports.RuleMigrationsDataResourcesClient = RuleMigrationsDataResourcesClient;