"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleMigrationsDataService = exports.INDEX_PATTERN = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _indexAdapter = require("@kbn/index-adapter");
var _rule_migrations_field_maps = require("./rule_migrations_field_maps");
var _rule_migrations_data_client = require("./rule_migrations_data_client");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const TOTAL_FIELDS_LIMIT = 2500;
const INDEX_PATTERN = exports.INDEX_PATTERN = '.kibana-siem-rule-migrations';
class RuleMigrationsDataService {
  constructor(logger, kibanaVersion) {
    (0, _defineProperty2.default)(this, "adapters", void 0);
    this.logger = logger;
    this.kibanaVersion = kibanaVersion;
    this.adapters = {
      rules: this.createAdapter({
        id: 'rules',
        fieldMap: _rule_migrations_field_maps.ruleMigrationsFieldMap
      }),
      resources: this.createAdapter({
        id: 'resources',
        fieldMap: _rule_migrations_field_maps.ruleMigrationResourcesFieldMap
      })
    };
  }
  createAdapter({
    id,
    fieldMap
  }) {
    const name = `${INDEX_PATTERN}-${id}`;
    const adapter = new _indexAdapter.IndexPatternAdapter(name, {
      kibanaVersion: this.kibanaVersion,
      totalFieldsLimit: TOTAL_FIELDS_LIMIT
    });
    adapter.setComponentTemplate({
      name,
      fieldMap
    });
    adapter.setIndexTemplate({
      name,
      componentTemplateRefs: [name]
    });
    return adapter;
  }
  async install(params) {
    await Promise.all([this.adapters.rules.install({
      ...params,
      logger: this.logger
    }), this.adapters.resources.install({
      ...params,
      logger: this.logger
    })]);
  }
  createClient({
    spaceId,
    currentUser,
    esClient
  }) {
    const indexNameProviders = {
      rules: this.createIndexNameProvider('rules', spaceId),
      resources: this.createIndexNameProvider('resources', spaceId)
    };
    return new _rule_migrations_data_client.RuleMigrationsDataClient(indexNameProviders, currentUser.username, esClient, this.logger);
  }
  createIndexNameProvider(adapter, spaceId) {
    return async () => {
      await this.adapters[adapter].createIndex(spaceId); // This will resolve instantly when the index is already created
      return this.adapters[adapter].getIndexName(spaceId);
    };
  }
}
exports.RuleMigrationsDataService = RuleMigrationsDataService;