"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRuleMigrationAgent = getRuleMigrationAgent;
var _langgraph = require("@langchain/langgraph");
var _state = require("./state");
var _translate_query = require("./nodes/translate_query");
var _match_prebuilt_rule = require("./nodes/match_prebuilt_rule");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function getRuleMigrationAgent({
  model,
  inferenceClient,
  prebuiltRulesMap,
  resourceRetriever,
  connectorId,
  logger
}) {
  const matchPrebuiltRuleNode = (0, _match_prebuilt_rule.getMatchPrebuiltRuleNode)({
    model,
    prebuiltRulesMap,
    logger
  });
  const translationNode = (0, _translate_query.getTranslateQueryNode)({
    model,
    inferenceClient,
    resourceRetriever,
    connectorId,
    logger
  });
  const translateRuleGraph = new _langgraph.StateGraph(_state.migrateRuleState)
  // Nodes
  .addNode('matchPrebuiltRule', matchPrebuiltRuleNode).addNode('translation', translationNode)
  // Edges
  .addEdge(_langgraph.START, 'matchPrebuiltRule').addConditionalEdges('matchPrebuiltRule', matchedPrebuiltRuleConditional).addEdge('translation', _langgraph.END);
  const graph = translateRuleGraph.compile();
  graph.name = 'Rule Migration Graph'; // Customizes the name displayed in LangSmith
  return graph;
}
const matchedPrebuiltRuleConditional = state => {
  var _state$elastic_rule;
  if ((_state$elastic_rule = state.elastic_rule) !== null && _state$elastic_rule !== void 0 && _state$elastic_rule.prebuilt_rule_id) {
    return _langgraph.END;
  }
  return 'translation';
};