"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMatchPrebuiltRuleNode = void 0;
var _output_parsers = require("@langchain/core/output_parsers");
var _prebuilt_rules = require("../../../util/prebuilt_rules");
var _prompts = require("./prompts");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getMatchPrebuiltRuleNode = ({
  model,
  prebuiltRulesMap
}) => async state => {
  const mitreAttackIds = state.original_rule.mitre_attack_ids;
  if (!(mitreAttackIds !== null && mitreAttackIds !== void 0 && mitreAttackIds.length)) {
    return {};
  }
  const filteredPrebuiltRulesMap = (0, _prebuilt_rules.filterPrebuiltRules)(prebuiltRulesMap, mitreAttackIds);
  if (filteredPrebuiltRulesMap.size === 0) {
    return {};
  }
  const outputParser = new _output_parsers.StringOutputParser();
  const matchPrebuiltRule = _prompts.MATCH_PREBUILT_RULE_PROMPT.pipe(model).pipe(outputParser);
  const elasticSecurityRules = Array(filteredPrebuiltRulesMap.keys()).join('\n');
  const response = await matchPrebuiltRule.invoke({
    elasticSecurityRules,
    ruleTitle: state.original_rule.title
  });
  const cleanResponse = response.trim();
  if (cleanResponse === 'no_match') {
    return {};
  }
  const result = filteredPrebuiltRulesMap.get(cleanResponse);
  if (result != null) {
    return {
      elastic_rule: {
        title: result.rule.name,
        description: result.rule.description,
        prebuilt_rule_id: result.rule.rule_id,
        id: result.installedRuleId
      }
    };
  }
  return {};
};
exports.getMatchPrebuiltRuleNode = getMatchPrebuiltRuleNode;