"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTranslateQueryNode = void 0;
var _output_parsers = require("@langchain/core/output_parsers");
var _fp = require("lodash/fp");
var _esql_knowledge_base_caller = require("./esql_knowledge_base_caller");
var _replace_resources_prompt = require("./prompts/replace_resources_prompt");
var _esql_translation_prompt = require("./prompts/esql_translation_prompt");
var _constants = require("../../../../../../../../common/siem_migrations/constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getTranslateQueryNode = ({
  model,
  inferenceClient,
  resourceRetriever,
  connectorId,
  logger
}) => {
  const esqlKnowledgeBaseCaller = (0, _esql_knowledge_base_caller.getEsqlKnowledgeBase)({
    inferenceClient,
    connectorId,
    logger
  });
  return async state => {
    var _response$match$, _response$match, _response$match$2, _response$match2;
    let query = state.original_rule.query;
    const resources = await resourceRetriever.getResources(state.original_rule);
    if (!(0, _fp.isEmpty)(resources)) {
      const replaceQueryResourcesPrompt = (0, _replace_resources_prompt.getReplaceQueryResourcesPrompt)(state, resources);
      const stringParser = new _output_parsers.StringOutputParser();
      query = await model.pipe(stringParser).invoke(replaceQueryResourcesPrompt);
    }
    const prompt = (0, _esql_translation_prompt.getEsqlTranslationPrompt)(state, query);
    const response = await esqlKnowledgeBaseCaller(prompt);
    const esqlQuery = (_response$match$ = (_response$match = response.match(/```esql\n([\s\S]*?)\n```/)) === null || _response$match === void 0 ? void 0 : _response$match[1]) !== null && _response$match$ !== void 0 ? _response$match$ : '';
    const summary = (_response$match$2 = (_response$match2 = response.match(/## Migration Summary[\s\S]*$/)) === null || _response$match2 === void 0 ? void 0 : _response$match2[0]) !== null && _response$match$2 !== void 0 ? _response$match$2 : '';
    const translationResult = getTranslationResult(esqlQuery);
    return {
      response,
      comments: [summary],
      translation_result: translationResult,
      elastic_rule: {
        title: state.original_rule.title,
        description: state.original_rule.description,
        severity: 'low',
        query: esqlQuery,
        query_language: 'esql'
      }
    };
  };
};
exports.getTranslateQueryNode = getTranslateQueryNode;
const getTranslationResult = esqlQuery => {
  if (esqlQuery.match(/\[(macro|lookup):[\s\S]*\]/)) {
    return _constants.SiemMigrationRuleTranslationResult.PARTIAL;
  }
  return _constants.SiemMigrationRuleTranslationResult.FULL;
};