"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.retrievePrebuiltRulesMap = exports.filterPrebuiltRules = void 0;
var _fetch_rule_versions_triad = require("../../../../detection_engine/prebuilt_rules/logic/rule_versions/fetch_rule_versions_triad");
var _prebuilt_rule_objects_client = require("../../../../detection_engine/prebuilt_rules/logic/rule_objects/prebuilt_rule_objects_client");
var _prebuilt_rule_assets_client = require("../../../../detection_engine/prebuilt_rules/logic/rule_assets/prebuilt_rule_assets_client");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const retrievePrebuiltRulesMap = async ({
  soClient,
  rulesClient
}) => {
  const ruleAssetsClient = (0, _prebuilt_rule_assets_client.createPrebuiltRuleAssetsClient)(soClient);
  const ruleObjectsClient = (0, _prebuilt_rule_objects_client.createPrebuiltRuleObjectsClient)(rulesClient);
  const prebuiltRulesMap = await (0, _fetch_rule_versions_triad.fetchRuleVersionsTriad)({
    ruleAssetsClient,
    ruleObjectsClient
  });
  const prebuiltRulesByName = new Map();
  prebuiltRulesMap.forEach(ruleVersions => {
    const rule = ruleVersions.target || ruleVersions.current;
    if (rule) {
      var _ruleVersions$current;
      prebuiltRulesByName.set(rule.name, {
        rule,
        installedRuleId: (_ruleVersions$current = ruleVersions.current) === null || _ruleVersions$current === void 0 ? void 0 : _ruleVersions$current.id
      });
    }
  });
  return prebuiltRulesByName;
};
exports.retrievePrebuiltRulesMap = retrievePrebuiltRulesMap;
const filterPrebuiltRules = (prebuiltRulesByName, mitreAttackIds) => {
  const filteredPrebuiltRulesByName = new Map();
  if (mitreAttackIds !== null && mitreAttackIds !== void 0 && mitreAttackIds.length) {
    // If this rule has MITRE ATT&CK IDs, remove unrelated prebuilt rules
    prebuiltRulesByName.forEach(({
      rule
    }, ruleName) => {
      var _rule$threat;
      const mitreAttackThreat = (_rule$threat = rule.threat) === null || _rule$threat === void 0 ? void 0 : _rule$threat.filter(({
        framework
      }) => framework === 'MITRE ATT&CK');
      if (!mitreAttackThreat) {
        // If this rule has no MITRE ATT&CK reference we skip it
        return;
      }
      const sameTechnique = mitreAttackThreat.find(threat => {
        var _threat$technique;
        return (_threat$technique = threat.technique) === null || _threat$technique === void 0 ? void 0 : _threat$technique.some(({
          id
        }) => mitreAttackIds === null || mitreAttackIds === void 0 ? void 0 : mitreAttackIds.includes(id));
      });
      if (sameTechnique) {
        filteredPrebuiltRulesByName.set(ruleName, prebuiltRulesByName.get(ruleName));
      }
    });
  }
  return filteredPrebuiltRulesByName;
};
exports.filterPrebuiltRules = filterPrebuiltRules;