"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleResourceRetriever = exports.MAX_RECURSION_DEPTH = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _fp = require("lodash/fp");
var _resources = require("../../../../../../common/siem_migrations/rules/resources");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/* It's not a common practice to have more than 2-3 nested levels of resources.
 * This limit is just to prevent infinite recursion in case something goes wrong.
 */
const MAX_RECURSION_DEPTH = exports.MAX_RECURSION_DEPTH = 30;
class RuleResourceRetriever {
  constructor(migrationId, dataClient) {
    (0, _defineProperty2.default)(this, "recursiveRetriever", async (query, resourceIdentifier, it = 0) => {
      if (it >= MAX_RECURSION_DEPTH) {
        return {};
      }
      const identifiedResources = resourceIdentifier(query);
      const resources = {};
      const listNames = identifiedResources.list;
      if (listNames.length > 0) {
        const listsWithContent = await this.dataClient.resources.get(this.migrationId, 'list', listNames).then(withContent);
        if (listsWithContent.length > 0) {
          resources.list = listsWithContent;
        }
      }
      const macroNames = identifiedResources.macro;
      if (macroNames.length > 0) {
        const macrosWithContent = await this.dataClient.resources.get(this.migrationId, 'macro', macroNames).then(withContent);
        if (macrosWithContent.length > 0) {
          // retrieve nested resources inside macros
          const macrosNestedResources = await Promise.all(macrosWithContent.map(({
            content
          }) => this.recursiveRetriever(content, resourceIdentifier, it + 1)));

          // Process lists inside macros
          const macrosNestedLists = macrosNestedResources.flatMap(macroNestedResources => {
            var _macroNestedResources;
            return (_macroNestedResources = macroNestedResources.list) !== null && _macroNestedResources !== void 0 ? _macroNestedResources : [];
          });
          if (macrosNestedLists.length > 0) {
            var _resources$list;
            resources.list = ((_resources$list = resources.list) !== null && _resources$list !== void 0 ? _resources$list : []).concat(macrosNestedLists);
          }

          // Process macros inside macros
          const macrosNestedMacros = macrosNestedResources.flatMap(macroNestedResources => {
            var _macroNestedResources2;
            return (_macroNestedResources2 = macroNestedResources.macro) !== null && _macroNestedResources2 !== void 0 ? _macroNestedResources2 : [];
          });
          if (macrosNestedMacros.length > 0) {
            macrosWithContent.push(...macrosNestedMacros);
          }
          resources.macro = macrosWithContent;
        }
      }
      return resources;
    });
    this.migrationId = migrationId;
    this.dataClient = dataClient;
  }
  async getResources(originalRule) {
    const resourceIdentifier = (0, _resources.getRuleResourceIdentifier)(originalRule);
    return this.recursiveRetriever(originalRule.query, resourceIdentifier);
  }
}
exports.RuleResourceRetriever = RuleResourceRetriever;
const withContent = resources => {
  return resources.filter(resource => !(0, _fp.isEmpty)(resource.content));
};