"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.events = exports.createAssetCriticalityProcessedFileEvent = exports.RISK_SCORE_EXECUTION_SUCCESS_EVENT = exports.RISK_SCORE_EXECUTION_ERROR_EVENT = exports.RISK_SCORE_EXECUTION_CANCELLATION_EVENT = exports.FIELD_RETENTION_ENRICH_POLICY_EXECUTION_EVENT = exports.ENTITY_STORE_USAGE_EVENT = exports.ENTITY_ENGINE_RESOURCE_INIT_FAILURE_EVENT = exports.ENTITY_ENGINE_INITIALIZATION_EVENT = exports.ENDPOINT_RESPONSE_ACTION_STATUS_CHANGE_EVENT = exports.ENDPOINT_RESPONSE_ACTION_SENT_EVENT = exports.ENDPOINT_RESPONSE_ACTION_SENT_ERROR_EVENT = exports.ASSET_CRITICALITY_SYSTEM_PROCESSED_ASSIGNMENT_FILE_EVENT = exports.ALERT_SUPPRESSION_EVENT = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const RISK_SCORE_EXECUTION_SUCCESS_EVENT = exports.RISK_SCORE_EXECUTION_SUCCESS_EVENT = {
  eventType: 'risk_score_execution_success',
  schema: {
    scoresWritten: {
      type: 'long',
      _meta: {
        description: 'Number of risk scores written during this scoring task execution'
      }
    },
    taskDurationInSeconds: {
      type: 'long',
      _meta: {
        description: 'Duration (in seconds) of the current risk scoring task execution'
      }
    },
    interval: {
      type: 'keyword',
      _meta: {
        description: `Configured interval for the current risk scoring task`
      }
    },
    alertSampleSizePerShard: {
      type: 'long',
      _meta: {
        description: `Number of alerts to sample per shard for the current risk scoring task`
      }
    }
  }
};
const RISK_SCORE_EXECUTION_ERROR_EVENT = exports.RISK_SCORE_EXECUTION_ERROR_EVENT = {
  eventType: 'risk_score_execution_error',
  schema: {}
};
const RISK_SCORE_EXECUTION_CANCELLATION_EVENT = exports.RISK_SCORE_EXECUTION_CANCELLATION_EVENT = {
  eventType: 'risk_score_execution_cancellation',
  schema: {
    scoresWritten: {
      type: 'long',
      _meta: {
        description: 'Number of risk scores written during this scoring task execution'
      }
    },
    taskDurationInSeconds: {
      type: 'long',
      _meta: {
        description: 'Duration (in seconds) of the current risk scoring task execution'
      }
    },
    interval: {
      type: 'keyword',
      _meta: {
        description: `Configured interval for the current risk scoring task`
      }
    },
    alertSampleSizePerShard: {
      type: 'long',
      _meta: {
        description: `Number of alerts to sample per shard for the current risk scoring task`
      }
    }
  }
};
const ASSET_CRITICALITY_SYSTEM_PROCESSED_ASSIGNMENT_FILE_EVENT = exports.ASSET_CRITICALITY_SYSTEM_PROCESSED_ASSIGNMENT_FILE_EVENT = {
  eventType: 'Asset Criticality Csv Upload Processed',
  schema: {
    processing: {
      properties: {
        startTime: {
          type: 'date',
          _meta: {
            description: 'Processing start time'
          }
        },
        endTime: {
          type: 'date',
          _meta: {
            description: 'Processing end time'
          }
        },
        tookMs: {
          type: 'long',
          _meta: {
            description: 'How long processing took ms'
          }
        }
      }
    },
    result: {
      properties: {
        successful: {
          type: 'long',
          _meta: {
            description: 'Number of criticality records successfully created or updated'
          }
        },
        failed: {
          type: 'long',
          _meta: {
            description: 'Number of criticality records which had errors'
          }
        },
        total: {
          type: 'long',
          _meta: {
            description: 'Total number of lines in the file'
          }
        }
      }
    },
    status: {
      type: 'keyword',
      _meta: {
        description: 'Status of the processing either success, partial_success or fail'
      }
    }
  }
};
const FIELD_RETENTION_ENRICH_POLICY_EXECUTION_EVENT = exports.FIELD_RETENTION_ENRICH_POLICY_EXECUTION_EVENT = {
  eventType: 'field_retention_enrich_policy_execution',
  schema: {
    duration: {
      type: 'long',
      _meta: {
        description: 'Duration (in seconds) of the field retention enrich policy execution time'
      }
    },
    interval: {
      type: 'keyword',
      _meta: {
        description: 'Configured interval for the field retention enrich policy task'
      }
    }
  }
};
const ENTITY_ENGINE_RESOURCE_INIT_FAILURE_EVENT = exports.ENTITY_ENGINE_RESOURCE_INIT_FAILURE_EVENT = {
  eventType: 'entity_engine_resource_init_failure',
  schema: {
    error: {
      type: 'keyword',
      _meta: {
        description: 'Error message for a resource initialization failure'
      }
    }
  }
};
const ENTITY_ENGINE_INITIALIZATION_EVENT = exports.ENTITY_ENGINE_INITIALIZATION_EVENT = {
  eventType: 'entity_engine_initialization',
  schema: {
    duration: {
      type: 'long',
      _meta: {
        description: 'Duration (in seconds) of the entity engine initialization'
      }
    }
  }
};
const ENTITY_STORE_USAGE_EVENT = exports.ENTITY_STORE_USAGE_EVENT = {
  eventType: 'entity_store_usage',
  schema: {
    storeSize: {
      type: 'long',
      _meta: {
        description: 'Number of entities stored in the entity store'
      }
    }
  }
};
const ALERT_SUPPRESSION_EVENT = exports.ALERT_SUPPRESSION_EVENT = {
  eventType: 'alert_suppression_on_rule_execution',
  schema: {
    suppressionAlertsCreated: {
      type: 'long',
      _meta: {
        description: 'Number of alerts created during rule execution with configured alert suppression'
      }
    },
    suppressionAlertsSuppressed: {
      type: 'long',
      _meta: {
        description: 'Number of alerts suppressed during rule execution with configured alert suppression'
      }
    },
    suppressionRuleName: {
      type: 'keyword',
      _meta: {
        description: 'Name of rule'
      }
    },
    suppressionDuration: {
      type: 'long',
      _meta: {
        description: 'Duration in seconds of suppression period. -1 for per rule execution config'
      }
    },
    suppressionGroupByFieldsNumber: {
      type: 'long',
      _meta: {
        description: 'Number of Suppress by fields'
      }
    },
    suppressionGroupByFields: {
      type: 'array',
      items: {
        type: 'keyword',
        _meta: {
          description: 'Tag attached to the element...',
          optional: false
        }
      },
      _meta: {
        description: 'List of tags attached to the element...',
        optional: false
      }
    },
    suppressionRuleType: {
      type: 'keyword',
      _meta: {
        description: 'Rule type'
      }
    },
    suppressionMissingFields: {
      type: 'boolean',
      _meta: {
        description: 'Suppression of missing fields enabled'
      }
    },
    suppressionRuleId: {
      type: 'keyword',
      _meta: {
        description: 'ruleId'
      }
    }
  }
};
const createAssetCriticalityProcessedFileEvent = ({
  result,
  startTime,
  endTime
}) => {
  const status = getUploadStatus(result);
  const processing = {
    startTime: startTime.toISOString(),
    endTime: endTime.toISOString(),
    tookMs: endTime.getTime() - startTime.getTime()
  };
  return [ASSET_CRITICALITY_SYSTEM_PROCESSED_ASSIGNMENT_FILE_EVENT.eventType, {
    processing,
    result,
    status
  }];
};
exports.createAssetCriticalityProcessedFileEvent = createAssetCriticalityProcessedFileEvent;
const getUploadStatus = stats => {
  if (!stats) {
    return 'fail';
  }
  if (stats.failed === 0) {
    return 'success';
  }
  if (stats.successful > 0) {
    return 'partial_success';
  }
  return 'fail';
};
const ENDPOINT_RESPONSE_ACTION_SENT_ERROR_EVENT = exports.ENDPOINT_RESPONSE_ACTION_SENT_ERROR_EVENT = {
  eventType: 'endpoint_response_action_sent_error',
  schema: {
    responseActions: {
      properties: {
        agentType: {
          type: 'keyword',
          _meta: {
            description: 'The type of agent that the action was sent to',
            optional: false
          }
        },
        command: {
          type: 'keyword',
          _meta: {
            description: 'The command that was sent to the endpoint',
            optional: false
          }
        },
        error: {
          type: 'text',
          _meta: {
            description: 'The error message for the response action'
          }
        }
      }
    }
  }
};
const ENDPOINT_RESPONSE_ACTION_SENT_EVENT = exports.ENDPOINT_RESPONSE_ACTION_SENT_EVENT = {
  eventType: 'endpoint_response_action_sent',
  schema: {
    responseActions: {
      properties: {
        actionId: {
          type: 'keyword',
          _meta: {
            description: 'The ID of the action that was sent to the endpoint',
            optional: false
          }
        },
        agentType: {
          type: 'keyword',
          _meta: {
            description: 'The type of agent that the action was sent to',
            optional: false
          }
        },
        command: {
          type: 'keyword',
          _meta: {
            description: 'The command that was sent to the endpoint',
            optional: false
          }
        },
        isAutomated: {
          type: 'boolean',
          _meta: {
            description: 'Whether the action was auto-initiated by a pre-configured rule',
            optional: false
          }
        }
      }
    }
  }
};
const ENDPOINT_RESPONSE_ACTION_STATUS_CHANGE_EVENT = exports.ENDPOINT_RESPONSE_ACTION_STATUS_CHANGE_EVENT = {
  eventType: 'endpoint_response_action_status_change_event',
  schema: {
    responseActions: {
      properties: {
        actionId: {
          type: 'keyword',
          _meta: {
            description: 'The ID of the action that was sent to the endpoint',
            optional: false
          }
        },
        agentType: {
          type: 'keyword',
          _meta: {
            description: 'The type of agent that the action was sent to',
            optional: false
          }
        },
        actionStatus: {
          type: 'keyword',
          _meta: {
            description: 'The status of the action',
            optional: false
          }
        },
        command: {
          type: 'keyword',
          _meta: {
            description: 'The command that was sent to the endpoint',
            optional: false
          }
        }
      }
    }
  }
};
const events = exports.events = [RISK_SCORE_EXECUTION_SUCCESS_EVENT, RISK_SCORE_EXECUTION_ERROR_EVENT, RISK_SCORE_EXECUTION_CANCELLATION_EVENT, ASSET_CRITICALITY_SYSTEM_PROCESSED_ASSIGNMENT_FILE_EVENT, ALERT_SUPPRESSION_EVENT, ENDPOINT_RESPONSE_ACTION_SENT_EVENT, ENDPOINT_RESPONSE_ACTION_SENT_ERROR_EVENT, ENDPOINT_RESPONSE_ACTION_STATUS_CHANGE_EVENT, FIELD_RETENTION_ENRICH_POLICY_EXECUTION_EVENT, ENTITY_ENGINE_RESOURCE_INIT_FAILURE_EVENT, ENTITY_ENGINE_INITIALIZATION_EVENT, ENTITY_STORE_USAGE_EVENT];