"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getOverviewEmbeddableFactory = void 0;
var _eui = require("@elastic/eui");
var _react = require("@emotion/react");
var _i18n = require("@kbn/i18n");
var _common = require("@kbn/kibana-react-plugin/common");
var _public = require("@kbn/kibana-react-plugin/public");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _sharedUxRouter = require("@kbn/shared-ux-router");
var _reactQuery = require("@tanstack/react-query");
var _history = require("history");
var _react2 = _interopRequireWildcard(require("react"));
var _rxjs = require("rxjs");
var _plugin_context = require("../../../context/plugin_context");
var _constants = require("./constants");
var _group_view = require("./group_view/group_view");
var _slo_overview = require("./slo_overview");
var _slo_overview_grid = require("./slo_overview_grid");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const getOverviewPanelTitle = () => _i18n.i18n.translate('xpack.slo.sloEmbeddable.displayName', {
  defaultMessage: 'SLO Overview'
});
const getOverviewEmbeddableFactory = ({
  coreStart,
  pluginsStart,
  sloClient
}) => {
  const factory = {
    type: _constants.SLO_OVERVIEW_EMBEDDABLE_ID,
    deserializeState: state => {
      return state.rawState;
    },
    buildEmbeddable: async (state, buildApi, uuid, parentApi) => {
      const deps = {
        ...coreStart,
        ...pluginsStart
      };
      async function onEdit() {
        try {
          const {
            openSloConfiguration
          } = await Promise.resolve().then(() => _interopRequireWildcard(require('./slo_overview_open_configuration')));
          const result = await openSloConfiguration(coreStart, pluginsStart, sloClient, api.getSloGroupOverviewConfig());
          api.updateSloGroupOverviewConfig(result);
        } catch (e) {
          return Promise.reject();
        }
      }
      const {
        titlesApi,
        titleComparators,
        serializeTitles
      } = (0, _presentationPublishing.initializeTitles)(state);
      const defaultTitle$ = new _rxjs.BehaviorSubject(getOverviewPanelTitle());
      const sloId$ = new _rxjs.BehaviorSubject(state.sloId);
      const sloInstanceId$ = new _rxjs.BehaviorSubject(state.sloInstanceId);
      const showAllGroupByInstances$ = new _rxjs.BehaviorSubject(state.showAllGroupByInstances);
      const overviewMode$ = new _rxjs.BehaviorSubject(state.overviewMode);
      const groupFilters$ = new _rxjs.BehaviorSubject(state.groupFilters);
      const remoteName$ = new _rxjs.BehaviorSubject(state.remoteName);
      const reload$ = new _rxjs.Subject();
      const api = buildApi({
        ...titlesApi,
        defaultPanelTitle: defaultTitle$,
        getTypeDisplayName: () => _i18n.i18n.translate('xpack.slo.editSloOverviewEmbeddableTitle.typeDisplayName', {
          defaultMessage: 'criteria'
        }),
        isEditingEnabled: () => api.getSloGroupOverviewConfig().overviewMode === 'groups',
        onEdit: async () => {
          onEdit();
        },
        serializeState: () => {
          return {
            rawState: {
              ...serializeTitles(),
              sloId: sloId$.getValue(),
              sloInstanceId: sloInstanceId$.getValue(),
              showAllGroupByInstances: showAllGroupByInstances$.getValue(),
              overviewMode: overviewMode$.getValue(),
              groupFilters: groupFilters$.getValue(),
              remoteName: remoteName$.getValue()
            }
          };
        },
        getSloGroupOverviewConfig: () => {
          return {
            groupFilters: groupFilters$.getValue(),
            overviewMode: overviewMode$.getValue()
          };
        },
        updateSloGroupOverviewConfig: update => {
          groupFilters$.next(update.groupFilters);
        }
      }, {
        sloId: [sloId$, value => sloId$.next(value)],
        sloInstanceId: [sloInstanceId$, value => sloInstanceId$.next(value)],
        groupFilters: [groupFilters$, value => groupFilters$.next(value)],
        showAllGroupByInstances: [showAllGroupByInstances$, value => showAllGroupByInstances$.next(value)],
        remoteName: [remoteName$, value => remoteName$.next(value)],
        overviewMode: [overviewMode$, value => overviewMode$.next(value)],
        ...titleComparators
      });
      const fetchSubscription = (0, _presentationPublishing.fetch$)(api).pipe().subscribe(next => {
        reload$.next(next.isReload);
      });
      return {
        api,
        Component: () => {
          const [sloId, sloInstanceId, showAllGroupByInstances, overviewMode, groupFilters, remoteName] = (0, _presentationPublishing.useBatchedPublishingSubjects)(sloId$, sloInstanceId$, showAllGroupByInstances$, overviewMode$, groupFilters$, remoteName$);
          (0, _react2.useEffect)(() => {
            return () => {
              fetchSubscription.unsubscribe();
            };
          }, []);
          const renderOverview = () => {
            if (overviewMode === 'groups') {
              var _groupFilters$groupBy, _groupFilters$kqlQuer, _groupFilters$groups;
              const groupBy = (_groupFilters$groupBy = groupFilters === null || groupFilters === void 0 ? void 0 : groupFilters.groupBy) !== null && _groupFilters$groupBy !== void 0 ? _groupFilters$groupBy : 'status';
              const kqlQuery = (_groupFilters$kqlQuer = groupFilters === null || groupFilters === void 0 ? void 0 : groupFilters.kqlQuery) !== null && _groupFilters$kqlQuer !== void 0 ? _groupFilters$kqlQuer : '';
              const groups = (_groupFilters$groups = groupFilters === null || groupFilters === void 0 ? void 0 : groupFilters.groups) !== null && _groupFilters$groups !== void 0 ? _groupFilters$groups : [];
              return /*#__PURE__*/_react2.default.createElement("div", {
                css: ({
                  euiTheme
                }) => (0, _react.css)`
                    width: 100%;
                    padding: ${euiTheme.size.xs} ${euiTheme.size.base};
                    overflow: scroll;

                    .euiAccordion__buttonContent {
                      min-width: ${euiTheme.base * 6}px;
                    }
                  `
              }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexGroup, {
                "data-test-subj": "sloGroupOverviewPanel",
                "data-shared-item": ""
              }, /*#__PURE__*/_react2.default.createElement(_eui.EuiFlexItem, {
                css: ({
                  euiTheme
                }) => (0, _react.css)`
                        margin-top: ${euiTheme.base * 1.25}px;
                      `
              }, /*#__PURE__*/_react2.default.createElement(_group_view.GroupSloView, {
                view: "cardView",
                groupBy: groupBy,
                groups: groups,
                kqlQuery: kqlQuery,
                filters: groupFilters === null || groupFilters === void 0 ? void 0 : groupFilters.filters,
                reloadSubject: reload$
              }))));
            } else {
              return /*#__PURE__*/_react2.default.createElement(_slo_overview.SloOverview, {
                sloId: sloId,
                sloInstanceId: sloInstanceId,
                reloadSubject: reload$,
                showAllGroupByInstances: showAllGroupByInstances,
                remoteName: remoteName
              });
            }
          };
          const queryClient = new _reactQuery.QueryClient();
          return /*#__PURE__*/_react2.default.createElement(_sharedUxRouter.Router, {
            history: (0, _history.createBrowserHistory)()
          }, /*#__PURE__*/_react2.default.createElement(_common.EuiThemeProvider, {
            darkMode: true
          }, /*#__PURE__*/_react2.default.createElement(_public.KibanaContextProvider, {
            services: deps
          }, /*#__PURE__*/_react2.default.createElement(_plugin_context.PluginContext.Provider, {
            value: {
              observabilityRuleTypeRegistry: pluginsStart.observability.observabilityRuleTypeRegistry,
              ObservabilityPageTemplate: pluginsStart.observabilityShared.navigation.PageTemplate,
              sloClient
            }
          }, /*#__PURE__*/_react2.default.createElement(_reactQuery.QueryClientProvider, {
            client: queryClient
          }, showAllGroupByInstances ? /*#__PURE__*/_react2.default.createElement(_slo_overview_grid.SloCardChartList, {
            sloId: sloId
          }) : renderOverview())))));
        }
      };
    }
  };
  return factory;
};
exports.getOverviewEmbeddableFactory = getOverviewEmbeddableFactory;