"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EventsChartPanel = EventsChartPanel;
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _lodash = require("lodash");
var _react = _interopRequireDefault(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _timeslice_annotation = require("./timeslice_annotation");
var _events_area_chart = require("./events_area_chart");
var _use_get_preview_data = require("../../../hooks/use_get_preview_data");
var _use_kibana = require("../../../hooks/use_kibana");
var _good_bad_events_chart = require("../../../components/good_bad_events_chart/good_bad_events_chart");
var _get_discover_link = require("../../../utils/slo/get_discover_link");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function EventsChartPanel({
  slo,
  range,
  selectedTabId,
  onBrushed
}) {
  var _slo$remote;
  const {
    discover,
    uiSettings
  } = (0, _use_kibana.useKibana)().services;
  const {
    isLoading,
    data
  } = (0, _use_get_preview_data.useGetPreviewData)({
    range,
    isValid: true,
    groupBy: slo.groupBy,
    indicator: slo.indicator,
    groupings: slo.groupings,
    instanceId: slo.instanceId,
    remoteName: (_slo$remote = slo.remote) === null || _slo$remote === void 0 ? void 0 : _slo$remote.remoteName
  });
  const title = slo.indicator.type !== 'sli.metric.timeslice' ? /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("h2", null, _i18n.i18n.translate('xpack.slo.sloDetails.eventsChartPanel.title', {
    defaultMessage: 'Good vs bad events'
  }))) : /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("h2", null, _i18n.i18n.translate('xpack.slo.sloDetails.eventsChartPanel.timesliceTitle', {
    defaultMessage: 'Timeslice metric'
  })));
  const values = (data || []).map(row => {
    if (slo.indicator.type === 'sli.metric.timeslice') {
      return row.sliValue;
    } else {
      var _row$events;
      return (row === null || row === void 0 ? void 0 : (_row$events = row.events) === null || _row$events === void 0 ? void 0 : _row$events.total) || 0;
    }
  });
  const maxValue = (0, _lodash.max)(values);
  const minValue = (0, _lodash.min)(values);
  const annotation = /*#__PURE__*/_react.default.createElement(_timeslice_annotation.TimesliceAnnotation, {
    slo: slo,
    minValue: minValue,
    maxValue: maxValue
  });
  const showViewEventsLink = !['sli.apm.transactionErrorRate', 'sli.apm.transactionDuration'].includes(slo.indicator.type);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    paddingSize: "m",
    color: "transparent",
    hasBorder: true,
    "data-test-subj": "eventsChartPanel"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "l"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "none"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 1
  }, " ", title), selectedTabId !== 'history' && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    color: "subdued",
    size: "s"
  }, _i18n.i18n.translate('xpack.slo.sloDetails.eventsChartPanel.duration', {
    defaultMessage: 'Last 24h'
  })))), showViewEventsLink && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: 0
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
    color: "text",
    href: (0, _get_discover_link.getDiscoverLink)({
      slo,
      timeRange: {
        from: 'now-24h',
        to: 'now',
        mode: 'relative'
      },
      discover,
      uiSettings
    }),
    "data-test-subj": "sloDetailDiscoverLink"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: "sortRight",
    style: {
      marginRight: '4px'
    }
  }), /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.slo.sloDetails.viewEventsLink",
    defaultMessage: "View events"
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, slo.indicator.type !== 'sli.metric.timeslice' ? /*#__PURE__*/_react.default.createElement(_good_bad_events_chart.GoodBadEventsChart, {
    isLoading: isLoading,
    data: data || [],
    annotation: annotation,
    slo: slo,
    onBrushed: onBrushed
  }) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, isLoading && /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingChart, {
    size: "m",
    mono: true,
    "data-test-subj": "sliEventsChartLoading"
  }), !isLoading && /*#__PURE__*/_react.default.createElement(_events_area_chart.EventsAreaChart, {
    slo: slo,
    annotation: annotation,
    minValue: minValue,
    maxValue: maxValue,
    onBrushed: onBrushed
  })))));
}