"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OVERVIEW_TAB_ID = exports.HISTORY_TAB_ID = exports.ALERTS_TAB_ID = void 0;
exports.SloDetails = SloDetails;
exports.TAB_ID_URL_PARAM = void 0;
var _eui = require("@elastic/eui");
var _moment = _interopRequireDefault(require("moment"));
var _react = _interopRequireWildcard(require("react"));
var _burn_rate_panel = require("./burn_rate_panel/burn_rate_panel");
var _events_chart_panel = require("./events_chart_panel");
var _historical_data_charts = require("./historical_data_charts");
var _slo_details_history = require("./history/slo_details_history");
var _overview = require("./overview/overview");
var _slo_detail_alerts = require("./slo_detail_alerts");
var _slo_health_callout = require("./slo_health_callout");
var _slo_remote_callout = require("./slo_remote_callout");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const TAB_ID_URL_PARAM = exports.TAB_ID_URL_PARAM = 'tabId';
const OVERVIEW_TAB_ID = exports.OVERVIEW_TAB_ID = 'overview';
const HISTORY_TAB_ID = exports.HISTORY_TAB_ID = 'history';
const ALERTS_TAB_ID = exports.ALERTS_TAB_ID = 'alerts';
function SloDetails({
  slo,
  isAutoRefreshing,
  selectedTabId
}) {
  const [range, setRange] = (0, _react.useState)({
    from: (0, _moment.default)().subtract(1, 'day').toDate(),
    to: new Date()
  });
  (0, _react.useEffect)(() => {
    let intervalId;
    if (isAutoRefreshing) {
      intervalId = setInterval(() => {
        setRange({
          from: (0, _moment.default)().subtract(1, 'day').toDate(),
          to: new Date()
        });
      }, 60 * 1000);
    }
    return () => clearInterval(intervalId);
  }, [isAutoRefreshing]);
  if (selectedTabId === HISTORY_TAB_ID) {
    return /*#__PURE__*/_react.default.createElement(_slo_details_history.SLODetailsHistory, {
      slo: slo,
      isAutoRefreshing: isAutoRefreshing,
      selectedTabId: selectedTabId
    });
  }
  if (selectedTabId === ALERTS_TAB_ID) {
    return /*#__PURE__*/_react.default.createElement(_slo_detail_alerts.SloDetailsAlerts, {
      slo: slo
    });
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "xl"
  }, /*#__PURE__*/_react.default.createElement(_slo_remote_callout.SloRemoteCallout, {
    slo: slo
  }), /*#__PURE__*/_react.default.createElement(_slo_health_callout.SloHealthCallout, {
    slo: slo
  }), /*#__PURE__*/_react.default.createElement(_overview.Overview, {
    slo: slo
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "l"
  }, /*#__PURE__*/_react.default.createElement(_burn_rate_panel.BurnRatePanel, {
    slo: slo,
    isAutoRefreshing: isAutoRefreshing
  }), /*#__PURE__*/_react.default.createElement(_historical_data_charts.HistoricalDataCharts, {
    slo: slo,
    selectedTabId: selectedTabId,
    isAutoRefreshing: isAutoRefreshing
  }), /*#__PURE__*/_react.default.createElement(_events_chart_panel.EventsChartPanel, {
    slo: slo,
    range: range,
    selectedTabId: selectedTabId
  })));
}