"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFetchSLOsOverview = useFetchSLOsOverview;
var _esQuery = require("@kbn/es-query");
var _i18n = require("@kbn/i18n");
var _reactQuery = require("@tanstack/react-query");
var _react = require("react");
var _constants = require("../../../../common/constants");
var _query_key_factory = require("../../../hooks/query_key_factory");
var _use_create_data_view = require("../../../hooks/use_create_data_view");
var _use_plugin_context = require("../../../hooks/use_plugin_context");
var _use_kibana = require("../../../hooks/use_kibana");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useFetchSLOsOverview({
  kqlQuery = '',
  tagsFilter,
  statusFilter,
  filters: filterDSL = [],
  lastRefresh
} = {}) {
  const {
    sloClient
  } = (0, _use_plugin_context.usePluginContext)();
  const {
    notifications: {
      toasts
    }
  } = (0, _use_kibana.useKibana)().services;
  const {
    dataView
  } = (0, _use_create_data_view.useCreateDataView)({
    indexPatternString: _constants.SLO_SUMMARY_DESTINATION_INDEX_PATTERN
  });
  const filters = (0, _react.useMemo)(() => {
    try {
      return JSON.stringify((0, _esQuery.buildQueryFromFilters)([...filterDSL, ...(tagsFilter ? [tagsFilter] : []), ...(statusFilter ? [statusFilter] : [])], dataView, {
        ignoreFilterIfFieldNotInIndex: true
      }));
    } catch (e) {
      return '';
    }
  }, [filterDSL, tagsFilter, statusFilter, dataView]);
  const {
    data,
    isLoading,
    isSuccess,
    isError,
    isRefetching
  } = (0, _reactQuery.useQuery)({
    queryKey: _query_key_factory.sloKeys.overview({
      kqlQuery,
      filters,
      lastRefresh
    }),
    queryFn: async ({
      signal
    }) => {
      return await sloClient.fetch('GET /internal/observability/slos/overview', {
        params: {
          query: {
            ...(kqlQuery && {
              kqlQuery
            }),
            ...(filters && {
              filters
            })
          }
        },
        signal
      });
    },
    cacheTime: 0,
    refetchOnWindowFocus: false,
    retry: (failureCount, error) => {
      if (String(error) === 'Error: Forbidden') {
        return false;
      }
      return failureCount < 4;
    },
    onError: error => {
      toasts.addError(error, {
        title: _i18n.i18n.translate('xpack.slo.overview.list.errorNotification', {
          defaultMessage: 'Something went wrong while fetching SLOs overview'
        })
      });
    }
  });
  return {
    data,
    isLoading,
    isSuccess,
    isError,
    isRefetching
  };
}