"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSloRouteRepository = void 0;
var _elasticsearch = require("@elastic/elasticsearch");
var _boom = require("@hapi/boom");
var _sloSchema = require("@kbn/slo-schema");
var _get_overview = require("@kbn/slo-schema/src/rest_specs/routes/get_overview");
var _errors = require("../../errors");
var _services = require("../../services");
var _find_slo_definitions = require("../../services/find_slo_definitions");
var _get_burn_rates = require("../../services/get_burn_rates");
var _get_diagnosis = require("../../services/get_diagnosis");
var _get_preview_data = require("../../services/get_preview_data");
var _get_slo_instances = require("../../services/get_slo_instances");
var _get_slo_suggestions = require("../../services/get_slo_suggestions");
var _get_slos_overview = require("../../services/get_slos_overview");
var _historical_summary_client = require("../../services/historical_summary_client");
var _manage_slo = require("../../services/manage_slo");
var _reset_slo = require("../../services/reset_slo");
var _slo_definition_client = require("../../services/slo_definition_client");
var _slo_settings = require("../../services/slo_settings");
var _summary_search_client = require("../../services/summary_search_client");
var _summary_transform_generator = require("../../services/summary_transform_generator/summary_transform_generator");
var _transform_generators = require("../../services/transform_generators");
var _create_slo_server_route = require("../create_slo_server_route");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const assertPlatinumLicense = async plugins => {
  const licensing = await plugins.licensing.start();
  const hasCorrectLicense = (await licensing.getLicense()).hasAtLeast('platinum');
  if (!hasCorrectLicense) {
    throw (0, _boom.forbidden)('Platinum license or higher is needed to make use of this feature.');
  }
};
const getSpaceId = async (plugins, request) => {
  var _await$spaces$spacesS, _await$spaces$spacesS2, _spaces$spacesService;
  const spaces = await plugins.spaces.start();
  return (_await$spaces$spacesS = (_await$spaces$spacesS2 = await (spaces === null || spaces === void 0 ? void 0 : (_spaces$spacesService = spaces.spacesService) === null || _spaces$spacesService === void 0 ? void 0 : _spaces$spacesService.getActiveSpace(request))) === null || _await$spaces$spacesS2 === void 0 ? void 0 : _await$spaces$spacesS2.id) !== null && _await$spaces$spacesS !== void 0 ? _await$spaces$spacesS : 'default';
};
const createSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /api/observability/slos 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.createSLOParamsSchema,
  handler: async ({
    context,
    response,
    params,
    logger,
    request,
    plugins,
    corePlugins
  }) => {
    await assertPlatinumLicense(plugins);
    const sloContext = await context.slo;
    const dataViews = await plugins.dataViews.start();
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const soClient = core.savedObjects.client;
    const basePath = corePlugins.http.basePath;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const [spaceId, dataViewsService] = await Promise.all([getSpaceId(plugins, request), dataViews.dataViewsServiceFactory(soClient, esClient)]);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const createSLO = new _services.CreateSLO(esClient, scopedClusterClient, repository, transformManager, summaryTransformManager, logger, spaceId, basePath);
    return await (0, _errors.executeWithErrorHandler)(() => createSLO.execute(params.body));
  }
});
const inspectSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /internal/observability/slos/_inspect',
  options: {
    tags: ['access:slo_write'],
    access: 'internal'
  },
  params: _sloSchema.createSLOParamsSchema,
  handler: async ({
    context,
    params,
    logger,
    request,
    plugins,
    corePlugins
  }) => {
    await assertPlatinumLicense(plugins);
    const sloContext = await context.slo;
    const dataViews = await plugins.dataViews.start();
    const spaceId = await getSpaceId(plugins, request);
    const basePath = corePlugins.http.basePath;
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const soClient = core.savedObjects.client;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const createSLO = new _services.CreateSLO(esClient, scopedClusterClient, repository, transformManager, summaryTransformManager, logger, spaceId, basePath);
    return await (0, _errors.executeWithErrorHandler)(() => createSLO.inspect(params.body));
  }
});
const updateSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'PUT /api/observability/slos/{id} 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.updateSLOParamsSchema,
  handler: async ({
    context,
    request,
    params,
    logger,
    plugins,
    corePlugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const dataViews = await plugins.dataViews.start();
    const sloContext = await context.slo;
    const basePath = corePlugins.http.basePath;
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const soClient = core.savedObjects.client;
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const updateSLO = new _services.UpdateSLO(repository, transformManager, summaryTransformManager, esClient, scopedClusterClient, logger, spaceId, basePath);
    return await (0, _errors.executeWithErrorHandler)(() => updateSLO.execute(params.path.id, params.body));
  }
});
const deleteSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'DELETE /api/observability/slos/{id} 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.deleteSLOParamsSchema,
  handler: async ({
    request,
    response,
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const dataViews = await plugins.dataViews.start();
    const sloContext = await context.slo;
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const soClient = core.savedObjects.client;
    const alerting = await plugins.alerting.start();
    const rulesClient = await alerting.getRulesClientWithRequest(request);
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const deleteSLO = new _services.DeleteSLO(repository, transformManager, summaryTransformManager, esClient, scopedClusterClient, rulesClient);
    await (0, _errors.executeWithErrorHandler)(() => deleteSLO.execute(params.path.id));
    return response.noContent();
  }
});
const getSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /api/observability/slos/{id} 2023-10-31',
  options: {
    tags: ['access:slo_read'],
    access: 'public'
  },
  params: _sloSchema.getSLOParamsSchema,
  handler: async ({
    request,
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const soClient = (await context.core).savedObjects.client;
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const burnRatesClient = new _services.DefaultBurnRatesClient(esClient);
    const summaryClient = new _services.DefaultSummaryClient(esClient, burnRatesClient);
    const defintionClient = new _slo_definition_client.SloDefinitionClient(repository, esClient, logger);
    const getSLO = new _services.GetSLO(defintionClient, summaryClient);
    return await (0, _errors.executeWithErrorHandler)(() => getSLO.execute(params.path.id, spaceId, params.query));
  }
});
const enableSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /api/observability/slos/{id}/enable 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.manageSLOParamsSchema,
  handler: async ({
    request,
    response,
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const dataViews = await plugins.dataViews.start();
    const sloContext = await context.slo;
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const soClient = core.savedObjects.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const manageSLO = new _manage_slo.ManageSLO(repository, transformManager, summaryTransformManager);
    await (0, _errors.executeWithErrorHandler)(() => manageSLO.enable(params.path.id));
    return response.noContent();
  }
});
const disableSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /api/observability/slos/{id}/disable 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.manageSLOParamsSchema,
  handler: async ({
    response,
    request,
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const dataViews = await plugins.dataViews.start();
    const sloContext = await context.slo;
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const soClient = core.savedObjects.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const manageSLO = new _manage_slo.ManageSLO(repository, transformManager, summaryTransformManager);
    await (0, _errors.executeWithErrorHandler)(() => manageSLO.disable(params.path.id));
    return response.noContent();
  }
});
const resetSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /api/observability/slos/{id}/_reset 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.resetSLOParamsSchema,
  handler: async ({
    context,
    request,
    params,
    logger,
    plugins,
    corePlugins
  }) => {
    await assertPlatinumLicense(plugins);
    const sloContext = await context.slo;
    const dataViews = await plugins.dataViews.start();
    const spaceId = await getSpaceId(plugins, request);
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const soClient = core.savedObjects.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const basePath = corePlugins.http.basePath;
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const transformGenerators = (0, _transform_generators.createTransformGenerators)(spaceId, dataViewsService, sloContext.isServerless);
    const transformManager = new _services.DefaultTransformManager(transformGenerators, scopedClusterClient, logger);
    const summaryTransformManager = new _services.DefaultSummaryTransformManager(new _summary_transform_generator.DefaultSummaryTransformGenerator(), scopedClusterClient, logger);
    const resetSLO = new _reset_slo.ResetSLO(esClient, scopedClusterClient, repository, transformManager, summaryTransformManager, logger, spaceId, basePath);
    return await (0, _errors.executeWithErrorHandler)(() => resetSLO.execute(params.path.id));
  }
});
const findSLORoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /api/observability/slos 2023-10-31',
  options: {
    tags: ['access:slo_read'],
    access: 'public'
  },
  params: _sloSchema.findSLOParamsSchema,
  handler: async ({
    context,
    request,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const soClient = (await context.core).savedObjects.client;
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const summarySearchClient = new _summary_search_client.DefaultSummarySearchClient(esClient, soClient, logger, spaceId);
    const findSLO = new _services.FindSLO(repository, summarySearchClient);
    return await (0, _errors.executeWithErrorHandler)(() => {
      var _params$query;
      return findSLO.execute((_params$query = params === null || params === void 0 ? void 0 : params.query) !== null && _params$query !== void 0 ? _params$query : {});
    });
  }
});
const findSLOGroupsRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /internal/observability/slos/_groups',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _sloSchema.findSLOGroupsParamsSchema,
  handler: async ({
    context,
    request,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const soClient = (await context.core).savedObjects.client;
    const coreContext = context.core;
    const esClient = (await coreContext).elasticsearch.client.asCurrentUser;
    const findSLOGroups = new _services.FindSLOGroups(esClient, soClient, logger, spaceId);
    return await (0, _errors.executeWithErrorHandler)(() => {
      var _params$query2;
      return findSLOGroups.execute((_params$query2 = params === null || params === void 0 ? void 0 : params.query) !== null && _params$query2 !== void 0 ? _params$query2 : {});
    });
  }
});
const getSLOSuggestionsRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /internal/observability/slos/suggestions',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  handler: async ({
    context,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const soClient = (await context.core).savedObjects.client;
    const getSLOSuggestions = new _get_slo_suggestions.GetSLOSuggestions(soClient);
    return await (0, _errors.executeWithErrorHandler)(() => getSLOSuggestions.execute());
  }
});
const deleteSloInstancesRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /api/observability/slos/_delete_instances 2023-10-31',
  options: {
    tags: ['access:slo_write'],
    access: 'public'
  },
  params: _sloSchema.deleteSLOInstancesParamsSchema,
  handler: async ({
    response,
    context,
    params,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const deleteSloInstances = new _services.DeleteSLOInstances(esClient);
    await (0, _errors.executeWithErrorHandler)(() => deleteSloInstances.execute(params.body));
    return response.noContent();
  }
});
const findSloDefinitionsRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /api/observability/slos/_definitions 2023-10-31',
  options: {
    tags: ['access:slo_read'],
    access: 'public'
  },
  params: _sloSchema.findSloDefinitionsParamsSchema,
  handler: async ({
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const soClient = (await context.core).savedObjects.client;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const findSloDefinitions = new _find_slo_definitions.FindSLODefinitions(repository);
    return await (0, _errors.executeWithErrorHandler)(() => {
      var _params$query3;
      return findSloDefinitions.execute((_params$query3 = params === null || params === void 0 ? void 0 : params.query) !== null && _params$query3 !== void 0 ? _params$query3 : {});
    });
  }
});
const fetchHistoricalSummary = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /internal/observability/slos/_historical_summary',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _sloSchema.fetchHistoricalSummaryParamsSchema,
  handler: async ({
    context,
    params,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const historicalSummaryClient = new _historical_summary_client.DefaultHistoricalSummaryClient(esClient);
    return await (0, _errors.executeWithErrorHandler)(() => historicalSummaryClient.fetch(params.body));
  }
});
const getSLOInstancesRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /internal/observability/slos/{id}/_instances',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _sloSchema.getSLOInstancesParamsSchema,
  handler: async ({
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const soClient = (await context.core).savedObjects.client;
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const getSLOInstances = new _get_slo_instances.GetSLOInstances(repository, esClient);
    return await (0, _errors.executeWithErrorHandler)(() => getSLOInstances.execute(params.path.id));
  }
});
const getDiagnosisRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /internal/observability/slos/_diagnosis',
  options: {
    tags: [],
    access: 'internal'
  },
  params: undefined,
  handler: async ({
    context,
    plugins
  }) => {
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const licensing = await plugins.licensing.start();
    try {
      const response = await (0, _get_diagnosis.getGlobalDiagnosis)(esClient, licensing);
      return response;
    } catch (error) {
      if (error instanceof _elasticsearch.errors.ResponseError && error.statusCode === 403) {
        throw (0, _boom.forbidden)('Insufficient Elasticsearch cluster permissions to access feature.');
      }
      throw (0, _boom.failedDependency)(error);
    }
  }
});
const fetchSloHealthRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /internal/observability/slos/_health',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _sloSchema.fetchSLOHealthParamsSchema,
  handler: async ({
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const core = await context.core;
    const scopedClusterClient = core.elasticsearch.client;
    const soClient = core.savedObjects.client;
    const esClient = core.elasticsearch.client.asCurrentUser;
    const repository = new _services.KibanaSavedObjectsSLORepository(soClient, logger);
    const getSLOHealth = new _services.GetSLOHealth(esClient, scopedClusterClient, repository);
    return await (0, _errors.executeWithErrorHandler)(() => getSLOHealth.execute(params.body));
  }
});
const getSloBurnRates = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /internal/observability/slos/{id}/_burn_rates',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _sloSchema.getSLOBurnRatesParamsSchema,
  handler: async ({
    request,
    context,
    params,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const soClient = (await context.core).savedObjects.client;
    const {
      instanceId,
      windows,
      remoteName
    } = params.body;
    return await (0, _errors.executeWithErrorHandler)(() => (0, _get_burn_rates.getBurnRates)({
      instanceId,
      spaceId,
      windows,
      remoteName,
      sloId: params.path.id,
      services: {
        soClient,
        esClient,
        logger
      }
    }));
  }
});
const getPreviewData = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'POST /internal/observability/slos/_preview',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _sloSchema.getPreviewDataParamsSchema,
  handler: async ({
    request,
    context,
    params,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const spaceId = await getSpaceId(plugins, request);
    const dataViews = await plugins.dataViews.start();
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const soClient = (await context.core).savedObjects.client;
    const dataViewsService = await dataViews.dataViewsServiceFactory(soClient, esClient);
    const service = new _get_preview_data.GetPreviewData(esClient, spaceId, dataViewsService);
    return await service.execute(params.body);
  }
});
const getSloSettingsRoute = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /internal/slo/settings',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  handler: async ({
    context,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const soClient = (await context.core).savedObjects.client;
    return await (0, _errors.executeWithErrorHandler)(() => (0, _slo_settings.getSloSettings)(soClient));
  }
});
const putSloSettings = isServerless => (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'PUT /internal/slo/settings',
  options: {
    tags: ['access:slo_write'],
    access: 'internal'
  },
  params: isServerless ? _sloSchema.putSLOServerlessSettingsParamsSchema : _sloSchema.putSLOSettingsParamsSchema,
  handler: async ({
    context,
    params,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const soClient = (await context.core).savedObjects.client;
    return await (0, _errors.executeWithErrorHandler)(() => (0, _slo_settings.storeSloSettings)(soClient, params.body));
  }
});
const getSLOsOverview = (0, _create_slo_server_route.createSloServerRoute)({
  endpoint: 'GET /internal/observability/slos/overview',
  options: {
    tags: ['access:slo_read'],
    access: 'internal'
  },
  params: _get_overview.getOverviewParamsSchema,
  handler: async ({
    context,
    params,
    request,
    logger,
    plugins
  }) => {
    await assertPlatinumLicense(plugins);
    const soClient = (await context.core).savedObjects.client;
    const esClient = (await context.core).elasticsearch.client.asCurrentUser;
    const ruleRegistry = await plugins.ruleRegistry.start();
    const racClient = await ruleRegistry.getRacClientWithRequest(request);
    const spaceId = await getSpaceId(plugins, request);
    const alerting = await plugins.alerting.start();
    const rulesClient = await alerting.getRulesClientWithRequest(request);
    const slosOverview = new _get_slos_overview.GetSLOsOverview(soClient, esClient, spaceId, logger, rulesClient, racClient);
    return await (0, _errors.executeWithErrorHandler)(() => {
      var _params$query4;
      return slosOverview.execute((_params$query4 = params === null || params === void 0 ? void 0 : params.query) !== null && _params$query4 !== void 0 ? _params$query4 : {});
    });
  }
});
const getSloRouteRepository = isServerless => {
  return {
    ...fetchSloHealthRoute,
    ...getSloSettingsRoute,
    ...putSloSettings(isServerless),
    ...createSLORoute,
    ...inspectSLORoute,
    ...deleteSLORoute,
    ...deleteSloInstancesRoute,
    ...disableSLORoute,
    ...enableSLORoute,
    ...fetchHistoricalSummary,
    ...findSloDefinitionsRoute,
    ...findSLORoute,
    ...getSLORoute,
    ...updateSLORoute,
    ...getDiagnosisRoute,
    ...getSloBurnRates,
    ...getPreviewData,
    ...getSLOInstancesRoute,
    ...resetSLORoute,
    ...findSLOGroupsRoute,
    ...getSLOSuggestionsRoute,
    ...getSLOsOverview
  };
};
exports.getSloRouteRepository = getSloRouteRepository;