"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.KQLCustomTransformGenerator = void 0;
var _sloSchema = require("@kbn/slo-schema");
var _ = require(".");
var _constants = require("../../../common/constants");
var _slo_transform_template = require("../../assets/transform_templates/slo_transform_template");
var _errors = require("../../errors");
var _common = require("./common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

class KQLCustomTransformGenerator extends _.TransformGenerator {
  constructor(spaceId, dataViewService) {
    super(spaceId, dataViewService);
  }
  async getTransformParams(slo) {
    if (!_sloSchema.kqlCustomIndicatorSchema.is(slo.indicator)) {
      throw new _errors.InvalidTransformError(`Cannot handle SLO of indicator type: ${slo.indicator.type}`);
    }
    return (0, _slo_transform_template.getSLOTransformTemplate)(this.buildTransformId(slo), this.buildDescription(slo), await this.buildSource(slo, slo.indicator), this.buildDestination(slo), this.buildCommonGroupBy(slo, slo.indicator.params.timestampField), this.buildAggregations(slo, slo.indicator), this.buildSettings(slo, slo.indicator.params.timestampField), slo);
  }
  buildTransformId(slo) {
    return (0, _constants.getSLOTransformId)(slo.id, slo.revision);
  }
  async buildSource(slo, indicator) {
    const dataView = await this.getIndicatorDataView(indicator.params.dataViewId);
    return {
      index: (0, _.parseIndex)(indicator.params.index),
      runtime_mappings: this.buildCommonRuntimeMappings(dataView),
      query: {
        bool: {
          filter: [(0, _common.getFilterRange)(slo, indicator.params.timestampField), (0, _.getElasticsearchQueryOrThrow)(indicator.params.filter)]
        }
      }
    };
  }
  buildDestination(slo) {
    return {
      pipeline: (0, _constants.getSLOPipelineId)(slo.id, slo.revision),
      index: _constants.SLO_DESTINATION_INDEX_NAME
    };
  }
  buildAggregations(slo, indicator) {
    const numerator = (0, _.getElasticsearchQueryOrThrow)(indicator.params.good);
    const denominator = (0, _.getElasticsearchQueryOrThrow)(indicator.params.total);
    return {
      'slo.numerator': {
        filter: numerator
      },
      'slo.denominator': {
        filter: denominator
      },
      ...(_sloSchema.timeslicesBudgetingMethodSchema.is(slo.budgetingMethod) && {
        'slo.isGoodSlice': {
          bucket_script: {
            buckets_path: {
              goodEvents: 'slo.numerator>_count',
              totalEvents: 'slo.denominator>_count'
            },
            script: `if (params.totalEvents == 0) { return 1 } else { return params.goodEvents / params.totalEvents ${(0, _common.getTimesliceTargetComparator)(slo.objective.timesliceTarget)} ${slo.objective.timesliceTarget} ? 1 : 0 }`
          }
        }
      })
    };
  }
}
exports.KQLCustomTransformGenerator = KQLCustomTransformGenerator;