"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spacesManagementApp = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactDom = require("react-dom");
var _reactRouterDom = require("react-router-dom");
var _i18n = require("@kbn/i18n");
var _public = require("@kbn/kibana-react-plugin/public");
var _reactKibanaContextRender = require("@kbn/react-kibana-context-render");
var _sharedUxLinkRedirectApp = require("@kbn/shared-ux-link-redirect-app");
var _sharedUxRouter = require("@kbn/shared-ux-router");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const spacesManagementApp = exports.spacesManagementApp = Object.freeze({
  id: 'spaces',
  create({
    getStartServices,
    spacesManager,
    config,
    logger,
    eventTracker,
    getIsRoleManagementEnabled,
    getRolesAPIClient,
    getPrivilegesAPIClient,
    getSecurityLicense
  }) {
    const title = _i18n.i18n.translate('xpack.spaces.displayName', {
      defaultMessage: 'Spaces'
    });
    return {
      id: this.id,
      order: 2,
      title,
      async mount({
        element,
        setBreadcrumbs,
        history
      }) {
        const [[coreStart, {
          features
        }], {
          SpacesGridPage
        }, {
          CreateSpacePage
        }, {
          EditSpacePage
        }] = await Promise.all([getStartServices(), Promise.resolve().then(() => _interopRequireWildcard(require('./spaces_grid'))), Promise.resolve().then(() => _interopRequireWildcard(require('./create_space'))), Promise.resolve().then(() => _interopRequireWildcard(require('./edit_space')))]);
        const spacesFirstBreadcrumb = {
          text: title,
          href: `/`
        };
        const {
          notifications,
          application,
          chrome,
          http,
          overlays,
          theme
        } = coreStart;
        chrome.docTitle.change(title);
        const SpacesGridPageWithBreadcrumbs = () => {
          setBreadcrumbs([{
            ...spacesFirstBreadcrumb,
            href: undefined
          }]);
          return /*#__PURE__*/_react.default.createElement(SpacesGridPage, {
            capabilities: application.capabilities,
            getFeatures: features.getFeatures,
            notifications: notifications,
            spacesManager: spacesManager,
            serverBasePath: http.basePath.serverBasePath,
            history: history,
            getUrlForApp: application.getUrlForApp,
            maxSpaces: config.maxSpaces,
            allowSolutionVisibility: config.allowSolutionVisibility
          });
        };
        const CreateSpacePageWithBreadcrumbs = () => {
          setBreadcrumbs([spacesFirstBreadcrumb, {
            text: _i18n.i18n.translate('xpack.spaces.management.createSpaceBreadcrumb', {
              defaultMessage: 'Create'
            })
          }]);
          return /*#__PURE__*/_react.default.createElement(CreateSpacePage, {
            capabilities: application.capabilities,
            getFeatures: features.getFeatures,
            notifications: notifications,
            spacesManager: spacesManager,
            history: history,
            allowFeatureVisibility: config.allowFeatureVisibility,
            allowSolutionVisibility: config.allowSolutionVisibility,
            eventTracker: eventTracker
          });
        };
        const EditSpacePageWithBreadcrumbs = () => {
          const {
            spaceId,
            selectedTabId
          } = (0, _reactRouterDom.useParams)();
          const breadcrumbText = space => _i18n.i18n.translate('xpack.spaces.management.editSpaceBreadcrumb', {
            defaultMessage: 'Edit "{space}"',
            values: {
              space: space.name
            }
          });
          const onLoadSpace = space => {
            setBreadcrumbs([spacesFirstBreadcrumb, {
              text: breadcrumbText(space)
            }]);
          };
          return /*#__PURE__*/_react.default.createElement(EditSpacePage, {
            capabilities: application.capabilities,
            getUrlForApp: application.getUrlForApp,
            navigateToUrl: application.navigateToUrl,
            getSecurityLicense: getSecurityLicense,
            serverBasePath: http.basePath.serverBasePath,
            getFeatures: features.getFeatures,
            http: http,
            overlays: overlays,
            notifications: notifications,
            theme: theme,
            i18n: coreStart.i18n,
            logger: logger,
            spacesManager: spacesManager,
            spaceId: spaceId,
            onLoadSpace: onLoadSpace,
            history: history,
            selectedTabId: selectedTabId,
            getIsRoleManagementEnabled: getIsRoleManagementEnabled,
            getRolesAPIClient: getRolesAPIClient,
            allowFeatureVisibility: config.allowFeatureVisibility,
            allowSolutionVisibility: config.allowSolutionVisibility,
            getPrivilegesAPIClient: getPrivilegesAPIClient
          });
        };
        (0, _reactDom.render)( /*#__PURE__*/_react.default.createElement(_reactKibanaContextRender.KibanaRenderContextProvider, coreStart, /*#__PURE__*/_react.default.createElement(_public.KibanaContextProvider, {
          services: coreStart
        }, /*#__PURE__*/_react.default.createElement(_sharedUxLinkRedirectApp.RedirectAppLinks, {
          coreStart: coreStart
        }, /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Router, {
          history: history
        }, /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Routes, null, /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
          path: ['', '/'],
          exact: true
        }, /*#__PURE__*/_react.default.createElement(SpacesGridPageWithBreadcrumbs, null)), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
          path: "/create"
        }, /*#__PURE__*/_react.default.createElement(CreateSpacePageWithBreadcrumbs, null)), /*#__PURE__*/_react.default.createElement(_sharedUxRouter.Route, {
          path: ['/edit/:spaceId', '/edit/:spaceId/:selectedTabId'],
          exact: true
        }, /*#__PURE__*/_react.default.createElement(EditSpacePageWithBreadcrumbs, null))))))), element);
        return () => {
          chrome.docTitle.reset();
          (0, _reactDom.unmountComponentAtNode)(element);
        };
      }
    };
  }
});