"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.AdditionalOptionsConnectorFields = void 0;
var _react = _interopRequireWildcard(require("react"));
var _react2 = require("@emotion/react");
var _eui = require("@elastic/eui");
var _hook_form_lib = require("@kbn/es-ui-shared-plugin/static/forms/hook_form_lib");
var _i18nReact = require("@kbn/i18n-react");
var _helpers = require("@kbn/es-ui-shared-plugin/static/forms/helpers");
var _connector_configuration_form_items = require("../lib/dynamic_config/connector_configuration_form_items");
var i18n = _interopRequireWildcard(require("./translations"));
var _constants = require("./constants");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

// Custom trigger button CSS
const buttonCss = (0, _react2.css)`
  &:hover {
    text-decoration: none;
  }
`;
const AdditionalOptionsConnectorFields = ({
  config,
  readOnly,
  isEdit,
  taskTypeOptions,
  optionalProviderFormFields,
  taskTypeFormFields,
  taskTypeSchema,
  selectedTaskType,
  onSetProviderConfigEntry,
  onTaskTypeOptionsSelect
}) => {
  const xsFontSize = (0, _eui.useEuiFontSize)('xs').fontSize;
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const {
    setFieldValue,
    validateFields
  } = (0, _hook_form_lib.useFormContext)();
  const onSetTaskTypeConfigEntry = (0, _react.useCallback)(async (key, value) => {
    if (taskTypeSchema) {
      const entry = taskTypeSchema.find(p => p.key === key);
      if (entry) {
        if (!config.taskTypeConfig) {
          config.taskTypeConfig = {};
        }
        const newConfig = {
          ...config.taskTypeConfig
        };
        newConfig[key] = value;
        setFieldValue('config.taskTypeConfig', newConfig);
        await validateFields(['config.taskTypeConfig']);
      }
    }
  }, [config, setFieldValue, taskTypeSchema, validateFields]);
  const taskTypeSettings = (0, _react.useMemo)(() => {
    var _config$taskType;
    return selectedTaskType || (_config$taskType = config.taskType) !== null && _config$taskType !== void 0 && _config$taskType.length ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
      size: "xxs",
      "data-test-subj": "task-type-details-label"
    }, /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.stackConnectors.components.inference.taskTypeDetailsLabel",
      defaultMessage: "Task settings"
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "xs"
    }), /*#__PURE__*/_react.default.createElement("div", {
      css: (0, _react2.css)`
              font-size: ${xsFontSize};
              color: ${euiTheme.colors.subduedText};
            `
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.stackConnectors.components.inference.taskTypeHelpLabel",
      defaultMessage: "Configure the inference task. These settings are specific to the service and model selected."
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    }), /*#__PURE__*/_react.default.createElement(_hook_form_lib.UseField, {
      path: "config.taskType",
      config: {
        validations: [{
          validator: _helpers.fieldValidators.emptyField(i18n.getRequiredMessage('Task type')),
          isBlocking: true
        }]
      }
    }, field => {
      const {
        isInvalid,
        errorMessage
      } = (0, _hook_form_lib.getFieldValidityAndErrorMessage)(field);
      return /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
        id: "taskType",
        fullWidth: true,
        label: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "xpack.stackConnectors.components.inference.taskTypeLabel",
          defaultMessage: "Task type"
        }),
        isInvalid: isInvalid,
        error: errorMessage
      }, isEdit || readOnly ? /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
        css: {
          background: euiTheme.colors.disabled,
          color: euiTheme.colors.lightestShade
        },
        "data-test-subj": "taskTypeSelectDisabled",
        isDisabled: true
      }, config.taskType) : taskTypeOptions.length === 1 ? /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
        css: {
          background: euiTheme.colors.darkShade,
          color: euiTheme.colors.lightestShade
        },
        "data-test-subj": "taskTypeSelectSingle",
        onClick: () => onTaskTypeOptionsSelect(config.taskType)
      }, config.taskType) : /*#__PURE__*/_react.default.createElement(_eui.EuiButtonGroup, {
        "data-test-subj": "taskTypeSelect",
        buttonSize: "m",
        legend: "Task type",
        defaultValue: _constants.DEFAULT_TASK_TYPE,
        idSelected: config.taskType,
        onChange: id => onTaskTypeOptionsSelect(id),
        options: taskTypeOptions,
        color: "text",
        type: "single"
      }));
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "s"
    }), /*#__PURE__*/_react.default.createElement(_connector_configuration_form_items.ConnectorConfigurationFormItems, {
      itemsGrow: false,
      isLoading: false,
      direction: "column",
      items: taskTypeFormFields,
      setConfigEntry: onSetTaskTypeConfigEntry
    })) : null;
  }, [selectedTaskType, config === null || config === void 0 ? void 0 : config.taskType, xsFontSize, euiTheme.colors, taskTypeFormFields, onSetTaskTypeConfigEntry, isEdit, readOnly, taskTypeOptions, onTaskTypeOptionsSelect]);
  const inferenceUri = (0, _react.useMemo)(() => `_inference/${selectedTaskType}/`, [selectedTaskType]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiAccordion, {
    id: "inferenceAdditionalOptions",
    "data-test-subj": "inferenceAdditionalOptions",
    buttonProps: {
      css: buttonCss
    },
    css: (0, _react2.css)`
        .euiAccordion__triggerWrapper {
          display: inline-flex;
        }
      `,
    element: "fieldset",
    arrowDisplay: "right",
    arrowProps: {
      color: 'primary'
    },
    buttonElement: "button",
    borders: "none",
    buttonContent: /*#__PURE__*/_react.default.createElement(_eui.EuiTextColor, {
      color: euiTheme.colors.primary
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.stackConnectors.components.inference.additionalOptionsLabel",
      defaultMessage: "Additional options"
    })),
    initialIsOpen: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasBorder: true
  }, optionalProviderFormFields.length > 0 ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xxs",
    "data-test-subj": "provider-optional-settings-label"
  }, /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.stackConnectors.components.inference.providerOptionalSettingsLabel",
    defaultMessage: "Service settings"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement("div", {
    css: (0, _react2.css)`
                font-size: ${xsFontSize};
                color: ${euiTheme.colors.subduedText};
              `
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.stackConnectors.components.inference.providerOptionalSettingsHelpLabel",
    defaultMessage: "Configure the inference provider. These settings are optional provider settings."
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_connector_configuration_form_items.ConnectorConfigurationFormItems, {
    itemsGrow: false,
    isLoading: false,
    direction: "column",
    items: optionalProviderFormFields,
    setConfigEntry: onSetProviderConfigEntry
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  })) : null, taskTypeSettings, /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, null), /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xxs",
    "data-test-subj": "task-type-details-label"
  }, /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.stackConnectors.components.inference.inferenceEndpointLabel",
    defaultMessage: "Inference Endpoint"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement("div", {
    css: (0, _react2.css)`
            font-size: ${xsFontSize};
            color: ${euiTheme.colors.subduedText};
          `
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.stackConnectors.components.inference.inferenceEndpointHelpLabel",
    defaultMessage: "Inference endpoints provide a simplified method for using this configuration, ecpecially from the API"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_hook_form_lib.UseField, {
    path: "config.inferenceId"
  }, field => {
    const {
      isInvalid,
      errorMessage
    } = (0, _hook_form_lib.getFieldValidityAndErrorMessage)(field);
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
      id: "inferenceId",
      isInvalid: isInvalid,
      error: errorMessage,
      fullWidth: true,
      helpText: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.stackConnectors.components.inference.inferenceIdHelpLabel",
        defaultMessage: "This ID cannot be changed once created."
      })
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldText, {
      fullWidth: true,
      disabled: isEdit || readOnly,
      value: config.inferenceId,
      onChange: e => {
        setFieldValue('config.inferenceId', e.target.value);
      },
      prepend: inferenceUri,
      append: /*#__PURE__*/_react.default.createElement(_eui.EuiCopy, {
        beforeMessage: i18n.COPY_TOOLTIP,
        afterMessage: i18n.COPIED_TOOLTIP,
        textToCopy: `${inferenceUri}${config.inferenceId}`
      }, copy => /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
        iconType: "copy",
        size: "xs",
        iconSide: "right",
        onClick: copy,
        "data-test-subj": "copyInferenceUriToClipboard"
      }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.stackConnectors.components.inference.copyLabel",
        defaultMessage: "Copy"
      })))
    }));
  })));
};

// eslint-disable-next-line import/no-default-export
exports.default = exports.AdditionalOptionsConnectorFields = AdditionalOptionsConnectorFields;