"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _hook_form_lib = require("@kbn/es-ui-shared-plugin/static/forms/hook_form_lib");
var _i18nReact = require("@kbn/i18n-react");
var _public = require("@kbn/triggers-actions-ui-plugin/public");
var _helpers = require("@kbn/es-ui-shared-plugin/static/forms/helpers");
var _connector_configuration_form_items = require("../lib/dynamic_config/connector_configuration_form_items");
var _get_task_types = require("./get_task_types");
var i18n = _interopRequireWildcard(require("./translations"));
var _constants = require("./constants");
var _selectable = require("./providers/selectable");
var _helpers2 = require("./helpers");
var _get_providers = require("./providers/get_providers");
var _service_provider = require("./providers/render_service_provider/service_provider");
var _additional_options_fields = require("./additional_options_fields");
var _hidden_fields = require("./hidden_fields");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const InferenceAPIConnectorFields = ({
  readOnly,
  isEdit
}) => {
  const {
    http,
    notifications: {
      toasts
    }
  } = (0, _public.useKibana)().services;
  const {
    updateFieldValues,
    setFieldValue,
    validateFields,
    isSubmitting
  } = (0, _hook_form_lib.useFormContext)();
  const [{
    config,
    secrets
  }] = (0, _hook_form_lib.useFormData)({
    watch: ['secrets.providerSecrets', 'config.taskType', 'config.taskTypeConfig', 'config.inferenceId', 'config.provider', 'config.providerConfig']
  });
  const {
    data: providers,
    isLoading
  } = (0, _get_providers.useProviders)(http, toasts);
  const [isProviderPopoverOpen, setProviderPopoverOpen] = (0, _react.useState)(false);
  const [providerSchema, setProviderSchema] = (0, _react.useState)([]);
  const [optionalProviderFormFields, setOptionalProviderFormFields] = (0, _react.useState)([]);
  const [requiredProviderFormFields, setRequiredProviderFormFields] = (0, _react.useState)([]);
  const [taskTypeSchema, setTaskTypeSchema] = (0, _react.useState)([]);
  const [taskTypeOptions, setTaskTypeOptions] = (0, _react.useState)([]);
  const [selectedTaskType, setSelectedTaskType] = (0, _react.useState)(_constants.DEFAULT_TASK_TYPE);
  const [taskTypeFormFields, setTaskTypeFormFields] = (0, _react.useState)([]);
  const handleProviderClosePopover = (0, _react.useCallback)(() => {
    setProviderPopoverOpen(false);
  }, []);
  const handleProviderPopover = (0, _react.useCallback)(() => {
    setProviderPopoverOpen(isOpen => !isOpen);
  }, []);
  const handleProviderKeyboardOpen = (0, _react.useCallback)(event => {
    if (event.key === _eui.keys.ENTER) {
      setProviderPopoverOpen(true);
    }
  }, []);
  (0, _react.useEffect)(() => {
    if (!isEdit && config && !config.inferenceId) {
      (0, _helpers2.generateInferenceEndpointId)(config, setFieldValue);
    }
  }, [isEdit, setFieldValue, config]);
  (0, _react.useEffect)(() => {
    if (isSubmitting) {
      validateFields(['config.providerConfig']);
      validateFields(['secrets.providerSecrets']);
      validateFields(['config.taskTypeConfig']);
    }
  }, [isSubmitting, config, validateFields]);
  const onTaskTypeOptionsSelect = (0, _react.useCallback)(async (taskType, provider) => {
    var _newTaskType$configur, _newTaskType$configur2;
    // Get task type settings
    const currentTaskTypes = await (0, _get_task_types.getTaskTypes)(http, provider !== null && provider !== void 0 ? provider : config === null || config === void 0 ? void 0 : config.provider);
    const newTaskType = currentTaskTypes === null || currentTaskTypes === void 0 ? void 0 : currentTaskTypes.find(p => p.task_type === taskType);
    setSelectedTaskType(taskType);
    (0, _helpers2.generateInferenceEndpointId)(config, setFieldValue);

    // transform the schema
    const newTaskTypeSchema = Object.keys((_newTaskType$configur = newTaskType === null || newTaskType === void 0 ? void 0 : newTaskType.configuration) !== null && _newTaskType$configur !== void 0 ? _newTaskType$configur : {}).map(k => ({
      key: k,
      isValid: true,
      ...(newTaskType === null || newTaskType === void 0 ? void 0 : newTaskType.configuration[k])
    }));
    setTaskTypeSchema(newTaskTypeSchema);
    const configDefaults = Object.keys((_newTaskType$configur2 = newTaskType === null || newTaskType === void 0 ? void 0 : newTaskType.configuration) !== null && _newTaskType$configur2 !== void 0 ? _newTaskType$configur2 : {}).reduce((res, k) => {
      if (newTaskType !== null && newTaskType !== void 0 && newTaskType.configuration[k] && !!(newTaskType !== null && newTaskType !== void 0 && newTaskType.configuration[k].default_value)) {
        res[k] = newTaskType.configuration[k].default_value;
      } else {
        res[k] = null;
      }
      return res;
    }, {});
    updateFieldValues({
      config: {
        taskType,
        taskTypeConfig: configDefaults
      }
    });
  }, [config, http, setFieldValue, updateFieldValues]);
  const onProviderChange = (0, _react.useCallback)(async provider => {
    var _newProvider$taskType, _newProvider$configur, _newProvider$configur2;
    const newProvider = providers === null || providers === void 0 ? void 0 : providers.find(p => p.provider === provider);

    // Update task types list available for the selected provider
    const providerTaskTypes = (_newProvider$taskType = newProvider === null || newProvider === void 0 ? void 0 : newProvider.taskTypes) !== null && _newProvider$taskType !== void 0 ? _newProvider$taskType : [];
    setTaskTypeOptions((0, _helpers2.getTaskTypeOptions)(providerTaskTypes));
    if (providerTaskTypes.length > 0) {
      await onTaskTypeOptionsSelect(providerTaskTypes[0], provider);
    }

    // Update connector providerSchema
    const newProviderSchema = Object.keys((_newProvider$configur = newProvider === null || newProvider === void 0 ? void 0 : newProvider.configuration) !== null && _newProvider$configur !== void 0 ? _newProvider$configur : {}).map(k => ({
      key: k,
      isValid: true,
      ...(newProvider === null || newProvider === void 0 ? void 0 : newProvider.configuration[k])
    }));
    setProviderSchema(newProviderSchema);
    const defaultProviderConfig = {};
    const defaultProviderSecrets = {};
    Object.keys((_newProvider$configur2 = newProvider === null || newProvider === void 0 ? void 0 : newProvider.configuration) !== null && _newProvider$configur2 !== void 0 ? _newProvider$configur2 : {}).forEach(k => {
      if (!(newProvider !== null && newProvider !== void 0 && newProvider.configuration[k].sensitive)) {
        if (newProvider !== null && newProvider !== void 0 && newProvider.configuration[k] && !!(newProvider !== null && newProvider !== void 0 && newProvider.configuration[k].default_value)) {
          defaultProviderConfig[k] = newProvider.configuration[k].default_value;
        } else {
          defaultProviderConfig[k] = null;
        }
      } else {
        defaultProviderSecrets[k] = null;
      }
    });
    updateFieldValues({
      config: {
        provider: newProvider === null || newProvider === void 0 ? void 0 : newProvider.provider,
        providerConfig: defaultProviderConfig
      },
      secrets: {
        providerSecrets: defaultProviderSecrets
      }
    });
  }, [onTaskTypeOptionsSelect, providers, updateFieldValues]);
  (0, _react.useEffect)(() => {
    const getTaskTypeSchema = async () => {
      var _config$provider, _newTaskType$configur3;
      const currentTaskTypes = await (0, _get_task_types.getTaskTypes)(http, (_config$provider = config === null || config === void 0 ? void 0 : config.provider) !== null && _config$provider !== void 0 ? _config$provider : '');
      const newTaskType = currentTaskTypes === null || currentTaskTypes === void 0 ? void 0 : currentTaskTypes.find(p => p.task_type === (config === null || config === void 0 ? void 0 : config.taskType));

      // transform the schema
      const newTaskTypeSchema = Object.keys((_newTaskType$configur3 = newTaskType === null || newTaskType === void 0 ? void 0 : newTaskType.configuration) !== null && _newTaskType$configur3 !== void 0 ? _newTaskType$configur3 : {}).map(k => ({
        key: k,
        isValid: true,
        ...(newTaskType === null || newTaskType === void 0 ? void 0 : newTaskType.configuration[k])
      }));
      setTaskTypeSchema(newTaskTypeSchema);
    };
    if (config !== null && config !== void 0 && config.provider && isEdit) {
      var _newProvider$configur3;
      const newProvider = providers === null || providers === void 0 ? void 0 : providers.find(p => p.provider === config.provider);
      // Update connector providerSchema
      const newProviderSchema = Object.keys((_newProvider$configur3 = newProvider === null || newProvider === void 0 ? void 0 : newProvider.configuration) !== null && _newProvider$configur3 !== void 0 ? _newProvider$configur3 : {}).map(k => ({
        key: k,
        isValid: true,
        ...(newProvider === null || newProvider === void 0 ? void 0 : newProvider.configuration[k])
      }));
      setProviderSchema(newProviderSchema);
      getTaskTypeSchema();
    }
  }, [config === null || config === void 0 ? void 0 : config.provider, config === null || config === void 0 ? void 0 : config.taskType, http, isEdit, providers]);
  (0, _react.useEffect)(() => {
    // Set values from the provider secrets and config to the schema
    const existingConfiguration = providerSchema ? providerSchema.map(item => {
      const itemValue = item;
      itemValue.isValid = true;
      if (item.sensitive && secrets !== null && secrets !== void 0 && secrets.providerSecrets) {
        itemValue.value = secrets === null || secrets === void 0 ? void 0 : secrets.providerSecrets[item.key];
      } else if (config !== null && config !== void 0 && config.providerConfig) {
        itemValue.value = config === null || config === void 0 ? void 0 : config.providerConfig[item.key];
      }
      return itemValue;
    }) : [];
    existingConfiguration.sort((a, b) => {
      var _a$order, _b$order;
      return ((_a$order = a.order) !== null && _a$order !== void 0 ? _a$order : 0) - ((_b$order = b.order) !== null && _b$order !== void 0 ? _b$order : 0);
    });
    setOptionalProviderFormFields(existingConfiguration.filter(p => !p.required && !p.sensitive));
    setRequiredProviderFormFields(existingConfiguration.filter(p => p.required || p.sensitive));
  }, [config === null || config === void 0 ? void 0 : config.providerConfig, providerSchema, secrets]);
  (0, _react.useEffect)(() => {
    // Set values from the task type config to the schema
    const existingTaskTypeConfiguration = taskTypeSchema ? taskTypeSchema.map(item => {
      const itemValue = item;
      itemValue.isValid = true;
      if (config !== null && config !== void 0 && config.taskTypeConfig) {
        itemValue.value = config === null || config === void 0 ? void 0 : config.taskTypeConfig[item.key];
      }
      return itemValue;
    }) : [];
    existingTaskTypeConfiguration.sort((a, b) => {
      var _a$order2, _b$order2;
      return ((_a$order2 = a.order) !== null && _a$order2 !== void 0 ? _a$order2 : 0) - ((_b$order2 = b.order) !== null && _b$order2 !== void 0 ? _b$order2 : 0);
    });
    setTaskTypeFormFields(existingTaskTypeConfiguration);
  }, [config, taskTypeSchema]);
  const getProviderOptions = (0, _react.useCallback)(() => {
    return providers === null || providers === void 0 ? void 0 : providers.map(p => ({
      label: p.provider,
      key: p.provider
    }));
  }, [providers]);
  const onSetProviderConfigEntry = (0, _react.useCallback)(async (key, value) => {
    const entry = providerSchema.find(p => p.key === key);
    if (entry) {
      if (entry.sensitive) {
        if (!secrets.providerSecrets) {
          secrets.providerSecrets = {};
        }
        const newSecrets = {
          ...secrets.providerSecrets
        };
        newSecrets[key] = value;
        setFieldValue('secrets.providerSecrets', newSecrets);
        await validateFields(['secrets.providerSecrets']);
      } else {
        if (!config.providerConfig) {
          config.providerConfig = {};
        }
        const newConfig = {
          ...config.providerConfig
        };
        newConfig[key] = value;
        setFieldValue('config.providerConfig', newConfig);
        await validateFields(['config.providerConfig']);
      }
    }
  }, [config, providerSchema, secrets, setFieldValue, validateFields]);
  const onClearProvider = (0, _react.useCallback)(() => {
    onProviderChange();
    setFieldValue('config.taskType', '');
    setFieldValue('config.provider', '');
  }, [onProviderChange, setFieldValue]);
  const providerSuperSelect = (0, _react.useCallback)(isInvalid => /*#__PURE__*/_react.default.createElement(_eui.EuiFormControlLayout, {
    clear: isEdit || readOnly ? undefined : {
      onClick: onClearProvider
    },
    isDropdown: true,
    isDisabled: isEdit || readOnly,
    isInvalid: isInvalid,
    fullWidth: true,
    icon: !(config !== null && config !== void 0 && config.provider) ? {
      type: 'sparkles',
      side: 'left'
    } : _service_provider.SERVICE_PROVIDERS[config === null || config === void 0 ? void 0 : config.provider].icon
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldText, {
    onClick: handleProviderPopover,
    "data-test-subj": "provider-select",
    isInvalid: isInvalid,
    disabled: isEdit || readOnly,
    onKeyDown: handleProviderKeyboardOpen,
    value: config !== null && config !== void 0 && config.provider ? _service_provider.SERVICE_PROVIDERS[config === null || config === void 0 ? void 0 : config.provider].name : '',
    fullWidth: true,
    placeholder: i18n.SELECT_PROVIDER,
    icon: {
      type: 'arrowDown',
      side: 'right'
    },
    "aria-expanded": isProviderPopoverOpen,
    role: "combobox"
  })), [isEdit, readOnly, onClearProvider, config === null || config === void 0 ? void 0 : config.provider, handleProviderPopover, handleProviderKeyboardOpen, isProviderPopoverOpen]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_hook_form_lib.UseField, {
    path: "config.provider",
    config: {
      validations: [{
        validator: _helpers.fieldValidators.emptyField(i18n.PROVIDER_REQUIRED),
        isBlocking: true
      }]
    }
  }, field => {
    const {
      isInvalid,
      errorMessage
    } = (0, _hook_form_lib.getFieldValidityAndErrorMessage)(field);
    const selectInput = providerSuperSelect(isInvalid);
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
      id: "providerSelectBox",
      fullWidth: true,
      label: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.stackConnectors.components.inference.providerLabel",
        defaultMessage: "Service"
      }),
      isInvalid: isInvalid,
      error: errorMessage
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiInputPopover, {
      id: 'popoverId',
      fullWidth: true,
      input: selectInput,
      isOpen: isProviderPopoverOpen,
      closePopover: handleProviderClosePopover,
      className: "rightArrowIcon"
    }, /*#__PURE__*/_react.default.createElement(_selectable.SelectableProvider, {
      isLoading: isLoading,
      getSelectableOptions: getProviderOptions,
      onClosePopover: handleProviderClosePopover,
      onProviderChange: onProviderChange
    })));
  }), config !== null && config !== void 0 && config.provider ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_connector_configuration_form_items.ConnectorConfigurationFormItems, {
    itemsGrow: false,
    isLoading: false,
    direction: "column",
    items: requiredProviderFormFields,
    setConfigEntry: onSetProviderConfigEntry
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_additional_options_fields.AdditionalOptionsConnectorFields, {
    config: config,
    readOnly: readOnly,
    isEdit: isEdit,
    optionalProviderFormFields: optionalProviderFormFields,
    onSetProviderConfigEntry: onSetProviderConfigEntry,
    onTaskTypeOptionsSelect: onTaskTypeOptionsSelect,
    taskTypeFormFields: taskTypeFormFields,
    taskTypeSchema: taskTypeSchema,
    taskTypeOptions: taskTypeOptions,
    selectedTaskType: selectedTaskType
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, null), (0, _hidden_fields.getProviderSecretsHiddenField)(providerSchema, setRequiredProviderFormFields, isSubmitting), (0, _hidden_fields.getProviderConfigHiddenField)(providerSchema, setRequiredProviderFormFields, isSubmitting), (0, _hidden_fields.getTaskTypeConfigHiddenField)(taskTypeSchema, setTaskTypeFormFields, isSubmitting)) : null);
};

// eslint-disable-next-line import/no-default-export
exports.default = InferenceAPIConnectorFields;
module.exports = exports.default;