"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ServiceProviderName = exports.ServiceProviderIcon = exports.SERVICE_PROVIDERS = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _constants = require("../../../../../common/inference/constants");
var _elastic = _interopRequireDefault(require("../assets/images/elastic.svg"));
var _hugging_face = _interopRequireDefault(require("../assets/images/hugging_face.svg"));
var _cohere = _interopRequireDefault(require("../assets/images/cohere.svg"));
var _open_ai = _interopRequireDefault(require("../assets/images/open_ai.svg"));
var _azure_ai_studio = _interopRequireDefault(require("../assets/images/azure_ai_studio.svg"));
var _azure_open_ai = _interopRequireDefault(require("../assets/images/azure_open_ai.svg"));
var _google_ai_studio = _interopRequireDefault(require("../assets/images/google_ai_studio.svg"));
var _mistral = _interopRequireDefault(require("../assets/images/mistral.svg"));
var _amazon_bedrock = _interopRequireDefault(require("../assets/images/amazon_bedrock.svg"));
var _anthropic = _interopRequireDefault(require("../assets/images/anthropic.svg"));
var _alibaba_cloud = _interopRequireDefault(require("../assets/images/alibaba_cloud.svg"));
var _ibm_watsonx = _interopRequireDefault(require("../assets/images/ibm_watsonx.svg"));
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const SERVICE_PROVIDERS = exports.SERVICE_PROVIDERS = {
  [_constants.ServiceProviderKeys.amazonbedrock]: {
    icon: _amazon_bedrock.default,
    name: 'Amazon Bedrock',
    solutions: ['Observability', 'Security', 'Search']
  },
  [_constants.ServiceProviderKeys.azureaistudio]: {
    icon: _azure_ai_studio.default,
    name: 'Azure AI Studio',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.azureopenai]: {
    icon: _azure_open_ai.default,
    name: 'Azure OpenAI',
    solutions: ['Observability', 'Security', 'Search']
  },
  [_constants.ServiceProviderKeys.anthropic]: {
    icon: _anthropic.default,
    name: 'Anthropic',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.cohere]: {
    icon: _cohere.default,
    name: 'Cohere',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.elasticsearch]: {
    icon: _elastic.default,
    name: 'Elasticsearch',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.googleaistudio]: {
    icon: _google_ai_studio.default,
    name: 'Google AI Studio',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.googlevertexai]: {
    icon: _google_ai_studio.default,
    name: 'Google Vertex AI',
    solutions: ['Observability', 'Security', 'Search']
  },
  [_constants.ServiceProviderKeys.hugging_face]: {
    icon: _hugging_face.default,
    name: 'Hugging Face',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.mistral]: {
    icon: _mistral.default,
    name: 'Mistral',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.openai]: {
    icon: _open_ai.default,
    name: 'OpenAI',
    solutions: ['Observability', 'Security', 'Search']
  },
  [_constants.ServiceProviderKeys['alibabacloud-ai-search']]: {
    icon: _alibaba_cloud.default,
    name: 'AlibabaCloud AI Search',
    solutions: ['Search']
  },
  [_constants.ServiceProviderKeys.watsonxai]: {
    icon: _ibm_watsonx.default,
    name: 'IBM Watsonx',
    solutions: ['Search']
  }
};
const ServiceProviderIcon = ({
  providerKey
}) => {
  const provider = SERVICE_PROVIDERS[providerKey];
  return provider ? /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    "data-test-subj": `icon-service-provider-${providerKey}`,
    type: provider.icon
  }) : /*#__PURE__*/_react.default.createElement("span", null, providerKey);
};
exports.ServiceProviderIcon = ServiceProviderIcon;
const ServiceProviderName = ({
  providerKey,
  searchValue
}) => {
  const provider = SERVICE_PROVIDERS[providerKey];
  return provider ? /*#__PURE__*/_react.default.createElement(_eui.EuiHighlight, {
    search: searchValue !== null && searchValue !== void 0 ? searchValue : ''
  }, provider.name) : /*#__PURE__*/_react.default.createElement("span", null, providerKey);
};
exports.ServiceProviderName = ServiceProviderName;