"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SelectableProvider = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _service_provider = require("../render_service_provider/service_provider");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Modifies options by creating new property `providerTitle`(with value of `title`), and by setting `title` to undefined.
 * Thus prevents appearing default browser tooltip on option hover (attribute `title` that gets rendered on li element)
 *
 * @param {EuiSelectableOption[]} options
 * @returns {EuiSelectableOption[]} modified options
 */

const SelectableProviderComponent = ({
  isLoading,
  getSelectableOptions,
  onClosePopover,
  onProviderChange
}) => {
  const [searchProviderValue, setSearchProviderValue] = (0, _react.useState)('');
  const onSearchProvider = (0, _react.useCallback)(val => {
    setSearchProviderValue(val);
  }, [setSearchProviderValue]);
  const renderProviderOption = (0, _react.useCallback)((option, searchValue) => {
    const provider = _service_provider.SERVICE_PROVIDERS[option.label];
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "s",
      alignItems: "center",
      responsive: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_service_provider.ServiceProviderIcon, {
      providerKey: option.label
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: true
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "none",
      direction: "column",
      responsive: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      "data-test-subj": "provider"
    }, /*#__PURE__*/_react.default.createElement(_service_provider.ServiceProviderName, {
      providerKey: option.label,
      searchValue: searchValue
    })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "xs",
      responsive: false
    }, provider && provider.solutions.map(solution => /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiBadge, {
      color: "hollow"
    }, solution))))));
  }, []);
  const handleProviderChange = (0, _react.useCallback)(options => {
    const selectedProvider = options.filter(option => option.checked === 'on');
    if (selectedProvider != null && selectedProvider.length > 0) {
      onProviderChange(selectedProvider[0].label);
    }
    onClosePopover();
  }, [onClosePopover, onProviderChange]);
  const EuiSelectableContent = (0, _react.useCallback)((list, search) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, search, list), []);
  const searchProps = (0, _react.useMemo)(() => ({
    'data-test-subj': 'provider-super-select-search-box',
    placeholder: _i18n.i18n.translate('xpack.stackConnectors.components.inference.selectable.providerSearch', {
      defaultMessage: 'Search'
    }),
    onSearch: onSearchProvider,
    incremental: false,
    compressed: true,
    fullWidth: true
  }), [onSearchProvider]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiSelectable, {
    "data-test-subj": "selectable-provider-input",
    isLoading: isLoading,
    renderOption: renderProviderOption,
    onChange: handleProviderChange,
    searchable: true,
    searchProps: searchProps,
    singleSelection: true,
    options: getSelectableOptions(searchProviderValue)
  }, EuiSelectableContent);
};
const SelectableProvider = exports.SelectableProvider = /*#__PURE__*/(0, _react.memo)(SelectableProviderComponent);