"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConnectorConfigurationField = exports.ConfigSwitchField = exports.ConfigSensitiveTextArea = exports.ConfigSelectField = exports.ConfigNumberField = exports.ConfigInputTextArea = exports.ConfigInputPassword = exports.ConfigInputField = exports.ConfigCheckableField = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _fp = require("lodash/fp");
var _connector_configuration_utils = require("./connector_configuration_utils");
var _types = require("./types");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ConfigInputField = ({
  configEntry,
  isLoading,
  validateAndSetConfigValue
}) => {
  // eslint-disable-next-line @typescript-eslint/naming-convention
  const {
    isValid,
    placeholder,
    value,
    default_value,
    key
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(!value || value.toString().length === 0 ? default_value : value);
  (0, _react.useEffect)(() => {
    setInnerValue(!value || value.toString().length === 0 ? default_value : value);
  }, [default_value, value]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFieldText, {
    disabled: isLoading,
    "data-test-subj": `${key}-input`,
    fullWidth: true,
    value: (0, _connector_configuration_utils.ensureStringType)(innerValue),
    isInvalid: !isValid,
    onChange: event => {
      setInnerValue(event.target.value);
      validateAndSetConfigValue(event.target.value);
    },
    placeholder: placeholder
  });
};
exports.ConfigInputField = ConfigInputField;
const ConfigSwitchField = ({
  configEntry,
  isLoading,
  validateAndSetConfigValue
}) => {
  // eslint-disable-next-line @typescript-eslint/naming-convention
  const {
    label,
    value,
    default_value,
    key
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(value !== null && value !== void 0 ? value : default_value);
  (0, _react.useEffect)(() => {
    setInnerValue(value !== null && value !== void 0 ? value : default_value);
  }, [default_value, value]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiSwitch, {
    checked: (0, _connector_configuration_utils.ensureBooleanType)(innerValue),
    "data-test-subj": `${key}-switch`,
    disabled: isLoading,
    label: /*#__PURE__*/_react.default.createElement("p", null, label),
    onChange: event => {
      setInnerValue(event.target.checked);
      validateAndSetConfigValue(event.target.checked);
    }
  });
};
exports.ConfigSwitchField = ConfigSwitchField;
const ConfigInputTextArea = ({
  isLoading,
  configEntry,
  validateAndSetConfigValue
}) => {
  // eslint-disable-next-line @typescript-eslint/naming-convention
  const {
    isValid,
    placeholder,
    value,
    default_value,
    key
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(value !== null && value !== void 0 ? value : default_value);
  (0, _react.useEffect)(() => {
    setInnerValue(value !== null && value !== void 0 ? value : default_value);
  }, [default_value, value]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiTextArea, {
    disabled: isLoading,
    fullWidth: true,
    "data-test-subj": `${key}-textarea`
    // ensures placeholder shows up when value is empty string
    ,
    value: (0, _connector_configuration_utils.ensureStringType)(innerValue),
    isInvalid: !isValid,
    onChange: event => {
      setInnerValue(event.target.value);
      validateAndSetConfigValue(event.target.value);
    },
    placeholder: placeholder
  });
};
exports.ConfigInputTextArea = ConfigInputTextArea;
const ConfigNumberField = ({
  configEntry,
  isLoading,
  validateAndSetConfigValue
}) => {
  // eslint-disable-next-line @typescript-eslint/naming-convention
  const {
    isValid,
    placeholder,
    value,
    default_value,
    key
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(value !== null && value !== void 0 ? value : default_value);
  (0, _react.useEffect)(() => {
    setInnerValue(!value || value.toString().length === 0 ? default_value : value);
  }, [default_value, value]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFieldNumber, {
    fullWidth: true,
    disabled: isLoading,
    "data-test-subj": `${key}-number`,
    value: innerValue,
    isInvalid: !isValid,
    onChange: event => {
      const newValue = (0, _fp.isEmpty)(event.target.value) ? '0' : event.target.value;
      setInnerValue(newValue);
      validateAndSetConfigValue(newValue);
    },
    placeholder: placeholder
  });
};
exports.ConfigNumberField = ConfigNumberField;
const ConfigCheckableField = ({
  configEntry,
  validateAndSetConfigValue
}) => {
  const radioCardId = (0, _eui.useGeneratedHtmlId)({
    prefix: 'radioCard'
  });
  // eslint-disable-next-line @typescript-eslint/naming-convention
  const {
    value,
    options,
    default_value
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(value !== null && value !== void 0 ? value : default_value);
  (0, _react.useEffect)(() => {
    setInnerValue(value !== null && value !== void 0 ? value : default_value);
  }, [default_value, value]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, options === null || options === void 0 ? void 0 : options.map(o => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiCheckableCard, {
    id: radioCardId,
    label: o.label,
    value: innerValue,
    checked: innerValue === o.value,
    onChange: event => {
      setInnerValue(o.value);
      validateAndSetConfigValue(o.value);
    }
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }))));
};
exports.ConfigCheckableField = ConfigCheckableField;
const ConfigSensitiveTextArea = ({
  isLoading,
  configEntry,
  validateAndSetConfigValue
}) => {
  const {
    key,
    label
  } = configEntry;
  return /*#__PURE__*/_react.default.createElement(_eui.EuiAccordion, {
    id: key + '-accordion',
    buttonContent: /*#__PURE__*/_react.default.createElement("p", null, label)
  }, /*#__PURE__*/_react.default.createElement(ConfigInputTextArea, {
    isLoading: isLoading,
    configEntry: configEntry,
    validateAndSetConfigValue: validateAndSetConfigValue
  }));
};
exports.ConfigSensitiveTextArea = ConfigSensitiveTextArea;
const ConfigInputPassword = ({
  isLoading,
  configEntry,
  validateAndSetConfigValue
}) => {
  const {
    value,
    key
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(value !== null && value !== void 0 ? value : null);
  (0, _react.useEffect)(() => {
    setInnerValue(value !== null && value !== void 0 ? value : null);
  }, [value]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldPassword, {
    fullWidth: true,
    disabled: isLoading,
    "data-test-subj": `${key}-password`,
    type: "dual",
    value: (0, _connector_configuration_utils.ensureStringType)(innerValue),
    onChange: event => {
      setInnerValue(event.target.value);
      validateAndSetConfigValue(event.target.value);
    }
  }));
};
exports.ConfigInputPassword = ConfigInputPassword;
const ConfigSelectField = ({
  configEntry,
  isLoading,
  validateAndSetConfigValue
}) => {
  // eslint-disable-next-line @typescript-eslint/naming-convention
  const {
    isValid,
    options,
    value,
    default_value
  } = configEntry;
  const [innerValue, setInnerValue] = (0, _react.useState)(value !== null && value !== void 0 ? value : default_value);
  const optionsRes = options === null || options === void 0 ? void 0 : options.map(o => ({
    value: o.value,
    inputDisplay: /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "s",
      alignItems: "center",
      responsive: false
    }, o.icon ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      color: "subdued",
      style: {
        lineHeight: 'inherit'
      },
      type: o.icon
    })) : null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, o.label)))
  }));
  return /*#__PURE__*/_react.default.createElement(_eui.EuiSuperSelect, {
    fullWidth: true,
    isInvalid: !isValid,
    disabled: isLoading,
    options: optionsRes,
    valueOfSelected: innerValue,
    onChange: newValue => {
      setInnerValue(newValue);
      validateAndSetConfigValue(newValue);
    }
  });
};
exports.ConfigSelectField = ConfigSelectField;
const ConnectorConfigurationField = ({
  configEntry,
  isLoading,
  setConfigValue
}) => {
  const validateAndSetConfigValue = value => {
    setConfigValue((0, _connector_configuration_utils.ensureCorrectTyping)(configEntry.type, value));
  };
  const {
    key,
    display,
    sensitive
  } = configEntry;
  switch (display) {
    case _types.DisplayType.DROPDOWN:
      return /*#__PURE__*/_react.default.createElement(ConfigSelectField, {
        key: key,
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      });
    case _types.DisplayType.CHECKABLE:
      return /*#__PURE__*/_react.default.createElement(ConfigCheckableField, {
        key: key,
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      });
    case _types.DisplayType.NUMERIC:
      return /*#__PURE__*/_react.default.createElement(ConfigNumberField, {
        key: key,
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      });
    case _types.DisplayType.TEXTAREA:
      const textarea = /*#__PURE__*/_react.default.createElement(ConfigInputTextArea, {
        key: sensitive ? key + '-sensitive-text-area' : key + 'text-area',
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      });
      return sensitive ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(ConfigSensitiveTextArea, {
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      })) : textarea;
    case _types.DisplayType.TOGGLE:
      return /*#__PURE__*/_react.default.createElement(ConfigSwitchField, {
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      });
    default:
      return sensitive ? /*#__PURE__*/_react.default.createElement(ConfigInputPassword, {
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      }) : /*#__PURE__*/_react.default.createElement(ConfigInputField, {
        key: key,
        isLoading: isLoading,
        configEntry: configEntry,
        validateAndSetConfigValue: validateAndSetConfigValue
      });
  }
};
exports.ConnectorConfigurationField = ConnectorConfigurationField;