"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConnectorConfigurationFormItems = void 0;
var _react = _interopRequireDefault(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _types = require("./types");
var _connector_configuration_field = require("./connector_configuration_field");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ConnectorConfigurationFormItems = ({
  isLoading,
  items,
  setConfigEntry,
  direction,
  itemsGrow
}) => {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: direction,
    "data-test-subj": "connector-configuration-fields"
  }, items.map(configEntry => {
    const {
      depends_on: dependencies,
      key,
      display,
      isValid,
      label,
      sensitive,
      tooltip,
      validationErrors,
      required
    } = configEntry;
    const helpText = tooltip;
    // toggle and sensitive textarea labels go next to the element, not in the row
    const rowLabel = display === _types.DisplayType.TOGGLE || display === _types.DisplayType.TEXTAREA && sensitive ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null) : tooltip ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "xs"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement("p", null, label))) : /*#__PURE__*/_react.default.createElement("p", null, label);
    const optionalLabel = !required ? /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      color: "subdued",
      size: "xs"
    }, _i18n.i18n.translate('xpack.stackConnectors.components.inference.config.optionalValue', {
      defaultMessage: 'Optional'
    })) : undefined;
    if ((dependencies === null || dependencies === void 0 ? void 0 : dependencies.length) > 0) {
      return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
        key: key,
        grow: itemsGrow
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
        color: "subdued",
        borderRadius: "none"
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
        fullWidth: true,
        label: rowLabel,
        helpText: helpText,
        error: validationErrors,
        isInvalid: !isValid,
        labelAppend: optionalLabel,
        "data-test-subj": `connector-configuration-formrow-${key}`
      }, /*#__PURE__*/_react.default.createElement(_connector_configuration_field.ConnectorConfigurationField, {
        configEntry: configEntry,
        isLoading: isLoading,
        setConfigValue: value => {
          setConfigEntry(configEntry.key, value);
        }
      }))));
    }
    return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      key: key
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
      label: rowLabel,
      fullWidth: true,
      helpText: helpText,
      error: validationErrors,
      isInvalid: !isValid,
      labelAppend: optionalLabel,
      "data-test-subj": `connector-configuration-formrow-${key}`
    }, /*#__PURE__*/_react.default.createElement(_connector_configuration_field.ConnectorConfigurationField, {
      configEntry: configEntry,
      isLoading: isLoading,
      setConfigValue: value => {
        setConfigEntry(configEntry.key, value);
      }
    })), configEntry.sensitive ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "s"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      size: "s",
      color: "warning",
      title: `You will need to reenter you ${configEntry.label} each time you edit the connector`
    })) : null);
  }));
};
exports.ConnectorConfigurationFormItems = ConnectorConfigurationFormItems;