"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validIntInput = exports.hasUiRestrictions = exports.ensureStringType = exports.ensureIntType = exports.ensureCorrectTyping = exports.ensureBooleanType = void 0;
var _types = require("./types");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const validIntInput = value => {
  // reject non integers (including x.0 floats), but don't validate if empty
  return (value !== null || value !== '') && (isNaN(Number(value)) || !Number.isSafeInteger(Number(value)) || ensureStringType(value).indexOf('.') >= 0) ? false : true;
};
exports.validIntInput = validIntInput;
const ensureCorrectTyping = (type, value) => {
  switch (type) {
    case _types.FieldType.INTEGER:
      return validIntInput(value) ? ensureIntType(value) : value;
    case _types.FieldType.BOOLEAN:
      return ensureBooleanType(value);
    default:
      return ensureStringType(value);
  }
};
exports.ensureCorrectTyping = ensureCorrectTyping;
const ensureStringType = value => {
  return value !== null ? String(value) : '';
};
exports.ensureStringType = ensureStringType;
const ensureIntType = value => {
  // int is null-safe to prevent empty values from becoming zeroes
  if (value === null || value === '') {
    return null;
  }
  return parseInt(String(value), 10);
};
exports.ensureIntType = ensureIntType;
const ensureBooleanType = value => {
  return Boolean(value);
};
exports.ensureBooleanType = ensureBooleanType;
const hasUiRestrictions = configEntry => {
  var _configEntry$ui_restr;
  return ((_configEntry$ui_restr = configEntry.ui_restrictions) !== null && _configEntry$ui_restr !== void 0 ? _configEntry$ui_restr : []).length > 0;
};
exports.hasUiRestrictions = hasUiRestrictions;