"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getConditionType = exports.TimeWindowSchema = exports.StatusRulePramsSchema = exports.StatusRuleConditionSchema = exports.NumberOfChecksSchema = void 0;
var _configSchema = require("@kbn/config-schema");
var _lodash = require("lodash");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const TimeWindowSchema = exports.TimeWindowSchema = _configSchema.schema.object({
  unit: _configSchema.schema.oneOf([_configSchema.schema.literal('s'), _configSchema.schema.literal('m'), _configSchema.schema.literal('h'), _configSchema.schema.literal('d')], {
    defaultValue: 'm'
  }),
  size: _configSchema.schema.number({
    defaultValue: 5
  })
});
const NumberOfChecksSchema = exports.NumberOfChecksSchema = _configSchema.schema.object({
  numberOfChecks: _configSchema.schema.number({
    defaultValue: 5,
    min: 1,
    max: 100
  })
});
const StatusRuleConditionSchema = exports.StatusRuleConditionSchema = _configSchema.schema.object({
  groupBy: _configSchema.schema.maybe(_configSchema.schema.string({
    defaultValue: 'locationId'
  })),
  downThreshold: _configSchema.schema.maybe(_configSchema.schema.number({
    defaultValue: 3
  })),
  locationsThreshold: _configSchema.schema.maybe(_configSchema.schema.number({
    defaultValue: 1
  })),
  window: _configSchema.schema.oneOf([_configSchema.schema.object({
    time: TimeWindowSchema
  }), NumberOfChecksSchema]),
  includeRetests: _configSchema.schema.maybe(_configSchema.schema.boolean())
});
const StatusRulePramsSchema = exports.StatusRulePramsSchema = _configSchema.schema.object({
  condition: _configSchema.schema.maybe(StatusRuleConditionSchema),
  monitorIds: _configSchema.schema.maybe(_configSchema.schema.arrayOf(_configSchema.schema.string())),
  locations: _configSchema.schema.maybe(_configSchema.schema.arrayOf(_configSchema.schema.string())),
  tags: _configSchema.schema.maybe(_configSchema.schema.arrayOf(_configSchema.schema.string())),
  monitorTypes: _configSchema.schema.maybe(_configSchema.schema.arrayOf(_configSchema.schema.string())),
  projects: _configSchema.schema.maybe(_configSchema.schema.arrayOf(_configSchema.schema.string())),
  kqlQuery: _configSchema.schema.maybe(_configSchema.schema.string())
});
const getConditionType = condition => {
  var _condition$locationsT, _condition$downThresh2;
  let numberOfChecks = 1;
  let timeWindow = {
    unit: 'm',
    size: 1
  };
  if ((0, _lodash.isEmpty)(condition) || !(condition !== null && condition !== void 0 && condition.window)) {
    return {
      isLocationBased: false,
      useTimeWindow: false,
      timeWindow,
      useLatestChecks: true,
      numberOfChecks,
      downThreshold: 1,
      locationsThreshold: 1,
      isDefaultRule: true
    };
  }
  const useTimeWindow = condition.window && 'time' in condition.window;
  const useLatestChecks = condition.window && 'numberOfChecks' in condition.window;
  if (useLatestChecks) {
    numberOfChecks = condition && 'numberOfChecks' in condition.window ? condition.window.numberOfChecks : 1;
  }
  if (useTimeWindow) {
    var _condition$downThresh;
    timeWindow = condition.window.time;
    numberOfChecks = (_condition$downThresh = condition === null || condition === void 0 ? void 0 : condition.downThreshold) !== null && _condition$downThresh !== void 0 ? _condition$downThresh : 1;
  }
  return {
    useTimeWindow,
    timeWindow,
    useLatestChecks,
    numberOfChecks,
    locationsThreshold: (_condition$locationsT = condition === null || condition === void 0 ? void 0 : condition.locationsThreshold) !== null && _condition$locationsT !== void 0 ? _condition$locationsT : 1,
    downThreshold: (_condition$downThresh2 = condition === null || condition === void 0 ? void 0 : condition.downThreshold) !== null && _condition$downThresh2 !== void 0 ? _condition$downThresh2 : 1,
    isDefaultRule: (0, _lodash.isEmpty)(condition)
  };
};
exports.getConditionType = getConditionType;