"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStatsOverviewEmbeddableFactory = exports.getOverviewPanelTitle = void 0;
var _i18n = require("@kbn/i18n");
var _react = _interopRequireWildcard(require("react"));
var _presentationPublishing = require("@kbn/presentation-publishing");
var _rxjs = require("rxjs");
var _constants = require("../constants");
var _stats_overview_component = require("./stats_overview_component");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const getOverviewPanelTitle = () => _i18n.i18n.translate('xpack.synthetics.statusOverview.list.displayName', {
  defaultMessage: 'Synthetics Stats Overview'
});
exports.getOverviewPanelTitle = getOverviewPanelTitle;
const getStatsOverviewEmbeddableFactory = getStartServices => {
  const factory = {
    type: _constants.SYNTHETICS_STATS_OVERVIEW_EMBEDDABLE,
    deserializeState: state => {
      return state.rawState;
    },
    buildEmbeddable: async (state, buildApi, uuid, parentApi) => {
      const [coreStart, pluginStart] = await getStartServices();
      const {
        titlesApi,
        titleComparators,
        serializeTitles
      } = (0, _presentationPublishing.initializeTitles)(state);
      const defaultTitle$ = new _rxjs.BehaviorSubject(getOverviewPanelTitle());
      const reload$ = new _rxjs.Subject();
      const filters$ = new _rxjs.BehaviorSubject(state.filters);
      const api = buildApi({
        ...titlesApi,
        defaultPanelTitle: defaultTitle$,
        getTypeDisplayName: () => _i18n.i18n.translate('xpack.synthetics.editSloOverviewEmbeddableTitle.typeDisplayName', {
          defaultMessage: 'filters'
        }),
        isEditingEnabled: () => true,
        onEdit: async () => {
          try {
            const {
              openMonitorConfiguration
            } = await Promise.resolve().then(() => _interopRequireWildcard(require('../common/monitors_open_configuration')));
            const result = await openMonitorConfiguration({
              coreStart,
              pluginStart,
              initialState: {
                filters: filters$.getValue()
              },
              title: _i18n.i18n.translate('xpack.synthetics.editSloOverviewEmbeddableTitle.title', {
                defaultMessage: 'Create monitor stats'
              })
            });
            filters$.next(result.filters);
          } catch (e) {
            return Promise.reject();
          }
        },
        serializeState: () => {
          return {
            rawState: {
              ...serializeTitles(),
              filters: filters$.getValue()
            }
          };
        }
      }, {
        ...titleComparators,
        filters: [filters$, value => filters$.next(value)]
      });
      const fetchSubscription = (0, _presentationPublishing.fetch$)(api).pipe().subscribe(next => {
        reload$.next(next.isReload);
      });
      return {
        api,
        Component: () => {
          const [filters] = (0, _presentationPublishing.useBatchedPublishingSubjects)(filters$);
          (0, _react.useEffect)(() => {
            return () => {
              fetchSubscription.unsubscribe();
            };
          }, []);
          return /*#__PURE__*/_react.default.createElement("div", {
            style: {
              width: '100%'
            },
            "data-shared-item": "" // TODO: Remove data-shared-item and data-rendering-count as part of https://github.com/elastic/kibana/issues/179376
          }, /*#__PURE__*/_react.default.createElement(_stats_overview_component.StatsOverviewComponent, {
            reload$: reload$,
            filters: filters
          }));
        }
      };
    }
  };
  return factory;
};
exports.getStatsOverviewEmbeddableFactory = getStatsOverviewEmbeddableFactory;