"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerSyntheticsStatusCheckRule = void 0;
var _server = require("@kbn/core/server");
var _lodash = require("lodash");
var _server2 = require("@kbn/alerting-plugin/server");
var _common = require("@kbn/observability-plugin/common");
var _elasticApmNode = _interopRequireDefault(require("elastic-apm-node"));
var _synthetics_rule_field_map = require("../../../common/rules/synthetics_rule_field_map");
var _status_rule_executor = require("./status_rule_executor");
var _status_rule = require("../../../common/rules/status_rule");
var _synthetics_alerts = require("../../../common/constants/synthetics_alerts");
var _common2 = require("../common");
var _action_variables = require("../action_variables");
var _translations = require("../translations");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const registerSyntheticsStatusCheckRule = (server, plugins, syntheticsMonitorClient) => {
  if (!plugins.alerting) {
    throw new Error('Cannot register the synthetics monitor status rule type. The alerting plugin needs to be enabled.');
  }
  plugins.alerting.registerType({
    id: _synthetics_alerts.SYNTHETICS_ALERT_RULE_TYPES.MONITOR_STATUS,
    category: _server.DEFAULT_APP_CATEGORIES.observability.id,
    producer: 'uptime',
    name: _translations.STATUS_RULE_NAME,
    validate: {
      params: _status_rule.StatusRulePramsSchema
    },
    defaultActionGroupId: _synthetics_alerts.MONITOR_STATUS.id,
    actionGroups: [_synthetics_alerts.MONITOR_STATUS],
    actionVariables: (0, _action_variables.getActionVariables)({
      plugins
    }),
    isExportable: true,
    minimumLicenseRequired: 'basic',
    doesSetRecoveryContext: true,
    executor: async options => {
      var _params$condition$gro, _params$condition, _ruleState$meta;
      _elasticApmNode.default.setTransactionName('Synthetics Status Rule Executor');
      const {
        state: ruleState,
        params,
        services,
        spaceId
      } = options;
      const {
        alertsClient,
        uiSettingsClient
      } = services;
      if (!alertsClient) {
        throw new _server2.AlertsClientError();
      }
      const {
        basePath
      } = server;
      const [dateFormat, timezone] = await Promise.all([uiSettingsClient.get('dateFormat'), uiSettingsClient.get('dateFormat:tz')]);
      const tz = timezone === 'Browser' ? 'UTC' : timezone;
      const groupBy = (_params$condition$gro = params === null || params === void 0 ? void 0 : (_params$condition = params.condition) === null || _params$condition === void 0 ? void 0 : _params$condition.groupBy) !== null && _params$condition$gro !== void 0 ? _params$condition$gro : 'locationId';
      const groupByLocation = groupBy === 'locationId';
      const statusRule = new _status_rule_executor.StatusRuleExecutor(server, syntheticsMonitorClient, options);
      const {
        downConfigs,
        staleDownConfigs,
        upConfigs
      } = await statusRule.getDownChecks((_ruleState$meta = ruleState.meta) === null || _ruleState$meta === void 0 ? void 0 : _ruleState$meta.downConfigs);
      statusRule.handleDownMonitorThresholdAlert({
        downConfigs
      });
      (0, _common2.setRecoveredAlertsContext)({
        alertsClient,
        basePath,
        spaceId,
        dateFormat,
        tz,
        params,
        groupByLocation,
        staleDownConfigs,
        upConfigs
      });
      return {
        state: (0, _common2.updateState)(ruleState, !(0, _lodash.isEmpty)(downConfigs), {
          downConfigs
        })
      };
    },
    alerts: _common2.SyntheticsRuleTypeAlertDefinition,
    fieldsForAAD: Object.keys(_synthetics_rule_field_map.syntheticsRuleFieldMap),
    getViewInAppRelativeUrl: ({
      rule
    }) => _common.observabilityPaths.ruleDetails(rule.id)
  });
};
exports.registerSyntheticsStatusCheckRule = registerSyntheticsStatusCheckRule;