"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.queryFilterMonitors = queryFilterMonitors;
var _esQuery = require("@kbn/es-query");
var _client_defaults = require("../../../../common/constants/client_defaults");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

async function queryFilterMonitors({
  spaceId,
  esClient,
  ruleParams
}) {
  var _result$aggregations;
  if (!ruleParams.kqlQuery) {
    return;
  }
  const filters = (0, _esQuery.toElasticsearchQuery)((0, _esQuery.fromKueryExpression)(ruleParams.kqlQuery));
  const {
    body: result
  } = await esClient.search({
    body: {
      size: 0,
      query: {
        bool: {
          filter: [_client_defaults.FINAL_SUMMARY_FILTER, (0, _client_defaults.getRangeFilter)({
            from: 'now-24h/m',
            to: 'now/m'
          }), (0, _client_defaults.getTimeSpanFilter)(), {
            term: {
              'meta.space_id': spaceId
            }
          }, {
            bool: {
              should: filters
            }
          }, ...getFilters(ruleParams)]
        }
      },
      aggs: {
        ids: {
          terms: {
            size: 10000,
            field: 'config_id'
          }
        }
      }
    }
  });
  return (_result$aggregations = result.aggregations) === null || _result$aggregations === void 0 ? void 0 : _result$aggregations.ids.buckets.map(bucket => bucket.key);
}
const getFilters = ruleParams => {
  const {
    monitorTypes,
    locations,
    tags,
    projects
  } = ruleParams;
  const filters = [];
  if (monitorTypes !== null && monitorTypes !== void 0 && monitorTypes.length) {
    filters.push({
      terms: {
        'monitor.type': monitorTypes
      }
    });
  }
  if (locations !== null && locations !== void 0 && locations.length) {
    filters.push({
      terms: {
        'observer.name': locations
      }
    });
  }
  if (tags !== null && tags !== void 0 && tags.length) {
    filters.push({
      terms: {
        tags
      }
    });
  }
  if (projects !== null && projects !== void 0 && projects.length) {
    filters.push({
      terms: {
        'monitor.project.id': projects
      }
    });
  }
  return filters;
};