"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDoesMonitorMeetLocationThreshold = exports.getConfigsByIds = exports.StatusRuleExecutor = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _moment = _interopRequireDefault(require("moment"));
var _lodash = require("lodash");
var _common = require("@kbn/observability-plugin/common");
var _filter_monitors = require("./queries/filter_monitors");
var _common2 = require("../common");
var _message_utils = require("./message_utils");
var _query_monitor_status_alert = require("./queries/query_monitor_status_alert");
var _common3 = require("../../routes/common");
var _lib = require("../../lib");
var _constants = require("../../../common/constants");
var _get_all_monitors = require("../../saved_objects/synthetics_monitor/get_all_monitors");
var _status_rule = require("../../../common/rules/status_rule");
var _runtime_types = require("../../../common/runtime_types");
var _saved_objects = require("../../../common/types/saved_objects");
var _monitor_management = require("../../../common/constants/monitor_management");
var _action_variables = require("../action_variables");
var _synthetics_alerts = require("../../../common/constants/synthetics_alerts");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

class StatusRuleExecutor {
  constructor(server, syntheticsMonitorClient, options) {
    (0, _defineProperty2.default)(this, "previousStartedAt", void 0);
    (0, _defineProperty2.default)(this, "params", void 0);
    (0, _defineProperty2.default)(this, "esClient", void 0);
    (0, _defineProperty2.default)(this, "soClient", void 0);
    (0, _defineProperty2.default)(this, "server", void 0);
    (0, _defineProperty2.default)(this, "syntheticsMonitorClient", void 0);
    (0, _defineProperty2.default)(this, "monitors", []);
    (0, _defineProperty2.default)(this, "hasCustomCondition", void 0);
    (0, _defineProperty2.default)(this, "monitorLocationsMap", void 0);
    // monitorId: locationIds
    (0, _defineProperty2.default)(this, "dateFormat", void 0);
    (0, _defineProperty2.default)(this, "tz", void 0);
    (0, _defineProperty2.default)(this, "options", void 0);
    (0, _defineProperty2.default)(this, "logger", void 0);
    (0, _defineProperty2.default)(this, "ruleName", void 0);
    (0, _defineProperty2.default)(this, "getRange", maxPeriod => {
      let from = this.previousStartedAt ? (0, _moment.default)(this.previousStartedAt).subtract(1, 'minute').toISOString() : 'now-2m';
      const condition = this.params.condition;
      if (condition && 'numberOfChecks' in (condition === null || condition === void 0 ? void 0 : condition.window)) {
        const numberOfChecks = condition.window.numberOfChecks;
        from = (0, _moment.default)().subtract(maxPeriod * numberOfChecks, 'milliseconds').subtract(5, 'minutes').toISOString();
      } else if (condition && 'time' in condition.window) {
        const time = condition.window.time;
        const {
          unit,
          size
        } = time;
        from = (0, _moment.default)().subtract(size, unit).toISOString();
      }
      this.debug(`Using range from ${from} to now, diff of ${(0, _moment.default)().diff(from, 'minutes')} minutes`);
      return {
        from,
        to: 'now'
      };
    });
    (0, _defineProperty2.default)(this, "handleDownMonitorThresholdAlert", ({
      downConfigs
    }) => {
      var _this$params, _this$params$conditio, _this$params2, _this$params2$conditi;
      const {
        useTimeWindow,
        useLatestChecks,
        downThreshold,
        locationsThreshold
      } = (0, _status_rule.getConditionType)((_this$params = this.params) === null || _this$params === void 0 ? void 0 : _this$params.condition);
      const groupBy = (_this$params$conditio = (_this$params2 = this.params) === null || _this$params2 === void 0 ? void 0 : (_this$params2$conditi = _this$params2.condition) === null || _this$params2$conditi === void 0 ? void 0 : _this$params2$conditi.groupBy) !== null && _this$params$conditio !== void 0 ? _this$params$conditio : 'locationId';
      if (groupBy === 'locationId' && locationsThreshold === 1) {
        Object.entries(downConfigs).forEach(([idWithLocation, statusConfig]) => {
          const doesMonitorMeetLocationThreshold = getDoesMonitorMeetLocationThreshold({
            matchesByLocation: [statusConfig],
            locationsThreshold,
            downThreshold,
            useTimeWindow: useTimeWindow || false
          });
          if (doesMonitorMeetLocationThreshold) {
            var _statusConfig$ping$ob;
            const alertId = idWithLocation;
            const monitorSummary = this.getMonitorDownSummary({
              statusConfig
            });
            return this.scheduleAlert({
              idWithLocation,
              alertId,
              monitorSummary,
              statusConfig,
              downThreshold,
              useLatestChecks,
              locationNames: [(_statusConfig$ping$ob = statusConfig.ping.observer.geo) === null || _statusConfig$ping$ob === void 0 ? void 0 : _statusConfig$ping$ob.name],
              locationIds: [statusConfig.ping.observer.name]
            });
          }
        });
      } else {
        const downConfigsById = getConfigsByIds(downConfigs);
        for (const [configId, configs] of downConfigsById) {
          const doesMonitorMeetLocationThreshold = getDoesMonitorMeetLocationThreshold({
            matchesByLocation: configs,
            locationsThreshold,
            downThreshold,
            useTimeWindow: useTimeWindow || false
          });
          if (doesMonitorMeetLocationThreshold) {
            const alertId = configId;
            const monitorSummary = this.getUngroupedDownSummary({
              statusConfigs: configs
            });
            return this.scheduleAlert({
              idWithLocation: configId,
              alertId,
              monitorSummary,
              statusConfig: configs[0],
              downThreshold,
              useLatestChecks,
              locationNames: configs.map(c => {
                var _c$ping$observer$geo;
                return (_c$ping$observer$geo = c.ping.observer.geo) === null || _c$ping$observer$geo === void 0 ? void 0 : _c$ping$observer$geo.name;
              }),
              locationIds: configs.map(c => c.ping.observer.name)
            });
          }
        }
      }
    });
    const {
      services,
      params,
      previousStartedAt,
      rule
    } = options;
    const {
      scopedClusterClient,
      savedObjectsClient
    } = services;
    this.ruleName = rule.name;
    this.logger = server.logger;
    this.previousStartedAt = previousStartedAt;
    this.params = params;
    this.soClient = savedObjectsClient;
    this.esClient = new _lib.SyntheticsEsClient(this.soClient, scopedClusterClient.asCurrentUser, {
      heartbeatIndices: _constants.SYNTHETICS_INDEX_PATTERN
    });
    this.server = server;
    this.syntheticsMonitorClient = syntheticsMonitorClient;
    this.hasCustomCondition = !(0, _lodash.isEmpty)(this.params);
    this.monitorLocationsMap = {};
    this.options = options;
  }
  debug(message) {
    this.logger.debug(`[Status Rule Executor][${this.ruleName}] ${message}`);
  }
  async init() {
    const {
      uiSettingsClient
    } = this.options.services;
    this.dateFormat = await uiSettingsClient.get('dateFormat');
    const timezone = await uiSettingsClient.get('dateFormat:tz');
    this.tz = timezone === 'Browser' ? 'UTC' : timezone;
  }
  async getMonitors() {
    var _this$params3, _this$params4, _this$params5, _this$params6, _this$params7;
    const baseFilter = !this.hasCustomCondition ? `${_saved_objects.monitorAttributes}.${_monitor_management.AlertConfigKey.STATUS_ENABLED}: true` : '';
    const configIds = await (0, _filter_monitors.queryFilterMonitors)({
      spaceId: this.options.spaceId,
      esClient: this.esClient,
      ruleParams: this.params
    });
    const {
      filtersStr
    } = (0, _common3.parseArrayFilters)({
      configIds,
      filter: baseFilter,
      tags: (_this$params3 = this.params) === null || _this$params3 === void 0 ? void 0 : _this$params3.tags,
      locations: (_this$params4 = this.params) === null || _this$params4 === void 0 ? void 0 : _this$params4.locations,
      monitorTypes: (_this$params5 = this.params) === null || _this$params5 === void 0 ? void 0 : _this$params5.monitorTypes,
      monitorQueryIds: (_this$params6 = this.params) === null || _this$params6 === void 0 ? void 0 : _this$params6.monitorIds,
      projects: (_this$params7 = this.params) === null || _this$params7 === void 0 ? void 0 : _this$params7.projects
    });
    this.monitors = await (0, _get_all_monitors.getAllMonitors)({
      soClient: this.soClient,
      filter: filtersStr
    });
    this.debug(`Found ${this.monitors.length} monitors for params ${JSON.stringify(this.params)}`);
    return (0, _get_all_monitors.processMonitors)(this.monitors);
  }
  async getDownChecks(prevDownConfigs = {}) {
    var _this$params8, _this$params$conditio2;
    await this.init();
    const {
      enabledMonitorQueryIds,
      maxPeriod,
      monitorLocationIds,
      monitorLocationsMap
    } = await this.getMonitors();
    const range = this.getRange(maxPeriod);
    const {
      numberOfChecks
    } = (0, _status_rule.getConditionType)(this.params.condition);
    if (enabledMonitorQueryIds.length === 0) {
      const staleDownConfigs = this.markDeletedConfigs(prevDownConfigs);
      return {
        downConfigs: {
          ...prevDownConfigs
        },
        upConfigs: {},
        staleDownConfigs,
        enabledMonitorQueryIds,
        pendingConfigs: {}
      };
    }
    const queryLocations = (_this$params8 = this.params) === null || _this$params8 === void 0 ? void 0 : _this$params8.locations;

    // Account for locations filter
    const listOfLocationAfterFilter = queryLocations ? (0, _lodash.intersection)(monitorLocationIds, queryLocations) : monitorLocationIds;
    const currentStatus = await (0, _query_monitor_status_alert.queryMonitorStatusAlert)({
      esClient: this.esClient,
      monitorLocationIds: listOfLocationAfterFilter,
      range,
      monitorQueryIds: enabledMonitorQueryIds,
      numberOfChecks,
      monitorLocationsMap,
      includeRetests: (_this$params$conditio2 = this.params.condition) === null || _this$params$conditio2 === void 0 ? void 0 : _this$params$conditio2.includeRetests
    });
    const {
      downConfigs,
      upConfigs
    } = currentStatus;
    this.debug(`Found ${Object.keys(downConfigs).length} down configs and ${Object.keys(upConfigs).length} up configs`);
    const downConfigsById = getConfigsByIds(downConfigs);
    const upConfigsById = getConfigsByIds(upConfigs);
    (0, _lodash.uniq)([...downConfigsById.keys(), ...upConfigsById.keys()]).forEach(configId => {
      var _downConfigsById$get$, _downConfigsById$get, _upConfigsById$get$le, _upConfigsById$get, _this$monitors$find$a, _this$monitors$find;
      const downCount = (_downConfigsById$get$ = (_downConfigsById$get = downConfigsById.get(configId)) === null || _downConfigsById$get === void 0 ? void 0 : _downConfigsById$get.length) !== null && _downConfigsById$get$ !== void 0 ? _downConfigsById$get$ : 0;
      const upCount = (_upConfigsById$get$le = (_upConfigsById$get = upConfigsById.get(configId)) === null || _upConfigsById$get === void 0 ? void 0 : _upConfigsById$get.length) !== null && _upConfigsById$get$le !== void 0 ? _upConfigsById$get$le : 0;
      const name = (_this$monitors$find$a = (_this$monitors$find = this.monitors.find(m => m.id === configId)) === null || _this$monitors$find === void 0 ? void 0 : _this$monitors$find.attributes.name) !== null && _this$monitors$find$a !== void 0 ? _this$monitors$find$a : configId;
      this.debug(`Monitor: ${name} with id ${configId} has ${downCount} down check and ${upCount} up check`);
    });
    Object.keys(prevDownConfigs).forEach(locId => {
      if (!downConfigs[locId] && !upConfigs[locId]) {
        downConfigs[locId] = prevDownConfigs[locId];
      }
    });
    const staleDownConfigs = this.markDeletedConfigs(downConfigs);
    return {
      ...currentStatus,
      staleDownConfigs,
      pendingConfigs: {}
    };
  }
  markDeletedConfigs(downConfigs) {
    const monitors = this.monitors;
    const staleDownConfigs = {};
    Object.keys(downConfigs).forEach(locPlusId => {
      const downConfig = downConfigs[locPlusId];
      const monitor = monitors.find(m => {
        return m.id === downConfig.configId || m.attributes[_runtime_types.ConfigKey.MONITOR_QUERY_ID] === downConfig.monitorQueryId;
      });
      if (!monitor) {
        staleDownConfigs[locPlusId] = {
          ...downConfig,
          isDeleted: true
        };
        delete downConfigs[locPlusId];
      } else {
        const {
          locations
        } = monitor.attributes;
        const isLocationRemoved = !locations.some(l => l.id === downConfig.locationId);
        if (isLocationRemoved) {
          staleDownConfigs[locPlusId] = {
            ...downConfig,
            isLocationRemoved: true
          };
          delete downConfigs[locPlusId];
        }
      }
    });
    return staleDownConfigs;
  }
  getMonitorDownSummary({
    statusConfig
  }) {
    var _this$dateFormat, _this$tz;
    const {
      ping,
      configId,
      locationId,
      checks
    } = statusConfig;
    return (0, _message_utils.getMonitorSummary)({
      monitorInfo: ping,
      statusMessage: _message_utils.DOWN_LABEL,
      locationId: [locationId],
      configId,
      dateFormat: (_this$dateFormat = this.dateFormat) !== null && _this$dateFormat !== void 0 ? _this$dateFormat : 'Y-MM-DD HH:mm:ss',
      tz: (_this$tz = this.tz) !== null && _this$tz !== void 0 ? _this$tz : 'UTC',
      checks,
      params: this.params
    });
  }
  getUngroupedDownSummary({
    statusConfigs
  }) {
    const sampleConfig = statusConfigs[0];
    const {
      ping,
      configId,
      checks
    } = sampleConfig;
    const baseSummary = (0, _message_utils.getMonitorSummary)({
      monitorInfo: ping,
      statusMessage: _message_utils.DOWN_LABEL,
      locationId: statusConfigs.map(c => c.ping.observer.name),
      configId,
      dateFormat: this.dateFormat,
      tz: this.tz,
      checks,
      params: this.params
    });
    baseSummary.reason = (0, _message_utils.getUngroupedReasonMessage)({
      statusConfigs,
      monitorName: baseSummary.monitorName,
      params: this.params
    });
    if (statusConfigs.length > 1) {
      baseSummary.locationNames = statusConfigs.map(c => {
        var _c$ping$observer$geo2;
        return (_c$ping$observer$geo2 = c.ping.observer.geo) === null || _c$ping$observer$geo2 === void 0 ? void 0 : _c$ping$observer$geo2.name;
      }).join(` ${_common2.AND_LABEL} `);
    }
    return baseSummary;
  }
  scheduleAlert({
    idWithLocation,
    alertId,
    monitorSummary,
    statusConfig,
    downThreshold,
    useLatestChecks = false,
    locationNames,
    locationIds
  }) {
    var _ref;
    const {
      configId,
      locationId,
      checks
    } = statusConfig;
    const {
      spaceId,
      startedAt
    } = this.options;
    const {
      alertsClient
    } = this.options.services;
    const {
      basePath
    } = this.server;
    if (!alertsClient) return;
    const {
      uuid: alertUuid,
      start
    } = alertsClient.report({
      id: alertId,
      actionGroup: _synthetics_alerts.MONITOR_STATUS.id
    });
    const errorStartedAt = (_ref = start !== null && start !== void 0 ? start : startedAt.toISOString()) !== null && _ref !== void 0 ? _ref : monitorSummary.timestamp;
    let relativeViewInAppUrl = '';
    if (monitorSummary.stateId) {
      relativeViewInAppUrl = (0, _common2.getRelativeViewInAppUrl)({
        configId,
        locationId,
        stateId: monitorSummary.stateId
      });
    }
    const context = {
      ...monitorSummary,
      idWithLocation,
      checks,
      downThreshold,
      errorStartedAt,
      linkMessage: monitorSummary.stateId ? (0, _common2.getFullViewInAppMessage)(basePath, spaceId, relativeViewInAppUrl) : '',
      [_action_variables.VIEW_IN_APP_URL]: (0, _common2.getViewInAppUrl)(basePath, spaceId, relativeViewInAppUrl),
      [_action_variables.ALERT_DETAILS_URL]: (0, _common.getAlertDetailsUrl)(basePath, spaceId, alertUuid)
    };
    const alertDocument = (0, _message_utils.getMonitorAlertDocument)(monitorSummary, locationNames, locationIds, useLatestChecks);
    alertsClient.setAlertData({
      id: alertId,
      payload: alertDocument,
      context
    });
  }
}
exports.StatusRuleExecutor = StatusRuleExecutor;
const getDoesMonitorMeetLocationThreshold = ({
  matchesByLocation,
  locationsThreshold,
  downThreshold,
  useTimeWindow
}) => {
  // for location based we need to make sure, monitor is down for the threshold for all locations
  const getMatchingLocationsWithDownThresholdWithXChecks = matches => {
    return matches.filter(config => {
      var _config$checks$downWi, _config$checks;
      return ((_config$checks$downWi = (_config$checks = config.checks) === null || _config$checks === void 0 ? void 0 : _config$checks.downWithinXChecks) !== null && _config$checks$downWi !== void 0 ? _config$checks$downWi : 1) >= downThreshold;
    });
  };
  const getMatchingLocationsWithDownThresholdWithinTimeWindow = matches => {
    return matches.filter(config => {
      var _config$checks$down, _config$checks2;
      return ((_config$checks$down = (_config$checks2 = config.checks) === null || _config$checks2 === void 0 ? void 0 : _config$checks2.down) !== null && _config$checks$down !== void 0 ? _config$checks$down : 1) >= downThreshold;
    });
  };
  if (useTimeWindow) {
    const matchingLocationsWithDownThreshold = getMatchingLocationsWithDownThresholdWithinTimeWindow(matchesByLocation);
    return matchingLocationsWithDownThreshold.length >= locationsThreshold;
  } else {
    const matchingLocationsWithDownThreshold = getMatchingLocationsWithDownThresholdWithXChecks(matchesByLocation);
    return matchingLocationsWithDownThreshold.length >= locationsThreshold;
  }
};
exports.getDoesMonitorMeetLocationThreshold = getDoesMonitorMeetLocationThreshold;
const getConfigsByIds = downConfigs => {
  const downConfigsById = new Map();
  Object.entries(downConfigs).forEach(([_, config]) => {
    var _downConfigsById$get2;
    const {
      configId
    } = config;
    if (!downConfigsById.has(configId)) {
      downConfigsById.set(configId, []);
    }
    (_downConfigsById$get2 = downConfigsById.get(configId)) === null || _downConfigsById$get2 === void 0 ? void 0 : _downConfigsById$get2.push(config);
  });
  return downConfigsById;
};
exports.getConfigsByIds = getConfigsByIds;