"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.migrateLegacyPrivateLocations = void 0;
var _private_locations = require("../../../../common/saved_objects/private_locations");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const migrateLegacyPrivateLocations = async ({
  server,
  savedObjectsClient
}) => {
  try {
    var _obj$attributes$locat, _obj;
    let obj;
    try {
      obj = await savedObjectsClient.get(_private_locations.legacyPrivateLocationsSavedObjectName, _private_locations.legacyPrivateLocationsSavedObjectId);
    } catch (e) {
      server.logger.error(`Error getting legacy private locations: ${e}`);
      return;
    }
    const legacyLocations = (_obj$attributes$locat = (_obj = obj) === null || _obj === void 0 ? void 0 : _obj.attributes.locations) !== null && _obj$attributes$locat !== void 0 ? _obj$attributes$locat : [];
    if (legacyLocations.length === 0) {
      return;
    }
    const soClient = server.coreStart.savedObjects.createInternalRepository();
    await soClient.bulkCreate(legacyLocations.map(location => ({
      id: location.id,
      attributes: location,
      type: _private_locations.privateLocationSavedObjectName,
      initialNamespaces: ['*']
    })), {
      overwrite: true
    });
    const {
      total
    } = await savedObjectsClient.find({
      type: _private_locations.privateLocationSavedObjectName,
      fields: [],
      perPage: 0
    });
    if (total === legacyLocations.length) {
      await savedObjectsClient.delete(_private_locations.legacyPrivateLocationsSavedObjectName, _private_locations.legacyPrivateLocationsSavedObjectId, {});
    }
  } catch (e) {
    server.logger.error(`Error migrating legacy private locations: ${e}`);
  }
};
exports.migrateLegacyPrivateLocations = migrateLegacyPrivateLocations;