"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPrivateLocations = void 0;
var _server = require("@kbn/core/server");
var _lodash = require("lodash");
var _private_locations = require("../../common/saved_objects/private_locations");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getPrivateLocations = async client => {
  try {
    const finder = client.createPointInTimeFinder({
      type: _private_locations.privateLocationSavedObjectName,
      perPage: 1000
    });
    const results = [];
    for await (const response of finder.find()) {
      results.push(...response.saved_objects);
    }
    finder.close().catch(e => {});
    const legacyLocations = await getLegacyPrivateLocations(client);
    return (0, _lodash.uniqBy)([...results.map(r => r.attributes), ...legacyLocations], 'id');
  } catch (getErr) {
    if (_server.SavedObjectsErrorHelpers.isNotFoundError(getErr)) {
      return [];
    }
    throw getErr;
  }
};
exports.getPrivateLocations = getPrivateLocations;
const getLegacyPrivateLocations = async client => {
  try {
    var _obj$attributes$locat;
    const obj = await client.get(_private_locations.legacyPrivateLocationsSavedObjectName, _private_locations.legacyPrivateLocationsSavedObjectId);
    return (_obj$attributes$locat = obj === null || obj === void 0 ? void 0 : obj.attributes.locations) !== null && _obj$attributes$locat !== void 0 ? _obj$attributes$locat : [];
  } catch (getErr) {
    return [];
  }
};