"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.selectTasksByCapacity = selectTasksByCapacity;
var _task_claiming = require("../../queries/task_claiming");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

// given a list of tasks and capacity info, select the tasks that meet capacity
function selectTasksByCapacity(tasks, batches) {
  // create a map of task type - concurrency
  const limitedBatches = batches.filter(_task_claiming.isLimited);
  const limitedMap = new Map();
  for (const limitedBatch of limitedBatches) {
    const {
      tasksTypes,
      concurrency
    } = limitedBatch;
    limitedMap.set(tasksTypes, concurrency);
  }

  // apply the limited concurrency
  const result = [];
  for (const task of tasks) {
    const concurrency = limitedMap.get(task.taskType);
    if (concurrency == null) {
      result.push(task);
      continue;
    }
    if (concurrency > 0) {
      result.push(task);
      limitedMap.set(task.taskType, concurrency - 1);
    }
  }
  return result;
}