"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MarkAsUntrackedAlertAction = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _eui = require("@elastic/eui");
var _ruleDataUtils = require("@kbn/rule-data-utils");
var _ = require("../../../..");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Alerts table row action to mark the selected alert as untracked
 */
const MarkAsUntrackedAlertAction = exports.MarkAsUntrackedAlertAction = /*#__PURE__*/(0, _react.memo)(({
  alert,
  refresh,
  onActionExecuted
}) => {
  const {
    mutateAsync: untrackAlerts
  } = (0, _.useBulkUntrackAlerts)();
  const isAlertActive = (0, _react.useMemo)(() => {
    var _alert$ALERT_STATUS;
    return ((_alert$ALERT_STATUS = alert[_ruleDataUtils.ALERT_STATUS]) === null || _alert$ALERT_STATUS === void 0 ? void 0 : _alert$ALERT_STATUS[0]) === _ruleDataUtils.ALERT_STATUS_ACTIVE;
  }, [alert]);
  const handleUntrackAlert = (0, _react.useCallback)(async () => {
    var _alert$_index;
    await untrackAlerts({
      indices: [(_alert$_index = alert._index) !== null && _alert$_index !== void 0 ? _alert$_index : ''],
      alertUuids: [alert._id]
    });
    onActionExecuted === null || onActionExecuted === void 0 ? void 0 : onActionExecuted();
    refresh();
  }, [untrackAlerts, alert._index, alert._id, onActionExecuted, refresh]);
  if (!isAlertActive) {
    return null;
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenuItem, {
    "data-test-subj": "untrackAlert",
    key: "untrackAlert",
    size: "s",
    onClick: handleUntrackAlert
  }, _i18n.i18n.translate('xpack.triggersActionsUI.alertsTable.actions.untrack', {
    defaultMessage: 'Mark as untracked'
  }));
});