"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RuleFormAdvancedOptions = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _eui = require("@elastic/eui");
var _rule_settings_flapping_form = require("@kbn/alerts-ui-shared/src/rule_settings/rule_settings_flapping_form");
var _rule_settings_flapping_title_tooltip = require("@kbn/alerts-ui-shared/src/rule_settings/rule_settings_flapping_title_tooltip");
var _use_fetch_flapping_settings = require("@kbn/alerts-ui-shared/src/common/hooks/use_fetch_flapping_settings");
var _kibana = require("../../../common/lib/kibana");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const alertDelayFormRowLabel = _i18n.i18n.translate('xpack.triggersActionsUI.sections.ruleForm.alertDelayLabel', {
  defaultMessage: 'Alert delay'
});
const alertDelayIconTipDescription = _i18n.i18n.translate('xpack.triggersActionsUI.sections.ruleForm.alertDelayFieldHelp', {
  defaultMessage: 'An alert occurs only when the specified number of consecutive runs meet the rule conditions.'
});
const alertDelayPrependLabel = _i18n.i18n.translate('xpack.triggersActionsUI.sections.ruleForm.alertDelayFieldLabel', {
  defaultMessage: 'Alert after'
});
const alertDelayAppendLabel = _i18n.i18n.translate('xpack.triggersActionsUI.sections.ruleForm.alertDelayFieldAppendLabel', {
  defaultMessage: 'consecutive matches'
});
const flappingFormRowLabel = _i18n.i18n.translate('xpack.triggersActionsUI.sections.ruleForm.flappingLabel', {
  defaultMessage: 'Alert flapping detection'
});
const INTEGER_REGEX = /^[1-9][0-9]*$/;
const RuleFormAdvancedOptions = props => {
  const {
    alertDelay,
    flappingSettings,
    enabledFlapping = true,
    onAlertDelayChange,
    onFlappingChange
  } = props;
  const {
    application: {
      capabilities: {
        rulesSettings
      }
    },
    http
  } = (0, _kibana.useKibana)().services;
  const {
    writeFlappingSettingsUI
  } = rulesSettings || {};
  const [isFlappingTitlePopoverOpen, setIsFlappingTitlePopoverOpen] = (0, _react.useState)(false);
  const {
    data: spaceFlappingSettings,
    isInitialLoading
  } = (0, _use_fetch_flapping_settings.useFetchFlappingSettings)({
    http,
    enabled: enabledFlapping
  });
  const internalOnAlertDelayChange = (0, _react.useCallback)(e => {
    const value = e.target.value;
    if (value === '' || INTEGER_REGEX.test(value)) {
      onAlertDelayChange(value);
    }
  }, [onAlertDelayChange]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    color: "subdued",
    hasShadow: false,
    "data-test-subj": "ruleFormAdvancedOptions"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    fullWidth: true,
    label: /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "xs"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, alertDelayFormRowLabel), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiIconTip, {
      content: alertDelayIconTipDescription,
      position: "top"
    }))),
    "data-test-subj": "alertDelayFormRow",
    display: "rowCompressed"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldNumber, {
    fullWidth: true,
    min: 1,
    value: alertDelay || '',
    name: "alertDelay",
    "data-test-subj": "alertDelayInput",
    prepend: alertDelayPrependLabel,
    append: alertDelayAppendLabel,
    onChange: internalOnAlertDelayChange
  }))), isInitialLoading && /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingSpinner, null), spaceFlappingSettings && enabledFlapping && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    fullWidth: true,
    label: /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      gutterSize: "none",
      alignItems: "center"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, flappingFormRowLabel), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_rule_settings_flapping_title_tooltip.RuleSettingsFlappingTitleTooltip, {
      isOpen: isFlappingTitlePopoverOpen,
      setIsPopoverOpen: setIsFlappingTitlePopoverOpen
    }))),
    "data-test-subj": "alertFlappingFormRow",
    display: "rowCompressed"
  }, /*#__PURE__*/_react.default.createElement(_rule_settings_flapping_form.RuleSettingsFlappingForm, {
    flappingSettings: flappingSettings,
    spaceFlappingSettings: spaceFlappingSettings,
    canWriteFlappingSettingsUI: !!writeFlappingSettingsUI,
    onFlappingChange: onFlappingChange
  })))));
};
exports.RuleFormAdvancedOptions = RuleFormAdvancedOptions;