"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Histogram = Histogram;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _eui = require("@elastic/eui");
var _react = require("@emotion/react");
var _react2 = _interopRequireWildcard(require("react"));
var _public = require("@kbn/inspector-plugin/public");
var _types = require("../types");
var _build_bucket_interval = require("./utils/build_bucket_interval");
var _use_time_range = require("./hooks/use_time_range");
var _use_stable_callback = require("../hooks/use_stable_callback");
var _use_lens_props = require("./hooks/use_lens_props");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const computeTotalHits = (hasLensSuggestions, adapterTables, isPlainRecord) => {
  if (isPlainRecord && hasLensSuggestions) {
    var _Object$values, _Object$values$, _Object$values$$rows;
    return (_Object$values = Object.values(adapterTables !== null && adapterTables !== void 0 ? adapterTables : {})) === null || _Object$values === void 0 ? void 0 : (_Object$values$ = _Object$values[0]) === null || _Object$values$ === void 0 ? void 0 : (_Object$values$$rows = _Object$values$.rows) === null || _Object$values$$rows === void 0 ? void 0 : _Object$values$$rows.length;
  } else if (isPlainRecord && !hasLensSuggestions) {
    var _Object$values2, _Object$values2$;
    // ES|QL histogram case
    const rows = (_Object$values2 = Object.values(adapterTables !== null && adapterTables !== void 0 ? adapterTables : {})) === null || _Object$values2 === void 0 ? void 0 : (_Object$values2$ = _Object$values2[0]) === null || _Object$values2$ === void 0 ? void 0 : _Object$values2$.rows;
    if (!rows) {
      return undefined;
    }
    let rowsCount = 0;
    rows.forEach(r => {
      rowsCount += r.results;
    });
    return rowsCount;
  } else {
    var _adapterTables$unifie, _adapterTables$unifie2, _adapterTables$unifie3;
    return adapterTables === null || adapterTables === void 0 ? void 0 : (_adapterTables$unifie = adapterTables.unifiedHistogram) === null || _adapterTables$unifie === void 0 ? void 0 : (_adapterTables$unifie2 = _adapterTables$unifie.meta) === null || _adapterTables$unifie2 === void 0 ? void 0 : (_adapterTables$unifie3 = _adapterTables$unifie2.statistics) === null || _adapterTables$unifie3 === void 0 ? void 0 : _adapterTables$unifie3.totalCount;
  }
};
function Histogram({
  services: {
    data,
    lens,
    uiSettings
  },
  dataView,
  request,
  hits,
  chart: {
    timeInterval
  },
  isPlainRecord,
  hasLensSuggestions,
  getTimeRange,
  refetch$,
  visContext,
  disableTriggers,
  disabledActions,
  onTotalHitsChange,
  onChartLoad,
  onFilter,
  onBrushEnd,
  withDefaultActions,
  abortController
}) {
  const [bucketInterval, setBucketInterval] = (0, _react2.useState)();
  const {
    timeRangeText,
    timeRangeDisplay
  } = (0, _use_time_range.useTimeRange)({
    uiSettings,
    bucketInterval,
    timeRange: getTimeRange(),
    timeInterval,
    isPlainRecord,
    timeField: dataView.timeFieldName
  });
  const {
    attributes
  } = visContext;
  const onLoad = (0, _use_stable_callback.useStableCallback)((isLoading, adapters, lensEmbeddableOutput$) => {
    var _adapters$requests, _lensRequest$response, _adapters$tables, _response$_shards;
    const lensRequest = adapters === null || adapters === void 0 ? void 0 : (_adapters$requests = adapters.requests) === null || _adapters$requests === void 0 ? void 0 : _adapters$requests.getRequests()[0];
    const requestFailed = (lensRequest === null || lensRequest === void 0 ? void 0 : lensRequest.status) === _public.RequestStatus.ERROR;
    const json = lensRequest === null || lensRequest === void 0 ? void 0 : (_lensRequest$response = lensRequest.response) === null || _lensRequest$response === void 0 ? void 0 : _lensRequest$response.json;
    const response = json === null || json === void 0 ? void 0 : json.rawResponse;
    if (requestFailed) {
      onTotalHitsChange === null || onTotalHitsChange === void 0 ? void 0 : onTotalHitsChange(_types.UnifiedHistogramFetchStatus.error, undefined);
      onChartLoad === null || onChartLoad === void 0 ? void 0 : onChartLoad({
        adapters: adapters !== null && adapters !== void 0 ? adapters : {}
      });
      return;
    }
    const adapterTables = adapters === null || adapters === void 0 ? void 0 : (_adapters$tables = adapters.tables) === null || _adapters$tables === void 0 ? void 0 : _adapters$tables.tables;
    const totalHits = computeTotalHits(hasLensSuggestions, adapterTables, isPlainRecord);
    if (response !== null && response !== void 0 && (_response$_shards = response._shards) !== null && _response$_shards !== void 0 && _response$_shards.failed || response !== null && response !== void 0 && response.timed_out) {
      onTotalHitsChange === null || onTotalHitsChange === void 0 ? void 0 : onTotalHitsChange(_types.UnifiedHistogramFetchStatus.error, totalHits);
    } else {
      onTotalHitsChange === null || onTotalHitsChange === void 0 ? void 0 : onTotalHitsChange(isLoading ? _types.UnifiedHistogramFetchStatus.loading : _types.UnifiedHistogramFetchStatus.complete, totalHits !== null && totalHits !== void 0 ? totalHits : hits === null || hits === void 0 ? void 0 : hits.total);
    }
    if (response) {
      const newBucketInterval = (0, _build_bucket_interval.buildBucketInterval)({
        data,
        dataView,
        timeInterval,
        timeRange: getTimeRange(),
        response
      });
      setBucketInterval(newBucketInterval);
    }
    onChartLoad === null || onChartLoad === void 0 ? void 0 : onChartLoad({
      adapters: adapters !== null && adapters !== void 0 ? adapters : {},
      embeddableOutput$: lensEmbeddableOutput$
    });
  });
  const {
    lensProps,
    requestData
  } = (0, _use_lens_props.useLensProps)({
    request,
    getTimeRange,
    refetch$,
    visContext,
    onLoad
  });
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const boxShadow = `0 2px 2px -1px ${euiTheme.colors.mediumShade},
  0 1px 5px -2px ${euiTheme.colors.mediumShade}`;
  const chartCss = (0, _react.css)`
    position: relative;
    flex-grow: 1;
    margin-block: ${euiTheme.size.xs};

    & > div {
      height: 100%;
      position: absolute;
      width: 100%;
    }

    & .lnsExpressionRenderer {
      width: ${attributes.visualizationType === 'lnsMetric' ? '90%' : '100%'};
      margin: auto;
      box-shadow: ${attributes.visualizationType === 'lnsMetric' ? boxShadow : 'none'};
    }

    & .echLegend .echLegendList {
      padding-right: ${euiTheme.size.s};
    }

    & > .euiLoadingChart {
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
    }
  `;
  return /*#__PURE__*/_react2.default.createElement(_react2.default.Fragment, null, /*#__PURE__*/_react2.default.createElement("div", {
    "data-test-subj": "unifiedHistogramChart",
    "data-time-range": timeRangeText,
    "data-request-data": requestData,
    "data-suggestion-type": visContext.suggestionType,
    css: chartCss
  }, /*#__PURE__*/_react2.default.createElement(lens.EmbeddableComponent, (0, _extends2.default)({}, lensProps, {
    abortController: abortController,
    disableTriggers: disableTriggers,
    disabledActions: disabledActions,
    onFilter: onFilter,
    onBrushEnd: onBrushEnd,
    withDefaultActions: withDefaultActions
  }))), timeRangeDisplay);
}