"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ESQLMenuPopover = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _public = require("@kbn/kibana-react-plugin/public");
var _i18n = require("@kbn/i18n");
var _esqlUtils = require("@kbn/esql-utils");
var _esqlValidationAutocomplete = require("@kbn/esql-validation-autocomplete");
var _languageDocumentation = require("@kbn/language-documentation");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const ESQLMenuPopover = ({
  onESQLDocsFlyoutVisibilityChanged,
  adHocDataview,
  onESQLQuerySubmit
}) => {
  var _docLinks$links$query, _docLinks$links, _docLinks$links$query2;
  const kibana = (0, _public.useKibana)();
  const {
    docLinks
  } = kibana.services;
  const [isESQLMenuPopoverOpen, setIsESQLMenuPopoverOpen] = (0, _react.useState)(false);
  const [isLanguageComponentOpen, setIsLanguageComponentOpen] = (0, _react.useState)(false);
  const toggleLanguageComponent = (0, _react.useCallback)(async () => {
    setIsLanguageComponentOpen(!isLanguageComponentOpen);
    setIsESQLMenuPopoverOpen(false);
  }, [isLanguageComponentOpen]);
  const onHelpMenuVisibilityChange = (0, _react.useCallback)(status => {
    setIsLanguageComponentOpen(status);
    onESQLDocsFlyoutVisibilityChanged === null || onESQLDocsFlyoutVisibilityChanged === void 0 ? void 0 : onESQLDocsFlyoutVisibilityChanged(status);
  }, [setIsLanguageComponentOpen, onESQLDocsFlyoutVisibilityChanged]);
  const esqlContextMenuPanels = (0, _react.useMemo)(() => {
    const recommendedQueries = [];
    if (adHocDataview && typeof adHocDataview !== 'string') {
      var _adHocDataview$timeFi, _adHocDataview$fields, _adHocDataview$fields2, _adHocDataview$fields3;
      const queryString = `from ${adHocDataview.name}`;
      const timeFieldName = (_adHocDataview$timeFi = adHocDataview.timeFieldName) !== null && _adHocDataview$timeFi !== void 0 ? _adHocDataview$timeFi : (_adHocDataview$fields = adHocDataview.fields) === null || _adHocDataview$fields === void 0 ? void 0 : (_adHocDataview$fields2 = _adHocDataview$fields.getByType('date')) === null || _adHocDataview$fields2 === void 0 ? void 0 : (_adHocDataview$fields3 = _adHocDataview$fields2[0]) === null || _adHocDataview$fields3 === void 0 ? void 0 : _adHocDataview$fields3.name;
      recommendedQueries.push(...(0, _esqlValidationAutocomplete.getRecommendedQueries)({
        fromCommand: queryString,
        timeField: timeFieldName
      }));
    }
    const panels = [{
      id: 0,
      items: [{
        name: _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.quickReference', {
          defaultMessage: 'Quick Reference'
        }),
        icon: 'nedocumentationsted',
        renderItem: () => /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenuItem, {
          key: "quickReference",
          icon: "documentation",
          "data-test-subj": "esql-quick-reference",
          onClick: () => toggleLanguageComponent()
        }, _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.quickReference', {
          defaultMessage: 'Quick Reference'
        }))
      }, {
        name: _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.documentation', {
          defaultMessage: 'Documentation'
        }),
        icon: 'iInCircle',
        renderItem: () => /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenuItem, {
          key: "about",
          icon: "iInCircle",
          "data-test-subj": "esql-about",
          target: "_blank",
          href: docLinks.links.query.queryESQL,
          onClick: () => setIsESQLMenuPopoverOpen(false)
        }, _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.documentation', {
          defaultMessage: 'Documentation'
        }))
      }, ...(Boolean(recommendedQueries.length) ? [{
        name: _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.exampleQueries', {
          defaultMessage: 'Recommended queries'
        }),
        icon: 'nested',
        panel: 1,
        'data-test-subj': 'esql-recommended-queries'
      }] : []), {
        name: _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.feedback', {
          defaultMessage: 'Submit feedback'
        }),
        icon: 'editorComment',
        renderItem: () => /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenuItem, {
          key: "feedback",
          icon: "editorComment",
          "data-test-subj": "esql-feedback",
          target: "_blank",
          href: _esqlUtils.FEEDBACK_LINK,
          onClick: () => setIsESQLMenuPopoverOpen(false)
        }, _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.feedback', {
          defaultMessage: 'Submit feedback'
        }))
      }]
    }, {
      id: 1,
      title: _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.exampleQueries', {
        defaultMessage: 'Recommended queries'
      }),
      items: recommendedQueries.map(query => {
        return {
          name: query.label,
          onClick: () => {
            onESQLQuerySubmit === null || onESQLQuerySubmit === void 0 ? void 0 : onESQLQuerySubmit(query.queryString);
            setIsESQLMenuPopoverOpen(false);
          }
        };
      })
    }];
    return panels;
  }, [adHocDataview, docLinks.links.query.queryESQL, onESQLQuerySubmit, toggleLanguageComponent]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiPopover, {
    button: /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      color: "text",
      onClick: () => setIsESQLMenuPopoverOpen(!isESQLMenuPopoverOpen),
      "data-test-subj": "esql-menu-button",
      size: "s"
    }, _i18n.i18n.translate('unifiedSearch.query.queryBar.esqlMenu.label', {
      defaultMessage: 'ES|QL help'
    })),
    panelProps: {
      ['data-test-subj']: 'esql-menu-popover',
      css: {
        width: 240
      }
    },
    isOpen: isESQLMenuPopoverOpen,
    closePopover: () => setIsESQLMenuPopoverOpen(false),
    panelPaddingSize: "s",
    display: "block"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiContextMenu, {
    initialPanelId: 0,
    panels: esqlContextMenuPanels
  })), /*#__PURE__*/_react.default.createElement(_languageDocumentation.LanguageDocumentationFlyout, {
    searchInDescription: true,
    linkToDocumentation: (_docLinks$links$query = docLinks === null || docLinks === void 0 ? void 0 : (_docLinks$links = docLinks.links) === null || _docLinks$links === void 0 ? void 0 : (_docLinks$links$query2 = _docLinks$links.query) === null || _docLinks$links$query2 === void 0 ? void 0 : _docLinks$links$query2.queryESQL) !== null && _docLinks$links$query !== void 0 ? _docLinks$links$query : '',
    isHelpMenuOpen: isLanguageComponentOpen,
    onHelpMenuVisibilityChange: onHelpMenuVisibilityChange
  }));
};
exports.ESQLMenuPopover = ESQLMenuPopover;