"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getESUpgradeStatus = getESUpgradeStatus;
var _migrations = require("./migrations");
var _health_indicators = require("./health_indicators");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

async function getESUpgradeStatus(dataClient, featureSet) {
  const getCombinedDeprecations = async () => {
    const healthIndicators = await (0, _health_indicators.getHealthIndicators)(dataClient);
    const enrichedDeprecations = await (0, _migrations.getEnrichedDeprecations)(dataClient);
    const toggledMigrationsDeprecations = enrichedDeprecations.filter(({
      type,
      correctiveAction
    }) => {
      /**
       * This disables showing the ML deprecations in the UA if `featureSet.mlSnapshots`
       * is set to `false`.
       *
       * This config should be set to true only on the `x.last` versions, or when
       * the constant `MachineLearningField.MIN_CHECKED_SUPPORTED_SNAPSHOT_VERSION`
       * is incremented to something higher than 7.0.0 in the Elasticsearch code.
       */
      if (type === 'ml_settings' || (correctiveAction === null || correctiveAction === void 0 ? void 0 : correctiveAction.type) === 'mlSnapshot') {
        return featureSet.mlSnapshots;
      }

      /**
       * This disables showing the Data streams deprecations in the UA if
       * `featureSet.migrateDataStreams` is set to `false`.
       */
      if (type === 'data_streams') {
        return !!featureSet.migrateDataStreams;
      }

      /**
       * This disables showing the reindexing deprecations in the UA if
       * `featureSet.reindexCorrectiveActions` is set to `false`.
       */
      if ((correctiveAction === null || correctiveAction === void 0 ? void 0 : correctiveAction.type) === 'reindex') {
        return !!featureSet.reindexCorrectiveActions;
      }
      return true;
    });
    const enrichedHealthIndicators = healthIndicators.filter(({
      status
    }) => {
      return status !== 'green';
    });
    return [...enrichedHealthIndicators, ...toggledMigrationsDeprecations];
  };
  const combinedDeprecations = await getCombinedDeprecations();
  const criticalWarnings = combinedDeprecations.filter(({
    isCritical
  }) => isCritical === true);
  return {
    totalCriticalDeprecations: criticalWarnings.length,
    deprecations: combinedDeprecations
  };
}