"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUiSettingsConfig = exports.VisTypeHeatmapServerPlugin = void 0;
var _i18n = require("@kbn/i18n");
var _configSchema = require("@kbn/config-schema");
var _common = require("../common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const getUiSettingsConfig = () => ({
  // TODO: Remove this when vislib heatmap is removed
  [_common.LEGACY_HEATMAP_CHARTS_LIBRARY]: {
    name: _i18n.i18n.translate('visTypeHeatmap.advancedSettings.visualization.legacyHeatmapChartsLibrary.name', {
      defaultMessage: 'Heatmap legacy charts library'
    }),
    requiresPageReload: true,
    value: false,
    description: _i18n.i18n.translate('visTypeHeatmap.advancedSettings.visualization.legacyHeatmapChartsLibrary.description', {
      defaultMessage: 'Enables legacy charts library for heatmap charts in visualize.'
    }),
    deprecation: {
      message: _i18n.i18n.translate('visTypeHeatmap.advancedSettings.visualization.legacyHeatmapChartsLibrary.deprecation', {
        defaultMessage: 'The legacy charts library for heatmap in visualize is deprecated and will not be supported in a future version.'
      }),
      docLinksKey: 'visualizationSettings'
    },
    category: ['visualization'],
    schema: _configSchema.schema.boolean()
  }
});
exports.getUiSettingsConfig = getUiSettingsConfig;
class VisTypeHeatmapServerPlugin {
  constructor(initializerContext) {
    this.initializerContext = initializerContext;
    this.initializerContext = initializerContext;
  }
  setup(core, plugins) {
    core.uiSettings.register(getUiSettingsConfig());
    const {
      readOnly
    } = this.initializerContext.config.get();
    if (readOnly) {
      plugins.visualizations.registerReadOnlyVisType('heatmap');
    }
    return {};
  }
  start() {
    return {};
  }
}
exports.VisTypeHeatmapServerPlugin = VisTypeHeatmapServerPlugin;