"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getVisualizeEmbeddableFactory = void 0;
var _eui = require("@elastic/eui");
var _chartExpressionsCommon = require("@kbn/chart-expressions-common");
var _public = require("@kbn/data-plugin/public");
var _public2 = require("@kbn/embeddable-plugin/public");
var _public3 = require("@kbn/expressions-plugin/public");
var _i18n = require("@kbn/i18n");
var _public4 = require("@kbn/kibana-utils-plugin/public");
var _presentationContainers = require("@kbn/presentation-containers");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _publishes_search_session = require("@kbn/presentation-publishing/interfaces/fetch/publishes_search_session");
var _lodash = require("lodash");
var _react = _interopRequireWildcard(require("react"));
var _rxjs = require("rxjs");
var _reactHooks = require("@kbn/react-hooks");
var _constants = require("../../common/constants");
var _events = require("./events");
var _services = require("../services");
var _triggers = require("../triggers");
var _create_vis_instance = require("./create_vis_instance");
var _get_expression_renderer_props = require("./get_expression_renderer_props");
var _save_to_library = require("./save_to_library");
var _state = require("./state");
var _types = require("./types");
var _initialize_edit_api = require("./initialize_edit_api");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const getVisualizeEmbeddableFactory = ({
  embeddableStart,
  embeddableEnhancedStart
}) => ({
  type: _constants.VISUALIZE_EMBEDDABLE_TYPE,
  deserializeState: _state.deserializeState,
  buildEmbeddable: async (initialState, buildApi, uuid, parentApi) => {
    var _state$savedObjectId, _dynamicActionsApi$dy, _dynamicActionsApi$dy2;
    // Handle state transfer from legacy visualize editor, which uses the legacy visualize embeddable and doesn't
    // produce a snapshot state. If buildEmbeddable is passed only a savedObjectId in the state, this means deserializeState
    // was never run, and it needs to be invoked manually
    const state = (0, _types.isVisualizeSavedObjectState)(initialState) ? await (0, _state.deserializeState)({
      rawState: initialState
    }) : initialState;

    // Initialize dynamic actions
    const dynamicActionsApi = embeddableEnhancedStart === null || embeddableEnhancedStart === void 0 ? void 0 : embeddableEnhancedStart.initializeReactEmbeddableDynamicActions(uuid, () => titlesApi.panelTitle.getValue(), state);
    // if it is provided, start the dynamic actions manager
    const maybeStopDynamicActions = dynamicActionsApi === null || dynamicActionsApi === void 0 ? void 0 : dynamicActionsApi.startDynamicActions();
    const {
      titlesApi,
      titleComparators,
      serializeTitles
    } = (0, _presentationPublishing.initializeTitles)(state);

    // Count renders; mostly used for testing.
    const renderCount$ = new _rxjs.BehaviorSubject(0);
    const hasRendered$ = new _rxjs.BehaviorSubject(false);

    // Track vis data and initialize it into a vis instance
    const serializedVis$ = new _rxjs.BehaviorSubject(state.serializedVis);
    const initialVisInstance = await (0, _create_vis_instance.createVisInstance)(state.serializedVis);
    const vis$ = new _rxjs.BehaviorSubject(initialVisInstance);

    // Track UI state
    const onUiStateChange = () => serializedVis$.next(vis$.getValue().serialize());
    initialVisInstance.uiState.on('change', onUiStateChange);
    vis$.subscribe(vis => vis.uiState.on('change', onUiStateChange));

    // When the serialized vis changes, update the vis instance
    serializedVis$.pipe((0, _rxjs.switchMap)(async serializedVis => {
      const currentVis = vis$.getValue();
      if (currentVis) currentVis.uiState.off('change', onUiStateChange);
      const vis = await (0, _create_vis_instance.createVisInstance)(serializedVis);
      const {
        params,
        abortController
      } = await getExpressionParams();
      return {
        vis,
        params,
        abortController
      };
    })).subscribe(({
      vis,
      params,
      abortController
    }) => {
      vis$.next(vis);
      if (params) expressionParams$.next(params);
      expressionAbortController$.next(abortController);
    });

    // Track visualizations linked to a saved object in the library
    const savedObjectId$ = new _rxjs.BehaviorSubject((_state$savedObjectId = state.savedObjectId) !== null && _state$savedObjectId !== void 0 ? _state$savedObjectId : state.serializedVis.id);
    const savedObjectProperties$ = new _rxjs.BehaviorSubject(undefined);
    const linkedToLibrary$ = new _rxjs.BehaviorSubject(state.linkedToLibrary);

    // Track the vis expression
    const expressionParams$ = new _rxjs.BehaviorSubject({
      expression: ''
    });
    const expressionAbortController$ = new _rxjs.BehaviorSubject(new AbortController());
    let getExpressionParams = async () => ({
      params: expressionParams$.getValue(),
      abortController: expressionAbortController$.getValue()
    });
    const {
      api: customTimeRangeApi,
      serialize: serializeCustomTimeRange,
      comparators: customTimeRangeComparators
    } = (0, _presentationPublishing.initializeTimeRange)(state);
    const searchSessionId$ = new _rxjs.BehaviorSubject('');
    const executionContext = (0, _presentationPublishing.apiHasExecutionContext)(parentApi) ? parentApi.executionContext : undefined;
    const disableTriggers = (0, _presentationPublishing.apiHasDisableTriggers)(parentApi) ? parentApi.disableTriggers : undefined;
    const inspectorAdapters$ = new _rxjs.BehaviorSubject({});

    // Track data views
    let initialDataViews = [];
    if (initialVisInstance.data.indexPattern) initialDataViews = [initialVisInstance.data.indexPattern];
    if (initialVisInstance.type.getUsedIndexPattern) {
      initialDataViews = await initialVisInstance.type.getUsedIndexPattern(initialVisInstance.params);
    }
    const dataLoading$ = new _rxjs.BehaviorSubject(true);
    const defaultPanelTitle = new _rxjs.BehaviorSubject(initialVisInstance.title);
    const api = buildApi({
      ...customTimeRangeApi,
      ...titlesApi,
      ...((_dynamicActionsApi$dy = dynamicActionsApi === null || dynamicActionsApi === void 0 ? void 0 : dynamicActionsApi.dynamicActionsApi) !== null && _dynamicActionsApi$dy !== void 0 ? _dynamicActionsApi$dy : {}),
      defaultPanelTitle,
      dataLoading: dataLoading$,
      dataViews: new _rxjs.BehaviorSubject(initialDataViews),
      supportedTriggers: () => [_triggers.ACTION_CONVERT_TO_LENS, _public.APPLY_FILTER_TRIGGER, _public2.SELECT_RANGE_TRIGGER],
      serializeState: () => {
        var _dynamicActionsApi$se, _dynamicActionsApi$se2;
        const savedObjectProperties = savedObjectProperties$.getValue();
        return (0, _state.serializeState)({
          serializedVis: vis$.getValue().serialize(),
          titles: serializeTitles(),
          id: savedObjectId$.getValue(),
          linkedToLibrary:
          // In the visualize editor, linkedToLibrary should always be false to force the full state to be serialized,
          // instead of just passing a reference to the linked saved object. Other contexts like dashboards should
          // serialize the state with just the savedObjectId so that the current revision of the vis is always used
          (0, _presentationPublishing.apiIsOfType)(parentApi, _constants.VISUALIZE_APP_NAME) ? false : linkedToLibrary$.getValue(),
          ...(savedObjectProperties ? {
            savedObjectProperties
          } : {}),
          ...((_dynamicActionsApi$se = dynamicActionsApi === null || dynamicActionsApi === void 0 ? void 0 : (_dynamicActionsApi$se2 = dynamicActionsApi.serializeDynamicActions) === null || _dynamicActionsApi$se2 === void 0 ? void 0 : _dynamicActionsApi$se2.call(dynamicActionsApi)) !== null && _dynamicActionsApi$se !== void 0 ? _dynamicActionsApi$se : {}),
          ...serializeCustomTimeRange()
        });
      },
      getVis: () => vis$.getValue(),
      getInspectorAdapters: () => inspectorAdapters$.getValue(),
      ...(0, _initialize_edit_api.initializeEditApi)({
        customTimeRange$: customTimeRangeApi.timeRange$,
        description$: titlesApi.panelDescription,
        parentApi,
        savedObjectId$,
        searchSessionId$,
        title$: titlesApi.panelTitle,
        vis$,
        uuid
      }),
      updateVis: async visUpdates => {
        const currentSerializedVis = vis$.getValue().serialize();
        serializedVis$.next({
          ...currentSerializedVis,
          ...visUpdates,
          params: {
            ...currentSerializedVis.params,
            ...visUpdates.params
          },
          data: {
            ...currentSerializedVis.data,
            ...visUpdates.data
          }
        });
        if (visUpdates.title) {
          titlesApi.setPanelTitle(visUpdates.title);
        }
      },
      openInspector: () => {
        var _titlesApi$panelTitle;
        const adapters = inspectorAdapters$.getValue();
        if (!adapters) return;
        const inspector = (0, _services.getInspector)();
        if (!inspector.isAvailable(adapters)) return;
        return (0, _services.getInspector)().open(adapters, {
          title: ((_titlesApi$panelTitle = titlesApi.panelTitle) === null || _titlesApi$panelTitle === void 0 ? void 0 : _titlesApi$panelTitle.getValue()) || _i18n.i18n.translate('visualizations.embeddable.inspectorTitle', {
            defaultMessage: 'Inspector'
          })
        });
      },
      // Library transforms
      saveToLibrary: newTitle => {
        titlesApi.setPanelTitle(newTitle);
        const {
          rawState,
          references
        } = (0, _state.serializeState)({
          serializedVis: vis$.getValue().serialize(),
          titles: {
            ...serializeTitles(),
            title: newTitle
          }
        });
        return (0, _save_to_library.saveToLibrary)({
          uiState: vis$.getValue().uiState,
          rawState: rawState,
          references
        });
      },
      canLinkToLibrary: () => !state.linkedToLibrary,
      canUnlinkFromLibrary: () => !!state.linkedToLibrary,
      checkForDuplicateTitle: () => false,
      // Handled by saveToLibrary action
      getByValueState: () => ({
        savedVis: vis$.getValue().serialize(),
        ...serializeTitles()
      }),
      getByReferenceState: libraryId => (0, _state.serializeState)({
        serializedVis: vis$.getValue().serialize(),
        titles: serializeTitles(),
        id: libraryId,
        linkedToLibrary: true
      }).rawState
    }, {
      ...titleComparators,
      ...customTimeRangeComparators,
      ...((_dynamicActionsApi$dy2 = dynamicActionsApi === null || dynamicActionsApi === void 0 ? void 0 : dynamicActionsApi.dynamicActionsComparator) !== null && _dynamicActionsApi$dy2 !== void 0 ? _dynamicActionsApi$dy2 : {
        enhancements: (0, _presentationPublishing.getUnchangingComparator)()
      }),
      serializedVis: [serializedVis$, value => {
        serializedVis$.next(value);
      }, (a, b) => {
        const visA = a ? {
          ...(0, _lodash.omitBy)(a, _lodash.isEmpty),
          data: (0, _lodash.omitBy)(a.data, _lodash.isNil),
          params: (0, _lodash.omitBy)(a.params, _lodash.isNil)
        } : {};
        const visB = b ? {
          ...(0, _lodash.omitBy)(b, _lodash.isEmpty),
          data: (0, _lodash.omitBy)(b.data, _lodash.isNil),
          params: (0, _lodash.omitBy)(b.params, _lodash.isNil)
        } : {};
        return (0, _lodash.isEqual)(visA, visB);
      }],
      savedObjectId: [savedObjectId$, value => savedObjectId$.next(value), (a, b) => {
        if (!a && !b) return true;
        return a === b;
      }],
      savedObjectProperties: (0, _presentationPublishing.getUnchangingComparator)(),
      linkedToLibrary: [linkedToLibrary$, value => linkedToLibrary$.next(value)]
    });
    const fetchSubscription = (0, _presentationPublishing.fetch$)(api).pipe((0, _rxjs.switchMap)(async data => {
      var _ref;
      const unifiedSearch = (0, _presentationPublishing.apiPublishesUnifiedSearch)(parentApi) ? {
        query: data.query,
        filters: data.filters
      } : {};
      const searchSessionId = (0, _publishes_search_session.apiPublishesSearchSession)(parentApi) ? data.searchSessionId : '';
      searchSessionId$.next(searchSessionId);
      const settings = (0, _presentationContainers.apiPublishesSettings)(parentApi) ? {
        syncColors: parentApi.settings.syncColors$.getValue(),
        syncCursor: parentApi.settings.syncCursor$.getValue(),
        syncTooltips: parentApi.settings.syncTooltips$.getValue()
      } : {};
      dataLoading$.next(true);
      const timeslice = (0, _presentationPublishing.apiPublishesTimeslice)(parentApi) ? parentApi.timeslice$.getValue() : undefined;
      const customTimeRange = customTimeRangeApi.timeRange$.getValue();
      const parentTimeRange = (0, _presentationPublishing.apiPublishesTimeRange)(parentApi) ? data.timeRange : undefined;
      const timesliceTimeRange = timeslice ? {
        from: new Date(timeslice[0]).toISOString(),
        to: new Date(timeslice[1]).toISOString(),
        mode: 'absolute'
      } : undefined;

      // Precedence should be:
      //  custom time range from state >
      //  timeslice time range >
      //  parent API time range from e.g. unified search
      const timeRangeToRender = (_ref = customTimeRange !== null && customTimeRange !== void 0 ? customTimeRange : timesliceTimeRange) !== null && _ref !== void 0 ? _ref : parentTimeRange;
      getExpressionParams = async () => {
        return await (0, _get_expression_renderer_props.getExpressionRendererProps)({
          unifiedSearch,
          vis: vis$.getValue(),
          settings,
          disableTriggers,
          searchSessionId,
          parentExecutionContext: executionContext,
          abortController: expressionAbortController$.getValue(),
          timeRange: timeRangeToRender,
          onRender: async renderCount => {
            var _executionContext$typ;
            if (renderCount === renderCount$.getValue()) return;
            renderCount$.next(renderCount);
            const visInstance = vis$.getValue();
            const visTypeName = visInstance.type.name;
            let telemetryVisTypeName = visTypeName;
            if (visTypeName === 'metrics') {
              telemetryVisTypeName = 'legacy_metric';
            }
            if (visTypeName === 'pie' && visInstance.params.isDonut) {
              telemetryVisTypeName = 'donut';
            }
            if (visTypeName === 'area' && visInstance.params.seriesParams.some(seriesParams => seriesParams.mode === 'stacked')) {
              telemetryVisTypeName = 'area_stacked';
            }
            (0, _services.getUsageCollection)().reportUiCounter((_executionContext$typ = executionContext === null || executionContext === void 0 ? void 0 : executionContext.type) !== null && _executionContext$typ !== void 0 ? _executionContext$typ : '', 'count', `render_agg_based_${telemetryVisTypeName}`);
            if (hasRendered$.getValue() === true) return;
            hasRendered$.next(true);
            hasRendered$.complete();
          },
          onEvent: async event => {
            // Visualize doesn't respond to sizing events, so ignore.
            if ((0, _chartExpressionsCommon.isChartSizeEvent)(event)) {
              return;
            }
            const currentVis = vis$.getValue();
            if (!disableTriggers) {
              const triggerId = (0, _lodash.get)(_events.VIS_EVENT_TO_TRIGGER, event.name, _events.VIS_EVENT_TO_TRIGGER.filter);
              let context;
              if (triggerId === _events.VIS_EVENT_TO_TRIGGER.applyFilter) {
                var _currentVis$data$inde;
                context = {
                  embeddable: api,
                  timeFieldName: (_currentVis$data$inde = currentVis.data.indexPattern) === null || _currentVis$data$inde === void 0 ? void 0 : _currentVis$data$inde.timeFieldName,
                  ...event.data
                };
              } else {
                var _currentVis$data$inde2;
                context = {
                  embeddable: api,
                  data: {
                    timeFieldName: (_currentVis$data$inde2 = currentVis.data.indexPattern) === null || _currentVis$data$inde2 === void 0 ? void 0 : _currentVis$data$inde2.timeFieldName,
                    ...event.data
                  }
                };
              }
              await (0, _services.getUiActions)().getTrigger(triggerId).exec(context);
            }
          },
          onData: (_, inspectorAdapters) => {
            inspectorAdapters$.next(typeof inspectorAdapters === 'function' ? inspectorAdapters() : inspectorAdapters);
            dataLoading$.next(false);
          }
        });
      };
      return await getExpressionParams();
    })).subscribe(({
      params,
      abortController
    }) => {
      if (params) expressionParams$.next(params);
      expressionAbortController$.next(abortController);
    });
    return {
      api,
      Component: () => {
        var _api$hidePanelTitle, _api$panelTitle$getVa, _api$panelTitle, _api$panelDescription, _api$panelDescription2;
        const expressionParams = (0, _presentationPublishing.useStateFromPublishingSubject)(expressionParams$);
        const renderCount = (0, _presentationPublishing.useStateFromPublishingSubject)(renderCount$);
        const hasRendered = (0, _presentationPublishing.useStateFromPublishingSubject)(hasRendered$);
        const domNode = (0, _react.useRef)(null);
        const {
          error,
          isLoading
        } = (0, _public3.useExpressionRenderer)(domNode, expressionParams);
        const errorTextStyle = (0, _reactHooks.useErrorTextStyle)();
        (0, _react.useEffect)(() => {
          return () => {
            fetchSubscription.unsubscribe();
            maybeStopDynamicActions === null || maybeStopDynamicActions === void 0 ? void 0 : maybeStopDynamicActions.stopDynamicActions();
          };
        }, []);
        (0, _react.useEffect)(() => {
          if (hasRendered && domNode.current) {
            (0, _public4.dispatchRenderComplete)(domNode.current);
          }
        }, [hasRendered]);
        return /*#__PURE__*/_react.default.createElement("div", {
          style: {
            width: '100%',
            height: '100%'
          },
          ref: domNode,
          "data-test-subj": "visualizationLoader",
          "data-rendering-count": renderCount /* Used for functional tests */,
          "data-render-complete": hasRendered,
          "data-title": !((_api$hidePanelTitle = api.hidePanelTitle) !== null && _api$hidePanelTitle !== void 0 && _api$hidePanelTitle.getValue()) ? (_api$panelTitle$getVa = (_api$panelTitle = api.panelTitle) === null || _api$panelTitle === void 0 ? void 0 : _api$panelTitle.getValue()) !== null && _api$panelTitle$getVa !== void 0 ? _api$panelTitle$getVa : '' : '',
          "data-description": (_api$panelDescription = (_api$panelDescription2 = api.panelDescription) === null || _api$panelDescription2 === void 0 ? void 0 : _api$panelDescription2.getValue()) !== null && _api$panelDescription !== void 0 ? _api$panelDescription : '',
          "data-shared-item": true
        }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
          style: {
            height: '100%'
          },
          justifyContent: "center",
          alignItems: "center"
        }, isLoading && /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingChart, {
          size: "l",
          mono: true
        }), !isLoading && error && /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
          iconType: "error",
          color: "danger",
          "data-test-subj": "embeddableError",
          title: /*#__PURE__*/_react.default.createElement("h2", null, _i18n.i18n.translate('visualizations.embeddable.errorTitle', {
            defaultMessage: 'Unable to load visualization '
          })),
          body: /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
            css: errorTextStyle
          }, error.name, ": ", error.message)
        })));
      }
    };
  }
});
exports.getVisualizeEmbeddableFactory = getVisualizeEmbeddableFactory;