"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VulnerabilitiesFindingsDetailsTable = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _cloudSecurityPostureCommon = require("@kbn/cloud-security-posture-common");
var _securitySolutionDistributionBar = require("@kbn/security-solution-distribution-bar");
var _use_vulnerabilities_findings = require("@kbn/cloud-security-posture/src/hooks/use_vulnerabilities_findings");
var _cloudSecurityPosture = require("@kbn/cloud-security-posture");
var _ui_metrics = require("@kbn/cloud-security-posture-common/utils/ui_metrics");
var _analytics = require("@kbn/analytics");
var _deeplinksSecurity = require("@kbn/deeplinks-security");
var _use_get_navigation_url_params = require("@kbn/cloud-security-posture/src/hooks/use_get_navigation_url_params");
var _links = require("../../../common/components/links");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const VulnerabilitiesFindingsDetailsTable = exports.VulnerabilitiesFindingsDetailsTable = /*#__PURE__*/(0, _react.memo)(({
  queryName
}) => {
  (0, _react.useEffect)(() => {
    _ui_metrics.uiMetricService.trackUiMetric(_analytics.METRIC_TYPE.COUNT, _ui_metrics.ENTITY_FLYOUT_EXPAND_VULNERABILITY_VIEW_VISITS);
  }, []);
  const {
    data
  } = (0, _use_vulnerabilities_findings.useVulnerabilitiesFindings)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)('host.name', queryName),
    sort: [],
    enabled: true,
    pageSize: 1
  });
  const {
    CRITICAL = 0,
    HIGH = 0,
    MEDIUM = 0,
    LOW = 0,
    NONE = 0
  } = (data === null || data === void 0 ? void 0 : data.count) || {};
  const [pageIndex, setPageIndex] = (0, _react.useState)(0);
  const [pageSize, setPageSize] = (0, _react.useState)(10);
  const findingsPagination = findings => {
    let pageOfItems;
    if (!pageIndex && !pageSize) {
      pageOfItems = findings;
    } else {
      const startIndex = pageIndex * pageSize;
      pageOfItems = findings === null || findings === void 0 ? void 0 : findings.slice(startIndex, Math.min(startIndex + pageSize, findings === null || findings === void 0 ? void 0 : findings.length));
    }
    return {
      pageOfItems,
      totalItemCount: findings === null || findings === void 0 ? void 0 : findings.length
    };
  };
  const {
    pageOfItems,
    totalItemCount
  } = findingsPagination((data === null || data === void 0 ? void 0 : data.rows) || []);
  const pagination = {
    pageIndex,
    pageSize,
    totalItemCount,
    pageSizeOptions: [10, 25, 100]
  };
  const onTableChange = ({
    page
  }) => {
    if (page) {
      const {
        index,
        size
      } = page;
      setPageIndex(index);
      setPageSize(size);
    }
  };
  const getNavUrlParams = (0, _use_get_navigation_url_params.useGetNavigationUrlParams)();
  const getVulnerabilityUrl = (name, queryField) => {
    return getNavUrlParams({
      [queryField]: name
    }, 'vulnerabilities');
  };
  const getVulnerabilityUrlFilteredByVulnerabilityAndResourceId = (vulnerabilityId, resourceId, vulnerabilityPackageName, vulnerabilityPackageVersion) => {
    return getNavUrlParams({
      'vulnerability.id': vulnerabilityId,
      'resource.id': resourceId,
      'vulnerability.package.name': vulnerabilityPackageName,
      'vulnerability.package.version': vulnerabilityPackageVersion
    }, 'vulnerabilities');
  };
  const columns = [{
    field: 'vulnerability',
    name: '',
    width: '5%',
    render: (vulnerability, finding) => {
      var _finding$resource, _vulnerability$packag, _vulnerability$packag2;
      return /*#__PURE__*/_react.default.createElement(_links.SecuritySolutionLinkAnchor, {
        deepLinkId: _deeplinksSecurity.SecurityPageName.cloudSecurityPostureFindings,
        path: `${getVulnerabilityUrlFilteredByVulnerabilityAndResourceId(vulnerability === null || vulnerability === void 0 ? void 0 : vulnerability.id, (finding === null || finding === void 0 ? void 0 : (_finding$resource = finding.resource) === null || _finding$resource === void 0 ? void 0 : _finding$resource.id) || '', vulnerability === null || vulnerability === void 0 ? void 0 : (_vulnerability$packag = vulnerability.package) === null || _vulnerability$packag === void 0 ? void 0 : _vulnerability$packag.name, vulnerability === null || vulnerability === void 0 ? void 0 : (_vulnerability$packag2 = vulnerability.package) === null || _vulnerability$packag2 === void 0 ? void 0 : _vulnerability$packag2.version)}`,
        target: '_blank',
        external: false
      }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
        type: 'popout'
      }));
    }
  }, {
    field: 'vulnerability',
    render: vulnerability => /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, vulnerability === null || vulnerability === void 0 ? void 0 : vulnerability.id),
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.vulnerability.table.resultColumnName', {
      defaultMessage: 'Vulnerability'
    }),
    width: '20%'
  }, {
    field: 'vulnerability',
    render: vulnerability => {
      var _vulnerability$score, _vulnerability$score2;
      return /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        size: "s"
      }, /*#__PURE__*/_react.default.createElement(_cloudSecurityPosture.CVSScoreBadge, {
        version: vulnerability === null || vulnerability === void 0 ? void 0 : (_vulnerability$score = vulnerability.score) === null || _vulnerability$score === void 0 ? void 0 : _vulnerability$score.version,
        score: vulnerability === null || vulnerability === void 0 ? void 0 : (_vulnerability$score2 = vulnerability.score) === null || _vulnerability$score2 === void 0 ? void 0 : _vulnerability$score2.base
      }));
    },
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.vulnerability.table.ruleColumnName', {
      defaultMessage: 'CVSS'
    }),
    width: '15%'
  }, {
    field: 'vulnerability',
    render: vulnerability => {
      var _vulnerability$severi;
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        size: "s"
      }, /*#__PURE__*/_react.default.createElement(_cloudSecurityPosture.SeverityStatusBadge, {
        severity: vulnerability === null || vulnerability === void 0 ? void 0 : (_vulnerability$severi = vulnerability.severity) === null || _vulnerability$severi === void 0 ? void 0 : _vulnerability$severi.toUpperCase()
      })));
    },
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.vulnerability.table.ruleColumnName', {
      defaultMessage: 'Severity'
    }),
    width: '20%'
  }, {
    field: 'vulnerability',
    render: vulnerability => {
      var _vulnerability$packag3;
      return /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
        size: "s"
      }, vulnerability === null || vulnerability === void 0 ? void 0 : (_vulnerability$packag3 = vulnerability.package) === null || _vulnerability$packag3 === void 0 ? void 0 : _vulnerability$packag3.name);
    },
    name: _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.vulnerability.table.ruleColumnName', {
      defaultMessage: 'Package'
    }),
    width: '40%'
  }];
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    hasShadow: false
  }, /*#__PURE__*/_react.default.createElement(_links.SecuritySolutionLinkAnchor, {
    deepLinkId: _deeplinksSecurity.SecurityPageName.cloudSecurityPostureFindings,
    path: `${getVulnerabilityUrl(queryName, 'host.name')}`,
    target: '_blank',
    external: false,
    onClick: () => {
      _ui_metrics.uiMetricService.trackUiMetric(_analytics.METRIC_TYPE.CLICK, _ui_metrics.NAV_TO_FINDINGS_BY_HOST_NAME_FRPOM_ENTITY_FLYOUT);
    }
  }, _i18n.i18n.translate('xpack.securitySolution.flyout.left.insights.vulnerability.tableTitle', {
    defaultMessage: 'Vulnerability '
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: 'popout'
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xl"
  }), /*#__PURE__*/_react.default.createElement(_securitySolutionDistributionBar.DistributionBar, {
    stats: (0, _cloudSecurityPosture.getVulnerabilityStats)({
      critical: CRITICAL,
      high: HIGH,
      medium: MEDIUM,
      low: LOW,
      none: NONE
    })
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiBasicTable, {
    items: pageOfItems || [],
    rowHeader: "result",
    columns: columns,
    pagination: pagination,
    onChange: onTableChange,
    "data-test-subj": 'securitySolutionFlyoutVulnerabilitiesFindingsTable'
  })));
});
VulnerabilitiesFindingsDetailsTable.displayName = 'VulnerabilitiesFindingsDetailsTable';