"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VulnerabilitiesInsight = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var _css = require("@emotion/css");
var _use_vulnerabilities_preview = require("@kbn/cloud-security-posture/src/hooks/use_vulnerabilities_preview");
var _cloudSecurityPostureCommon = require("@kbn/cloud-security-posture-common");
var _cloudSecurityPosture = require("@kbn/cloud-security-posture");
var _ui_metrics = require("@kbn/cloud-security-posture-common/utils/ui_metrics");
var _analytics = require("@kbn/analytics");
var _insight_distribution_bar = require("./insight_distribution_bar");
var _formatted_number = require("../../../../common/components/formatted_number");
var _preview_link = require("../../../shared/components/preview_link");
var _context = require("../context");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/*
 * Displays a distribution bar and the total vulnerabilities count for a given host
 */
const VulnerabilitiesInsight = ({
  hostName,
  direction,
  'data-test-subj': dataTestSubj,
  telemetrySuffix
}) => {
  const {
    scopeId,
    isPreview
  } = (0, _context.useDocumentDetailsContext)();
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const {
    data
  } = (0, _use_vulnerabilities_preview.useVulnerabilitiesPreview)({
    query: (0, _cloudSecurityPostureCommon.buildEntityFlyoutPreviewQuery)('host.name', hostName),
    sort: [],
    enabled: true,
    pageSize: 1
  });
  (0, _react.useEffect)(() => {
    _ui_metrics.uiMetricService.trackUiMetric(_analytics.METRIC_TYPE.COUNT, `${_ui_metrics.VULNERABILITIES_INSIGHT}-${telemetrySuffix}`);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const {
    CRITICAL = 0,
    HIGH = 0,
    MEDIUM = 0,
    LOW = 0,
    NONE = 0
  } = (data === null || data === void 0 ? void 0 : data.count) || {};
  const totalVulnerabilities = (0, _react.useMemo)(() => CRITICAL + HIGH + MEDIUM + LOW + NONE, [CRITICAL, HIGH, MEDIUM, LOW, NONE]);
  const hasVulnerabilitiesFindings = (0, _react.useMemo)(() => (0, _cloudSecurityPosture.hasVulnerabilitiesData)({
    critical: CRITICAL,
    high: HIGH,
    medium: MEDIUM,
    low: LOW,
    none: NONE
  }), [CRITICAL, HIGH, MEDIUM, LOW, NONE]);
  const vulnerabilitiesStats = (0, _react.useMemo)(() => (0, _cloudSecurityPosture.getVulnerabilityStats)({
    critical: CRITICAL,
    high: HIGH,
    medium: MEDIUM,
    low: LOW,
    none: NONE
  }), [CRITICAL, HIGH, MEDIUM, LOW, NONE]);
  const count = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement("div", {
    css: (0, _css.css)`
          margin-top: ${euiTheme.size.xs};
          margin-bottom: ${euiTheme.size.xs};
        `
  }, /*#__PURE__*/_react.default.createElement(_preview_link.PreviewLink, {
    field: 'host.name',
    value: hostName,
    scopeId: scopeId,
    isPreview: isPreview,
    "data-test-subj": `${dataTestSubj}-count`
  }, /*#__PURE__*/_react.default.createElement(_formatted_number.FormattedCount, {
    count: totalVulnerabilities
  }))), [totalVulnerabilities, hostName, scopeId, isPreview, dataTestSubj, euiTheme.size]);
  if (!hasVulnerabilitiesFindings) return null;
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    "data-test-subj": dataTestSubj
  }, /*#__PURE__*/_react.default.createElement(_insight_distribution_bar.InsightDistributionBar, {
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.securitySolution.flyout.insights.vulnerabilitiesTitle",
      defaultMessage: "Vulnerabilities:"
    }),
    stats: vulnerabilitiesStats,
    count: count,
    direction: direction,
    "data-test-subj": `${dataTestSubj}-distribution-bar`
  }));
};
exports.VulnerabilitiesInsight = VulnerabilitiesInsight;
VulnerabilitiesInsight.displayName = 'VulnerabilitiesInsight';